/* Generated by Cython 0.25.2 */

/* BEGIN: Cython Metadata
{
    "distutils": {},
    "module_name": "cPyparsing"
}
END: Cython Metadata */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03020000)
    #error Cython requires Python 2.6+ or Python 3.2+.
#else
#define CYTHON_ABI "0_25_2"
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x03030000 || (PY_MAJOR_VERSION == 2 && PY_VERSION_HEX >= 0x02070000)
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef METH_FASTCALL
  #define METH_FASTCALL 0x80
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject **args,
                                              Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : PyInstanceMethod_New(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif


#define __PYX_ERR(f_index, lineno, Ln_error) \
{ \
  __pyx_filename = __pyx_f[f_index]; __pyx_lineno = lineno; __pyx_clineno = __LINE__; goto Ln_error; \
}

#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#endif

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__cPyparsing
#define __PYX_HAVE_API__cPyparsing
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#ifdef PYREX_WITHOUT_ASSERTIONS
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER) && defined (_M_X64)
    #define __Pyx_sst_abs(value) _abs64(value)
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyObject_AsSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#if PY_MAJOR_VERSION < 3
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u)
{
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#else
#define __Pyx_Py_UNICODE_strlen Py_UNICODE_strlen
#endif
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
#define __Pyx_PyBool_FromLong(b) ((b) ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False))
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c));
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */

static PyObject *__pyx_m;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "cPyparsing.pyx",
};

/*--- Type declarations ---*/
struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_3__itervalues;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__iteritems;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_7___iadd__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_8___str__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_9_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_asDict;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_asXML;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_dump;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_16_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_17__trim_arity;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_setBreak;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_addCondition;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_23_scanString;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_24_split;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_25___mul__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_26___init__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_28_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_29___init__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_30_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_31___init__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_33_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_34___init__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_36___init__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_38___str__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_40___init__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_42___str__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_44___init__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_46___str__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_48___init__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_parseImpl;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_53___str__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_traceParseAction;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_countedArray;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_srange;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_67__expanded;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_68_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_69_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_replaceWith;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_tokenMap;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___new__;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_convertToDate;
struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_convertToDatetime;
struct __pyx_defaults;
typedef struct __pyx_defaults __pyx_defaults;
struct __pyx_defaults1;
typedef struct __pyx_defaults1 __pyx_defaults1;
struct __pyx_defaults2;
typedef struct __pyx_defaults2 __pyx_defaults2;
struct __pyx_defaults3;
typedef struct __pyx_defaults3 __pyx_defaults3;
struct __pyx_defaults4;
typedef struct __pyx_defaults4 __pyx_defaults4;
struct __pyx_defaults5;
typedef struct __pyx_defaults5 __pyx_defaults5;
struct __pyx_defaults6;
typedef struct __pyx_defaults6 __pyx_defaults6;
struct __pyx_defaults7;
typedef struct __pyx_defaults7 __pyx_defaults7;
struct __pyx_defaults8;
typedef struct __pyx_defaults8 __pyx_defaults8;
struct __pyx_defaults9;
typedef struct __pyx_defaults9 __pyx_defaults9;
struct __pyx_defaults10;
typedef struct __pyx_defaults10 __pyx_defaults10;
struct __pyx_defaults11;
typedef struct __pyx_defaults11 __pyx_defaults11;
struct __pyx_defaults {
  PyObject *__pyx_arg_isinstance;
};
struct __pyx_defaults1 {
  PyObject *__pyx_arg_isinstance;
};
struct __pyx_defaults2 {
  PyObject *__pyx_arg_maxMatches;
};
struct __pyx_defaults3 {
  PyObject *__pyx_arg_maxMatches;
};
struct __pyx_defaults4 {
  PyObject *__pyx_arg_maxsplit;
};
struct __pyx_defaults5 {
  PyObject *__pyx_arg_validateTrace;
};
struct __pyx_defaults6 {
  PyObject *__pyx_arg_wordChars;
};
struct __pyx_defaults7 {
  PyObject *__pyx_arg_wordChars;
};
struct __pyx_defaults8 {
  PyObject *__pyx_arg_validateTrace;
};
struct __pyx_defaults9 {
  PyObject *__pyx_arg_validateTrace;
};
struct __pyx_defaults10 {
  PyObject *__pyx_arg_default;
};
struct __pyx_defaults11 {
  PyObject *__pyx_arg_validateTrace;
};

/* "cPyparsing.pyx":158
 *             continue
 * 
 * _generatorType = type((y for y in range(1)))             # <<<<<<<<<<<<<<
 * 
 * 
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr {
  PyObject_HEAD
  PyObject *__pyx_v_y;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "cPyparsing.pyx":166
 *     # ampersand must be replaced first
 *     from_symbols = '&><"\''
 *     to_symbols = ('&' + s + ';' for s in "amp gt lt quot apos".split())             # <<<<<<<<<<<<<<
 *     for from_, to_ in zip(from_symbols, to_symbols):
 *         data = data.replace(from_, to_)
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr {
  PyObject_HEAD
  PyObject *__pyx_v_s;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
};


/* "cPyparsing.pyx":181
 * alphanums = alphas + nums
 * _bslash = chr(92)
 * printables = "".join(c for c in string.printable if c not in string.whitespace)             # <<<<<<<<<<<<<<
 * 
 * 
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr {
  PyObject_HEAD
  PyObject *__pyx_v_c;
};


/* "cPyparsing.pyx":465
 *             return iter(self.__tokdict)
 * 
 *     def _itervalues(self):             # <<<<<<<<<<<<<<
 *         return (self[k] for k in self._iterkeys())
 * 
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_3__itervalues {
  PyObject_HEAD
  PyObject *__pyx_v_self;
};


/* "cPyparsing.pyx":466
 * 
 *     def _itervalues(self):
 *         return (self[k] for k in self._iterkeys())             # <<<<<<<<<<<<<<
 * 
 *     def _iteritems(self):
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_3__itervalues *__pyx_outer_scope;
  PyObject *__pyx_v_k;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "cPyparsing.pyx":468
 *         return (self[k] for k in self._iterkeys())
 * 
 *     def _iteritems(self):             # <<<<<<<<<<<<<<
 *         return ((k, self[k]) for k in self._iterkeys())
 * 
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__iteritems {
  PyObject_HEAD
  PyObject *__pyx_v_self;
};


/* "cPyparsing.pyx":469
 * 
 *     def _iteritems(self):
 *         return ((k, self[k]) for k in self._iterkeys())             # <<<<<<<<<<<<<<
 * 
 *     if PY_3:
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__iteritems *__pyx_outer_scope;
  PyObject *__pyx_v_k;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "cPyparsing.pyx":660
 *         return ret
 * 
 *     def __iadd__(self, other):             # <<<<<<<<<<<<<<
 *         if other.__tokdict:
 *             offset = len(self.__toklist)
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_7___iadd__ {
  PyObject_HEAD
  Py_ssize_t __pyx_v_offset;
};


/* "cPyparsing.pyx":688
 *         return "(%s, %s)" % (repr(self.__toklist), repr(self.__tokdict))
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'
 * 
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_8___str__ {
  PyObject_HEAD
  PyObject *__pyx_v_self;
};


/* "cPyparsing.pyx":689
 * 
 *     def __str__(self):
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'             # <<<<<<<<<<<<<<
 * 
 *     def _asStringList(self, sep=''):
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_9_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_8___str__ *__pyx_outer_scope;
  PyObject *__pyx_v_i;
};


/* "cPyparsing.pyx":718
 *         return [res.asList() if isinstance(res, ParseResults) else res for res in self.__toklist]
 * 
 *     def asDict(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the named parse results as a nested dictionary.
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_asDict {
  PyObject_HEAD
  PyObject *__pyx_v_item_fn;
  PyObject *__pyx_v_toItem;
};


/* "cPyparsing.pyx":751
 *                 return obj
 * 
 *         return dict((k, toItem(v)) for k, v in item_fn())             # <<<<<<<<<<<<<<
 * 
 *     def copy(self):
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_asDict *__pyx_outer_scope;
  PyObject *__pyx_v_k;
  PyObject *__pyx_v_v;
};


/* "cPyparsing.pyx":764
 *         return ret
 * 
 *     def asXML(self, doctag=None, namedItemsOnly=False, indent="", formatted=True):             # <<<<<<<<<<<<<<
 *         """
 *         (Deprecated) Returns the parse results as XML. Tags are created for tokens and lists that have defined results names.
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_asXML {
  PyObject_HEAD
  PyObject *__pyx_v_self;
};


/* "cPyparsing.pyx":770
 *         nl = "\n"
 *         out = []
 *         namedItems = dict((v[1], k) for (k, vlist) in self.__tokdict.items()             # <<<<<<<<<<<<<<
 *                           for v in vlist)
 *         nextLevelIndent = indent + "  "
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_asXML *__pyx_outer_scope;
  PyObject *__pyx_v_k;
  PyObject *__pyx_v_v;
  PyObject *__pyx_v_vlist;
};


/* "cPyparsing.pyx":869
 *             return None
 * 
 *     def dump(self, indent='', depth=0, full=True):             # <<<<<<<<<<<<<<
 *         """
 *         Diagnostic method for listing out the contents of a C{ParseResults}.
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_dump {
  PyObject_HEAD
  PyObject *__pyx_v_self;
};


/* "cPyparsing.pyx":892
 *         if full:
 *             if self.haskeys():
 *                 items = sorted((str(k), v) for k, v in self.items())             # <<<<<<<<<<<<<<
 *                 for k, v in items:
 *                     if out:
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_dump *__pyx_outer_scope;
  PyObject *__pyx_v_k;
  PyObject *__pyx_v_v;
};


/* "cPyparsing.pyx":904
 *                     else:
 *                         out.append(repr(v))
 *             elif any(isinstance(vv, ParseResults) for vv in self):             # <<<<<<<<<<<<<<
 *                 v = self
 *                 for i, vv in enumerate(v):
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_16_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_dump *__pyx_outer_scope;
  PyObject *__pyx_v_vv;
};


/* "cPyparsing.pyx":1023
 * 
 * 
 * def _trim_arity(func, maxargs=2):             # <<<<<<<<<<<<<<
 *     """decorator to trim function calls to match the arity of the target"""
 * 
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_17__trim_arity {
  PyObject_HEAD
  PyObject *__pyx_v_extract_tb;
  int __pyx_v_foundArity;
  PyObject *__pyx_v_func;
  PyObject *__pyx_v_limit;
  PyObject *__pyx_v_maxargs;
  PyObject *__pyx_v_tb_info_synth;
};


/* "cPyparsing.pyx":1218
 *         return newself
 * 
 *     def setBreak(self, breakFlag=True):             # <<<<<<<<<<<<<<
 *         """Method to invoke the Python pdb debugger when this element is
 *            about to be parsed. Set C{breakFlag} to True to enable, False to
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_setBreak {
  PyObject_HEAD
  PyObject *__pyx_v__parseMethod;
};


/* "cPyparsing.pyx":1285
 *         return self
 * 
 *     def addCondition(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """Add a boolean predicate function to expression's list of parse actions. See
 *         L{I{setParseAction}<setParseAction>} for function call signatures. Unlike C{setParseAction},
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_addCondition {
  PyObject_HEAD
  PyObject *__pyx_v_exc_type;
  PyObject *__pyx_v_fn;
  PyObject *__pyx_v_msg;
};


/* "cPyparsing.pyx":1444
 * 
 *     class _UnboundedCache(object):
 *         def __init__(self):             # <<<<<<<<<<<<<<
 *             cache = {}
 *             self.not_in_cache = not_in_cache = object()
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__ {
  PyObject_HEAD
  PyObject *__pyx_v_cache;
  PyObject *__pyx_v_not_in_cache;
};


/* "cPyparsing.pyx":1467
 *     if _OrderedDict is not None:
 *         class _FifoCache(object):
 *             def __init__(self, size):             # <<<<<<<<<<<<<<
 *                 self.not_in_cache = not_in_cache = object()
 * 
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__ {
  PyObject_HEAD
  PyObject *__pyx_v_cache;
  PyObject *__pyx_v_not_in_cache;
  PyObject *__pyx_v_size;
};


/* "cPyparsing.pyx":1496
 *     else:
 *         class _FifoCache(object):
 *             def __init__(self, size):             # <<<<<<<<<<<<<<
 *                 self.not_in_cache = not_in_cache = object()
 * 
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__ {
  PyObject_HEAD
  PyObject *__pyx_v_cache;
  PyObject *__pyx_v_key_fifo;
  PyObject *__pyx_v_not_in_cache;
  PyObject *__pyx_v_size;
};


/* "cPyparsing.pyx":1647
 *             return tokens
 * 
 *     def scanString(self, instring, maxMatches=_MAX_INT, overlap=False):             # <<<<<<<<<<<<<<
 *         """
 *         Scan the input string for expression matches.  Each match will return the
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_23_scanString {
  PyObject_HEAD
  PyObject *__pyx_v_e;
  PyObject *__pyx_v_exc;
  PyObject *__pyx_v_instring;
  Py_ssize_t __pyx_v_instrlen;
  PyObject *__pyx_v_loc;
  long __pyx_v_matches;
  PyObject *__pyx_v_maxMatches;
  PyObject *__pyx_v_nextLoc;
  PyObject *__pyx_v_nextloc;
  PyObject *__pyx_v_overlap;
  PyObject *__pyx_v_parseFn;
  PyObject *__pyx_v_preloc;
  PyObject *__pyx_v_preparseFn;
  PyObject *__pyx_v_self;
  PyObject *__pyx_v_tokens;
  PyObject *__pyx_t_0;
  PyObject *__pyx_t_1;
  PyObject *__pyx_t_2;
  PyObject *__pyx_t_3;
  PyObject *__pyx_t_4;
  PyObject *__pyx_t_5;
};


/* "cPyparsing.pyx":1788
 *                 raise exc
 * 
 *     def split(self, instring, maxsplit=_MAX_INT, includeSeparators=False):             # <<<<<<<<<<<<<<
 *         """
 *         Generator method to split a string using the given expression as a separator.
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_24_split {
  PyObject_HEAD
  PyObject *__pyx_v_e;
  PyObject *__pyx_v_includeSeparators;
  PyObject *__pyx_v_instring;
  PyObject *__pyx_v_last;
  PyObject *__pyx_v_maxsplit;
  PyObject *__pyx_v_s;
  PyObject *__pyx_v_self;
  long __pyx_v_splits;
  PyObject *__pyx_v_t;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "cPyparsing.pyx":1866
 *         return other - self
 * 
 *     def __mul__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of * operator, allows use of C{expr * 3} in place of
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_25___mul__ {
  PyObject_HEAD
  PyObject *__pyx_v_makeOptionalList;
  PyObject *__pyx_v_self;
};


/* "cPyparsing.pyx":2656
 *     """
 * 
 *     def __init__(self, initChars, bodyChars=None, min=1, max=0, exact=0, asKeyword=False, excludeChars=None):             # <<<<<<<<<<<<<<
 *         super(Word, self).__init__()
 *         if excludeChars:
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_26___init__ {
  PyObject_HEAD
  PyObject *__pyx_v_bodyChars;
  PyObject *__pyx_v_excludeChars;
  PyObject *__pyx_v_initChars;
};


/* "cPyparsing.pyx":2659
 *         super(Word, self).__init__()
 *         if excludeChars:
 *             initChars = ''.join(c for c in initChars if c not in excludeChars)             # <<<<<<<<<<<<<<
 *             if bodyChars:
 *                 bodyChars = ''.join(c for c in bodyChars if c not in excludeChars)
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_26___init__ *__pyx_outer_scope;
  PyObject *__pyx_v_c;
};


/* "cPyparsing.pyx":2661
 *             initChars = ''.join(c for c in initChars if c not in excludeChars)
 *             if bodyChars:
 *                 bodyChars = ''.join(c for c in bodyChars if c not in excludeChars)             # <<<<<<<<<<<<<<
 *         self.initCharsOrig = initChars
 *         self.initChars = set(initChars)
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_28_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_26___init__ *__pyx_outer_scope;
  PyObject *__pyx_v_c;
};


/* "cPyparsing.pyx":2867
 *     """
 * 
 *     def __init__(self, quoteChar, escChar=None, escQuote=None, multiline=False, unquoteResults=True, endQuoteChar=None, convertWhitespaceEscapes=True):             # <<<<<<<<<<<<<<
 *         super(QuotedString, self).__init__()
 * 
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_29___init__ {
  PyObject_HEAD
  PyObject *__pyx_v_self;
};


/* "cPyparsing.pyx":2908
 *         if len(self.endQuoteChar) > 1:
 *             self.pattern += (
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),             # <<<<<<<<<<<<<<
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')'
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_30_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_29___init__ *__pyx_outer_scope;
  PyObject *__pyx_v_i;
};


/* "cPyparsing.pyx":3068
 *     }
 * 
 *     def __init__(self, ws=" \t\r\n", min=1, max=0, exact=0):             # <<<<<<<<<<<<<<
 *         super(White, self).__init__()
 *         self.matchWhite = ws
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_31___init__ {
  PyObject_HEAD
  PyObject *__pyx_v_self;
};


/* "cPyparsing.pyx":3071
 *         super(White, self).__init__()
 *         self.matchWhite = ws
 *         self.setWhitespaceChars("".join(c for c in self.whiteChars if c not in self.matchWhite))             # <<<<<<<<<<<<<<
 *         #~ self.leaveWhitespace()
 *         self.name = ("".join(White.whiteStrs[c] for c in self.matchWhite))
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_31___init__ *__pyx_outer_scope;
  PyObject *__pyx_v_c;
};


/* "cPyparsing.pyx":3073
 *         self.setWhitespaceChars("".join(c for c in self.whiteChars if c not in self.matchWhite))
 *         #~ self.leaveWhitespace()
 *         self.name = ("".join(White.whiteStrs[c] for c in self.matchWhite))             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 *         self.errmsg = "Expected " + self.name
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_33_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_31___init__ *__pyx_outer_scope;
  PyObject *__pyx_v_c;
};


/* "cPyparsing.pyx":3281
 *     """
 * 
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(ParseExpression, self).__init__(savelist)
 *         if isinstance(exprs, _generatorType):
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_34___init__ {
  PyObject_HEAD
  PyObject *__pyx_v_exprs;
};


/* "cPyparsing.pyx":3291
 *             exprs = list(exprs)
 *             # if sequence of strings provided, wrap with Literal
 *             if all(isinstance(expr, basestring) for expr in exprs):             # <<<<<<<<<<<<<<
 *                 exprs = map(ParserElement._literalStringClass, exprs)
 *             self.exprs = list(exprs)
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_34___init__ *__pyx_outer_scope;
  PyObject *__pyx_v_expr;
};


/* "cPyparsing.pyx":3412
 *             self.leaveWhitespace()
 * 
 *     def __init__(self, exprs, savelist=True):             # <<<<<<<<<<<<<<
 *         super(And, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_36___init__ {
  PyObject_HEAD
  PyObject *__pyx_v_self;
};


/* "cPyparsing.pyx":3414
 *     def __init__(self, exprs, savelist=True):
 *         super(And, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         self.setWhitespaceChars(self.exprs[0].whiteChars)
 *         self.skipWhitespace = self.exprs[0].skipWhitespace
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_36___init__ *__pyx_outer_scope;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":3456
 *                 break
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_38___str__ {
  PyObject_HEAD
  PyObject *__pyx_v_self;
};


/* "cPyparsing.pyx":3461
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + " ".join(_ustr(e) for e in self.exprs) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_38___str__ *__pyx_outer_scope;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":3481
 *     """
 * 
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(Or, self).__init__(exprs, savelist)
 *         if self.exprs:
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_40___init__ {
  PyObject_HEAD
  PyObject *__pyx_v_self;
};


/* "cPyparsing.pyx":3484
 *         super(Or, self).__init__(exprs, savelist)
 *         if self.exprs:
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         else:
 *             self.mayReturnEmpty = True
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_40___init__ *__pyx_outer_scope;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":3530
 *         return self.append(other)  # Or( [ self, other ] )
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_42___str__ {
  PyObject_HEAD
  PyObject *__pyx_v_self;
};


/* "cPyparsing.pyx":3535
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + " ^ ".join(_ustr(e) for e in self.exprs) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_42___str__ *__pyx_outer_scope;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":3563
 *     """
 * 
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(MatchFirst, self).__init__(exprs, savelist)
 *         if self.exprs:
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_44___init__ {
  PyObject_HEAD
  PyObject *__pyx_v_self;
};


/* "cPyparsing.pyx":3566
 *         super(MatchFirst, self).__init__(exprs, savelist)
 *         if self.exprs:
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         else:
 *             self.mayReturnEmpty = True
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_44___init__ *__pyx_outer_scope;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":3599
 *         return self.append(other)  # MatchFirst( [ self, other ] )
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_46___str__ {
  PyObject_HEAD
  PyObject *__pyx_v_self;
};


/* "cPyparsing.pyx":3604
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + " | ".join(_ustr(e) for e in self.exprs) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_46___str__ *__pyx_outer_scope;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":3669
 *     """
 * 
 *     def __init__(self, exprs, savelist=True):             # <<<<<<<<<<<<<<
 *         super(Each, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_48___init__ {
  PyObject_HEAD
  PyObject *__pyx_v_self;
};


/* "cPyparsing.pyx":3671
 *     def __init__(self, exprs, savelist=True):
 *         super(Each, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = True
 *         self.initExprGroups = True
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_48___init__ *__pyx_outer_scope;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":3675
 *         self.initExprGroups = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.initExprGroups:
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_parseImpl {
  PyObject_HEAD
  PyObject *__pyx_v_self;
  PyObject *__pyx_v_tmpReqd;
};


/* "cPyparsing.pyx":3677
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if self.initExprGroups:
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))             # <<<<<<<<<<<<<<
 *             opt1 = [e.expr for e in self.exprs if isinstance(e, Optional)]
 *             opt2 = [e for e in self.exprs if e.mayReturnEmpty and not isinstance(e, Optional)]
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_parseImpl *__pyx_outer_scope;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":3710
 * 
 *         if tmpReqd:
 *             missing = ", ".join(_ustr(e) for e in tmpReqd)             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, "Missing one or more required elements (%s)" % missing)
 * 
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_parseImpl *__pyx_outer_scope;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":3724
 *         return loc, finalResults
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_53___str__ {
  PyObject_HEAD
  PyObject *__pyx_v_self;
};


/* "cPyparsing.pyx":3729
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + " & ".join(_ustr(e) for e in self.exprs) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_53___str__ *__pyx_outer_scope;
  PyObject *__pyx_v_e;
};


/* "cPyparsing.pyx":4465
 * 
 * 
 * def traceParseAction(f):             # <<<<<<<<<<<<<<
 *     """
 *     Decorator for debugging parse actions.
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_traceParseAction {
  PyObject_HEAD
  PyObject *__pyx_v_f;
};


/* "cPyparsing.pyx":4532
 * 
 * 
 * def countedArray(expr, intExpr=None):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define a counted list of expressions.
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_countedArray {
  PyObject_HEAD
  PyObject *__pyx_v_arrayExpr;
  PyObject *__pyx_v_expr;
};


/* "cPyparsing.pyx":4575
 * 
 * 
 * def matchPreviousLiteral(expr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define an expression that is indirectly defined from
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral {
  PyObject_HEAD
  PyObject *__pyx_v_rep;
};


/* "cPyparsing.pyx":4590
 *     rep = Forward()
 * 
 *     def copyTokenToRepeater(s, l, t):             # <<<<<<<<<<<<<<
 *         if t:
 *             if len(t) == 1:
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral *__pyx_outer_scope;
  PyObject *__pyx_v_tflat;
};


/* "cPyparsing.pyx":4597
 *                 # flatten t tokens
 *                 tflat = _flatten(t.asList())
 *                 rep << And(Literal(tt) for tt in tflat)             # <<<<<<<<<<<<<<
 *         else:
 *             rep << Empty()
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater *__pyx_outer_scope;
  PyObject *__pyx_v_tt;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "cPyparsing.pyx":4605
 * 
 * 
 * def matchPreviousExpr(expr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define an expression that is indirectly defined from
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr {
  PyObject_HEAD
  PyObject *__pyx_v_rep;
};


/* "cPyparsing.pyx":4623
 *     rep <<= e2
 * 
 *     def copyTokenToRepeater(s, l, t):             # <<<<<<<<<<<<<<
 *         matchTokens = _flatten(t.asList())
 * 
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr *__pyx_outer_scope;
  PyObject *__pyx_v_matchTokens;
};


/* "cPyparsing.pyx":4645
 * 
 * 
 * def oneOf(strs, caseless=False, useRegex=True):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to quickly define a set of alternative Literals, and makes sure to do
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf {
  PyObject_HEAD
  PyObject *__pyx_v_parseElementClass;
  PyObject *__pyx_v_symbols;
};


/* "cPyparsing.pyx":4707
 *         try:
 *             if len(symbols) == len("".join(symbols)):
 *                 return Regex("[%s]" % "".join(_escapeRegexRangeChars(sym) for sym in symbols)).setName(' | '.join(symbols))             # <<<<<<<<<<<<<<
 *             else:
 *                 return Regex("|".join(re.escape(sym) for sym in symbols)).setName(' | '.join(symbols))
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf *__pyx_outer_scope;
  PyObject *__pyx_v_sym;
};


/* "cPyparsing.pyx":4709
 *                 return Regex("[%s]" % "".join(_escapeRegexRangeChars(sym) for sym in symbols)).setName(' | '.join(symbols))
 *             else:
 *                 return Regex("|".join(re.escape(sym) for sym in symbols)).setName(' | '.join(symbols))             # <<<<<<<<<<<<<<
 *         except Exception:
 *             warnings.warn("Exception creating Regex for oneOf, building MatchFirst",
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf *__pyx_outer_scope;
  PyObject *__pyx_v_sym;
};


/* "cPyparsing.pyx":4715
 * 
 *     # last resort, just use MatchFirst
 *     return MatchFirst(parseElementClass(sym) for sym in symbols).setName(' | '.join(symbols))             # <<<<<<<<<<<<<<
 * 
 * 
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf *__pyx_outer_scope;
  PyObject *__pyx_v_sym;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "cPyparsing.pyx":4839
 * 
 * 
 * def srange(s):             # <<<<<<<<<<<<<<
 *     r"""
 *     Helper to easily define string ranges for use in Word construction.  Borrows
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_srange {
  PyObject_HEAD
  PyObject *__pyx_v__expanded;
  PyObject *__pyx_v_s;
};


/* "cPyparsing.pyx":4857
 *      - any combination of the above (C{'aeiouy'}, C{'a-zA-Z0-9_$'}, etc.)
 *     """
 *     def _expanded(p): return p if not isinstance(p, ParseResults) else ''.join(unichr(c) for c in range(ord(p[0]), ord(p[1]) + 1))             # <<<<<<<<<<<<<<
 *     try:
 *         return "".join(_expanded(part) for part in _reBracketExpr.parseString(s).body)
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_67__expanded {
  PyObject_HEAD
  PyObject *__pyx_v_p;
};

struct __pyx_obj_10cPyparsing___pyx_scope_struct_68_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_67__expanded *__pyx_outer_scope;
  PyObject *__pyx_v_c;
};


/* "cPyparsing.pyx":4859
 *     def _expanded(p): return p if not isinstance(p, ParseResults) else ''.join(unichr(c) for c in range(ord(p[0]), ord(p[1]) + 1))
 *     try:
 *         return "".join(_expanded(part) for part in _reBracketExpr.parseString(s).body)             # <<<<<<<<<<<<<<
 *     except Exception:
 *         return ""
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_69_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_srange *__pyx_outer_scope;
  PyObject *__pyx_v_part;
};


/* "cPyparsing.pyx":4864
 * 
 * 
 * def matchOnlyAtCol(n):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for defining parse actions that require matching at a specific
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol {
  PyObject_HEAD
  PyObject *__pyx_v_n;
};


/* "cPyparsing.pyx":4875
 * 
 * 
 * def replaceWith(replStr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for common parse actions that simply return a literal value.  Especially
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_replaceWith {
  PyObject_HEAD
  PyObject *__pyx_v_replStr;
};


/* "cPyparsing.pyx":4905
 * 
 * 
 * def tokenMap(func, *args):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define a parse action by mapping a function to all elements of a ParseResults list.If any additional
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_tokenMap {
  PyObject_HEAD
  PyObject *__pyx_v_args;
  PyObject *__pyx_v_func;
};


/* "cPyparsing.pyx":4972
 *             Optional("/", default=[False]).setResultsName("empty").setParseAction(lambda s, l, t: t[0] == '/') + Suppress(">")
 *     else:
 *         printablesLessRAbrack = "".join(c for c in printables if c not in ">")             # <<<<<<<<<<<<<<
 *         tagAttrValue = quotedString.copy().setParseAction(removeQuotes) | Word(printablesLessRAbrack)
 *         openTag = Suppress("<") + tagStr("tag") + \
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_genexpr {
  PyObject_HEAD
  PyObject *__pyx_v_c;
};


/* "cPyparsing.pyx":5069
 *     ANY_VALUE = object()
 * 
 *     def __new__(cls, *args, **attrDict):             # <<<<<<<<<<<<<<
 *         if args:
 *             attrs = args[:]
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___new__ {
  PyObject_HEAD
  PyObject *__pyx_v_attrs;
  PyObject *__pyx_v_cls;
};


/* "cPyparsing.pyx":5341
 * 
 * 
 * def indentedBlock(blockStatementExpr, indentStack, indent=True):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for defining space-delimited indentation blocks, such as
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock {
  PyObject_HEAD
  PyObject *__pyx_v_indentStack;
};


/* "cPyparsing.pyx":5686
 *     _full_ipv6_address = (_ipv6_part + (':' + _ipv6_part) * 7).setName("full IPv6 address")
 *     _short_ipv6_address = (Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6)) + "::" + Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))).setName("short IPv6 address")
 *     _short_ipv6_address.addCondition(lambda t: sum(1 for tt in t if pyparsing_common._ipv6_part.matches(tt)) < 8)             # <<<<<<<<<<<<<<
 *     _mixed_ipv6_address = ("::ffff:" + ipv4_address).setName("mixed IPv6 address")
 *     ipv6_address = Combine((_full_ipv6_address | _mixed_ipv6_address | _short_ipv6_address).setName("IPv6 address")).setName("IPv6 address")
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56 {
  PyObject_HEAD
  PyObject *__pyx_v_t;
};

struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr {
  PyObject_HEAD
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56 *__pyx_outer_scope;
  PyObject *__pyx_v_tt;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "cPyparsing.pyx":5695
 * 
 *     @staticmethod
 *     def convertToDate(fmt="%Y-%m-%d"):             # <<<<<<<<<<<<<<
 *         """
 *         Helper to create a parse action for converting parsed date string to Python datetime.date
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_convertToDate {
  PyObject_HEAD
  PyObject *__pyx_v_fmt;
};


/* "cPyparsing.pyx":5717
 * 
 *     @staticmethod
 *     def convertToDatetime(fmt="%Y-%m-%dT%H:%M:%S.%f"):             # <<<<<<<<<<<<<<
 *         """
 *         Helper to create a parse action for converting parsed datetime string to Python datetime.datetime
 */
struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_convertToDatetime {
  PyObject_HEAD
  PyObject *__pyx_v_fmt;
};


/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* GetModuleGlobalName.proto */
static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name);

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, int nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* PyObjectCallNoArg.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o,n,NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = PyThreadState_GET();
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace);
#else
#define __Pyx_PyInt_SubtractObjC(op1, op2, intval, inplace)\
    (inplace ? PyNumber_InPlaceSubtract(op1, op2) : PyNumber_Subtract(op1, op2))
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* PyObjectCallMethod0.proto */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* RaiseNoneIterError.proto */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* UnpackTupleError.proto */
static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index);

/* UnpackTuple2.proto */
static CYTHON_INLINE int __Pyx_unpack_tuple2(PyObject* tuple, PyObject** value1, PyObject** value2,
                                             int is_tuple, int has_known_size, int decref_tuple);

/* dict_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

/* None.proto */
static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname);

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* PyObjectCallMethod1.proto */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* append.proto */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x);

/* SliceObject.proto */
#define __Pyx_PyObject_DelSlice(obj, cstart, cstop, py_start, py_stop, py_slice, has_cstart, has_cstop, wraparound)\
    __Pyx_PyObject_SetSlice(obj, (PyObject*)NULL, cstart, cstop, py_start, py_stop, py_slice, has_cstart, has_cstop, wraparound)
static CYTHON_INLINE int __Pyx_PyObject_SetSlice(
        PyObject* obj, PyObject* value, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* FetchCommonType.proto */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);

/* CythonFunction.proto */
#define __Pyx_CyFunction_USED 1
#include <structmember.h>
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#define __Pyx_CyFunction_GetClassObj(f)\
    (((__pyx_CyFunctionObject *) (f))->func_classobj)
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
    PyCFunctionObject func;
#if PY_VERSION_HEX < 0x030500A0
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
    PyObject *func_classobj;
    void *defaults;
    int defaults_pyobjects;
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
} __pyx_CyFunctionObject;
static PyTypeObject *__pyx_CyFunctionType = 0;
#define __Pyx_CyFunction_NewEx(ml, flags, qualname, self, module, globals, code)\
    __Pyx_CyFunction_New(__pyx_CyFunctionType, ml, flags, qualname, self, module, globals, code)
static PyObject *__Pyx_CyFunction_New(PyTypeObject *, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *self,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(void);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, long intval, int inplace);
#else
#define __Pyx_PyInt_EqObjC(op1, op2, intval, inplace)\
    PyObject_RichCompare(op1, op2, Py_EQ)
    #endif

/* PyDictContains.proto */
static CYTHON_INLINE int __Pyx_PyDict_ContainsTF(PyObject* item, PyObject* dict, int eq) {
    int result = PyDict_Contains(dict, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            PyObject* args = PyTuple_Pack(1, key);
            if (likely(args))
                PyErr_SetObject(PyExc_KeyError, args);
            Py_XDECREF(args);
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#else
    #define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#endif

/* IterNext.proto */
#define __Pyx_PyIter_Next(obj) __Pyx_PyIter_Next2(obj, NULL)
static CYTHON_INLINE PyObject *__Pyx_PyIter_Next2(PyObject *, PyObject *);

/* KeywordStringCheck.proto */
static CYTHON_INLINE int __Pyx_CheckKeywordStrings(PyObject *kwdict, const char* function_name, int kw_allowed);

/* SliceTupleAndList.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice(PyObject* src, Py_ssize_t start, Py_ssize_t stop);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_GetSlice(PyObject* src, Py_ssize_t start, Py_ssize_t stop);
#else
#define __Pyx_PyList_GetSlice(seq, start, stop)   PySequence_GetSlice(seq, start, stop)
#define __Pyx_PyTuple_GetSlice(seq, start, stop)  PySequence_GetSlice(seq, start, stop)
#endif

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* None.proto */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname);

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* dict_getitem_default.proto */
static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value);

/* py_dict_clear.proto */
#define __Pyx_PyDict_Clear(d) (PyDict_Clear(d), 0)

/* PyObjectLookupSpecial.proto */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x02070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name) {
    PyObject *res;
    PyTypeObject *tp = Py_TYPE(obj);
#if PY_MAJOR_VERSION < 3
    if (unlikely(PyInstance_Check(obj)))
        return __Pyx_PyObject_GetAttrStr(obj, attr_name);
#endif
    res = _PyType_Lookup(tp, attr_name);
    if (likely(res)) {
        descrgetfunc f = Py_TYPE(res)->tp_descr_get;
        if (!f) {
            Py_INCREF(res);
        } else {
            res = f(res, obj, (PyObject *)tp);
        }
    } else {
        PyErr_SetObject(PyExc_AttributeError, attr_name);
    }
    return res;
}
#else
#define __Pyx_PyObject_LookupSpecial(o,n) __Pyx_PyObject_GetAttrStr(o,n)
#endif

/* SetItemInt.proto */
#define __Pyx_SetItemInt(o, i, v, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_SetItemInt_Fast(o, (Py_ssize_t)i, v, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list assignment index out of range"), -1) :\
               __Pyx_SetItemInt_Generic(o, to_py_func(i), v)))
static CYTHON_INLINE int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v);
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v,
                                               int is_list, int wraparound, int boundscheck);

/* DelItemInt.proto */
#define __Pyx_DelItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_DelItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list assignment index out of range"), -1) :\
               __Pyx_DelItem_Generic(o, to_py_func(i))))
static CYTHON_INLINE int __Pyx_DelItem_Generic(PyObject *o, PyObject *j);
static CYTHON_INLINE int __Pyx_DelItemInt_Fast(PyObject *o, Py_ssize_t i,
                                               int is_list, int wraparound);

/* ListExtend.proto */
static CYTHON_INLINE int __Pyx_PyList_Extend(PyObject* L, PyObject* v) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject* none = _PyList_Extend((PyListObject*)L, v);
    if (unlikely(!none))
        return -1;
    Py_DECREF(none);
    return 0;
#else
    return PyList_SetSlice(L, PY_SSIZE_T_MAX, PY_SSIZE_T_MAX, v);
#endif
}

/* UnicodeAsUCS4.proto */
static CYTHON_INLINE Py_UCS4 __Pyx_PyUnicode_AsPy_UCS4(PyObject*);

/* object_ord.proto */
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyObject_Ord(c)\
    (likely(PyUnicode_Check(c)) ? (long)__Pyx_PyUnicode_AsPy_UCS4(c) : __Pyx__PyObject_Ord(c))
#else
#define __Pyx_PyObject_Ord(c) __Pyx__PyObject_Ord(c)
#endif
static long __Pyx__PyObject_Ord(PyObject* c);

/* PyUnicodeContains.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_ContainsTF(PyObject* substring, PyObject* text, int eq) {
    int result = PyUnicode_Contains(text, substring);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* py_dict_items.proto */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d);

/* UnpackUnboundCMethod.proto */
typedef struct {
    PyObject *type;
    PyObject **method_name;
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;

/* CallUnboundCMethod0.proto */
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CallUnboundCMethod0(cfunc, self)\
    ((likely((cfunc)->func)) ?\
        (likely((cfunc)->flag == METH_NOARGS) ?  (*((cfunc)->func))(self, NULL) :\
         (likely((cfunc)->flag == (METH_VARARGS | METH_KEYWORDS)) ?  ((*(PyCFunctionWithKeywords)(cfunc)->func)(self, __pyx_empty_tuple, NULL)) :\
             ((cfunc)->flag == METH_VARARGS ?  (*((cfunc)->func))(self, __pyx_empty_tuple) :\
              (PY_VERSION_HEX >= 0x030600B1 && (cfunc)->flag == METH_FASTCALL ?  (*(__Pyx_PyCFunctionFast)(cfunc)->func)(self, &PyTuple_GET_ITEM(__pyx_empty_tuple, 0), 0, NULL) :\
                __Pyx__CallUnboundCMethod0(cfunc, self))))) :\
        __Pyx__CallUnboundCMethod0(cfunc, self))
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* pop.proto */
static CYTHON_INLINE PyObject* __Pyx__PyObject_Pop(PyObject* L);
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE PyObject* __Pyx_PyList_Pop(PyObject* L);
#define __Pyx_PyObject_Pop(L) (likely(PyList_CheckExact(L)) ?\
    __Pyx_PyList_Pop(L) : __Pyx__PyObject_Pop(L))
#else
#define __Pyx_PyList_Pop(L)  __Pyx__PyObject_Pop(L)
#define __Pyx_PyObject_Pop(L)  __Pyx__PyObject_Pop(L)
#endif

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* CalculateMetaclass.proto */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* ClassMethod.proto */
#include "descrobject.h"
static PyObject* __Pyx_Method_ClassMethod(PyObject *method);

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* Common.proto */
static int __Pyx_check_twos_complement(void) {
    if (-1 != ~0) {
        PyErr_SetString(PyExc_RuntimeError, "Two's complement required for overflow checks.");
        return 1;
    } else if (sizeof(short) == sizeof(int)) {
        PyErr_SetString(PyExc_RuntimeError, "sizeof(short) < sizeof(int) required for overflow checks.");
        return 1;
    } else {
        return 0;
    }
}
#define __PYX_IS_UNSIGNED(type) (((type) -1) > 0)
#define __PYX_SIGN_BIT(type)    (((unsigned type) 1) << (sizeof(type) * 8 - 1))
#define __PYX_HALF_MAX(type)    (((type) 1) << (sizeof(type) * 8 - 2))
#define __PYX_MIN(type)         (__PYX_IS_UNSIGNED(type) ? (type) 0 : 0 - __PYX_HALF_MAX(type) - __PYX_HALF_MAX(type))
#define __PYX_MAX(type)         (~__PYX_MIN(type))
#define __Pyx_add_no_overflow(a, b, overflow) ((a) + (b))
#define __Pyx_add_const_no_overflow(a, b, overflow) ((a) + (b))
#define __Pyx_sub_no_overflow(a, b, overflow) ((a) - (b))
#define __Pyx_sub_const_no_overflow(a, b, overflow) ((a) - (b))
#define __Pyx_mul_no_overflow(a, b, overflow) ((a) * (b))
#define __Pyx_mul_const_no_overflow(a, b, overflow) ((a) * (b))
#define __Pyx_div_no_overflow(a, b, overflow) ((a) / (b))
#define __Pyx_div_const_no_overflow(a, b, overflow) ((a) / (b))

/* BaseCaseSigned.proto */
static CYTHON_INLINE long __Pyx_add_long_checking_overflow(long a, long b, int *overflow);
static CYTHON_INLINE long __Pyx_sub_long_checking_overflow(long a, long b, int *overflow);
static CYTHON_INLINE long __Pyx_mul_long_checking_overflow(long a, long b, int *overflow);
static CYTHON_INLINE long __Pyx_div_long_checking_overflow(long a, long b, int *overflow);
static CYTHON_INLINE long __Pyx_add_const_long_checking_overflow(long a, long b, int *overflow);
static CYTHON_INLINE long __Pyx_sub_const_long_checking_overflow(long a, long b, int *overflow);
static CYTHON_INLINE long __Pyx_mul_const_long_checking_overflow(long a, long constant, int *overflow);
#define __Pyx_div_const_long_checking_overflow __Pyx_div_long_checking_overflow

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* BaseCaseSigned.proto */
static CYTHON_INLINE int __Pyx_add_int_checking_overflow(int a, int b, int *overflow);
static CYTHON_INLINE int __Pyx_sub_int_checking_overflow(int a, int b, int *overflow);
static CYTHON_INLINE int __Pyx_mul_int_checking_overflow(int a, int b, int *overflow);
static CYTHON_INLINE int __Pyx_div_int_checking_overflow(int a, int b, int *overflow);
static CYTHON_INLINE int __Pyx_add_const_int_checking_overflow(int a, int b, int *overflow);
static CYTHON_INLINE int __Pyx_sub_const_int_checking_overflow(int a, int b, int *overflow);
static CYTHON_INLINE int __Pyx_mul_const_int_checking_overflow(int a, int constant, int *overflow);
#define __Pyx_div_const_int_checking_overflow __Pyx_div_int_checking_overflow

/* BaseCaseSigned.proto */
static CYTHON_INLINE long long __Pyx_add_long_long_checking_overflow(long long a, long long b, int *overflow);
static CYTHON_INLINE long long __Pyx_sub_long_long_checking_overflow(long long a, long long b, int *overflow);
static CYTHON_INLINE long long __Pyx_mul_long_long_checking_overflow(long long a, long long b, int *overflow);
static CYTHON_INLINE long long __Pyx_div_long_long_checking_overflow(long long a, long long b, int *overflow);
static CYTHON_INLINE long long __Pyx_add_const_long_long_checking_overflow(long long a, long long b, int *overflow);
static CYTHON_INLINE long long __Pyx_sub_const_long_long_checking_overflow(long long a, long long b, int *overflow);
static CYTHON_INLINE long long __Pyx_mul_const_long_long_checking_overflow(long long a, long long constant, int *overflow);
#define __Pyx_div_const_long_long_checking_overflow __Pyx_div_long_long_checking_overflow

/* BaseCaseUnsigned.proto */
static CYTHON_INLINE unsigned int __Pyx_add_unsigned_int_checking_overflow(unsigned int a, unsigned int b, int *overflow);
static CYTHON_INLINE unsigned int __Pyx_sub_unsigned_int_checking_overflow(unsigned int a, unsigned int b, int *overflow);
static CYTHON_INLINE unsigned int __Pyx_mul_unsigned_int_checking_overflow(unsigned int a, unsigned int b, int *overflow);
static CYTHON_INLINE unsigned int __Pyx_div_unsigned_int_checking_overflow(unsigned int a, unsigned int b, int *overflow);
#define __Pyx_add_const_unsigned_int_checking_overflow __Pyx_add_unsigned_int_checking_overflow
#define __Pyx_sub_const_unsigned_int_checking_overflow __Pyx_sub_unsigned_int_checking_overflow
static CYTHON_INLINE unsigned int __Pyx_mul_const_unsigned_int_checking_overflow(unsigned int a, unsigned int constant, int *overflow);
#define __Pyx_div_const_unsigned_int_checking_overflow __Pyx_div_unsigned_int_checking_overflow

/* BaseCaseUnsigned.proto */
static CYTHON_INLINE unsigned long __Pyx_add_unsigned_long_checking_overflow(unsigned long a, unsigned long b, int *overflow);
static CYTHON_INLINE unsigned long __Pyx_sub_unsigned_long_checking_overflow(unsigned long a, unsigned long b, int *overflow);
static CYTHON_INLINE unsigned long __Pyx_mul_unsigned_long_checking_overflow(unsigned long a, unsigned long b, int *overflow);
static CYTHON_INLINE unsigned long __Pyx_div_unsigned_long_checking_overflow(unsigned long a, unsigned long b, int *overflow);
#define __Pyx_add_const_unsigned_long_checking_overflow __Pyx_add_unsigned_long_checking_overflow
#define __Pyx_sub_const_unsigned_long_checking_overflow __Pyx_sub_unsigned_long_checking_overflow
static CYTHON_INLINE unsigned long __Pyx_mul_const_unsigned_long_checking_overflow(unsigned long a, unsigned long constant, int *overflow);
#define __Pyx_div_const_unsigned_long_checking_overflow __Pyx_div_unsigned_long_checking_overflow

/* BaseCaseUnsigned.proto */
static CYTHON_INLINE unsigned long long __Pyx_add_unsigned_long_long_checking_overflow(unsigned long long a, unsigned long long b, int *overflow);
static CYTHON_INLINE unsigned long long __Pyx_sub_unsigned_long_long_checking_overflow(unsigned long long a, unsigned long long b, int *overflow);
static CYTHON_INLINE unsigned long long __Pyx_mul_unsigned_long_long_checking_overflow(unsigned long long a, unsigned long long b, int *overflow);
static CYTHON_INLINE unsigned long long __Pyx_div_unsigned_long_long_checking_overflow(unsigned long long a, unsigned long long b, int *overflow);
#define __Pyx_add_const_unsigned_long_long_checking_overflow __Pyx_add_unsigned_long_long_checking_overflow
#define __Pyx_sub_const_unsigned_long_long_checking_overflow __Pyx_sub_unsigned_long_long_checking_overflow
static CYTHON_INLINE unsigned long long __Pyx_mul_const_unsigned_long_long_checking_overflow(unsigned long long a, unsigned long long constant, int *overflow);
#define __Pyx_div_const_unsigned_long_long_checking_overflow __Pyx_div_unsigned_long_long_checking_overflow

/* SizeCheck.proto */
static int __Pyx_check_sane_Py_ssize_t(void) {
    if (sizeof(Py_ssize_t) <= sizeof(int) ||
#ifdef HAVE_LONG_LONG
            sizeof(Py_ssize_t) == sizeof(PY_LONG_LONG) ||
#endif
            sizeof(Py_ssize_t) == sizeof(long)) {
        return 0;
    } else {
        PyErr_Format(PyExc_RuntimeError,\
            "Bad size for int type %.60s: %d", "Py_ssize_t", (int) sizeof(Py_ssize_t));
        return 1;
    }
}

/* Binop.proto */
static CYTHON_INLINE Py_ssize_t __Pyx_add_Py_ssize_t_checking_overflow(Py_ssize_t a, Py_ssize_t b, int *overflow);

/* Binop.proto */
static CYTHON_INLINE Py_ssize_t __Pyx_sub_const_Py_ssize_t_checking_overflow(Py_ssize_t a, Py_ssize_t b, int *overflow);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CoroutineBase.proto */
typedef PyObject *(*__pyx_coroutine_body_t)(PyObject *, PyObject *);
typedef struct {
    PyObject_HEAD
    __pyx_coroutine_body_t body;
    PyObject *closure;
    PyObject *exc_type;
    PyObject *exc_value;
    PyObject *exc_traceback;
    PyObject *gi_weakreflist;
    PyObject *classobj;
    PyObject *yieldfrom;
    PyObject *gi_name;
    PyObject *gi_qualname;
    PyObject *gi_modulename;
    int resume_label;
    char is_running;
} __pyx_CoroutineObject;
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
    PyTypeObject *type, __pyx_coroutine_body_t body, PyObject *closure,
    PyObject *name, PyObject *qualname, PyObject *module_name);
static int __Pyx_Coroutine_clear(PyObject *self);
#if 1 || PY_VERSION_HEX < 0x030300B0
static int __Pyx_PyGen_FetchStopIterationValue(PyObject **pvalue);
#else
#define __Pyx_PyGen_FetchStopIterationValue(pvalue) PyGen_FetchStopIterationValue(pvalue)
#endif

/* PatchModuleWithCoroutine.proto */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code);

/* PatchGeneratorABC.proto */
static int __Pyx_patch_abc(void);

/* Generator.proto */
#define __Pyx_Generator_USED
static PyTypeObject *__pyx_GeneratorType = 0;
#define __Pyx_Generator_CheckExact(obj) (Py_TYPE(obj) == __pyx_GeneratorType)
#define __Pyx_Generator_New(body, closure, name, qualname, module_name)\
    __Pyx__Coroutine_New(__pyx_GeneratorType, body, closure, name, qualname, module_name)
static PyObject *__Pyx_Generator_Next(PyObject *self);
static int __pyx_Generator_init(void);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);


/* Module declarations from 'cPyparsing' */
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct__genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_1_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_2_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_3__itervalues = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_4_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_5__iteritems = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_6_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_7___iadd__ = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_8___str__ = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_9_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_10_asDict = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_11_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_12_asXML = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_13_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_14_dump = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_15_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_16_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_17__trim_arity = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_18_setBreak = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_19_addCondition = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_20___init__ = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_21___init__ = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_22___init__ = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_23_scanString = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_24_split = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_25___mul__ = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_26___init__ = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_27_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_28_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_29___init__ = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_30_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_31___init__ = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_32_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_33_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_34___init__ = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_35_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_36___init__ = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_37_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_38___str__ = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_39_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_40___init__ = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_41_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_42___str__ = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_43_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_44___init__ = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_45_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_46___str__ = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_47_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_48___init__ = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_49_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_50_parseImpl = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_51_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_52_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_53___str__ = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_54_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_55_traceParseAction = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_56_countedArray = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_59_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_62_oneOf = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_63_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_64_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_65_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_66_srange = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_67__expanded = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_68_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_69_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_71_replaceWith = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_72_tokenMap = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_73_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_74___new__ = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_75_indentedBlock = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56 = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_77_genexpr = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_78_convertToDate = 0;
static PyTypeObject *__pyx_ptype_10cPyparsing___pyx_scope_struct_79_convertToDatetime = 0;
#define __Pyx_MODULE_NAME "cPyparsing"
int __pyx_module_is_main_cPyparsing = 0;

/* Implementation of 'cPyparsing' */
static PyObject *__pyx_builtin_ImportError;
static PyObject *__pyx_builtin_chr;
static PyObject *__pyx_builtin_sum;
static PyObject *__pyx_builtin_sorted;
static PyObject *__pyx_builtin_reversed;
static PyObject *__pyx_builtin_any;
static PyObject *__pyx_builtin_all;
static PyObject *__pyx_builtin_min;
static PyObject *__pyx_builtin_max;
static PyObject *__pyx_builtin_xrange;
static PyObject *__pyx_builtin_AttributeError;
static PyObject *__pyx_builtin_object;
static PyObject *__pyx_builtin_staticmethod;
static PyObject *__pyx_builtin_zip;
static PyObject *__pyx_builtin_KeyError;
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_builtin_IndexError;
static PyObject *__pyx_builtin_enumerate;
static PyObject *__pyx_builtin_print;
static PyObject *__pyx_builtin_map;
static PyObject *__pyx_builtin_SyntaxWarning;
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_open;
static PyObject *__pyx_builtin_vars;
static PyObject *__pyx_builtin_super;
static PyObject *__pyx_builtin_id;
static PyObject *__pyx_builtin_SyntaxError;
static const char __pyx_k_L[] = "_L";
static const char __pyx_k_a[] = "a";
static const char __pyx_k_b[] = "\\b";
static const char __pyx_k_c[] = "c";
static const char __pyx_k_d[] = "d";
static const char __pyx_k_e[] = "e";
static const char __pyx_k_f[] = "\\f";
static const char __pyx_k_i[] = "i";
static const char __pyx_k_j[] = "j";
static const char __pyx_k_k[] = "k";
static const char __pyx_k_l[] = "l";
static const char __pyx_k_n[] = "n";
static const char __pyx_k_p[] = "p";
static const char __pyx_k_r[] = "r";
static const char __pyx_k_s[] = "s";
static const char __pyx_k_t[] = "t";
static const char __pyx_k_u[] = "u";
static const char __pyx_k_v[] = "v";
static const char __pyx_k_w[] = "\\w";
static const char __pyx_k_z[] = "z";
static const char __pyx_k_0x[] = "\\0x";
static const char __pyx_k_CR[] = "<CR>";
static const char __pyx_k_FF[] = "<FF>";
static const char __pyx_k_LF[] = "<LF>";
static const char __pyx_k_NL[] = "NL";
static const char __pyx_k_Or[] = "Or";
static const char __pyx_k__6[] = "&";
static const char __pyx_k__7[] = ";";
static const char __pyx_k__8[] = "&><\"'";
static const char __pyx_k__9[] = "";
static const char __pyx_k_e2[] = "e2";
static const char __pyx_k_eq[] = "__eq__";
static const char __pyx_k_fn[] = "fn";
static const char __pyx_k_id[] = "id";
static const char __pyx_k_ne[] = "__ne__";
static const char __pyx_k_nl[] = "nl";
static const char __pyx_k_or[] = "__or__";
static const char __pyx_k_os[] = "os";
static const char __pyx_k_p1[] = "p1";
static const char __pyx_k_p2[] = "p2";
static const char __pyx_k_pa[] = "pa";
static const char __pyx_k_pe[] = "pe";
static const char __pyx_k_re[] = "re";
static const char __pyx_k_se[] = "se";
static const char __pyx_k_tb[] = "tb";
static const char __pyx_k_to[] = "to_";
static const char __pyx_k_ve[] = "ve";
static const char __pyx_k_vv[] = "vv";
static const char __pyx_k_ws[] = "ws";
static const char __pyx_k_wt[] = "wt";
static const char __pyx_k_A_Z[] = "[A-Z]";
static const char __pyx_k_And[] = "And";
static const char __pyx_k_HIT[] = "HIT";
static const char __pyx_k_L_2[] = "L";
static const char __pyx_k_SPC[] = "<SPC>";
static const char __pyx_k_TAB[] = "<TAB>";
static const char __pyx_k_W_s[] = "W:(%s)";
static const char __pyx_k__10[] = ">!<";
static const char __pyx_k__16[] = "[";
static const char __pyx_k__17[] = ", ";
static const char __pyx_k__18[] = "]";
static const char __pyx_k__21[] = "\n";
static const char __pyx_k__22[] = "  ";
static const char __pyx_k__23[] = "<";
static const char __pyx_k__24[] = ">";
static const char __pyx_k__25[] = "</";
static const char __pyx_k__26[] = " -> ";
static const char __pyx_k__38[] = "*";
static const char __pyx_k__82[] = "#";
static const char __pyx_k__84[] = " ";
static const char __pyx_k__85[] = "^";
static const char __pyx_k__88[] = "...";
static const char __pyx_k__92[] = "|(?:";
static const char __pyx_k__93[] = ")|(?:";
static const char __pyx_k__94[] = ")";
static const char __pyx_k__95[] = "(.)";
static const char __pyx_k__96[] = "\\";
static const char __pyx_k__97[] = "\t";
static const char __pyx_k__98[] = "\014";
static const char __pyx_k__99[] = "\r";
static const char __pyx_k_add[] = "__add__";
static const char __pyx_k_all[] = "all";
static const char __pyx_k_and[] = "__and__";
static const char __pyx_k_any[] = "any";
static const char __pyx_k_b_2[] = "b";
static const char __pyx_k_chr[] = "chr";
static const char __pyx_k_cls[] = "cls";
static const char __pyx_k_col[] = "col";
static const char __pyx_k_cpy[] = "cpy";
static const char __pyx_k_cur[] = "cur";
static const char __pyx_k_d_2[] = "[+-]?\\d+";
static const char __pyx_k_d_d[] = "(%d,%d)";
static const char __pyx_k_dir[] = "__dir__";
static const char __pyx_k_doc[] = "__doc__";
static const char __pyx_k_end[] = "end";
static const char __pyx_k_err[] = "err";
static const char __pyx_k_exc[] = "exc";
static const char __pyx_k_f_2[] = "f";
static const char __pyx_k_fmt[] = "fmt";
static const char __pyx_k_fns[] = "fns";
static const char __pyx_k_g_1[] = "\\g<1>";
static const char __pyx_k_get[] = "get";
static const char __pyx_k_ior[] = "__ior__";
static const char __pyx_k_key[] = "key";
static const char __pyx_k_len[] = "__len__";
static const char __pyx_k_loc[] = "loc";
static const char __pyx_k_map[] = "map";
static const char __pyx_k_mat[] = "mat";
static const char __pyx_k_max[] = "max";
static const char __pyx_k_min[] = "min";
static const char __pyx_k_msg[] = "msg";
static const char __pyx_k_mul[] = "__mul__";
static const char __pyx_k_n_2[] = "\\n";
static const char __pyx_k_n_n[] = "//(?:\\\\\\n|[^\\n])*";
static const char __pyx_k_new[] = "__new__";
static const char __pyx_k_obj[] = "obj";
static const char __pyx_k_out[] = "out";
static const char __pyx_k_par[] = "par";
static const char __pyx_k_pdb[] = "pdb";
static const char __pyx_k_pop[] = "pop";
static const char __pyx_k_r_2[] = "\\r";
static const char __pyx_k_ref[] = "ref";
static const char __pyx_k_rep[] = "rep";
static const char __pyx_k_req[] = "__req__";
static const char __pyx_k_res[] = "res";
static const char __pyx_k_ret[] = "ret";
static const char __pyx_k_rne[] = "__rne__";
static const char __pyx_k_ror[] = "__ror__";
static const char __pyx_k_s_2[] = "\"%s\"";
static const char __pyx_k_s_3[] = "'%s'";
static const char __pyx_k_s_4[] = "[%s]+";
static const char __pyx_k_s_5[] = "|(?:%s)";
static const char __pyx_k_s_6[] = "|(?:%s.)";
static const char __pyx_k_s_7[] = ")*%s";
static const char __pyx_k_s_8[] = "[%s]";
static const char __pyx_k_s_9[] = "<%s>";
static const char __pyx_k_s_S[] = "<!--[\\s\\S]*?-->";
static const char __pyx_k_s_m[] = "s_m";
static const char __pyx_k_s_s[] = "(%s, %s)";
static const char __pyx_k_sep[] = "sep";
static const char __pyx_k_set[] = "set";
static const char __pyx_k_src[] = "src";
static const char __pyx_k_str[] = "str";
static const char __pyx_k_sub[] = "sub";
static const char __pyx_k_sum[] = "sum";
static const char __pyx_k_sys[] = "sys";
static const char __pyx_k_t_2[] = "\\t";
static const char __pyx_k_tag[] = "tag";
static const char __pyx_k_tmp[] = "tmp";
static const char __pyx_k_tok[] = "tok";
static const char __pyx_k_tup[] = "tup";
static const char __pyx_k_xml[] = "xml";
static const char __pyx_k_xor[] = "__xor__";
static const char __pyx_k_zip[] = "zip";
static const char __pyx_k_Dict[] = "Dict";
static const char __pyx_k_Each[] = "Each";
static const char __pyx_k_FAIL[] = "FAIL: ";
static const char __pyx_k_ITEM[] = "ITEM";
static const char __pyx_k_LEFT[] = "LEFT";
static const char __pyx_k_MISS[] = "MISS";
static const char __pyx_k_PEER[] = "PEER";
static const char __pyx_k_PY_3[] = "PY_3";
static const char __pyx_k_Re_s[] = "Re:(%s)";
static const char __pyx_k_UUID[] = "UUID";
static const char __pyx_k_Word[] = "Word";
static const char __pyx_k__102[] = " \t\r\n";
static const char __pyx_k__108[] = "-";
static const char __pyx_k__111[] = "{";
static const char __pyx_k__112[] = "}";
static const char __pyx_k__113[] = " ^ ";
static const char __pyx_k__115[] = " | ";
static const char __pyx_k__119[] = " & ";
static const char __pyx_k__123[] = "~{";
static const char __pyx_k__124[] = "}...";
static const char __pyx_k__125[] = "]...";
static const char __pyx_k__127[] = ": ...";
static const char __pyx_k__129[] = ".";
static const char __pyx_k__132[] = ",";
static const char __pyx_k__133[] = " [";
static const char __pyx_k__146[] = "|";
static const char __pyx_k__166[] = "/";
static const char __pyx_k__167[] = "_-:";
static const char __pyx_k__170[] = "=";
static const char __pyx_k__182[] = ":";
static const char __pyx_k__195[] = "(";
static const char __pyx_k__205[] = "\t ";
static const char __pyx_k__355[] = " \n\t\r";
static const char __pyx_k__508[] = "_$";
static const char __pyx_k__653[] = "_";
static const char __pyx_k__823[] = "\\[]-*.$+^?()~ ";
static const char __pyx_k__826[] = "\\]";
static const char __pyx_k__857[] = "\"";
static const char __pyx_k__860[] = "'";
static const char __pyx_k__873[] = "_:";
static const char __pyx_k__875[] = "><& \"'";
static const char __pyx_k__876[] = ");";
static const char __pyx_k__880[] = "/\\*(?:[^*]|\\*(?!/))*";
static const char __pyx_k__882[] = "*/";
static const char __pyx_k__886[] = ".*";
static const char __pyx_k__893[] = "#.*";
static const char __pyx_k__896[] = " \t";
static const char __pyx_k__921[] = "::";
static const char __pyx_k_args[] = "args";
static const char __pyx_k_body[] = "body";
static const char __pyx_k_bool[] = "__bool__";
static const char __pyx_k_call[] = "__call__";
static const char __pyx_k_copy[] = "copy";
static const char __pyx_k_data[] = "data";
static const char __pyx_k_date[] = "date";
static const char __pyx_k_dump[] = "dump";
static const char __pyx_k_elem[] = "elem";
static const char __pyx_k_exit[] = "__exit__";
static const char __pyx_k_expr[] = "expr";
static const char __pyx_k_ffff[] = "::ffff:";
static const char __pyx_k_find[] = "find";
static const char __pyx_k_flag[] = "flag";
static const char __pyx_k_from[] = "from_";
static const char __pyx_k_full[] = "full";
static const char __pyx_k_func[] = "func";
static const char __pyx_k_hash[] = "__hash__";
static const char __pyx_k_iadd[] = "__iadd__";
static const char __pyx_k_ikey[] = "ikey";
static const char __pyx_k_init[] = "__init__";
static const char __pyx_k_item[] = "item";
static const char __pyx_k_iter[] = "__iter__";
static const char __pyx_k_ixor[] = "__ixor__";
static const char __pyx_k_keys[] = "keys";
static const char __pyx_k_last[] = "last";
static const char __pyx_k_line[] = "line";
static const char __pyx_k_loc2[] = "loc2";
static const char __pyx_k_locn[] = "locn";
static const char __pyx_k_lpar[] = "lpar";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_name[] = "name";
static const char __pyx_k_nums[] = "nums";
static const char __pyx_k_open[] = "open";
static const char __pyx_k_opt1[] = "opt1";
static const char __pyx_k_opt2[] = "opt2";
static const char __pyx_k_prev[] = "(prev) ";
static const char __pyx_k_pstr[] = "pstr";
static const char __pyx_k_radd[] = "__radd__";
static const char __pyx_k_rand[] = "__rand__";
static const char __pyx_k_read[] = "read";
static const char __pyx_k_real[] = "real";
static const char __pyx_k_repr[] = "_repr";
static const char __pyx_k_rmul[] = "__rmul__";
static const char __pyx_k_rpar[] = "rpar";
static const char __pyx_k_rsub[] = "__rsub__";
static const char __pyx_k_rxor[] = "__rxor__";
static const char __pyx_k_s_10[] = "</%s>";
static const char __pyx_k_self[] = "self";
static const char __pyx_k_send[] = "send";
static const char __pyx_k_size[] = "size";
static const char __pyx_k_sort[] = "sort";
static const char __pyx_k_strg[] = "strg";
static const char __pyx_k_strs[] = "strs";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_toks[] = "toks";
static const char __pyx_k_ustr[] = "_ustr";
static const char __pyx_k_utf8[] = "utf8";
static const char __pyx_k_uuid[] = "uuid";
static const char __pyx_k_vars[] = "vars";
static const char __pyx_k_warn[] = "warn";
static const char __pyx_k_0_0_7[] = "\\\\0[0-7]+";
static const char __pyx_k_2_2_0[] = "2.2.0";
static const char __pyx_k_Empty[] = "Empty";
static const char __pyx_k_FATAL[] = "(FATAL)";
static const char __pyx_k_Group[] = "Group";
static const char __pyx_k_Match[] = "Match ";
static const char __pyx_k_RIGHT[] = "RIGHT";
static const char __pyx_k_RLock[] = "RLock";
static const char __pyx_k_Regex[] = "Regex";
static const char __pyx_k_Token[] = "Token";
static const char __pyx_k_W_s_2[] = "!W:(%s...)";
static const char __pyx_k_W_s_3[] = "!W:(%s)";
static const char __pyx_k_W_s_s[] = "W:(%s,%s)";
static const char __pyx_k_White[] = "White";
static const char __pyx_k_Y_m_d[] = "%Y-%m-%d";
static const char __pyx_k_all_2[] = "__all__";
static const char __pyx_k_aname[] = "aname";
static const char __pyx_k_arity[] = "arity";
static const char __pyx_k_asXML[] = "asXML";
static const char __pyx_k_attrs[] = "attrs";
static const char __pyx_k_cache[] = "cache";
static const char __pyx_k_chars[] = "chars";
static const char __pyx_k_class[] = "__class__";
static const char __pyx_k_clear[] = "clear";
static const char __pyx_k_close[] = "close";
static const char __pyx_k_colno[] = "colno";
static const char __pyx_k_count[] = "count";
static const char __pyx_k_d_d_2[] = "[+-]?\\d+\\.\\d*";
static const char __pyx_k_debug[] = "debug";
static const char __pyx_k_delim[] = "delim";
static const char __pyx_k_depth[] = "depth";
static const char __pyx_k_deque[] = "deque";
static const char __pyx_k_dummy[] = "dummy";
static const char __pyx_k_empty[] = "empty";
static const char __pyx_k_ender[] = "ender";
static const char __pyx_k_enter[] = "__enter__";
static const char __pyx_k_error[] = "error";
static const char __pyx_k_exact[] = "exact";
static const char __pyx_k_exprs[] = "exprs";
static const char __pyx_k_fatal[] = "fatal";
static const char __pyx_k_flags[] = "flags";
static const char __pyx_k_fname[] = "fname";
static const char __pyx_k_group[] = "group";
static const char __pyx_k_ident[] = "ident";
static const char __pyx_k_index[] = "index";
static const char __pyx_k_items[] = "items";
static const char __pyx_k_lastE[] = "lastE";
static const char __pyx_k_len_2[] = "(len) ";
static const char __pyx_k_len_3[] = "len";
static const char __pyx_k_limit[] = "limit";
static const char __pyx_k_lower[] = "lower";
static const char __pyx_k_masks[] = "masks";
static const char __pyx_k_match[] = "match";
static const char __pyx_k_modal[] = "modal";
static const char __pyx_k_mylen[] = "mylen";
static const char __pyx_k_oneOf[] = "oneOf";
static const char __pyx_k_other[] = "other";
static const char __pyx_k_parse[] = "_parse";
static const char __pyx_k_print[] = "print";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_reset[] = "reset";
static const char __pyx_k_rfind[] = "rfind";
static const char __pyx_k_s_s_2[] = "%s[%s]*";
static const char __pyx_k_s_s_3[] = "[%s][%s]*";
static const char __pyx_k_s_s_4[] = "%s[^%s]";
static const char __pyx_k_s_s_5[] = "%s:(%s)";
static const char __pyx_k_s_s_s[] = "%s%s- %s: ";
static const char __pyx_k_split[] = "split";
static const char __pyx_k_start[] = "start";
static const char __pyx_k_state[] = "state";
static const char __pyx_k_str_2[] = "__str__";
static const char __pyx_k_strip[] = "strip";
static const char __pyx_k_sub_2[] = "__sub__";
static const char __pyx_k_super[] = "super";
static const char __pyx_k_tests[] = "tests";
static const char __pyx_k_tflat[] = "tflat";
static const char __pyx_k_throw[] = "throw";
static const char __pyx_k_title[] = "title";
static const char __pyx_k_types[] = "types";
static const char __pyx_k_upper[] = "upper";
static const char __pyx_k_value[] = "value";
static const char __pyx_k_vlist[] = "vlist";
static const char __pyx_k_wkref[] = "wkref";
static const char __pyx_k_write[] = "write";
static const char __pyx_k_wslit[] = "wslit";
static const char __pyx_k_100_FF[] = "\n        100\n        FF\n        ";
static const char __pyx_k_DOTALL[] = "DOTALL";
static const char __pyx_k_INDENT[] = "INDENT";
static const char __pyx_k_NotAny[] = "NotAny";
static const char __pyx_k_SkipTo[] = "SkipTo";
static const char __pyx_k_UNDENT[] = "UNDENT";
static const char __pyx_k_alphas[] = "alphas";
static const char __pyx_k_append[] = "append";
static const char __pyx_k_asDict[] = "asDict";
static const char __pyx_k_asList[] = "asList";
static const char __pyx_k_at_loc[] = " at loc ";
static const char __pyx_k_bslash[] = "_bslash";
static const char __pyx_k_called[] = "called";
static const char __pyx_k_closer[] = "closer";
static const char __pyx_k_column[] = "column";
static const char __pyx_k_curCol[] = "curCol";
static const char __pyx_k_cvt_fn[] = "cvt_fn";
static const char __pyx_k_decode[] = "decode";
static const char __pyx_k_dictOf[] = "dictOf";
static const char __pyx_k_dlName[] = "dlName";
static const char __pyx_k_doctag[] = "doctag";
static const char __pyx_k_endloc[] = "endloc";
static const char __pyx_k_entity[] = "entity";
static const char __pyx_k_errmsg[] = "errmsg";
static const char __pyx_k_escape[] = "escape";
static const char __pyx_k_extend[] = "extend";
static const char __pyx_k_failOn[] = "failOn";
static const char __pyx_k_failed[] = "failed";
static const char __pyx_k_frames[] = "frames";
static const char __pyx_k_from_2[] = "from";
static const char __pyx_k_ignore[] = "ignore";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_indent[] = "indent";
static const char __pyx_k_insStr[] = "insStr";
static const char __pyx_k_insert[] = "insert";
static const char __pyx_k_invert[] = "__invert__";
static const char __pyx_k_kwargs[] = "kwargs";
static const char __pyx_k_lambda[] = "<lambda>";
static const char __pyx_k_lastCR[] = "lastCR";
static const char __pyx_k_lineno[] = "lineno";
static const char __pyx_k_lookup[] = "__lookup";
static const char __pyx_k_lshift[] = "__lshift__";
static const char __pyx_k_lstrip[] = "lstrip";
static const char __pyx_k_maxLen[] = "maxLen";
static const char __pyx_k_maxlen[] = "maxlen";
static const char __pyx_k_maxloc[] = "maxloc";
static const char __pyx_k_minLen[] = "minLen";
static const char __pyx_k_module[] = "__module__";
static const char __pyx_k_name_2[] = "__name__";
static const char __pyx_k_negate[] = "negate";
static const char __pyx_k_newloc[] = "newloc";
static const char __pyx_k_nextCR[] = "nextCR";
static const char __pyx_k_number[] = "number";
static const char __pyx_k_object[] = "object";
static const char __pyx_k_offset[] = "offset";
static const char __pyx_k_opExpr[] = "opExpr";
static const char __pyx_k_opList[] = "opList";
static const char __pyx_k_opener[] = "opener";
static const char __pyx_k_paArgs[] = "paArgs";
static const char __pyx_k_pprint[] = "pprint";
static const char __pyx_k_preloc[] = "preloc";
static const char __pyx_k_py_str[] = "py_str";
static const char __pyx_k_remove[] = "remove";
static const char __pyx_k_repr_2[] = "repr";
static const char __pyx_k_repr_3[] = "__repr__";
static const char __pyx_k_resTag[] = "resTag";
static const char __pyx_k_result[] = "result";
static const char __pyx_k_retobj[] = "retobj";
static const char __pyx_k_rstrip[] = "rstrip";
static const char __pyx_k_s_term[] = "%s term";
static const char __pyx_k_select[] = "select";
static const char __pyx_k_smExpr[] = "smExpr";
static const char __pyx_k_sorted[] = "sorted";
static const char __pyx_k_splits[] = "splits";
static const char __pyx_k_srange[] = "srange";
static const char __pyx_k_stderr[] = "stderr";
static const char __pyx_k_stopOn[] = "stopOn";
static const char __pyx_k_string[] = "string";
static const char __pyx_k_tables[] = "tables";
static const char __pyx_k_tagStr[] = "tagStr";
static const char __pyx_k_thread[] = "_thread";
static const char __pyx_k_tmpLoc[] = "tmpLoc";
static const char __pyx_k_tmpOpt[] = "tmpOpt";
static const char __pyx_k_tmploc[] = "tmploc";
static const char __pyx_k_toItem[] = "toItem";
static const char __pyx_k_tokens[] = "tokens";
static const char __pyx_k_unichr[] = "unichr";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_values[] = "values";
static const char __pyx_k_ws_map[] = "ws_map";
static const char __pyx_k_wschar[] = "wschar";
static const char __pyx_k_xrange[] = "xrange";
static const char __pyx_k_Combine[] = "Combine";
static const char __pyx_k_Forward[] = "Forward";
static const char __pyx_k_Keyword[] = "Keyword";
static const char __pyx_k_LineEnd[] = "LineEnd";
static const char __pyx_k_Literal[] = "Literal";
static const char __pyx_k_MAX_INT[] = "_MAX_INT";
static const char __pyx_k_Matched[] = "Matched ";
static const char __pyx_k_NoMatch[] = "NoMatch";
static const char __pyx_k_UNICODE[] = "UNICODE";
static const char __pyx_k_WordEnd[] = "WordEnd";
static const char __pyx_k_any_tag[] = "any tag";
static const char __pyx_k_breaker[] = "breaker";
static const char __pyx_k_builtin[] = "__builtin__";
static const char __pyx_k_class_2[] = "class";
static const char __pyx_k_columns[] = "columns";
static const char __pyx_k_combine[] = "combine";
static const char __pyx_k_command[] = "command";
static const char __pyx_k_comment[] = "comment";
static const char __pyx_k_compile[] = "compile";
static const char __pyx_k_content[] = "content";
static const char __pyx_k_default[] = "default";
static const char __pyx_k_delitem[] = "__delitem__";
static const char __pyx_k_escChar[] = "escChar";
static const char __pyx_k_flatten[] = "_flatten";
static const char __pyx_k_fnumber[] = "fnumber";
static const char __pyx_k_genexpr[] = "genexpr";
static const char __pyx_k_getName[] = "getName";
static const char __pyx_k_getattr[] = "__getattr__";
static const char __pyx_k_getitem[] = "__getitem__";
static const char __pyx_k_haskeys[] = "haskeys";
static const char __pyx_k_hexnums[] = "hexnums";
static const char __pyx_k_ilshift[] = "__ilshift__";
static const char __pyx_k_include[] = "include";
static const char __pyx_k_indices[] = "indices";
static const char __pyx_k_intExpr[] = "intExpr";
static const char __pyx_k_integer[] = "integer";
static const char __pyx_k_isequal[] = "isequal";
static const char __pyx_k_isspace[] = "isspace";
static const char __pyx_k_item_fn[] = "item_fn";
static const char __pyx_k_itemseq[] = "itemseq";
static const char __pyx_k_lineEnd[] = "lineEnd";
static const char __pyx_k_locator[] = "locator";
static const char __pyx_k_matches[] = "matches";
static const char __pyx_k_maxargs[] = "maxargs";
static const char __pyx_k_maxsize[] = "maxsize";
static const char __pyx_k_message[] = "message";
static const char __pyx_k_missing[] = "missing";
static const char __pyx_k_newself[] = "newself";
static const char __pyx_k_nextLoc[] = "nextLoc";
static const char __pyx_k_nextloc[] = "nextloc";
static const char __pyx_k_nonzero[] = "__nonzero__";
static const char __pyx_k_opAssoc[] = "opAssoc";
static const char __pyx_k_opExpr1[] = "opExpr1";
static const char __pyx_k_opExpr2[] = "opExpr2";
static const char __pyx_k_openTag[] = "openTag";
static const char __pyx_k_operDef[] = "operDef";
static const char __pyx_k_opt1map[] = "opt1map";
static const char __pyx_k_os_path[] = "os.path";
static const char __pyx_k_overlap[] = "overlap";
static const char __pyx_k_parseFn[] = "parseFn";
static const char __pyx_k_pattern[] = "pattern";
static const char __pyx_k_popitem[] = "popitem";
static const char __pyx_k_popleft[] = "popleft";
static const char __pyx_k_prepare[] = "__prepare__";
static const char __pyx_k_removed[] = "removed";
static const char __pyx_k_replStr[] = "replStr";
static const char __pyx_k_replace[] = "replace";
static const char __pyx_k_resname[] = "resname";
static const char __pyx_k_results[] = "results";
static const char __pyx_k_retToks[] = "retToks";
static const char __pyx_k_s_class[] = "%s:class";
static const char __pyx_k_s_s_s_2[] = "%s(?:[^%s%s]";
static const char __pyx_k_selfTag[] = "selfTag";
static const char __pyx_k_setName[] = "setName";
static const char __pyx_k_setitem[] = "__setitem__";
static const char __pyx_k_strRepr[] = "strRepr";
static const char __pyx_k_success[] = "success";
static const char __pyx_k_symbols[] = "symbols";
static const char __pyx_k_tb_info[] = "tb_info";
static const char __pyx_k_thiscol[] = "thiscol";
static const char __pyx_k_tmpReqd[] = "tmpReqd";
static const char __pyx_k_toklist[] = "toklist";
static const char __pyx_k_ungroup[] = "ungroup";
static const char __pyx_k_version[] = "__version__";
static const char __pyx_k_weakref[] = "weakref";
static const char __pyx_k_wrapper[] = "wrapper";
static const char __pyx_k_Expected[] = "Expected ";
static const char __pyx_k_Iterable[] = "Iterable";
static const char __pyx_k_KeyError[] = "KeyError";
static const char __pyx_k_OnlyOnce[] = "OnlyOnce";
static const char __pyx_k_Optional[] = "Optional";
static const char __pyx_k_Or___str[] = "Or.__str__";
static const char __pyx_k_P_entity[] = "&(?P<entity>";
static const char __pyx_k_Suppress[] = "Suppress";
static const char __pyx_k_UNINDENT[] = "UNINDENT";
static const char __pyx_k_adjacent[] = "adjacent";
static const char __pyx_k_arrayLen[] = "arrayLen";
static const char __pyx_k_asString[] = "asString";
static const char __pyx_k_attrDict[] = "attrDict";
static const char __pyx_k_attrName[] = "attrName";
static const char __pyx_k_baseExpr[] = "baseExpr";
static const char __pyx_k_callable[] = "callable";
static const char __pyx_k_caseless[] = "caseless";
static const char __pyx_k_closeTag[] = "closeTag";
static const char __pyx_k_comments[] = "comments";
static const char __pyx_k_contains[] = "__contains__";
static const char __pyx_k_d_d_eE_d[] = "[+-]?\\d+\\.?\\d*([eE][+-]?\\d+)?";
static const char __pyx_k_datetime[] = "datetime";
static const char __pyx_k_endswith[] = "endswith";
static const char __pyx_k_escQuote[] = "escQuote";
static const char __pyx_k_exc_info[] = "exc_info";
static const char __pyx_k_exc_type[] = "exc_type";
static const char __pyx_k_expanded[] = "_expanded";
static const char __pyx_k_filename[] = "filename";
static const char __pyx_k_fraction[] = "fraction";
static const char __pyx_k_fullDump[] = "fullDump";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_instring[] = "instring";
static const char __pyx_k_instrlen[] = "instrlen";
static const char __pyx_k_iterkeys[] = "iterkeys";
static const char __pyx_k_keepTabs[] = "keepTabs";
static const char __pyx_k_key_fifo[] = "key_fifo";
static const char __pyx_k_lastExpr[] = "lastExpr";
static const char __pyx_k_line_str[] = "line_str";
static const char __pyx_k_locn_end[] = "locn_end";
static const char __pyx_k_lookup_2[] = "lookup";
static const char __pyx_k_makeTags[] = "_makeTags";
static const char __pyx_k_matchLen[] = "matchLen";
static const char __pyx_k_maxsplit[] = "maxsplit";
static const char __pyx_k_notChars[] = "notChars";
static const char __pyx_k_notchars[] = "notchars";
static const char __pyx_k_original[] = "original";
static const char __pyx_k_parseAll[] = "parseAll";
static const char __pyx_k_position[] = "position";
static const char __pyx_k_preParse[] = "preParse";
static const char __pyx_k_punc8bit[] = "punc8bit";
static const char __pyx_k_qualname[] = "__qualname__";
static const char __pyx_k_reString[] = "reString";
static const char __pyx_k_register[] = "register";
static const char __pyx_k_required[] = "required";
static const char __pyx_k_reversed[] = "reversed";
static const char __pyx_k_runTests[] = "runTests";
static const char __pyx_k_s_s_term[] = "%s%s term";
static const char __pyx_k_savelist[] = "savelist";
static const char __pyx_k_sci_real[] = "sci_real";
static const char __pyx_k_setBreak[] = "setBreak";
static const char __pyx_k_setDebug[] = "setDebug";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_skiptext[] = "skiptext";
static const char __pyx_k_startloc[] = "startloc";
static const char __pyx_k_strptime[] = "strptime";
static const char __pyx_k_suppress[] = "suppress";
static const char __pyx_k_termName[] = "termName";
static const char __pyx_k_thisExpr[] = "thisExpr";
static const char __pyx_k_thisFunc[] = "thisFunc";
static const char __pyx_k_tmpExprs[] = "tmpExprs";
static const char __pyx_k_tokenMap[] = "tokenMap";
static const char __pyx_k_tryParse[] = "tryParse";
static const char __pyx_k_useRegex[] = "useRegex";
static const char __pyx_k_validate[] = "validate";
static const char __pyx_k_warnings[] = "warnings";
static const char __pyx_k_ANY_VALUE[] = "ANY_VALUE";
static const char __pyx_k_And___str[] = "And.__str__";
static const char __pyx_k_Constants[] = "_Constants";
static const char __pyx_k_ErrorStop[] = "_ErrorStop";
static const char __pyx_k_FILE_NAME[] = "_FILE_NAME";
static const char __pyx_k_FifoCache[] = "_FifoCache";
static const char __pyx_k_LineStart[] = "LineStart";
static const char __pyx_k_MULTILINE[] = "MULTILINE";
static const char __pyx_k_NullToken[] = "_NullToken";
static const char __pyx_k_OneOrMore[] = "OneOrMore";
static const char __pyx_k_Or___init[] = "Or.__init__";
static const char __pyx_k_Or___ixor[] = "Or.__ixor__";
static const char __pyx_k_StringEnd[] = "StringEnd";
static const char __pyx_k_TypeError[] = "TypeError";
static const char __pyx_k_WordStart[] = "WordStart";
static const char __pyx_k_addoffset[] = "addoffset";
static const char __pyx_k_alphanums[] = "alphanums";
static const char __pyx_k_arrayExpr[] = "arrayExpr";
static const char __pyx_k_asKeyword[] = "asKeyword";
static const char __pyx_k_attrValue[] = "attrValue";
static const char __pyx_k_bodyChars[] = "bodyChars";
static const char __pyx_k_bodychars[] = "bodychars";
static const char __pyx_k_breakFlag[] = "breakFlag";
static const char __pyx_k_cache_len[] = "cache_len";
static const char __pyx_k_charRange[] = "_charRange";
static const char __pyx_k_classattr[] = "classattr";
static const char __pyx_k_classname[] = "classname";
static const char __pyx_k_commaItem[] = "commaItem";
static const char __pyx_k_comment_2[] = "// comment";
static const char __pyx_k_debugging[] = "debugging";
static const char __pyx_k_dictvalue[] = "dictvalue";
static const char __pyx_k_doActions[] = "doActions";
static const char __pyx_k_enumerate[] = "enumerate";
static const char __pyx_k_errorStop[] = "errorStop";
static const char __pyx_k_exception[] = "exception";
static const char __pyx_k_formatted[] = "formatted";
static const char __pyx_k_fromToken[] = "fromToken";
static const char __pyx_k_func_name[] = "func_name";
static const char __pyx_k_groupdict[] = "groupdict";
static const char __pyx_k_initChars[] = "initChars";
static const char __pyx_k_ipv6_part[] = "_ipv6_part";
static const char __pyx_k_iteritems[] = "iteritems";
static const char __pyx_k_lineStart[] = "lineStart";
static const char __pyx_k_locMarker[] = "locMarker";
static const char __pyx_k_matchExpr[] = "matchExpr";
static const char __pyx_k_maxExcLoc[] = "maxExcLoc";
static const char __pyx_k_metaclass[] = "__metaclass__";
static const char __pyx_k_multiline[] = "multiline";
static const char __pyx_k_namespace[] = "namespace";
static const char __pyx_k_not_ender[] = "not_ender";
static const char __pyx_k_optionals[] = "optionals";
static const char __pyx_k_parseFile[] = "parseFile";
static const char __pyx_k_parseImpl[] = "parseImpl";
static const char __pyx_k_postParse[] = "postParse";
static const char __pyx_k_printable[] = "printable";
static const char __pyx_k_quoteChar[] = "quoteChar";
static const char __pyx_k_retTokens[] = "retTokens";
static const char __pyx_k_s_s_n_r_s[] = "%s(?:[^%s\\n\\r%s]";
static const char __pyx_k_setOffset[] = "setOffset";
static const char __pyx_k_set_trace[] = "set_trace";
static const char __pyx_k_simpleSQL[] = "simpleSQL";
static const char __pyx_k_stringEnd[] = "stringEnd";
static const char __pyx_k_tableName[] = "tableName";
static const char __pyx_k_threading[] = "threading";
static const char __pyx_k_tmptokens[] = "tmptokens";
static const char __pyx_k_tokenlist[] = "tokenlist";
static const char __pyx_k_traceback[] = "traceback";
static const char __pyx_k_verifyCol[] = "verifyCol";
static const char __pyx_k_whiteStrs[] = "whiteStrs";
static const char __pyx_k_withClass[] = "withClass";
static const char __pyx_k_wordChars[] = "wordChars";
static const char __pyx_k_0123456789[] = "0123456789";
static const char __pyx_k_And___iadd[] = "And.__iadd__";
static const char __pyx_k_And___init[] = "And.__init__";
static const char __pyx_k_CharsNotIn[] = "CharsNotIn";
static const char __pyx_k_CloseMatch[] = "CloseMatch";
static const char __pyx_k_Each___str[] = "Each.__str__";
static const char __pyx_k_FollowedBy[] = "FollowedBy";
static const char __pyx_k_GoToColumn[] = "GoToColumn";
static const char __pyx_k_IndexError[] = "IndexError";
static const char __pyx_k_MatchFirst[] = "MatchFirst";
static const char __pyx_k_MethodType[] = "MethodType";
static const char __pyx_k_ValueError[] = "ValueError";
static const char __pyx_k_Word___str[] = "Word.__str__";
static const char __pyx_k_ZeroOrMore[] = "ZeroOrMore";
static const char __pyx_k_allResults[] = "allResults";
static const char __pyx_k_alphas8bit[] = "alphas8bit";
static const char __pyx_k_anyOpenTag[] = "anyOpenTag";
static const char __pyx_k_basestring[] = "basestring";
static const char __pyx_k_cPyparsing[] = "cPyparsing";
static const char __pyx_k_charsAsStr[] = "charsAsStr";
static const char __pyx_k_columnName[] = "columnName";
static const char __pyx_k_columnSpec[] = "columnSpec";
static const char __pyx_k_expandtabs[] = "expandtabs";
static const char __pyx_k_expr_parse[] = "expr_parse";
static const char __pyx_k_exprsFound[] = "exprsFound";
static const char __pyx_k_exprtokens[] = "exprtokens";
static const char __pyx_k_extract_tb[] = "extract_tb";
static const char __pyx_k_failAction[] = "failAction";
static const char __pyx_k_foundArity[] = "foundArity";
static const char __pyx_k_getnewargs[] = "__getnewargs__";
static const char __pyx_k_identChars[] = "identChars";
static const char __pyx_k_identifier[] = "identifier";
static const char __pyx_k_ignoreExpr[] = "ignoreExpr";
static const char __pyx_k_isinstance[] = "isinstance";
static const char __pyx_k_iterkeys_2[] = "_iterkeys";
static const char __pyx_k_itervalues[] = "itervalues";
static const char __pyx_k_joinString[] = "joinString";
static const char __pyx_k_locn_start[] = "locn_start";
static const char __pyx_k_matchOrder[] = "matchOrder";
static const char __pyx_k_matchWhite[] = "matchWhite";
static const char __pyx_k_maxMatches[] = "maxMatches";
static const char __pyx_k_methodCall[] = "methodCall";
static const char __pyx_k_mismatches[] = "mismatches";
static const char __pyx_k_namedItems[] = "namedItems";
static const char __pyx_k_nestedExpr[] = "nestedExpr";
static const char __pyx_k_otheritems[] = "otheritems";
static const char __pyx_k_parseCache[] = "_parseCache";
static const char __pyx_k_preparseFn[] = "preparseFn";
static const char __pyx_k_printables[] = "printables";
static const char __pyx_k_resetCache[] = "resetCache";
static const char __pyx_k_restOfLine[] = "restOfLine";
static const char __pyx_k_resultlist[] = "resultlist";
static const char __pyx_k_reversed_2[] = "__reversed__";
static const char __pyx_k_saveAsList[] = "saveAsList";
static const char __pyx_k_scanString[] = "scanString";
static const char __pyx_k_singleChar[] = "_singleChar";
static const char __pyx_k_skipresult[] = "skipresult";
static const char __pyx_k_splitlines[] = "splitlines";
static const char __pyx_k_stacklevel[] = "stacklevel";
static const char __pyx_k_startswith[] = "startswith";
static const char __pyx_k_streamline[] = "streamline";
static const char __pyx_k_testString[] = "testString";
static const char __pyx_k_to_symbols[] = "to_symbols";
static const char __pyx_k_trim_arity[] = "_trim_arity";
static const char __pyx_k_whiteChars[] = "whiteChars";
static const char __pyx_k_whitespace[] = "whitespace";
static const char __pyx_k_xml_escape[] = "_xml_escape";
static const char __pyx_k_Dict___init[] = "Dict.__init__";
static const char __pyx_k_Each___init[] = "Each.__init__";
static const char __pyx_k_ImportError[] = "ImportError";
static const char __pyx_k_MAC_address[] = "MAC address";
static const char __pyx_k_OrderedDict[] = "_OrderedDict";
static const char __pyx_k_Regex___str[] = "Regex.__str__";
static const char __pyx_k_StringStart[] = "StringStart";
static const char __pyx_k_SyntaxError[] = "SyntaxError";
static const char __pyx_k_Word___init[] = "Word.__init__";
static const char __pyx_k_anyCloseTag[] = "anyCloseTag";
static const char __pyx_k_check_ender[] = "check_ender";
static const char __pyx_k_collections[] = "collections";
static const char __pyx_k_escapedPunc[] = "_escapedPunc";
static const char __pyx_k_extractText[] = "extractText";
static const char __pyx_k_hex_integer[] = "hex integer";
static const char __pyx_k_htmlComment[] = "htmlComment";
static const char __pyx_k_ignoreExprs[] = "ignoreExprs";
static const char __pyx_k_indentStack[] = "indentStack";
static const char __pyx_k_iteritems_2[] = "_iteritems";
static const char __pyx_k_line_column[] = "line_column";
static const char __pyx_k_locatedExpr[] = "locatedExpr";
static const char __pyx_k_mac_address[] = "mac_address";
static const char __pyx_k_makeXMLTags[] = "makeXMLTags";
static const char __pyx_k_matchString[] = "matchString";
static const char __pyx_k_matchTokens[] = "matchTokens";
static const char __pyx_k_minElements[] = "minElements";
static const char __pyx_k_occurrences[] = "occurrences";
static const char __pyx_k_optElements[] = "optElements";
static const char __pyx_k_ordereddict[] = "ordereddict";
static const char __pyx_k_parseAction[] = "parseAction";
static const char __pyx_k_parseMethod[] = "_parseMethod";
static const char __pyx_k_parseString[] = "parseString";
static const char __pyx_k_real_number[] = "real number";
static const char __pyx_k_replaceWith[] = "replaceWith";
static const char __pyx_k_resultsName[] = "resultsName";
static const char __pyx_k_s_s_d_s_s_s[] = "\n%s%s[%d]:\n%s%s%s";
static const char __pyx_k_selectToken[] = "selectToken";
static const char __pyx_k_startAction[] = "startAction";
static const char __pyx_k_streamlined[] = "streamlined";
static const char __pyx_k_stringStart[] = "stringStart";
static const char __pyx_k_tagAttrName[] = "tagAttrName";
static const char __pyx_k_theseTokens[] = "theseTokens";
static const char __pyx_k_tokensStart[] = "tokensStart";
static const char __pyx_k_traceback_2[] = "__traceback__";
static const char __pyx_k_xmlBodyText[] = "xmlBodyText";
static const char __pyx_k_ABCDEFabcdef[] = "ABCDEFabcdef";
static const char __pyx_k_Empty___init[] = "Empty.__init__";
static const char __pyx_k_Forward_copy[] = "Forward.copy";
static const char __pyx_k_Group___init[] = "Group.__init__";
static const char __pyx_k_HTML_comment[] = "HTML comment";
static const char __pyx_k_IPv4_address[] = "IPv4 address";
static const char __pyx_k_IPv6_address[] = "IPv6 address";
static const char __pyx_k_ISO8601_date[] = "ISO8601 date";
static const char __pyx_k_Keyword_copy[] = "Keyword.copy";
static const char __pyx_k_NotAny___str[] = "NotAny.__str__";
static const char __pyx_k_Or_parseImpl[] = "Or.parseImpl";
static const char __pyx_k_ParseResults[] = "ParseResults";
static const char __pyx_k_QuotedString[] = "QuotedString";
static const char __pyx_k_Regex___init[] = "Regex.__init__";
static const char __pyx_k_Token___init[] = "Token.__init__";
static const char __pyx_k_White___init[] = "White.__init__";
static const char __pyx_k_addCondition[] = "addCondition";
static const char __pyx_k_asStringList[] = "_asStringList";
static const char __pyx_k_callPreParse[] = "callPreParse";
static const char __pyx_k_callPreparse[] = "callPreparse";
static const char __pyx_k_canParseNext[] = "canParseNext";
static const char __pyx_k_commasepitem[] = "_commasepitem";
static const char __pyx_k_countedArray[] = "countedArray";
static const char __pyx_k_debugActions[] = "debugActions";
static const char __pyx_k_defaultValue[] = "defaultValue";
static const char __pyx_k_defaultvalue[] = "defaultvalue";
static const char __pyx_k_endQuoteChar[] = "endQuoteChar";
static const char __pyx_k_endlocMarker[] = "endlocMarker";
static const char __pyx_k_excludeChars[] = "excludeChars";
static const char __pyx_k_failureTests[] = "failureTests";
static const char __pyx_k_finalResults[] = "finalResults";
static const char __pyx_k_from_symbols[] = "from_symbols";
static const char __pyx_k_inAccumNames[] = "inAccumNames";
static const char __pyx_k_includeMatch[] = "includeMatch";
static const char __pyx_k_ipv4_address[] = "ipv4_address";
static const char __pyx_k_ipv6_address[] = "ipv6_address";
static const char __pyx_k_iso8601_date[] = "iso8601_date";
static const char __pyx_k_itervalues_2[] = "_itervalues";
static const char __pyx_k_keepMatching[] = "keepMatching";
static const char __pyx_k_makeHTMLTags[] = "makeHTMLTags";
static const char __pyx_k_markerString[] = "markerString";
static const char __pyx_k_match_string[] = "match_string";
static const char __pyx_k_maxException[] = "maxException";
static const char __pyx_k_maxSpecified[] = "maxSpecified";
static const char __pyx_k_modalResults[] = "modalResults";
static const char __pyx_k_not_in_cache[] = "not_in_cache";
static const char __pyx_k_original_end[] = "_original_end";
static const char __pyx_k_parseNoCache[] = "_parseNoCache";
static const char __pyx_k_parse_action[] = "<parse action>";
static const char __pyx_k_printResults[] = "printResults";
static const char __pyx_k_quoteCharLen[] = "quoteCharLen";
static const char __pyx_k_quotedString[] = "quotedString";
static const char __pyx_k_removeQuotes[] = "removeQuotes";
static const char __pyx_k_rest_of_line[] = "rest of line";
static const char __pyx_k_returnString[] = "returnString";
static const char __pyx_k_searchString[] = "searchString";
static const char __pyx_k_staticmethod[] = "staticmethod";
static const char __pyx_k_tagAttrValue[] = "tagAttrValue";
static const char __pyx_k_upcaseTokens[] = "upcaseTokens";
static const char __pyx_k_version_info[] = "version_info";
static const char __pyx_k_0_9a_fA_F_1_4[] = "[0-9a-fA-F]{1,4}";
static const char __pyx_k_And_parseImpl[] = "And.parseImpl";
static const char __pyx_k_Forward___str[] = "Forward.__str__";
static const char __pyx_k_MultipleMatch[] = "_MultipleMatch";
static const char __pyx_k_NotAny___init[] = "NotAny.__init__";
static const char __pyx_k_OrderedDict_2[] = "OrderedDict";
static const char __pyx_k_ParserElement[] = "ParserElement";
static const char __pyx_k_PositionToken[] = "_PositionToken";
static const char __pyx_k_SkipTo___init[] = "SkipTo.__init__";
static const char __pyx_k_SyntaxWarning[] = "SyntaxWarning";
static const char __pyx_k_bodyCharsOrig[] = "bodyCharsOrig";
static const char __pyx_k_cStyleComment[] = "cStyleComment";
static const char __pyx_k_callDuringTry[] = "callDuringTry";
static const char __pyx_k_caselessmatch[] = "caselessmatch";
static const char __pyx_k_checkUnindent[] = "checkUnindent";
static const char __pyx_k_convertToDate[] = "convertToDate";
static const char __pyx_k_d_eE_d_d_eE_d[] = "[+-]?\\d+([eE][+-]?\\d+|\\.\\d*([eE][+-]?\\d+)?)";
static const char __pyx_k_delimitedList[] = "delimitedList";
static const char __pyx_k_enablePackrat[] = "enablePackrat";
static const char __pyx_k_file_contents[] = "file_contents";
static const char __pyx_k_frame_summary[] = "frame_summary";
static const char __pyx_k_generatorType[] = "_generatorType";
static const char __pyx_k_hex_integer_2[] = "hex_integer";
static const char __pyx_k_htmlEntityMap[] = "_htmlEntityMap";
static const char __pyx_k_html_stripper[] = "_html_stripper";
static const char __pyx_k_indentedBlock[] = "indentedBlock";
static const char __pyx_k_infixNotation[] = "infixNotation";
static const char __pyx_k_initCharsOrig[] = "initCharsOrig";
static const char __pyx_k_markInputline[] = "markInputline";
static const char __pyx_k_maxMismatches[] = "maxMismatches";
static const char __pyx_k_mayIndexError[] = "mayIndexError";
static const char __pyx_k_mixed_integer[] = "mixed_integer";
static const char __pyx_k_multirequired[] = "multirequired";
static const char __pyx_k_packrat_cache[] = "packrat_cache";
static const char __pyx_k_parseWithTabs[] = "parseWithTabs";
static const char __pyx_k_parserElement[] = "parserElement";
static const char __pyx_k_reBracketExpr[] = "_reBracketExpr";
static const char __pyx_k_setFailAction[] = "setFailAction";
static const char __pyx_k_sre_constants[] = "sre_constants";
static const char __pyx_k_stripHTMLTags[] = "stripHTMLTags";
static const char __pyx_k_successAction[] = "successAction";
static const char __pyx_k_tableNameList[] = "tableNameList";
static const char __pyx_k_tb_info_synth[] = "tb_info_synth";
static const char __pyx_k_try_not_ender[] = "try_not_ender";
static const char __pyx_k_unicodeString[] = "unicodeString";
static const char __pyx_k_validateTrace[] = "validateTrace";
static const char __pyx_k_withAttribute[] = "withAttribute";
static const char __pyx_k_0_xX_0_9a_fA_F[] = "\\\\0?[xX][0-9a-fA-F]+";
static const char __pyx_k_And__ErrorStop[] = "And._ErrorStop";
static const char __pyx_k_AttributeError[] = "AttributeError";
static const char __pyx_k_Combine___init[] = "Combine.__init__";
static const char __pyx_k_Combine_ignore[] = "Combine.ignore";
static const char __pyx_k_Dict_postParse[] = "Dict.postParse";
static const char __pyx_k_Each_parseImpl[] = "Each.parseImpl";
static const char __pyx_k_FAIL_EXCEPTION[] = "FAIL-EXCEPTION: ";
static const char __pyx_k_Forward___init[] = "Forward.__init__";
static const char __pyx_k_Keyword___init[] = "Keyword.__init__";
static const char __pyx_k_LineEnd___init[] = "LineEnd.__init__";
static const char __pyx_k_Literal___init[] = "Literal.__init__";
static const char __pyx_k_MutableMapping[] = "MutableMapping";
static const char __pyx_k_NoMatch___init[] = "NoMatch.__init__";
static const char __pyx_k_OnlyOnce_reset[] = "OnlyOnce.reset";
static const char __pyx_k_Optional___str[] = "Optional.__str__";
static const char __pyx_k_ParseException[] = "ParseException";
static const char __pyx_k_TokenConverter[] = "TokenConverter";
static const char __pyx_k_UnboundedCache[] = "_UnboundedCache";
static const char __pyx_k_WordEnd___init[] = "WordEnd.__init__";
static const char __pyx_k_Word_parseImpl[] = "Word.parseImpl";
static const char __pyx_k_Y_m_dT_H_M_S_f[] = "%Y-%m-%dT%H:%M:%S.%f";
static const char __pyx_k_addParseAction[] = "addParseAction";
static const char __pyx_k_cPyparsing_pyx[] = "cPyparsing.pyx";
static const char __pyx_k_checkRecursion[] = "checkRecursion";
static const char __pyx_k_checkSubIndent[] = "checkSubIndent";
static const char __pyx_k_columnNameList[] = "columnNameList";
static const char __pyx_k_compiledREtype[] = "compiledREtype";
static const char __pyx_k_convertToFloat[] = "convertToFloat";
static const char __pyx_k_downcaseTokens[] = "downcaseTokens";
static const char __pyx_k_escapedHexChar[] = "_escapedHexChar";
static const char __pyx_k_escapedOctChar[] = "_escapedOctChar";
static const char __pyx_k_firstMatchChar[] = "firstMatchChar";
static const char __pyx_k_firstQuoteChar[] = "firstQuoteChar";
static const char __pyx_k_from_exception[] = "_from_exception";
static const char __pyx_k_hasIgnoreExprs[] = "hasIgnoreExprs";
static const char __pyx_k_indented_block[] = "indented block";
static const char __pyx_k_initExprGroups[] = "initExprGroups";
static const char __pyx_k_listAllMatches[] = "listAllMatches";
static const char __pyx_k_matchOnlyAtCol[] = "matchOnlyAtCol";
static const char __pyx_k_mayReturnEmpty[] = "mayReturnEmpty";
static const char __pyx_k_multioptionals[] = "multioptionals";
static const char __pyx_k_namedItemsOnly[] = "namedItemsOnly";
static const char __pyx_k_not_a_subentry[] = "not a subentry";
static const char __pyx_k_original_start[] = "_original_start";
static const char __pyx_k_otherdictitems[] = "otherdictitems";
static const char __pyx_k_packratEnabled[] = "_packratEnabled";
static const char __pyx_k_rightLeftAssoc[] = "rightLeftAssoc";
static const char __pyx_k_setParseAction[] = "setParseAction";
static const char __pyx_k_setResultsName[] = "setResultsName";
static const char __pyx_k_signed_integer[] = "signed integer";
static const char __pyx_k_skipIgnorables[] = "_skipIgnorables";
static const char __pyx_k_skipWhitespace[] = "skipWhitespace";
static const char __pyx_k_system_version[] = "system_version";
static const char __pyx_k_throwException[] = "throwException";
static const char __pyx_k_unquoteResults[] = "unquoteResults";
static const char __pyx_k_C_style_comment[] = "C style comment";
static const char __pyx_k_CaselessKeyword[] = "CaselessKeyword";
static const char __pyx_k_CaselessLiteral[] = "CaselessLiteral";
static const char __pyx_k_Group_postParse[] = "Group.postParse";
static const char __pyx_k_NullToken___str[] = "_NullToken.__str__";
static const char __pyx_k_OneOrMore___str[] = "OneOrMore.__str__";
static const char __pyx_k_OnlyOnce___call[] = "OnlyOnce.__call__";
static const char __pyx_k_OnlyOnce___init[] = "OnlyOnce.__init__";
static const char __pyx_k_Optional___init[] = "Optional.__init__";
static const char __pyx_k_ParseExpression[] = "ParseExpression";
static const char __pyx_k_Regex_parseImpl[] = "Regex.parseImpl";
static const char __pyx_k_White_parseImpl[] = "White.parseImpl";
static const char __pyx_k_ascii_lowercase[] = "ascii_lowercase";
static const char __pyx_k_ascii_uppercase[] = "ascii_uppercase";
static const char __pyx_k_checkPeerIndent[] = "checkPeerIndent";
static const char __pyx_k_cppStyleComment[] = "cppStyleComment";
static const char __pyx_k_dblQuotedString[] = "dblQuotedString";
static const char __pyx_k_dblSlashComment[] = "dblSlashComment";
static const char __pyx_k_endQuoteCharLen[] = "endQuoteCharLen";
static const char __pyx_k_exceptionAction[] = "exceptionAction";
static const char __pyx_k_illegal_nesting[] = "illegal nesting";
static const char __pyx_k_leaveWhitespace[] = "leaveWhitespace";
static const char __pyx_k_leaving_s_ret_r[] = "<<leaving %s (ret: %r)\n";
static const char __pyx_k_lineno_col_line[] = "lineno col line";
static const char __pyx_k_match_stringloc[] = "match_stringloc";
static const char __pyx_k_nextLevelIndent[] = "nextLevelIndent";
static const char __pyx_k_not_an_unindent[] = "not an unindent";
static const char __pyx_k_nullDebugAction[] = "nullDebugAction";
static const char __pyx_k_originalTextFor[] = "originalTextFor";
static const char __pyx_k_self_expr_parse[] = "self_expr_parse";
static const char __pyx_k_setDebugActions[] = "setDebugActions";
static const char __pyx_k_sglQuotedString[] = "sglQuotedString";
static const char __pyx_k_subRecCheckList[] = "subRecCheckList";
static const char __pyx_k_transformString[] = "transformString";
static const char __pyx_k_CharsNotIn___str[] = "CharsNotIn.__str__";
static const char __pyx_k_Exception_raised[] = "Exception raised:";
static const char __pyx_k_ForwardNoRecurse[] = "_ForwardNoRecurse";
static const char __pyx_k_Forward___lshift[] = "Forward.__lshift__";
static const char __pyx_k_Forward_validate[] = "Forward.validate";
static const char __pyx_k_ISO8601_datetime[] = "ISO8601 datetime";
static const char __pyx_k_LineStart___init[] = "LineStart.__init__";
static const char __pyx_k_MatchFirst___ior[] = "MatchFirst.__ior__";
static const char __pyx_k_MatchFirst___str[] = "MatchFirst.__str__";
static const char __pyx_k_NotAny_parseImpl[] = "NotAny.parseImpl";
static const char __pyx_k_NullToken___bool[] = "_NullToken.__bool__";
static const char __pyx_k_ParseResults_get[] = "ParseResults.get";
static const char __pyx_k_ParseResults_pop[] = "ParseResults.pop";
static const char __pyx_k_SkipTo_parseImpl[] = "SkipTo.parseImpl";
static const char __pyx_k_StringEnd___init[] = "StringEnd.__init__";
static const char __pyx_k_WordStart___init[] = "WordStart.__init__";
static const char __pyx_k_ZeroOrMore___str[] = "ZeroOrMore.__str__";
static const char __pyx_k_cache_size_limit[] = "cache_size_limit";
static const char __pyx_k_commonHTMLEntity[] = "commonHTMLEntity";
static const char __pyx_k_convertToInteger[] = "convertToInteger";
static const char __pyx_k_file_or_filename[] = "file_or_filename";
static const char __pyx_k_iso8601_datetime[] = "iso8601_datetime";
static const char __pyx_k_javaStyleComment[] = "javaStyleComment";
static const char __pyx_k_makeOptionalList[] = "makeOptionalList";
static const char __pyx_k_not_a_peer_entry[] = "not a peer entry";
static const char __pyx_k_parseElementList[] = "parseElementList";
static const char __pyx_k_pyparsing_common[] = "pyparsing_common";
static const char __pyx_k_signed_integer_2[] = "signed_integer";
static const char __pyx_k_traceParseAction[] = "traceParseAction";
static const char __pyx_k_C_style_comment_2[] = "C++ style comment";
static const char __pyx_k_CharsNotIn___init[] = "CharsNotIn.__init__";
static const char __pyx_k_CloseMatch___init[] = "CloseMatch.__init__";
static const char __pyx_k_Combine_postParse[] = "Combine.postParse";
static const char __pyx_k_FollowedBy___init[] = "FollowedBy.__init__";
static const char __pyx_k_Forward___ilshift[] = "Forward.__ilshift__";
static const char __pyx_k_GoToColumn___init[] = "GoToColumn.__init__";
static const char __pyx_k_Keyword_parseImpl[] = "Keyword.parseImpl";
static const char __pyx_k_LineEnd_parseImpl[] = "LineEnd.parseImpl";
static const char __pyx_k_Literal_parseImpl[] = "Literal.parseImpl";
static const char __pyx_k_MatchFirst___init[] = "MatchFirst.__init__";
static const char __pyx_k_NoMatch_parseImpl[] = "NoMatch.parseImpl";
static const char __pyx_k_Or_checkRecursion[] = "Or.checkRecursion";
static const char __pyx_k_ParseResults_copy[] = "ParseResults.copy";
static const char __pyx_k_ParseResults_dump[] = "ParseResults.dump";
static const char __pyx_k_ParseResults_keys[] = "ParseResults.keys";
static const char __pyx_k_Suppress_suppress[] = "Suppress.suppress";
static const char __pyx_k_Unmatchable_token[] = "Unmatchable token";
static const char __pyx_k_WordEnd_parseImpl[] = "WordEnd.parseImpl";
static const char __pyx_k_ZeroOrMore___init[] = "ZeroOrMore.__init__";
static const char __pyx_k_convertToDatetime[] = "convertToDatetime";
static const char __pyx_k_full_IPv6_address[] = "full IPv6 address";
static const char __pyx_k_full_ipv6_address[] = "_full_ipv6_address";
static const char __pyx_k_includeSeparators[] = "includeSeparators";
static const char __pyx_k_matchPreviousExpr[] = "matchPreviousExpr";
static const char __pyx_k_n_r_x_x_0_9a_fA_F[] = "\"(?:[^\"\\n\\r\\\\]|(?:\"\")|(?:\\\\(?:[^x]|x[0-9a-fA-F]+)))*";
static const char __pyx_k_parseElementClass[] = "parseElementClass";
static const char __pyx_k_parseElementTrace[] = "parseElementTrace";
static const char __pyx_k_replaceHTMLEntity[] = "replaceHTMLEntity";
static const char __pyx_k_singleArgBuiltins[] = "singleArgBuiltins";
static const char __pyx_k_And_checkRecursion[] = "And.checkRecursion";
static const char __pyx_k_Forward_streamline[] = "Forward.streamline";
static const char __pyx_k_No_match_found_for[] = "No match found for ";
static const char __pyx_k_Optional_parseImpl[] = "Optional.parseImpl";
static const char __pyx_k_ParseBaseException[] = "ParseBaseException";
static const char __pyx_k_ParseResults___add[] = "ParseResults.__add__";
static const char __pyx_k_ParseResults___dir[] = "ParseResults.__dir__";
static const char __pyx_k_ParseResults___len[] = "ParseResults.__len__";
static const char __pyx_k_ParseResults___new[] = "ParseResults.__new__";
static const char __pyx_k_ParseResults___str[] = "ParseResults.__str__";
static const char __pyx_k_ParseResults__name[] = "_ParseResults__name";
static const char __pyx_k_ParseResults_asXML[] = "ParseResults.asXML";
static const char __pyx_k_ParseResults_clear[] = "ParseResults.clear";
static const char __pyx_k_ParseResults_items[] = "ParseResults.items";
static const char __pyx_k_ParserElement___eq[] = "ParserElement.__eq__";
static const char __pyx_k_ParserElement___ne[] = "ParserElement.__ne__";
static const char __pyx_k_ParserElement___or[] = "ParserElement.__or__";
static const char __pyx_k_ParserElement_copy[] = "ParserElement.copy";
static const char __pyx_k_QuotedString___str[] = "QuotedString.__str__";
static const char __pyx_k_StringStart___init[] = "StringStart.__init__";
static const char __pyx_k_Suppress_postParse[] = "Suppress.postParse";
static const char __pyx_k_WRAP_CALL_LINE_NUM[] = "_WRAP_CALL_LINE_NUM";
static const char __pyx_k_blockStatementExpr[] = "blockStatementExpr";
static const char __pyx_k_commaSeparatedList[] = "commaSeparatedList";
static const char __pyx_k_common_HTML_entity[] = "common HTML entity";
static const char __pyx_k_literalStringClass[] = "_literalStringClass";
static const char __pyx_k_mixed_IPv6_address[] = "mixed IPv6 address";
static const char __pyx_k_mixed_ipv6_address[] = "_mixed_ipv6_address";
static const char __pyx_k_operatorPrecedence[] = "operatorPrecedence";
static const char __pyx_k_optionalNotMatched[] = "_optionalNotMatched";
static const char __pyx_k_packrat_cache_lock[] = "packrat_cache_lock";
static const char __pyx_k_pythonStyleComment[] = "pythonStyleComment";
static const char __pyx_k_setWhitespaceChars[] = "setWhitespaceChars";
static const char __pyx_k_short_IPv6_address[] = "short IPv6 address";
static const char __pyx_k_short_ipv6_address[] = "_short_ipv6_address";
static const char __pyx_k_tokenMap_locals_pa[] = "tokenMap.<locals>.pa";
static const char __pyx_k_verbose_stacktrace[] = "verbose_stacktrace";
static const char __pyx_k_0xa1_0xbf_0xd7_0xf7[] = "[\\0xa1-\\0xbf\\0xd7\\0xf7]";
static const char __pyx_k_DEFAULT_WHITE_CHARS[] = "DEFAULT_WHITE_CHARS";
static const char __pyx_k_Each_checkRecursion[] = "Each.checkRecursion";
static const char __pyx_k_GoToColumn_preParse[] = "GoToColumn.preParse";
static const char __pyx_k_LineStart_parseImpl[] = "LineStart.parseImpl";
static const char __pyx_k_ParseElementEnhance[] = "ParseElementEnhance";
static const char __pyx_k_ParseFatalException[] = "ParseFatalException";
static const char __pyx_k_ParseResults___bool[] = "ParseResults.__bool__";
static const char __pyx_k_ParseResults___iadd[] = "ParseResults.__iadd__";
static const char __pyx_k_ParseResults___init[] = "ParseResults.__init__";
static const char __pyx_k_ParseResults___iter[] = "ParseResults.__iter__";
static const char __pyx_k_ParseResults___radd[] = "ParseResults.__radd__";
static const char __pyx_k_ParseResults___repr[] = "ParseResults.__repr__";
static const char __pyx_k_ParseResults__modal[] = "_ParseResults__modal";
static const char __pyx_k_ParseResults_append[] = "ParseResults.append";
static const char __pyx_k_ParseResults_asDict[] = "ParseResults.asDict";
static const char __pyx_k_ParseResults_asList[] = "ParseResults.asList";
static const char __pyx_k_ParseResults_extend[] = "ParseResults.extend";
static const char __pyx_k_ParseResults_insert[] = "ParseResults.insert";
static const char __pyx_k_ParseResults_pprint[] = "ParseResults.pprint";
static const char __pyx_k_ParseResults_values[] = "ParseResults.values";
static const char __pyx_k_ParserElement___add[] = "ParserElement.__add__";
static const char __pyx_k_ParserElement___and[] = "ParserElement.__and__";
static const char __pyx_k_ParserElement___mul[] = "ParserElement.__mul__";
static const char __pyx_k_ParserElement___req[] = "ParserElement.__req__";
static const char __pyx_k_ParserElement___rne[] = "ParserElement.__rne__";
static const char __pyx_k_ParserElement___ror[] = "ParserElement.__ror__";
static const char __pyx_k_ParserElement___str[] = "ParserElement.__str__";
static const char __pyx_k_ParserElement___sub[] = "ParserElement.__sub__";
static const char __pyx_k_ParserElement___xor[] = "ParserElement.__xor__";
static const char __pyx_k_ParserElement_split[] = "ParserElement.split";
static const char __pyx_k_QuotedString___init[] = "QuotedString.__init__";
static const char __pyx_k_StringEnd_parseImpl[] = "StringEnd.parseImpl";
static const char __pyx_k_WordStart_parseImpl[] = "WordStart.parseImpl";
static const char __pyx_k_amp_gt_lt_quot_apos[] = "amp gt lt quot apos";
static const char __pyx_k_copyTokenToRepeater[] = "copyTokenToRepeater";
static const char __pyx_k_inlineLiteralsUsing[] = "inlineLiteralsUsing";
static const char __pyx_k_n_r_x_x_0_9a_fA_F_2[] = "'(?:[^'\\n\\r\\\\]|(?:'')|(?:\\\\(?:[^x]|x[0-9a-fA-F]+)))*";
static const char __pyx_k_oneOf_locals_lambda[] = "oneOf.<locals>.<lambda>";
static const char __pyx_k_originalParseMethod[] = "_originalParseMethod";
static const char __pyx_k_packrat_cache_stats[] = "packrat_cache_stats";
static const char __pyx_k_withAttribute___new[] = "withAttribute.__new__";
static const char __pyx_k_CharsNotIn_parseImpl[] = "CharsNotIn.parseImpl";
static const char __pyx_k_CloseMatch_parseImpl[] = "CloseMatch.parseImpl";
static const char __pyx_k_Expected_end_of_line[] = "Expected end of line";
static const char __pyx_k_Expected_end_of_text[] = "Expected end of text";
static const char __pyx_k_FollowedBy_parseImpl[] = "FollowedBy.parseImpl";
static const char __pyx_k_Found_unwanted_token[] = "Found unwanted token, ";
static const char __pyx_k_GoToColumn_parseImpl[] = "GoToColumn.parseImpl";
static const char __pyx_k_MatchFirst_parseImpl[] = "MatchFirst.parseImpl";
static const char __pyx_k_MultipleMatch___init[] = "_MultipleMatch.__init__";
static const char __pyx_k_ParseExpression_copy[] = "ParseExpression.copy";
static const char __pyx_k_ParseResults__asList[] = "_ParseResults__asList";
static const char __pyx_k_ParseResults__doinit[] = "_ParseResults__doinit";
static const char __pyx_k_ParseResults__lookup[] = "_ParseResults__lookup";
static const char __pyx_k_ParseResults__parent[] = "_ParseResults__parent";
static const char __pyx_k_ParseResults_getName[] = "ParseResults.getName";
static const char __pyx_k_ParseResults_haskeys[] = "ParseResults.haskeys";
static const char __pyx_k_ParseSyntaxException[] = "ParseSyntaxException";
static const char __pyx_k_ParserElement___call[] = "ParserElement.__call__";
static const char __pyx_k_ParserElement___hash[] = "ParserElement.__hash__";
static const char __pyx_k_ParserElement___init[] = "ParserElement.__init__";
static const char __pyx_k_ParserElement___radd[] = "ParserElement.__radd__";
static const char __pyx_k_ParserElement___rand[] = "ParserElement.__rand__";
static const char __pyx_k_ParserElement___repr[] = "ParserElement.__repr__";
static const char __pyx_k_ParserElement___rmul[] = "ParserElement.__rmul__";
static const char __pyx_k_ParserElement___rsub[] = "ParserElement.__rsub__";
static const char __pyx_k_ParserElement___rxor[] = "ParserElement.__rxor__";
static const char __pyx_k_ParserElement_ignore[] = "ParserElement.ignore";
static const char __pyx_k_PositionToken___init[] = "_PositionToken.__init__";
static const char __pyx_k_Python_style_comment[] = "Python style comment";
static const char __pyx_k_ZeroOrMore_parseImpl[] = "ZeroOrMore.parseImpl";
static const char __pyx_k_comma_separated_list[] = "comma separated list";
static const char __pyx_k_matchPreviousLiteral[] = "matchPreviousLiteral";
static const char __pyx_k_mustMatchTheseTokens[] = "mustMatchTheseTokens";
static const char __pyx_k_oneOf_locals_genexpr[] = "oneOf.<locals>.genexpr";
static const char __pyx_k_self_skip_ignorables[] = "self_skip_ignorables";
static const char __pyx_k_And__ErrorStop___init[] = "And._ErrorStop.__init__";
static const char __pyx_k_DEFAULT_KEYWORD_CHARS[] = "DEFAULT_KEYWORD_CHARS";
static const char __pyx_k_ParseExpression___str[] = "ParseExpression.__str__";
static const char __pyx_k_ParseResults___lookup[] = "ParseResults.__lookup";
static const char __pyx_k_ParseResults__tokdict[] = "_ParseResults__tokdict";
static const char __pyx_k_ParseResults__toklist[] = "_ParseResults__toklist";
static const char __pyx_k_ParserElement_matches[] = "ParserElement.matches";
static const char __pyx_k_ParserElement_setName[] = "ParserElement.setName";
static const char __pyx_k_StringStart_parseImpl[] = "StringStart.parseImpl";
static const char __pyx_k_TokenConverter___init[] = "TokenConverter.__init__";
static const char __pyx_k_copyDefaultWhiteChars[] = "copyDefaultWhiteChars";
static const char __pyx_k_countFieldParseAction[] = "countFieldParseAction";
static const char __pyx_k_entering_s_line_s_d_r[] = ">>entering %s(line: '%s', %d, %r)\n";
static const char __pyx_k_escCharReplacePattern[] = "escCharReplacePattern";
static const char __pyx_k_escapeRegexRangeChars[] = "_escapeRegexRangeChars";
static const char __pyx_k_leaving_s_exception_s[] = "<<leaving %s (exception: %s)\n";
static const char __pyx_k_nested_s_s_expression[] = "nested %s%s expression";
static const char __pyx_k_no_matching_attribute[] = "no matching attribute ";
static const char __pyx_k_printablesLessRAbrack[] = "printablesLessRAbrack";
static const char __pyx_k_srange_locals_genexpr[] = "srange.<locals>.genexpr";
static const char __pyx_k_ungroup_locals_lambda[] = "ungroup.<locals>.<lambda>";
static const char __pyx_k_CaselessKeyword___init[] = "CaselessKeyword.__init__";
static const char __pyx_k_CaselessLiteral___init[] = "CaselessLiteral.__init__";
static const char __pyx_k_Expected_start_of_line[] = "Expected start of line";
static const char __pyx_k_Expected_start_of_text[] = "Expected start of text";
static const char __pyx_k_ForwardNoRecurse___str[] = "_ForwardNoRecurse.__str__";
static const char __pyx_k_ParseExpression___init[] = "ParseExpression.__init__";
static const char __pyx_k_ParseExpression_append[] = "ParseExpression.append";
static const char __pyx_k_ParseExpression_ignore[] = "ParseExpression.ignore";
static const char __pyx_k_ParseResultsWithOffset[] = "_ParseResultsWithOffset";
static const char __pyx_k_ParseResults___delitem[] = "ParseResults.__delitem__";
static const char __pyx_k_ParseResults___getattr[] = "ParseResults.__getattr__";
static const char __pyx_k_ParseResults___getitem[] = "ParseResults.__getitem__";
static const char __pyx_k_ParseResults___setitem[] = "ParseResults.__setitem__";
static const char __pyx_k_ParseResults__iterkeys[] = "ParseResults._iterkeys";
static const char __pyx_k_ParserElement___invert[] = "ParserElement.__invert__";
static const char __pyx_k_ParserElement_preParse[] = "ParserElement.preParse";
static const char __pyx_k_ParserElement_runTests[] = "ParserElement.runTests";
static const char __pyx_k_ParserElement_setBreak[] = "ParserElement.setBreak";
static const char __pyx_k_ParserElement_setDebug[] = "ParserElement.setDebug";
static const char __pyx_k_ParserElement_suppress[] = "ParserElement.suppress";
static const char __pyx_k_ParserElement_tryParse[] = "ParserElement.tryParse";
static const char __pyx_k_ParserElement_validate[] = "ParserElement.validate";
static const char __pyx_k_QuotedString_parseImpl[] = "QuotedString.parseImpl";
static const char __pyx_k_comma_separated_list_2[] = "comma_separated_list";
static const char __pyx_k_makeTags_locals_lambda[] = "_makeTags.<locals>.<lambda>";
static const char __pyx_k_setDefaultKeywordChars[] = "setDefaultKeywordChars";
static const char __pyx_k_unicode_string_literal[] = "unicode string literal";
static const char __pyx_k_Forward_leaveWhitespace[] = "Forward.leaveWhitespace";
static const char __pyx_k_MultipleMatch_parseImpl[] = "_MultipleMatch.parseImpl";
static const char __pyx_k_ParseResults___contains[] = "ParseResults.__contains__";
static const char __pyx_k_ParseResults___getstate[] = "ParseResults.__getstate__";
static const char __pyx_k_ParseResults___reversed[] = "ParseResults.__reversed__";
static const char __pyx_k_ParseResults___setstate[] = "ParseResults.__setstate__";
static const char __pyx_k_ParseResults__iteritems[] = "ParseResults._iteritems";
static const char __pyx_k_ParserElement_parseFile[] = "ParserElement.parseFile";
static const char __pyx_k_ParserElement_parseImpl[] = "ParserElement.parseImpl";
static const char __pyx_k_ParserElement_postParse[] = "ParserElement.postParse";
static const char __pyx_k_defaultStartDebugAction[] = "_defaultStartDebugAction";
static const char __pyx_k_makeTags_locals_genexpr[] = "_makeTags.<locals>.genexpr";
static const char __pyx_k_pyparsing_common_lambda[] = "pyparsing_common.<lambda>";
static const char __pyx_k_srange_locals__expanded[] = "srange.<locals>._expanded";
static const char __pyx_k_Not_at_the_end_of_a_word[] = "Not at the end of a word";
static const char __pyx_k_ParseBaseException___dir[] = "ParseBaseException.__dir__";
static const char __pyx_k_ParseBaseException___str[] = "ParseBaseException.__str__";
static const char __pyx_k_ParseExpression_validate[] = "ParseExpression.validate";
static const char __pyx_k_ParseResults__accumNames[] = "_ParseResults__accumNames";
static const char __pyx_k_ParseResults__itervalues[] = "ParseResults._itervalues";
static const char __pyx_k_ParserElement__FifoCache[] = "ParserElement._FifoCache";
static const char __pyx_k_ParserElement_resetCache[] = "ParserElement.resetCache";
static const char __pyx_k_ParserElement_scanString[] = "ParserElement.scanString";
static const char __pyx_k_ParserElement_streamline[] = "ParserElement.streamline";
static const char __pyx_k_convertWhitespaceEscapes[] = "convertWhitespaceEscapes";
static const char __pyx_k_gt_lt_amp_nbsp_quot_apos[] = "gt lt amp nbsp quot apos";
static const char __pyx_k_nestedExpr_locals_lambda[] = "nestedExpr.<locals>.<lambda>";
static const char __pyx_k_s_at_char_d_line_d_col_d[] = "%s (at char %d), (line:%d, col:%d)";
static const char __pyx_k_self_failOn_canParseNext[] = "self_failOn_canParseNext";
static const char __pyx_k_self_ignoreExpr_tryParse[] = "self_ignoreExpr_tryParse";
static const char __pyx_k_trim_arity_locals_lambda[] = "_trim_arity.<locals>.<lambda>";
static const char __pyx_k_CaselessKeyword_parseImpl[] = "CaselessKeyword.parseImpl";
static const char __pyx_k_CaselessLiteral_parseImpl[] = "CaselessLiteral.parseImpl";
static const char __pyx_k_MatchFirst_checkRecursion[] = "MatchFirst.checkRecursion";
static const char __pyx_k_Or___str___locals_genexpr[] = "Or.__str__.<locals>.genexpr";
static const char __pyx_k_ParseBaseException___init[] = "ParseBaseException.__init__";
static const char __pyx_k_ParseBaseException___repr[] = "ParseBaseException.__repr__";
static const char __pyx_k_ParseElementEnhance___str[] = "ParseElementEnhance.__str__";
static const char __pyx_k_ParseExpression___getitem[] = "ParseExpression.__getitem__";
static const char __pyx_k_ParseResults___getnewargs[] = "ParseResults.__getnewargs__";
static const char __pyx_k_ParserElement__parseCache[] = "ParserElement._parseCache";
static const char __pyx_k_ParserElement_parseString[] = "ParserElement.parseString";
static const char __pyx_k_RecursiveGrammarException[] = "RecursiveGrammarException";
static const char __pyx_k_defaultSuccessDebugAction[] = "_defaultSuccessDebugAction";
static const char __pyx_k_locatedExpr_locals_lambda[] = "locatedExpr.<locals>.<lambda>";
static const char __pyx_k_replaceWith_locals_lambda[] = "replaceWith.<locals>.<lambda>";
static const char __pyx_k_setDefaultWhitespaceChars[] = "setDefaultWhitespaceChars";
static const char __pyx_k_traceParseAction_locals_z[] = "traceParseAction.<locals>.z";
static const char __pyx_k_trim_arity_locals_wrapper[] = "_trim_arity.<locals>.wrapper";
static const char __pyx_k_xml_escape_locals_genexpr[] = "_xml_escape.<locals>.genexpr";
static const char __pyx_k_And___str___locals_genexpr[] = "And.__str__.<locals>.genexpr";
static const char __pyx_k_Not_at_the_start_of_a_word[] = "Not at the start of a word";
static const char __pyx_k_Or___init___locals_genexpr[] = "Or.__init__.<locals>.genexpr";
static const char __pyx_k_Or_parseImpl_locals_lambda[] = "Or.parseImpl.<locals>.<lambda>";
static const char __pyx_k_ParseElementEnhance___init[] = "ParseElementEnhance.__init__";
static const char __pyx_k_ParseElementEnhance_ignore[] = "ParseElementEnhance.ignore";
static const char __pyx_k_ParseExpression_streamline[] = "ParseExpression.streamline";
static const char __pyx_k_ParseResults__asStringList[] = "ParseResults._asStringList";
static const char __pyx_k_ParserElement_addCondition[] = "ParserElement.addCondition";
static const char __pyx_k_ParserElement_canParseNext[] = "ParserElement.canParseNext";
static const char __pyx_k_ParserElement_searchString[] = "ParserElement.searchString";
static const char __pyx_k_countedArray_locals_lambda[] = "countedArray.<locals>.<lambda>";
static const char __pyx_k_And___init___locals_genexpr[] = "And.__init__.<locals>.genexpr";
static const char __pyx_k_Each___str___locals_genexpr[] = "Each.__str__.<locals>.genexpr";
static const char __pyx_k_ParserElement__parseNoCache[] = "ParserElement._parseNoCache";
static const char __pyx_k_ParserElement_enablePackrat[] = "ParserElement.enablePackrat";
static const char __pyx_k_ParserElement_parseWithTabs[] = "ParserElement.parseWithTabs";
static const char __pyx_k_ParserElement_setFailAction[] = "ParserElement.setFailAction";
static const char __pyx_k_RecursiveGrammarException_s[] = "RecursiveGrammarException: %s";
static const char __pyx_k_Text_not_in_expected_column[] = "Text not in expected column";
static const char __pyx_k_defaultExceptionDebugAction[] = "_defaultExceptionDebugAction";
static const char __pyx_k_Each___init___locals_genexpr[] = "Each.__init__.<locals>.genexpr";
static const char __pyx_k_ParseBaseException___getattr[] = "ParseBaseException.__getattr__";
static const char __pyx_k_ParseElementEnhance_validate[] = "ParseElementEnhance.validate";
static const char __pyx_k_ParserElement_addParseAction[] = "ParserElement.addParseAction";
static const char __pyx_k_ParserElement_checkRecursion[] = "ParserElement.checkRecursion";
static const char __pyx_k_ParserElement_setParseAction[] = "ParserElement.setParseAction";
static const char __pyx_k_ParserElement_setResultsName[] = "ParserElement.setResultsName";
static const char __pyx_k_Word___init___locals_genexpr[] = "Word.__init__.<locals>.genexpr";
static const char __pyx_k_trim_arity_locals_extract_tb[] = "_trim_arity.<locals>.extract_tb";
static const char __pyx_k_0xc0_0xd6_0xd8_0xf6_0xf8_0xff[] = "[\\0xc0-\\0xd6\\0xd8-\\0xf6\\0xf8-\\0xff]";
static const char __pyx_k_A_token_that_will_never_match[] = "\n    A token that will never match.\n    ";
static const char __pyx_k_Each_parseImpl_locals_genexpr[] = "Each.parseImpl.<locals>.genexpr";
static const char __pyx_k_ParseElementEnhance_parseImpl[] = "ParseElementEnhance.parseImpl";
static const char __pyx_k_ParseResultsWithOffset___init[] = "_ParseResultsWithOffset.__init__";
static const char __pyx_k_ParseResultsWithOffset___repr[] = "_ParseResultsWithOffset.__repr__";
static const char __pyx_k_ParserElement__UnboundedCache[] = "ParserElement._UnboundedCache.__init__.<locals>.get";
static const char __pyx_k_ParserElement__skipIgnorables[] = "ParserElement._skipIgnorables";
static const char __pyx_k_ParserElement_leaveWhitespace[] = "ParserElement.leaveWhitespace";
static const char __pyx_k_ParserElement_setDebugActions[] = "ParserElement.setDebugActions";
static const char __pyx_k_ParserElement_transformString[] = "ParserElement.transformString";
static const char __pyx_k_White___init___locals_genexpr[] = "White.__init__.<locals>.genexpr";
static const char __pyx_k_failed_user_defined_condition[] = "failed user-defined condition";
static const char __pyx_k_matched_token_not_at_column_d[] = "matched token not at column %d";
static const char __pyx_k_originalTextFor_locals_lambda[] = "originalTextFor.<locals>.<lambda>";
static const char __pyx_k_0_9a_fA_F_2_0_9a_fA_F_2_1_0_9a[] = "[0-9a-fA-F]{2}([:.-])[0-9a-fA-F]{2}(?:\\1[0-9a-fA-F]{2}){4}";
static const char __pyx_k_0_9a_fA_F_8_0_9a_fA_F_4_3_0_9a[] = "[0-9a-fA-F]{8}(-[0-9a-fA-F]{4}){3}-[0-9a-fA-F]{12}";
static const char __pyx_k_100_100_100_3_14159_6_02e23_1e[] = "\n        100\n        -100\n        +100\n        3.14159\n        6.02e23\n        1e-12\n        ";
static const char __pyx_k_A_variation_on_L_Literal_which[] = "\n    A variation on L{Literal} which matches \"close\" matches, that is,\n    strings with at most 'n' mismatching characters. C{CloseMatch} takes parameters:\n     - C{match_string} - string to be matched\n     - C{maxMismatches} - (C{default=1}) maximum number of mismatches allowed to count as a match\n\n    The results from a successful parse will contain the matched text from the input string and the following named results:\n     - C{mismatches} - a list of the positions within the match_string where mismatches were found\n     - C{original} - the original match_string used to compare against the input string\n\n    If C{mismatches} is an empty list, then the match was an exact match.\n\n    Example::\n        patt = CloseMatch(\"ATCATCGAATGGA\")\n        patt.parseString(\"ATCATCGAAXGGA\") # -> (['ATCATCGAAXGGA'], {'mismatches': [[9]], 'original': ['ATCATCGAATGGA']})\n        patt.parseString(\"ATCAXCGAAXGGA\") # -> Exception: Expected 'ATCATCGAATGGA' (with up to 1 mismatches) (at char 0), (line:1, col:1)\n\n        # exact match\n        patt.parseString(\"ATCATCGAATGGA\") # -> (['ATCATCGAATGGA'], {'mismatches': [[]], 'original': ['ATCATCGAATGGA']})\n\n        # close match allowing up to 2 mismatches\n        patt = CloseMatch(\"ATCATCGAATGGA\", maxMismatches=2)\n        patt.parseString(\"ATCAXCGAAXGGA\") # -> (['ATCAXCGAAXGGA'], {'mismatches': [[4, 9]], 'original': ['ATCATCGAATGGA']})\n    ";
static const char __pyx_k_Here_are_some_common_low_level[] = "\n    Here are some common low-level expressions that may be useful in jump-starting parser development:\n     - numeric forms (L{integers<integer>}, L{reals<real>}, L{scientific notation<sci_real>})\n     - common L{programming identifiers<identifier>}\n     - network addresses (L{MAC<mac_address>}, L{IPv4<ipv4_address>}, L{IPv6<ipv6_address>})\n     - ISO8601 L{dates<iso8601_date>} and L{datetime<iso8601_datetime>}\n     - L{UUID<uuid>}\n     - L{comma-separated list<comma_separated_list>}\n    Parse actions:\n     - C{L{convertToInteger}}\n     - C{L{convertToFloat}}\n     - C{L{convertToDate}}\n     - C{L{convertToDatetime}}\n     - C{L{stripHTMLTags}}\n     - C{L{upcaseTokens}}\n     - C{L{downcaseTokens}}\n\n    Example::\n        pyparsing_common.number.runTests('''\n            # any int or real number, returned as the appropriate type\n            100\n            -100\n            +100\n            3.14159\n            6.02e23\n            1e-12\n            ''')\n\n        pyparsing_common.fnumber.runTests('''\n            # any int or real number, returned as float\n            100\n            -100\n            +100\n            3.14159\n            6.02e23\n            1e-12\n            ''')\n\n        pyparsing_common.hex_integer.runTests('''\n            # hex numbers\n            100\n            FF\n            ''')\n\n        pyparsing_common.fraction.runTests('''\n            # fractions\n            1/2\n            -3/4\n            ''')\n\n        pyparsing_common.mixed_integer.runTests('''\n            # mixed fractions\n            1\n            1/2\n            -3/4\n            1-3/4\n            ''')\n\n        import uuid\n        pyparsing_common.uuid.setParseAction(tokenMap(uuid.UUID))\n        pyparsing_common.uuid.runTests('''\n            # uuid\n            12345678-1234-5678-1234-567812345678\n            ''')\n    prints::\n        # any int or real number, returned as the appropriate type\n        100\n        [100]\n\n       "" -100\n        [-100]\n\n        +100\n        [100]\n\n        3.14159\n        [3.14159]\n\n        6.02e23\n        [6.02e+23]\n\n        1e-12\n        [1e-12]\n\n        # any int or real number, returned as float\n        100\n        [100.0]\n\n        -100\n        [-100.0]\n\n        +100\n        [100.0]\n\n        3.14159\n        [3.14159]\n\n        6.02e23\n        [6.02e+23]\n\n        1e-12\n        [1e-12]\n\n        # hex numbers\n        100\n        [256]\n\n        FF\n        [255]\n\n        # fractions\n        1/2\n        [0.5]\n\n        -3/4\n        [-0.75]\n\n        # mixed fractions\n        1\n        [1]\n\n        1/2\n        [0.5]\n\n        -3/4\n        [-0.75]\n\n        1-3/4\n        [1.75]\n\n        # uuid\n        12345678-1234-5678-1234-567812345678\n        [UUID('12345678-1234-5678-1234-567812345678')]\n    ";
static const char __pyx_k_Keyword_setDefaultKeywordChars[] = "Keyword.setDefaultKeywordChars";
static const char __pyx_k_Lookahead_to_disallow_matching[] = "\n    Lookahead to disallow matching with the given parse expression.  C{NotAny}\n    does I{not} advance the parsing position within the input string, it only\n    verifies that the specified parse expression does I{not} match at the current\n    position.  Also, C{NotAny} does I{not} skip over leading whitespace. C{NotAny}\n    always returns a null token list.  May be constructed using the '~' operator.\n\n    Example::\n\n    ";
static const char __pyx_k_Matches_if_current_position_is[] = "\n    Matches if current position is at the beginning of a line within the parse string\n\n    Example::\n\n        test = '''        AAA this line\n        AAA and this line\n          AAA but not this one\n        B AAA and definitely not this one\n        '''\n\n        for t in (LineStart() + 'AAA' + restOfLine).searchString(test):\n            print(t)\n\n    Prints::\n        ['AAA', ' this line']\n        ['AAA', ' and this line']\n\n    ";
static const char __pyx_k_Optional_matching_of_the_given[] = "\n    Optional matching of the given expression.\n\n    Parameters:\n     - expr - expression that must match zero or more times\n     - default (optional) - value to be returned if the optional expression is not found.\n\n    Example::\n        # US postal code can be a 5-digit zip, plus optional 4-digit qualifier\n        zip = Combine(Word(nums, exact=5) + Optional('-' + Word(nums, exact=4)))\n        zip.runTests('''\n            # traditional ZIP code\n            12345\n\n            # ZIP+4 form\n            12101-0001\n\n            # invalid ZIP\n            98765-\n            ''')\n    prints::\n        # traditional ZIP code\n        12345\n        ['12345']\n\n        # ZIP+4 form\n        12101-0001\n        ['12101-0001']\n\n        # invalid ZIP\n        98765-\n             ^\n        FAIL: Expected end of text (at char 5), (line:1, col:6)\n    ";
static const char __pyx_k_Optional_repetition_of_zero_or[] = "\n    Optional repetition of zero or more of the given expression.\n\n    Parameters:\n     - expr - expression that must match zero or more times\n     - stopOn - (default=C{None}) - expression for a terminating sentinel\n          (only required if the sentinel would ordinarily match the repetition\n          expression)\n\n    Example: similar to L{OneOrMore}\n    ";
static const char __pyx_k_P_year_d_4_P_month_d_d_P_day_d[] = "(?P<year>\\d{4})(?:-(?P<month>\\d\\d)(?:-(?P<day>\\d\\d))?)?";
static const char __pyx_k_ParseElementEnhance_streamline[] = "ParseElementEnhance.streamline";
static const char __pyx_k_ParseExpression_setResultsName[] = "ParseExpression.setResultsName";
static const char __pyx_k_Token_to_advance_to_a_specific[] = "\n    Token to advance to a specific column of input text; useful for tabular report scraping.\n    ";
static const char __pyx_k_Word___str___locals_charsAsStr[] = "Word.__str__.<locals>.charsAsStr";
static const char __pyx_k_pyparsing_common_convertToDate[] = "pyparsing_common.convertToDate";
static const char __pyx_k_pyparsing_common_stripHTMLTags[] = "pyparsing_common.stripHTMLTags";
static const char __pyx_k_12345678_1234_5678_1234_5678123[] = "\n        12345678-1234-5678-1234-567812345678\n        ";
static const char __pyx_k_25_0_5_2_0_4_0_9_1_0_9_1_2_25_0[] = "(25[0-5]|2[0-4][0-9]|1?[0-9]{1,2})(\\.(25[0-5]|2[0-4][0-9]|1?[0-9]{1,2})){3}";
static const char __pyx_k_Abstract_C_ParserElement_subcla[] = "\n    Abstract C{ParserElement} subclass, for defining atomic matching patterns.\n    ";
static const char __pyx_k_Abstract_subclass_of_C_ParseExp[] = "\n    Abstract subclass of C{ParseExpression}, for converting parsed results.\n    ";
static const char __pyx_k_Abstract_subclass_of_C_ParserEl[] = "\n    Abstract subclass of C{ParserElement}, for combining and post-processing parsed tokens.\n    ";
static const char __pyx_k_Abstract_subclass_of_ParserElem[] = "\n    Abstract subclass of ParserElement, for combining and post-processing parsed tokens.\n    ";
static const char __pyx_k_An_empty_token_will_always_matc[] = "\n    An empty token, will always match.\n    ";
static const char __pyx_k_Caseless_version_of_L_Keyword_E[] = "\n    Caseless version of L{Keyword}.\n\n    Example::\n        OneOrMore(CaselessKeyword(\"CMD\")).parseString(\"cmd CMD Cmd10\") # -> ['CMD', 'CMD']\n\n    (Contrast with example for L{CaselessLiteral}.)\n    ";
static const char __pyx_k_Converter_for_ignoring_the_resu[] = "\n    Converter for ignoring the results of a parsed expression.\n\n    Example::\n        source = \"a, b, c,d\"\n        wd = Word(alphas)\n        wd_list1 = wd + ZeroOrMore(',' + wd)\n        print(wd_list1.parseString(source))\n\n        # often, delimiters that are useful during parsing are just in the\n        # way afterward - use Suppress to keep them out of the parsed output\n        wd_list2 = wd + ZeroOrMore(Suppress(',') + wd)\n        print(wd_list2.parseString(source))\n    prints::\n        ['a', ',', 'b', ',', 'c', ',', 'd']\n        ['a', 'b', 'c', 'd']\n    (See also L{delimitedList}.)\n    ";
static const char __pyx_k_Converter_to_concatenate_all_ma[] = "\n    Converter to concatenate all matching tokens to a single string.\n    By default, the matching patterns must also be contiguous in the input string;\n    this can be disabled by specifying C{'adjacent=False'} in the constructor.\n\n    Example::\n        real = Word(nums) + '.' + Word(nums)\n        print(real.parseString('3.1416')) # -> ['3', '.', '1416']\n        # will also erroneously match the following\n        print(real.parseString('3. 1416')) # -> ['3', '.', '1416']\n\n        real = Combine(Word(nums) + '.' + Word(nums))\n        print(real.parseString('3.1416')) # -> ['3.1416']\n        # no match when there are internal spaces\n        print(real.parseString('3. 1416')) # -> Exception: Expected W:(0123...)\n    ";
static const char __pyx_k_Converter_to_return_a_repetitiv[] = "\n    Converter to return a repetitive expression as a list, but also as a dictionary.\n    Each element can also be referenced using the first token in the expression as its key.\n    Useful for tabular report scraping when the first column can be used as a item key.\n\n    Example::\n        data_word = Word(alphas)\n        label = data_word + FollowedBy(':')\n        attr_expr = Group(label + Suppress(':') + OneOrMore(data_word).setParseAction(' '.join))\n\n        text = \"shape: SQUARE posn: upper left color: light blue texture: burlap\"\n        attr_expr = (label + Suppress(':') + OneOrMore(data_word, stopOn=label).setParseAction(' '.join))\n\n        # print attributes as plain groups\n        print(OneOrMore(attr_expr).parseString(text).dump())\n\n        # instead of OneOrMore(expr), parse using Dict(OneOrMore(Group(expr))) - Dict will auto-assign names\n        result = Dict(OneOrMore(Group(attr_expr))).parseString(text)\n        print(result.dump())\n\n        # access named fields as dict entries, or output as dict\n        print(result['shape'])\n        print(result.asDict())\n    prints::\n        ['shape', 'SQUARE', 'posn', 'upper left', 'color', 'light blue', 'texture', 'burlap']\n\n        [['shape', 'SQUARE'], ['posn', 'upper left'], ['color', 'light blue'], ['texture', 'burlap']]\n        - color: light blue\n        - posn: upper left\n        - shape: SQUARE\n        - texture: burlap\n        SQUARE\n        {'color': 'light blue', 'posn': 'upper left', 'texture': 'burlap', 'shape': 'SQUARE'}\n    See more examples at L{ParseResults} of accessing fields by results name.\n    ";
static const char __pyx_k_Converter_to_return_the_matched[] = "\n    Converter to return the matched tokens as a list - useful for returning tokens of C{L{ZeroOrMore}} and C{L{OneOrMore}} expressions.\n\n    Example::\n        ident = Word(alphas)\n        num = Word(nums)\n        term = ident | num\n        func = ident + Optional(delimitedList(term))\n        print(func.parseString(\"fn a,b,100\"))  # -> ['fn', 'a', 'b', '100']\n\n        func = ident + Group(Optional(delimitedList(term)))\n        print(func.parseString(\"fn a,b,100\"))  # -> ['fn', ['a', 'b', '100']]\n    ";
static const char __pyx_k_Exception_thrown_when_parse_exp[] = "\n    Exception thrown when parse expressions don't match class;\n    supported attributes by name are:\n     - lineno - returns the line number of the exception text\n     - col - returns the column number of the exception text\n     - line - returns the line containing the exception text\n\n    Example::\n        try:\n            Word(nums).setName(\"integer\").parseString(\"ABC\")\n        except ParseException as pe:\n            print(pe)\n            print(\"column: {}\".format(pe.col))\n\n    prints::\n       Expected integer (at char 0), (line:1, col:1)\n        column: 1\n    ";
static const char __pyx_k_Forward_declaration_of_an_expre[] = "\n    Forward declaration of an expression to be defined later -\n    used for recursive grammars, such as algebraic infix notation.\n    When the expression is known, it is assigned to the C{Forward} variable using the '<<' operator.\n\n    Note: take care when assigning to C{Forward} not to overlook precedence of operators.\n    Specifically, '|' has a lower precedence than '<<', so that::\n        fwdExpr << a | b | c\n    will actually be evaluated as::\n        (fwdExpr << a) | b | c\n    thereby leaving b and c out as parseable alternatives.  It is recommended that you\n    explicitly group the values inserted into the C{Forward}::\n        fwdExpr << (a | b | c)\n    Converting to use the '<<=' operator instead will avoid this problem.\n\n    See L{ParseResults.pprint} for an example of a recursive parser created using\n    C{Forward}.\n    ";
static const char __pyx_k_Helper_to_create_a_validating_p[] = "\n    Helper to create a validating parse action to be used with start tags created\n    with C{L{makeXMLTags}} or C{L{makeHTMLTags}}. Use C{withAttribute} to qualify a starting tag\n    with a required attribute value, to avoid false matches on common tags such as\n    C{<TD>} or C{<DIV>}.\n\n    Call C{withAttribute} with a series of attribute names and values. Specify the list\n    of filter attributes names and values as:\n     - keyword arguments, as in C{(align=\"right\")}, or\n     - as an explicit dict with C{**} operator, when an attribute name is also a Python\n          reserved word, as in C{**{\"class\":\"Customer\", \"align\":\"right\"}}\n     - a list of name-value tuples, as in ( (\"ns1:class\", \"Customer\"), (\"ns2:align\",\"right\") )\n    For attribute names with a namespace prefix, you must use the second form.  Attribute\n    names are matched insensitive to upper/lower case.\n\n    If just testing for C{class} (with or without a namespace), use C{L{withClass}}.\n\n    To verify that the attribute exists, but without specifying a value, pass\n    C{withAttribute.ANY_VALUE} as the value.\n\n    Example::\n        html = '''\n            <div>\n            Some text\n            <div type=\"grid\">1 4 0 1 0</div>\n            <div type=\"graph\">1,3 2,3 1,1</div>\n            <div>this has no type</div>\n            </div>\n\n        '''\n        div,div_end = makeHTMLTags(\"div\")\n\n        # only match div tag having a type attribute with value \"grid\"\n        div_grid = div().setParseAction(withAttribute(type=\"grid\"))\n        grid_expr = div_grid + SkipTo(div | div_end)(\"body\")\n        for grid_header in grid_expr.searchString(html):\n            print(grid_header.body)\n\n        # construct a match with any div tag having a type attribute, regardless of the value\n        div_any_type = div().setParseAction(withAttribute(type=withAttribute.ANY_VALUE))\n        div_expr = div_any_type + SkipTo(div | div_end)(\"body\")\n        for di""v_header in div_expr.searchString(html):\n            print(div_header.body)\n    prints::\n        1 4 0 1 0\n\n        1 4 0 1 0\n        1,3 2,3 1,1\n    ";
static const char __pyx_k_Lookahead_matching_of_the_given[] = "\n    Lookahead matching of the given parse expression.  C{FollowedBy}\n    does I{not} advance the parsing position within the input string, it only\n    verifies that the specified parse expression matches at the current\n    position.  C{FollowedBy} always returns a null token list.\n\n    Example::\n        # use FollowedBy to match a label only if it is followed by a ':'\n        data_word = Word(alphas)\n        label = data_word + FollowedBy(':')\n        attr_expr = Group(label + Suppress(':') + OneOrMore(data_word, stopOn=label).setParseAction(' '.join))\n\n        OneOrMore(attr_expr).parseString(\"shape: SQUARE color: BLACK posn: upper left\").pprint()\n    prints::\n        [['shape', 'SQUARE'], ['color', 'BLACK'], ['posn', 'upper left']]\n    ";
static const char __pyx_k_Matches_if_the_current_position[] = "\n    Matches if the current position is at the beginning of a Word, and\n    is not preceded by any character in a given set of C{wordChars}\n    (default=C{printables}). To emulate the C{\010} behavior of regular expressions,\n    use C{WordStart(alphanums)}. C{WordStart} will also match at the beginning of\n    the string being parsed, or at the beginning of a line.\n    ";
static const char __pyx_k_ParseExpression___init___locals[] = "ParseExpression.__init__.<locals>.genexpr";
static const char __pyx_k_ParseExpression_leaveWhitespace[] = "ParseExpression.leaveWhitespace";
static const char __pyx_k_ParseResultsWithOffset___getite[] = "_ParseResultsWithOffset.__getitem__";
static const char __pyx_k_ParseResultsWithOffset_setOffse[] = "_ParseResultsWithOffset.setOffset";
static const char __pyx_k_ParseResults__itervalues_locals[] = "ParseResults._itervalues.<locals>.genexpr";
static const char __pyx_k_ParserElement__FifoCache___init[] = "ParserElement._FifoCache.__init__.<locals>.get";
static const char __pyx_k_ParserElement__UnboundedCache_2[] = "ParserElement._UnboundedCache.__init__.<locals>.set";
static const char __pyx_k_ParserElement__UnboundedCache_3[] = "ParserElement._UnboundedCache.__init__.<locals>.clear";
static const char __pyx_k_ParserElement__UnboundedCache_4[] = "ParserElement._UnboundedCache.__init__.<locals>.cache_len";
static const char __pyx_k_ParserElement__UnboundedCache_5[] = "ParserElement._UnboundedCache";
static const char __pyx_k_ParserElement__UnboundedCache_6[] = "ParserElement._UnboundedCache.__init__";
static const char __pyx_k_RecursiveGrammarException___str[] = "RecursiveGrammarException.__str__";
static const char __pyx_k_Repetition_of_one_or_more_of_th[] = "\n    Repetition of one or more of the given expression.\n\n    Parameters:\n     - expr - expression that must match one or more times\n     - stopOn - (default=C{None}) - expression for a terminating sentinel\n          (only required if the sentinel would ordinarily match the repetition\n          expression)\n\n    Example::\n        data_word = Word(alphas)\n        label = data_word + FollowedBy(':')\n        attr_expr = Group(label + Suppress(':') + OneOrMore(data_word).setParseAction(' '.join))\n\n        text = \"shape: SQUARE posn: upper left color: BLACK\"\n        OneOrMore(attr_expr).parseString(text).pprint()  # Fail! read 'color' as data instead of next label -> [['shape', 'SQUARE color']]\n\n        # use stopOn attribute for OneOrMore to avoid reading label string as part of the data\n        attr_expr = Group(label + Suppress(':') + OneOrMore(data_word, stopOn=label).setParseAction(' '.join))\n        OneOrMore(attr_expr).parseString(text).pprint() # Better -> [['shape', 'SQUARE'], ['posn', 'upper left'], ['color', 'BLACK']]\n\n        # could also be written as\n        (attr_expr * (1,)).parseString(text).pprint()\n    ";
static const char __pyx_k_Requires_all_given_C_ParseExpre[] = "\n    Requires all given C{ParseExpression}s to be found in the given order.\n    Expressions may be separated by whitespace.\n    May be constructed using the C{'+'} operator.\n    May also be constructed using the C{'-'} operator, which will suppress backtracking.\n\n    Example::\n        integer = Word(nums)\n        name_expr = OneOrMore(Word(alphas))\n\n        expr = And([integer(\"id\"),name_expr(\"name\"),integer(\"age\")])\n        # more easily written as:\n        expr = integer(\"id\") + name_expr(\"name\") + integer(\"age\")\n    ";
static const char __pyx_k_Requires_that_at_least_one_C_Pa[] = "\n    Requires that at least one C{ParseExpression} is found.\n    If two expressions match, the expression that matches the longest string will be used.\n    May be constructed using the C{'^'} operator.\n\n    Example::\n        # construct Or using '^' operator\n\n        number = Word(nums) ^ Combine(Word(nums) + '.' + Word(nums))\n        print(number.searchString(\"123 3.1416 789\"))\n    prints::\n        [['123'], ['3.1416'], ['789']]\n    ";
static const char __pyx_k_Special_matching_class_for_matc[] = "\n    Special matching class for matching whitespace.  Normally, whitespace is ignored\n    by pyparsing grammars.  This class is included when some whitespace structures\n    are significant.  Define with a string containing the whitespace characters to be\n    matched; default is C{\" \\t\\r\\n\"}.  Also takes optional C{min}, C{max}, and C{exact} arguments,\n    as defined for the C{L{Word}} class.\n    ";
static const char __pyx_k_Structured_parse_results_to_pro[] = "\n    Structured parse results, to provide multiple means of access to the parsed data:\n       - as a list (C{len(results)})\n       - by list index (C{results[0], results[1]}, etc.)\n       - by attribute (C{results.<resultsName>} - see L{ParserElement.setResultsName})\n\n    Example::\n        integer = Word(nums)\n        date_str = (integer.setResultsName(\"year\") + '/'\n                        + integer.setResultsName(\"month\") + '/'\n                        + integer.setResultsName(\"day\"))\n        # equivalent form:\n        # date_str = integer(\"year\") + '/' + integer(\"month\") + '/' + integer(\"day\")\n\n        # parseString returns a ParseResults object\n        result = date_str.parseString(\"1999/12/31\")\n\n        def test(s, fn=repr):\n            print(\"%s -> %s\" % (s, fn(eval(s))))\n        test(\"list(result)\")\n        test(\"result[0]\")\n        test(\"result['month']\")\n        test(\"result.day\")\n        test(\"'month' in result\")\n        test(\"'minutes' in result\")\n        test(\"result.dump()\", str)\n    prints::\n        list(result) -> ['1999', '/', '12', '/', '31']\n        result[0] -> '1999'\n        result['month'] -> '12'\n        result.day -> '31'\n        'month' in result -> True\n        'minutes' in result -> False\n        result.dump() -> ['1999', '/', '12', '/', '31']\n        - day: 31\n        - month: 12\n        - year: 1999\n    ";
static const char __pyx_k_Token_for_matching_strings_that[] = "\n    Token for matching strings that match a given regular expression.\n    Defined with string specifying the regular expression in a form recognized by the inbuilt Python re module.\n    If the given regex contains named groups (defined using C{(?P<name>...)}), these will be preserved as\n    named parse results.\n\n    Example::\n        realnum = Regex(r\"[+-]?\\d+\\.\\d*\")\n        date = Regex(r'(?P<year>\\d{4})-(?P<month>\\d\\d?)-(?P<day>\\d\\d?)')\n        # ref: http://stackoverflow.com/questions/267399/how-do-you-match-only-valid-roman-numerals-with-a-regular-expression\n        roman = Regex(r\"M{0,4}(CM|CD|D?C{0,3})(XC|XL|L?X{0,3})(IX|IV|V?I{0,3})\")\n    ";
static const char __pyx_k_Token_for_matching_words_compos[] = "\n    Token for matching words composed of allowed character sets.\n    Defined with string containing all allowed initial characters,\n    an optional string containing allowed body characters (if omitted,\n    defaults to the initial character set), and an optional minimum,\n    maximum, and/or exact length.  The default value for C{min} is 1 (a\n    minimum value < 1 is not valid); the default values for C{max} and C{exact}\n    are 0, meaning no maximum or exact length restriction. An optional\n    C{excludeChars} parameter can list characters that might be found in\n    the input C{bodyChars} string; useful to define a word of all printables\n    except for one or two characters, for instance.\n\n    L{srange} is useful for defining custom character set strings for defining\n    C{Word} expressions, using range notation from regular expression character sets.\n\n    A common mistake is to use C{Word} to match a specific literal string, as in\n    C{Word(\"Address\")}. Remember that C{Word} uses the string argument to define\n    I{sets} of matchable characters. This expression would match \"Add\", \"AAA\",\n    \"dAred\", or any other word made up of the characters 'A', 'd', 'r', 'e', and 's'.\n    To match an exact literal string, use L{Literal} or L{Keyword}.\n\n    pyparsing includes helper strings for building Words:\n     - L{alphas}\n     - L{nums}\n     - L{alphanums}\n     - L{hexnums}\n     - L{alphas8bit} (alphabetic characters in ASCII range 128-255 - accented, tilded, umlauted, etc.)\n     - L{punc8bit} (non-alphabetic characters in ASCII range 128-255 - currency, symbols, superscripts, diacriticals, etc.)\n     - L{printables} (any non-whitespace character)\n\n    Example::\n        # a word composed of digits\n        integer = Word(nums) # equivalent to Word(\"0123456789\") or Word(srange(\"0-9\"))\n\n        # a word with a leading capital, and zero or more lowercase\n        capital_word = Word(alphas.upper(), alphas.lower())\n\n        # hostn""ames are alphanumeric, with leading alpha, and '-'\n        hostname = Word(alphas, alphanums+'-')\n\n        # roman numeral (not a strict parser, accepts invalid mix of characters)\n        roman = Word(\"IVXLCDM\")\n\n        # any string of non-whitespace characters, except for ','\n        csv_value = Word(printables, excludeChars=\",\")\n    ";
static const char __pyx_k_Token_for_skipping_over_all_und[] = "\n    Token for skipping over all undefined text until the matched expression is found.\n\n    Parameters:\n     - expr - target expression marking the end of the data to be skipped\n     - include - (default=C{False}) if True, the target expression is also parsed\n          (the skipped text and target expression are returned as a 2-element list).\n     - ignore - (default=C{None}) used to define grammars (typically quoted strings and\n          comments) that might contain false matches to the target expression\n     - failOn - (default=C{None}) define expressions that are not allowed to be\n          included in the skipped test; if found before the target expression is found,\n          the SkipTo is not a match\n\n    Example::\n        report = '''\n            Outstanding Issues Report - 1 Jan 2000\n\n               # | Severity | Description                               |  Days Open\n            -----+----------+-------------------------------------------+-----------\n             101 | Critical | Intermittent system crash                 |          6\n              94 | Cosmetic | Spelling error on Login ('log|n')         |         14\n              79 | Minor    | System slow when running too many reports |         47\n            '''\n        integer = Word(nums)\n        SEP = Suppress('|')\n        # use SkipTo to simply match everything up until the next SEP\n        # - ignore quoted strings, so that a '|' character inside a quoted string does not match\n        # - parse action will call token.strip() for each matched token, i.e., the description body\n        string_data = SkipTo(SEP, ignore=quotedString)\n        string_data.setParseAction(tokenMap(str.strip))\n        ticket_expr = (integer(\"issue_num\") + SEP\n                      + string_data(\"sev\") + SEP\n                      + string_data(\"desc\") + SEP\n                      + integer(\"days_open\"))\n\n        for tkt in ticket_expr.searchString(report):\n            print tkt.dump()""\n    prints::\n        ['101', 'Critical', 'Intermittent system crash', '6']\n        - days_open: 6\n        - desc: Intermittent system crash\n        - issue_num: 101\n        - sev: Critical\n        ['94', 'Cosmetic', \"Spelling error on Login ('log|n')\", '14']\n        - days_open: 14\n        - desc: Spelling error on Login ('log|n')\n        - issue_num: 94\n        - sev: Cosmetic\n        ['79', 'Minor', 'System slow when running too many reports', '47']\n        - days_open: 47\n        - desc: System slow when running too many reports\n        - issue_num: 79\n        - sev: Minor\n    ";
static const char __pyx_k_Token_to_exactly_match_a_specif[] = "\n    Token to exactly match a specified string.\n\n    Example::\n        Literal('blah').parseString('blah')  # -> ['blah']\n        Literal('blah').parseString('blahfooblah')  # -> ['blah']\n        Literal('blah').parseString('bla')  # -> Exception: Expected \"blah\"\n\n    For case-insensitive matching, use L{CaselessLiteral}.\n\n    For keyword matching (force word break before and after the matched string),\n    use L{Keyword} or L{CaselessKeyword}.\n    ";
static const char __pyx_k_Token_to_match_a_specified_stri[] = "\n    Token to match a specified string, ignoring case of letters.\n    Note: the matched results will always be in the case of the given\n    match string, NOT the case of the input text.\n\n    Example::\n        OneOrMore(CaselessLiteral(\"CMD\")).parseString(\"cmd CMD Cmd10\") # -> ['CMD', 'CMD', 'CMD']\n\n    (Contrast with example for L{CaselessKeyword}.)\n    ";
static const char __pyx_k_Wrapper_for_parse_actions_to_en[] = "\n    Wrapper for parse actions, to ensure they are only called once.\n    ";
static const char __pyx_k_as_column_list_and_dotted_table[] = "\n        # '*' as column list and dotted table name\n        select * from SYS.XYZZY\n\n        # caseless match on \"SELECT\", and casts back to \"select\"\n        SELECT * from XYZZY, ABC\n\n        # list of column names, and mixed case SELECT keyword\n        Select AA,BB,CC from Sys.dual\n\n        # multiple tables\n        Select A, B, C from Sys.dual, Table2\n\n        # invalid SELECT keyword - should fail\n        Xelect A, B, C from Sys.dual\n\n        # incomplete command - should fail\n        Select\n\n        # invalid column name - should fail\n        Select ^^^ frox Sys.dual\n\n        ";
static const char __pyx_k_attribute_s_has_value_s_must_be[] = "attribute '%s' has value '%s', must be '%s'";
static const char __pyx_k_cPyparsing_is_an_alternative_im[] = "\ncPyparsing is an alternative implementation of pyparsing in Cython.\n\ncPyparsing is a module by Evan Hubinger released under the Apache 2.0 license.\n\ncPyparsing is based on pyparsing; copyright notice included below:\n\nCopyright (c) 2003-2016  Paul T. McGuire\n\nPermission is hereby granted, free of charge, to any person obtaining\na copy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.\nIN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY\nCLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,\nTORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE\nSOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.\n";
static const char __pyx_k_cannot_specify_a_minimum_length[] = "cannot specify a minimum length < 1; use Optional(Word()) if zero-length word is permitted";
static const char __pyx_k_home_travis_build_evhub_cpypars[] = "/home/travis/build/evhub/cpyparsing/cPyparsing.pyx";
static const char __pyx_k_just_like_L_ParseFatalException[] = "just like L{ParseFatalException}, but thrown internally when an\n       L{ErrorStop<And._ErrorStop>} ('-' operator) indicates that parsing is to stop\n       immediately because an unbacktrackable syntax error has been found";
static const char __pyx_k_matchOnlyAtCol_locals_verifyCol[] = "matchOnlyAtCol.<locals>.verifyCol";
static const char __pyx_k_null_string_passed_to_Regex_use[] = "null string passed to Regex; use Empty() instead";
static const char __pyx_k_operator_must_be_unary_1_binary[] = "operator must be unary (1), binary (2), or ternary (3)";
static const char __pyx_k_operator_must_indicate_right_or[] = "operator must indicate right or left associativity";
static const char __pyx_k_user_throwable_exception_thrown[] = "user-throwable exception thrown when inconsistent parse content\n       is found; stops all parsing immediately";
static const char __pyx_k_withAttribute___new___locals_pa[] = "withAttribute.__new__.<locals>.pa";
static const char __pyx_k_Abstract_base_level_parser_eleme[] = "Abstract base level parser element class.";
static const char __pyx_k_Cannot_combine_element_of_type_s[] = "Cannot combine element of type %s with ParserElement";
static const char __pyx_k_Exception_creating_Regex_for_one[] = "Exception creating Regex for oneOf, building MatchFirst";
static const char __pyx_k_Expected_r_with_up_to_d_mismatch[] = "Expected %r (with up to %d mismatches)";
static const char __pyx_k_Invalid_argument_to_oneOf_expect[] = "Invalid argument to oneOf, expected string or iterable";
static const char __pyx_k_MatchFirst___init___locals_genex[] = "MatchFirst.__init__.<locals>.genexpr";
static const char __pyx_k_MatchFirst___str___locals_genexp[] = "MatchFirst.__str__.<locals>.genexpr";
static const char __pyx_k_Matches_if_current_position_is_2[] = "\n    Matches if current position is at the end of a line within the parse string\n    ";
static const char __pyx_k_Matches_if_current_position_is_3[] = "\n    Matches if current position is at the beginning of the parse string\n    ";
static const char __pyx_k_Matches_if_current_position_is_4[] = "\n    Matches if current position is at the end of the parse string\n    ";
static const char __pyx_k_Missing_one_or_more_required_ele[] = "Missing one or more required elements (%s)";
static const char __pyx_k_P_year_d_4_P_month_d_d_P_day_d_2[] = "(?P<year>\\d{4})-(?P<month>\\d\\d)-(?P<day>\\d\\d)[T ](?P<hour>\\d\\d):(?P<minute>\\d\\d)(:(?P<second>\\d\\d(\\.\\d*)?)?)?(?P<tz>Z|[+-]\\d\\d:?\\d\\d)?";
static const char __pyx_k_ParseBaseException__from_excepti[] = "ParseBaseException._from_exception";
static const char __pyx_k_ParseBaseException_markInputline[] = "ParseBaseException.markInputline";
static const char __pyx_k_ParseElementEnhance_checkRecursi[] = "ParseElementEnhance.checkRecursion";
static const char __pyx_k_ParseElementEnhance_leaveWhitesp[] = "ParseElementEnhance.leaveWhitespace";
static const char __pyx_k_ParseResults___iadd___locals_add[] = "ParseResults.__iadd__.<locals>.addoffset";
static const char __pyx_k_ParseResults___str___locals_gene[] = "ParseResults.__str__.<locals>.genexpr";
static const char __pyx_k_ParseResults__iteritems_locals_g[] = "ParseResults._iteritems.<locals>.genexpr";
static const char __pyx_k_ParseResults_asDict_locals_genex[] = "ParseResults.asDict.<locals>.genexpr";
static const char __pyx_k_ParseResults_asDict_locals_toIte[] = "ParseResults.asDict.<locals>.toItem";
static const char __pyx_k_ParseResults_asXML_locals_genexp[] = "ParseResults.asXML.<locals>.genexpr";
static const char __pyx_k_ParseResults_dump_locals_genexpr[] = "ParseResults.dump.<locals>.genexpr";
static const char __pyx_k_ParserElement___mul___locals_mak[] = "ParserElement.__mul__.<locals>.makeOptionalList";
static const char __pyx_k_ParserElement_addCondition_local[] = "ParserElement.addCondition.<locals>.pa";
static const char __pyx_k_ParserElement_inlineLiteralsUsin[] = "ParserElement.inlineLiteralsUsing";
static const char __pyx_k_ParserElement_setBreak_locals_br[] = "ParserElement.setBreak.<locals>.breaker";
static const char __pyx_k_ParserElement_setDefaultWhitespa[] = "ParserElement.setDefaultWhitespaceChars";
static const char __pyx_k_ParserElement_setWhitespaceChars[] = "ParserElement.setWhitespaceChars";
static const char __pyx_k_QuotedString___init___locals_gen[] = "QuotedString.__init__.<locals>.genexpr";
static const char __pyx_k_RecursiveGrammarException___init[] = "RecursiveGrammarException.__init__";
static const char __pyx_k_Regex_may_only_be_constructed_wi[] = "Regex may only be constructed with a string or a compiled RE object";
static const char __pyx_k_base_exception_class_for_all_par[] = "base exception class for all parsing runtime exceptions";
static const char __pyx_k_cannot_multiply_ParserElement_an[] = "cannot multiply 'ParserElement' and ('%s','%s') objects";
static const char __pyx_k_cannot_multiply_ParserElement_by[] = "cannot multiply ParserElement by negative value";
static const char __pyx_k_countedArray_locals_countFieldPa[] = "countedArray.<locals>.countFieldParseAction";
static const char __pyx_k_endQuoteChar_cannot_be_the_empty[] = "endQuoteChar cannot be the empty string";
static const char __pyx_k_exception_thrown_by_L_ParserElem[] = "exception thrown by L{ParserElement.validate} if the grammar could be improperly recursive";
static const char __pyx_k_fraction_or_mixed_integer_fracti[] = "fraction or mixed integer-fraction";
static const char __pyx_k_if_numterms_3_opExpr_must_be_a_t[] = "if numterms=3, opExpr must be a tuple or list of two expressions";
static const char __pyx_k_indentedBlock_locals_checkPeerIn[] = "indentedBlock.<locals>.checkPeerIndent";
static const char __pyx_k_indentedBlock_locals_checkSubInd[] = "indentedBlock.<locals>.checkSubIndent";
static const char __pyx_k_indentedBlock_locals_checkUninde[] = "indentedBlock.<locals>.checkUnindent";
static const char __pyx_k_invalid_pattern_s_passed_to_Rege[] = "invalid pattern (%s) passed to Regex";
static const char __pyx_k_matchPreviousExpr_locals_copyTok[] = "matchPreviousExpr.<locals>.copyTokenToRepeater.<locals>.mustMatchTheseTokens";
static const char __pyx_k_matchPreviousLiteral_locals_copy[] = "matchPreviousLiteral.<locals>.copyTokenToRepeater.<locals>.genexpr";
static const char __pyx_k_no_defined_alternatives_to_match[] = "no defined alternatives to match";
static const char __pyx_k_null_string_passed_to_Keyword_us[] = "null string passed to Keyword; use Empty() instead";
static const char __pyx_k_null_string_passed_to_Literal_us[] = "null string passed to Literal; use Empty() instead";
static const char __pyx_k_opening_and_closing_arguments_mu[] = "opening and closing arguments must be strings if no content expression is given";
static const char __pyx_k_opening_and_closing_strings_cann[] = "opening and closing strings cannot be the same";
static const char __pyx_k_originalTextFor_locals_extractTe[] = "originalTextFor.<locals>.extractText";
static const char __pyx_k_pop_got_an_unexpected_keyword_ar[] = "pop() got an unexpected keyword argument '%s'";
static const char __pyx_k_pyparsing_common_convertToDate_l[] = "pyparsing_common.convertToDate.<locals>.cvt_fn";
static const char __pyx_k_pyparsing_common_convertToDateti[] = "pyparsing_common.convertToDatetime.<locals>.cvt_fn";
static const char __pyx_k_pyparsing_common_lambda_locals_g[] = "pyparsing_common.<lambda>.<locals>.genexpr";
static const char __pyx_k_quoteChar_cannot_be_the_empty_st[] = "quoteChar cannot be the empty string";
static const char __pyx_k_quotedString_using_single_or_dou[] = "quotedString using single or double quotes";
static const char __pyx_k_quoted_string_starting_with_s_en[] = "quoted string, starting with %s ending with %s";
static const char __pyx_k_real_number_with_scientific_nota[] = "real number with scientific notation";
static const char __pyx_k_second_tuple_value_must_be_great[] = "second tuple value must be greater or equal to first tuple value";
static const char __pyx_k_srange_locals__expanded_locals_g[] = "srange.<locals>._expanded.<locals>.genexpr";
static const char __pyx_k_string_enclosed_in_double_quotes[] = "string enclosed in double quotes";
static const char __pyx_k_string_enclosed_in_single_quotes[] = "string enclosed in single quotes";
static const char __pyx_k_sum_len_sorted_reversed_list_tup[] = "sum len sorted reversed list tuple set any all min max";
static const char __pyx_k_Matches_if_the_current_position_2[] = "\n    Matches if the current position is at the end of a Word, and\n    is not followed by any character in a given set of C{wordChars}\n    (default=C{printables}). To emulate the C{\010} behavior of regular expressions,\n    use C{WordEnd(alphanums)}. C{WordEnd} will also match at the end of\n    the string being parsed, or at the end of a line.\n    ";
static const char __pyx_k_ParserElement__FifoCache___init_2[] = "ParserElement._FifoCache.__init__.<locals>.set";
static const char __pyx_k_ParserElement__FifoCache___init_3[] = "ParserElement._FifoCache.__init__.<locals>.clear";
static const char __pyx_k_ParserElement__FifoCache___init_4[] = "ParserElement._FifoCache.__init__.<locals>.cache_len";
static const char __pyx_k_ParserElement__FifoCache___init_5[] = "ParserElement._FifoCache.__init__";
static const char __pyx_k_Requires_all_given_C_ParseExpre_2[] = "\n    Requires all given C{ParseExpression}s to be found, but in any order.\n    Expressions may be separated by whitespace.\n    May be constructed using the C{'&'} operator.\n\n    Example::\n        color = oneOf(\"RED ORANGE YELLOW GREEN BLUE PURPLE BLACK WHITE BROWN\")\n        shape_type = oneOf(\"SQUARE CIRCLE TRIANGLE STAR HEXAGON OCTAGON\")\n        integer = Word(nums)\n        shape_attr = \"shape:\" + shape_type(\"shape\")\n        posn_attr = \"posn:\" + Group(integer(\"x\") + ',' + integer(\"y\"))(\"posn\")\n        color_attr = \"color:\" + color(\"color\")\n        size_attr = \"size:\" + integer(\"size\")\n\n        # use Each (using operator '&') to accept attributes in any order\n        # (shape and posn are required, color and size are optional)\n        shape_spec = shape_attr & posn_attr & Optional(color_attr) & Optional(size_attr)\n\n        shape_spec.runTests('''\n            shape: SQUARE color: BLACK posn: 100, 120\n            shape: CIRCLE size: 50 color: BLUE posn: 50,80\n            color:GREEN size:20 shape:TRIANGLE posn:20,40\n            '''\n            )\n    prints::\n        shape: SQUARE color: BLACK posn: 100, 120\n        ['shape:', 'SQUARE', 'color:', 'BLACK', 'posn:', ['100', ',', '120']]\n        - color: BLACK\n        - posn: ['100', ',', '120']\n          - x: 100\n          - y: 120\n        - shape: SQUARE\n\n\n        shape: CIRCLE size: 50 color: BLUE posn: 50,80\n        ['shape:', 'CIRCLE', 'size:', '50', 'color:', 'BLUE', 'posn:', ['50', ',', '80']]\n        - color: BLUE\n        - posn: ['50', ',', '80']\n          - x: 50\n          - y: 80\n        - shape: CIRCLE\n        - size: 50\n\n\n        color: GREEN size: 20 shape: TRIANGLE posn: 20,40\n        ['color:', 'GREEN', 'size:', '20', 'shape:', 'TRIANGLE', 'posn:', ['20', ',', '40']]\n        - color: GREEN\n        - posn: ['20', ',', '40']\n          - x: 20\n          - y: 40\n        - shape: TRIANGLE\n        - size: 20\n    ";
static const char __pyx_k_Requires_that_at_least_one_C_Pa_2[] = "\n    Requires that at least one C{ParseExpression} is found.\n    If two expressions match, the first one listed is the one that will match.\n    May be constructed using the C{'|'} operator.\n\n    Example::\n        # construct MatchFirst using '|' operator\n\n        # watch the order of expressions to match\n        number = Word(nums) | Combine(Word(nums) + '.' + Word(nums))\n        print(number.searchString(\"123 3.1416 789\")) #  Fail! -> [['123'], ['3'], ['1416'], ['789']]\n\n        # put more selective expression first\n        number = Combine(Word(nums) + '.' + Word(nums)) | Word(nums)\n        print(number.searchString(\"123 3.1416 789\")) #  Better -> [['123'], ['3.1416'], ['789']]\n    ";
static const char __pyx_k_Token_for_matching_strings_that_2[] = "\n    Token for matching strings that are delimited by quoting characters.\n\n    Defined with the following parameters:\n        - quoteChar - string of one or more characters defining the quote delimiting string\n        - escChar - character to escape quotes, typically backslash (default=C{None})\n        - escQuote - special quote sequence to escape an embedded quote string (such as SQL's \"\" to escape an embedded \") (default=C{None})\n        - multiline - boolean indicating whether quotes can span multiple lines (default=C{False})\n        - unquoteResults - boolean indicating whether the matched text should be unquoted (default=C{True})\n        - endQuoteChar - string of one or more characters defining the end of the quote delimited string (default=C{None} => same as quoteChar)\n        - convertWhitespaceEscapes - convert escaped whitespace (C{'\\t'}, C{'\\n'}, etc.) to actual whitespace (default=C{True})\n\n    Example::\n        qs = QuotedString('\"')\n        print(qs.searchString('lsjdf \"This is the quote\" sldjf'))\n        complex_qs = QuotedString('{{', endQuoteChar='}}')\n        print(complex_qs.searchString('lsjdf {{This is the \"quote\"}} sldjf'))\n        sql_qs = QuotedString('\"', escQuote='\"\"')\n        print(sql_qs.searchString('lsjdf \"This is the quote with \"\"embedded\"\" quotes\" sldjf'))\n    prints::\n        [['This is the quote']]\n        [['This is the \"quote\"']]\n        [['This is the quote with \"embedded\" quotes']]\n    ";
static const char __pyx_k_Token_for_matching_words_compos_2[] = "\n    Token for matching words composed of characters I{not} in a given set (will\n    include whitespace in matched characters if not listed in the provided exclusion set - see example).\n    Defined with string containing all disallowed characters, and an optional\n    minimum, maximum, and/or exact length.  The default value for C{min} is 1 (a\n    minimum value < 1 is not valid); the default values for C{max} and C{exact}\n    are 0, meaning no maximum or exact length restriction.\n\n    Example::\n        # define a comma-separated-value as anything that is not a ','\n        csv_value = CharsNotIn(',')\n        print(delimitedList(csv_value).parseString(\"dkls,lsdkjf,s12 34,@!#,213\"))\n    prints::\n        ['dkls', 'lsdkjf', 's12 34', '@!#', '213']\n    ";
static const char __pyx_k_Token_to_exactly_match_a_specif_2[] = "\n    Token to exactly match a specified string as a keyword, that is, it must be\n    immediately followed by a non-keyword character.  Compare with C{L{Literal}}:\n     - C{Literal(\"if\")} will match the leading C{'if'} in C{'ifAndOnlyIf'}.\n     - C{Keyword(\"if\")} will not; it will only match the leading C{'if'} in C{'if x=1'}, or C{'if(y==2)'}\n    Accepts two optional constructor arguments in addition to the keyword string:\n     - C{identChars} is a string of characters that would be valid identifier characters,\n          defaulting to all alphanumerics + \"_\" and \"$\"\n     - C{caseless} allows case-insensitive matching, default is C{False}.\n\n    Example::\n        Keyword(\"start\").parseString(\"start\")  # -> ['start']\n        Keyword(\"start\").parseString(\"starting\")  # -> Exception\n\n    For case-insensitive matching, use L{CaselessKeyword}.\n    ";
static const char __pyx_k_cannot_specify_a_minimum_length_2[] = "cannot specify a minimum length < 1; use Optional(CharsNotIn()) if zero-length char group is permitted";
static const char __pyx_k_cannot_multiply_ParserElement_an_2[] = "cannot multiply 'ParserElement' and '%s' objects";
static const char __pyx_k_cannot_multiply_ParserElement_by_2[] = "cannot multiply ParserElement by 0 or (0,0)";
static const char __pyx_k_matchPreviousExpr_locals_copyTok_2[] = "matchPreviousExpr.<locals>.copyTokenToRepeater";
static const char __pyx_k_matchPreviousLiteral_locals_copy_2[] = "matchPreviousLiteral.<locals>.copyTokenToRepeater";
static const char __pyx_k_pyparsing_common_convertToDateti_2[] = "pyparsing_common.convertToDatetime";
static PyObject *__pyx_kp_u_0123456789;
static PyObject *__pyx_kp_u_0_0_7;
static PyObject *__pyx_kp_u_0_9a_fA_F_1_4;
static PyObject *__pyx_kp_u_0_9a_fA_F_2_0_9a_fA_F_2_1_0_9a;
static PyObject *__pyx_kp_u_0_9a_fA_F_8_0_9a_fA_F_4_3_0_9a;
static PyObject *__pyx_kp_u_0_xX_0_9a_fA_F;
static PyObject *__pyx_kp_u_0x;
static PyObject *__pyx_kp_u_0xa1_0xbf_0xd7_0xf7;
static PyObject *__pyx_kp_u_0xc0_0xd6_0xd8_0xf6_0xf8_0xff;
static PyObject *__pyx_kp_u_100_100_100_3_14159_6_02e23_1e;
static PyObject *__pyx_kp_u_100_FF;
static PyObject *__pyx_kp_u_12345678_1234_5678_1234_5678123;
static PyObject *__pyx_kp_u_25_0_5_2_0_4_0_9_1_0_9_1_2_25_0;
static PyObject *__pyx_kp_u_2_2_0;
static PyObject *__pyx_n_u_ABCDEFabcdef;
static PyObject *__pyx_n_s_ANY_VALUE;
static PyObject *__pyx_kp_u_A_Z;
static PyObject *__pyx_kp_s_A_token_that_will_never_match;
static PyObject *__pyx_kp_s_A_variation_on_L_Literal_which;
static PyObject *__pyx_kp_s_Abstract_C_ParserElement_subcla;
static PyObject *__pyx_kp_s_Abstract_base_level_parser_eleme;
static PyObject *__pyx_kp_s_Abstract_subclass_of_C_ParseExp;
static PyObject *__pyx_kp_s_Abstract_subclass_of_C_ParserEl;
static PyObject *__pyx_kp_s_Abstract_subclass_of_ParserElem;
static PyObject *__pyx_kp_s_An_empty_token_will_always_matc;
static PyObject *__pyx_n_s_And;
static PyObject *__pyx_n_u_And;
static PyObject *__pyx_n_s_And__ErrorStop;
static PyObject *__pyx_n_s_And__ErrorStop___init;
static PyObject *__pyx_n_s_And___iadd;
static PyObject *__pyx_n_s_And___init;
static PyObject *__pyx_n_s_And___init___locals_genexpr;
static PyObject *__pyx_n_s_And___str;
static PyObject *__pyx_n_s_And___str___locals_genexpr;
static PyObject *__pyx_n_s_And_checkRecursion;
static PyObject *__pyx_n_s_And_parseImpl;
static PyObject *__pyx_n_s_AttributeError;
static PyObject *__pyx_kp_u_CR;
static PyObject *__pyx_kp_u_C_style_comment;
static PyObject *__pyx_kp_u_C_style_comment_2;
static PyObject *__pyx_kp_u_Cannot_combine_element_of_type_s;
static PyObject *__pyx_n_s_CaselessKeyword;
static PyObject *__pyx_n_u_CaselessKeyword;
static PyObject *__pyx_n_s_CaselessKeyword___init;
static PyObject *__pyx_n_s_CaselessKeyword_parseImpl;
static PyObject *__pyx_n_s_CaselessLiteral;
static PyObject *__pyx_n_u_CaselessLiteral;
static PyObject *__pyx_n_s_CaselessLiteral___init;
static PyObject *__pyx_n_s_CaselessLiteral_parseImpl;
static PyObject *__pyx_kp_s_Caseless_version_of_L_Keyword_E;
static PyObject *__pyx_n_s_CharsNotIn;
static PyObject *__pyx_n_u_CharsNotIn;
static PyObject *__pyx_n_s_CharsNotIn___init;
static PyObject *__pyx_n_s_CharsNotIn___str;
static PyObject *__pyx_n_s_CharsNotIn_parseImpl;
static PyObject *__pyx_n_s_CloseMatch;
static PyObject *__pyx_n_u_CloseMatch;
static PyObject *__pyx_n_s_CloseMatch___init;
static PyObject *__pyx_n_s_CloseMatch_parseImpl;
static PyObject *__pyx_n_s_Combine;
static PyObject *__pyx_n_u_Combine;
static PyObject *__pyx_n_s_Combine___init;
static PyObject *__pyx_n_s_Combine_ignore;
static PyObject *__pyx_n_s_Combine_postParse;
static PyObject *__pyx_n_s_Constants;
static PyObject *__pyx_kp_s_Converter_for_ignoring_the_resu;
static PyObject *__pyx_kp_s_Converter_to_concatenate_all_ma;
static PyObject *__pyx_kp_s_Converter_to_return_a_repetitiv;
static PyObject *__pyx_kp_s_Converter_to_return_the_matched;
static PyObject *__pyx_n_s_DEFAULT_KEYWORD_CHARS;
static PyObject *__pyx_n_s_DEFAULT_WHITE_CHARS;
static PyObject *__pyx_n_s_DOTALL;
static PyObject *__pyx_n_s_Dict;
static PyObject *__pyx_n_u_Dict;
static PyObject *__pyx_n_s_Dict___init;
static PyObject *__pyx_n_s_Dict_postParse;
static PyObject *__pyx_n_s_Each;
static PyObject *__pyx_n_u_Each;
static PyObject *__pyx_n_s_Each___init;
static PyObject *__pyx_n_s_Each___init___locals_genexpr;
static PyObject *__pyx_n_s_Each___str;
static PyObject *__pyx_n_s_Each___str___locals_genexpr;
static PyObject *__pyx_n_s_Each_checkRecursion;
static PyObject *__pyx_n_s_Each_parseImpl;
static PyObject *__pyx_n_s_Each_parseImpl_locals_genexpr;
static PyObject *__pyx_n_s_Empty;
static PyObject *__pyx_n_u_Empty;
static PyObject *__pyx_n_s_Empty___init;
static PyObject *__pyx_n_s_ErrorStop;
static PyObject *__pyx_kp_u_Exception_creating_Regex_for_one;
static PyObject *__pyx_kp_u_Exception_raised;
static PyObject *__pyx_kp_s_Exception_thrown_when_parse_exp;
static PyObject *__pyx_kp_u_Expected;
static PyObject *__pyx_kp_u_Expected_end_of_line;
static PyObject *__pyx_kp_u_Expected_end_of_text;
static PyObject *__pyx_kp_u_Expected_r_with_up_to_d_mismatch;
static PyObject *__pyx_kp_u_Expected_start_of_line;
static PyObject *__pyx_kp_u_Expected_start_of_text;
static PyObject *__pyx_kp_u_FAIL;
static PyObject *__pyx_kp_u_FAIL_EXCEPTION;
static PyObject *__pyx_kp_u_FATAL;
static PyObject *__pyx_kp_u_FF;
static PyObject *__pyx_n_s_FILE_NAME;
static PyObject *__pyx_n_s_FifoCache;
static PyObject *__pyx_n_s_FollowedBy;
static PyObject *__pyx_n_u_FollowedBy;
static PyObject *__pyx_n_s_FollowedBy___init;
static PyObject *__pyx_n_s_FollowedBy_parseImpl;
static PyObject *__pyx_n_s_Forward;
static PyObject *__pyx_n_u_Forward;
static PyObject *__pyx_n_s_ForwardNoRecurse;
static PyObject *__pyx_n_s_ForwardNoRecurse___str;
static PyObject *__pyx_n_s_Forward___ilshift;
static PyObject *__pyx_n_s_Forward___init;
static PyObject *__pyx_n_s_Forward___lshift;
static PyObject *__pyx_n_s_Forward___str;
static PyObject *__pyx_n_s_Forward_copy;
static PyObject *__pyx_kp_s_Forward_declaration_of_an_expre;
static PyObject *__pyx_n_s_Forward_leaveWhitespace;
static PyObject *__pyx_n_s_Forward_streamline;
static PyObject *__pyx_n_s_Forward_validate;
static PyObject *__pyx_kp_u_Found_unwanted_token;
static PyObject *__pyx_n_s_GoToColumn;
static PyObject *__pyx_n_u_GoToColumn;
static PyObject *__pyx_n_s_GoToColumn___init;
static PyObject *__pyx_n_s_GoToColumn_parseImpl;
static PyObject *__pyx_n_s_GoToColumn_preParse;
static PyObject *__pyx_n_s_Group;
static PyObject *__pyx_n_u_Group;
static PyObject *__pyx_n_s_Group___init;
static PyObject *__pyx_n_s_Group_postParse;
static PyObject *__pyx_n_s_HIT;
static PyObject *__pyx_kp_u_HTML_comment;
static PyObject *__pyx_kp_s_Helper_to_create_a_validating_p;
static PyObject *__pyx_kp_s_Here_are_some_common_low_level;
static PyObject *__pyx_n_s_INDENT;
static PyObject *__pyx_n_u_INDENT;
static PyObject *__pyx_kp_u_IPv4_address;
static PyObject *__pyx_kp_u_IPv6_address;
static PyObject *__pyx_kp_u_ISO8601_date;
static PyObject *__pyx_kp_u_ISO8601_datetime;
static PyObject *__pyx_n_u_ITEM;
static PyObject *__pyx_n_s_ImportError;
static PyObject *__pyx_n_s_IndexError;
static PyObject *__pyx_kp_u_Invalid_argument_to_oneOf_expect;
static PyObject *__pyx_n_s_Iterable;
static PyObject *__pyx_n_s_KeyError;
static PyObject *__pyx_n_s_Keyword;
static PyObject *__pyx_n_u_Keyword;
static PyObject *__pyx_n_s_Keyword___init;
static PyObject *__pyx_n_s_Keyword_copy;
static PyObject *__pyx_n_s_Keyword_parseImpl;
static PyObject *__pyx_n_s_Keyword_setDefaultKeywordChars;
static PyObject *__pyx_n_s_L;
static PyObject *__pyx_n_s_LEFT;
static PyObject *__pyx_kp_u_LF;
static PyObject *__pyx_n_s_L_2;
static PyObject *__pyx_n_s_LineEnd;
static PyObject *__pyx_n_u_LineEnd;
static PyObject *__pyx_n_s_LineEnd___init;
static PyObject *__pyx_n_s_LineEnd_parseImpl;
static PyObject *__pyx_n_s_LineStart;
static PyObject *__pyx_n_u_LineStart;
static PyObject *__pyx_n_s_LineStart___init;
static PyObject *__pyx_n_s_LineStart_parseImpl;
static PyObject *__pyx_n_s_Literal;
static PyObject *__pyx_n_u_Literal;
static PyObject *__pyx_n_s_Literal___init;
static PyObject *__pyx_n_s_Literal_parseImpl;
static PyObject *__pyx_kp_s_Lookahead_matching_of_the_given;
static PyObject *__pyx_kp_s_Lookahead_to_disallow_matching;
static PyObject *__pyx_kp_u_MAC_address;
static PyObject *__pyx_n_s_MAX_INT;
static PyObject *__pyx_n_s_MISS;
static PyObject *__pyx_n_s_MULTILINE;
static PyObject *__pyx_kp_u_Match;
static PyObject *__pyx_n_s_MatchFirst;
static PyObject *__pyx_n_u_MatchFirst;
static PyObject *__pyx_n_s_MatchFirst___init;
static PyObject *__pyx_n_s_MatchFirst___init___locals_genex;
static PyObject *__pyx_n_s_MatchFirst___ior;
static PyObject *__pyx_n_s_MatchFirst___str;
static PyObject *__pyx_n_s_MatchFirst___str___locals_genexp;
static PyObject *__pyx_n_s_MatchFirst_checkRecursion;
static PyObject *__pyx_n_s_MatchFirst_parseImpl;
static PyObject *__pyx_kp_u_Matched;
static PyObject *__pyx_kp_s_Matches_if_current_position_is;
static PyObject *__pyx_kp_s_Matches_if_current_position_is_2;
static PyObject *__pyx_kp_s_Matches_if_current_position_is_3;
static PyObject *__pyx_kp_s_Matches_if_current_position_is_4;
static PyObject *__pyx_kp_s_Matches_if_the_current_position;
static PyObject *__pyx_kp_s_Matches_if_the_current_position_2;
static PyObject *__pyx_n_s_MethodType;
static PyObject *__pyx_kp_u_Missing_one_or_more_required_ele;
static PyObject *__pyx_n_s_MultipleMatch;
static PyObject *__pyx_n_s_MultipleMatch___init;
static PyObject *__pyx_n_s_MultipleMatch_parseImpl;
static PyObject *__pyx_n_s_MutableMapping;
static PyObject *__pyx_n_s_NL;
static PyObject *__pyx_n_s_NoMatch;
static PyObject *__pyx_n_u_NoMatch;
static PyObject *__pyx_n_s_NoMatch___init;
static PyObject *__pyx_n_s_NoMatch_parseImpl;
static PyObject *__pyx_kp_u_No_match_found_for;
static PyObject *__pyx_n_s_NotAny;
static PyObject *__pyx_n_u_NotAny;
static PyObject *__pyx_n_s_NotAny___init;
static PyObject *__pyx_n_s_NotAny___str;
static PyObject *__pyx_n_s_NotAny_parseImpl;
static PyObject *__pyx_kp_u_Not_at_the_end_of_a_word;
static PyObject *__pyx_kp_u_Not_at_the_start_of_a_word;
static PyObject *__pyx_n_s_NullToken;
static PyObject *__pyx_n_s_NullToken___bool;
static PyObject *__pyx_n_s_NullToken___str;
static PyObject *__pyx_n_s_OneOrMore;
static PyObject *__pyx_n_u_OneOrMore;
static PyObject *__pyx_n_s_OneOrMore___str;
static PyObject *__pyx_n_s_OnlyOnce;
static PyObject *__pyx_n_u_OnlyOnce;
static PyObject *__pyx_n_s_OnlyOnce___call;
static PyObject *__pyx_n_s_OnlyOnce___init;
static PyObject *__pyx_n_s_OnlyOnce_reset;
static PyObject *__pyx_n_s_Optional;
static PyObject *__pyx_n_u_Optional;
static PyObject *__pyx_n_s_Optional___init;
static PyObject *__pyx_n_s_Optional___str;
static PyObject *__pyx_kp_s_Optional_matching_of_the_given;
static PyObject *__pyx_n_s_Optional_parseImpl;
static PyObject *__pyx_kp_s_Optional_repetition_of_zero_or;
static PyObject *__pyx_n_s_Or;
static PyObject *__pyx_n_u_Or;
static PyObject *__pyx_n_s_Or___init;
static PyObject *__pyx_n_s_Or___init___locals_genexpr;
static PyObject *__pyx_n_s_Or___ixor;
static PyObject *__pyx_n_s_Or___str;
static PyObject *__pyx_n_s_Or___str___locals_genexpr;
static PyObject *__pyx_n_s_Or_checkRecursion;
static PyObject *__pyx_n_s_Or_parseImpl;
static PyObject *__pyx_n_s_Or_parseImpl_locals_lambda;
static PyObject *__pyx_n_s_OrderedDict;
static PyObject *__pyx_n_s_OrderedDict_2;
static PyObject *__pyx_n_s_PEER;
static PyObject *__pyx_n_s_PY_3;
static PyObject *__pyx_kp_u_P_entity;
static PyObject *__pyx_kp_u_P_year_d_4_P_month_d_d_P_day_d;
static PyObject *__pyx_kp_u_P_year_d_4_P_month_d_d_P_day_d_2;
static PyObject *__pyx_n_s_ParseBaseException;
static PyObject *__pyx_n_u_ParseBaseException;
static PyObject *__pyx_n_s_ParseBaseException___dir;
static PyObject *__pyx_n_s_ParseBaseException___getattr;
static PyObject *__pyx_n_s_ParseBaseException___init;
static PyObject *__pyx_n_s_ParseBaseException___repr;
static PyObject *__pyx_n_s_ParseBaseException___str;
static PyObject *__pyx_n_s_ParseBaseException__from_excepti;
static PyObject *__pyx_n_s_ParseBaseException_markInputline;
static PyObject *__pyx_n_s_ParseElementEnhance;
static PyObject *__pyx_n_u_ParseElementEnhance;
static PyObject *__pyx_n_s_ParseElementEnhance___init;
static PyObject *__pyx_n_s_ParseElementEnhance___str;
static PyObject *__pyx_n_s_ParseElementEnhance_checkRecursi;
static PyObject *__pyx_n_s_ParseElementEnhance_ignore;
static PyObject *__pyx_n_s_ParseElementEnhance_leaveWhitesp;
static PyObject *__pyx_n_s_ParseElementEnhance_parseImpl;
static PyObject *__pyx_n_s_ParseElementEnhance_streamline;
static PyObject *__pyx_n_s_ParseElementEnhance_validate;
static PyObject *__pyx_n_s_ParseException;
static PyObject *__pyx_n_u_ParseException;
static PyObject *__pyx_n_s_ParseExpression;
static PyObject *__pyx_n_u_ParseExpression;
static PyObject *__pyx_n_s_ParseExpression___getitem;
static PyObject *__pyx_n_s_ParseExpression___init;
static PyObject *__pyx_n_s_ParseExpression___init___locals;
static PyObject *__pyx_n_s_ParseExpression___str;
static PyObject *__pyx_n_s_ParseExpression_append;
static PyObject *__pyx_n_s_ParseExpression_copy;
static PyObject *__pyx_n_s_ParseExpression_ignore;
static PyObject *__pyx_n_s_ParseExpression_leaveWhitespace;
static PyObject *__pyx_n_s_ParseExpression_setResultsName;
static PyObject *__pyx_n_s_ParseExpression_streamline;
static PyObject *__pyx_n_s_ParseExpression_validate;
static PyObject *__pyx_n_s_ParseFatalException;
static PyObject *__pyx_n_u_ParseFatalException;
static PyObject *__pyx_n_s_ParseResults;
static PyObject *__pyx_n_u_ParseResults;
static PyObject *__pyx_n_s_ParseResultsWithOffset;
static PyObject *__pyx_n_s_ParseResultsWithOffset___getite;
static PyObject *__pyx_n_s_ParseResultsWithOffset___init;
static PyObject *__pyx_n_s_ParseResultsWithOffset___repr;
static PyObject *__pyx_n_s_ParseResultsWithOffset_setOffse;
static PyObject *__pyx_n_s_ParseResults___add;
static PyObject *__pyx_n_s_ParseResults___bool;
static PyObject *__pyx_n_s_ParseResults___contains;
static PyObject *__pyx_n_s_ParseResults___delitem;
static PyObject *__pyx_n_s_ParseResults___dir;
static PyObject *__pyx_n_s_ParseResults___getattr;
static PyObject *__pyx_n_s_ParseResults___getitem;
static PyObject *__pyx_n_s_ParseResults___getnewargs;
static PyObject *__pyx_n_s_ParseResults___getstate;
static PyObject *__pyx_n_s_ParseResults___iadd;
static PyObject *__pyx_n_s_ParseResults___iadd___locals_add;
static PyObject *__pyx_n_s_ParseResults___init;
static PyObject *__pyx_n_s_ParseResults___iter;
static PyObject *__pyx_n_s_ParseResults___len;
static PyObject *__pyx_n_s_ParseResults___lookup;
static PyObject *__pyx_n_s_ParseResults___new;
static PyObject *__pyx_n_s_ParseResults___radd;
static PyObject *__pyx_n_s_ParseResults___repr;
static PyObject *__pyx_n_s_ParseResults___reversed;
static PyObject *__pyx_n_s_ParseResults___setitem;
static PyObject *__pyx_n_s_ParseResults___setstate;
static PyObject *__pyx_n_s_ParseResults___str;
static PyObject *__pyx_n_s_ParseResults___str___locals_gene;
static PyObject *__pyx_n_s_ParseResults__accumNames;
static PyObject *__pyx_n_s_ParseResults__asList;
static PyObject *__pyx_n_s_ParseResults__asStringList;
static PyObject *__pyx_n_s_ParseResults__doinit;
static PyObject *__pyx_n_s_ParseResults__iteritems;
static PyObject *__pyx_n_s_ParseResults__iteritems_locals_g;
static PyObject *__pyx_n_s_ParseResults__iterkeys;
static PyObject *__pyx_n_s_ParseResults__itervalues;
static PyObject *__pyx_n_s_ParseResults__itervalues_locals;
static PyObject *__pyx_n_s_ParseResults__lookup;
static PyObject *__pyx_n_s_ParseResults__modal;
static PyObject *__pyx_n_s_ParseResults__name;
static PyObject *__pyx_n_s_ParseResults__parent;
static PyObject *__pyx_n_s_ParseResults__tokdict;
static PyObject *__pyx_n_s_ParseResults__toklist;
static PyObject *__pyx_n_s_ParseResults_append;
static PyObject *__pyx_n_s_ParseResults_asDict;
static PyObject *__pyx_n_s_ParseResults_asDict_locals_genex;
static PyObject *__pyx_n_s_ParseResults_asDict_locals_toIte;
static PyObject *__pyx_n_s_ParseResults_asList;
static PyObject *__pyx_n_s_ParseResults_asXML;
static PyObject *__pyx_n_s_ParseResults_asXML_locals_genexp;
static PyObject *__pyx_n_s_ParseResults_clear;
static PyObject *__pyx_n_s_ParseResults_copy;
static PyObject *__pyx_n_s_ParseResults_dump;
static PyObject *__pyx_n_s_ParseResults_dump_locals_genexpr;
static PyObject *__pyx_n_s_ParseResults_extend;
static PyObject *__pyx_n_s_ParseResults_get;
static PyObject *__pyx_n_s_ParseResults_getName;
static PyObject *__pyx_n_s_ParseResults_haskeys;
static PyObject *__pyx_n_s_ParseResults_insert;
static PyObject *__pyx_n_s_ParseResults_items;
static PyObject *__pyx_n_s_ParseResults_keys;
static PyObject *__pyx_n_s_ParseResults_pop;
static PyObject *__pyx_n_s_ParseResults_pprint;
static PyObject *__pyx_n_s_ParseResults_values;
static PyObject *__pyx_n_s_ParseSyntaxException;
static PyObject *__pyx_n_u_ParseSyntaxException;
static PyObject *__pyx_n_s_ParserElement;
static PyObject *__pyx_n_u_ParserElement;
static PyObject *__pyx_n_s_ParserElement__FifoCache;
static PyObject *__pyx_n_s_ParserElement__FifoCache___init;
static PyObject *__pyx_n_s_ParserElement__FifoCache___init_2;
static PyObject *__pyx_n_s_ParserElement__FifoCache___init_3;
static PyObject *__pyx_n_s_ParserElement__FifoCache___init_4;
static PyObject *__pyx_n_s_ParserElement__FifoCache___init_5;
static PyObject *__pyx_n_s_ParserElement__UnboundedCache;
static PyObject *__pyx_n_s_ParserElement__UnboundedCache_2;
static PyObject *__pyx_n_s_ParserElement__UnboundedCache_3;
static PyObject *__pyx_n_s_ParserElement__UnboundedCache_4;
static PyObject *__pyx_n_s_ParserElement__UnboundedCache_5;
static PyObject *__pyx_n_s_ParserElement__UnboundedCache_6;
static PyObject *__pyx_n_s_ParserElement___add;
static PyObject *__pyx_n_s_ParserElement___and;
static PyObject *__pyx_n_s_ParserElement___call;
static PyObject *__pyx_n_s_ParserElement___eq;
static PyObject *__pyx_n_s_ParserElement___hash;
static PyObject *__pyx_n_s_ParserElement___init;
static PyObject *__pyx_n_s_ParserElement___invert;
static PyObject *__pyx_n_s_ParserElement___mul;
static PyObject *__pyx_n_s_ParserElement___mul___locals_mak;
static PyObject *__pyx_n_s_ParserElement___ne;
static PyObject *__pyx_n_s_ParserElement___or;
static PyObject *__pyx_n_s_ParserElement___radd;
static PyObject *__pyx_n_s_ParserElement___rand;
static PyObject *__pyx_n_s_ParserElement___repr;
static PyObject *__pyx_n_s_ParserElement___req;
static PyObject *__pyx_n_s_ParserElement___rmul;
static PyObject *__pyx_n_s_ParserElement___rne;
static PyObject *__pyx_n_s_ParserElement___ror;
static PyObject *__pyx_n_s_ParserElement___rsub;
static PyObject *__pyx_n_s_ParserElement___rxor;
static PyObject *__pyx_n_s_ParserElement___str;
static PyObject *__pyx_n_s_ParserElement___sub;
static PyObject *__pyx_n_s_ParserElement___xor;
static PyObject *__pyx_n_s_ParserElement__parseCache;
static PyObject *__pyx_n_s_ParserElement__parseNoCache;
static PyObject *__pyx_n_s_ParserElement__skipIgnorables;
static PyObject *__pyx_n_s_ParserElement_addCondition;
static PyObject *__pyx_n_s_ParserElement_addCondition_local;
static PyObject *__pyx_n_s_ParserElement_addParseAction;
static PyObject *__pyx_n_s_ParserElement_canParseNext;
static PyObject *__pyx_n_s_ParserElement_checkRecursion;
static PyObject *__pyx_n_s_ParserElement_copy;
static PyObject *__pyx_n_s_ParserElement_enablePackrat;
static PyObject *__pyx_n_s_ParserElement_ignore;
static PyObject *__pyx_n_s_ParserElement_inlineLiteralsUsin;
static PyObject *__pyx_n_s_ParserElement_leaveWhitespace;
static PyObject *__pyx_n_s_ParserElement_matches;
static PyObject *__pyx_n_s_ParserElement_parseFile;
static PyObject *__pyx_n_s_ParserElement_parseImpl;
static PyObject *__pyx_n_s_ParserElement_parseString;
static PyObject *__pyx_n_s_ParserElement_parseWithTabs;
static PyObject *__pyx_n_s_ParserElement_postParse;
static PyObject *__pyx_n_s_ParserElement_preParse;
static PyObject *__pyx_n_s_ParserElement_resetCache;
static PyObject *__pyx_n_s_ParserElement_runTests;
static PyObject *__pyx_n_s_ParserElement_scanString;
static PyObject *__pyx_n_s_ParserElement_searchString;
static PyObject *__pyx_n_s_ParserElement_setBreak;
static PyObject *__pyx_n_s_ParserElement_setBreak_locals_br;
static PyObject *__pyx_n_s_ParserElement_setDebug;
static PyObject *__pyx_n_s_ParserElement_setDebugActions;
static PyObject *__pyx_n_s_ParserElement_setDefaultWhitespa;
static PyObject *__pyx_n_s_ParserElement_setFailAction;
static PyObject *__pyx_n_s_ParserElement_setName;
static PyObject *__pyx_n_s_ParserElement_setParseAction;
static PyObject *__pyx_n_s_ParserElement_setResultsName;
static PyObject *__pyx_n_s_ParserElement_setWhitespaceChars;
static PyObject *__pyx_n_s_ParserElement_split;
static PyObject *__pyx_n_s_ParserElement_streamline;
static PyObject *__pyx_n_s_ParserElement_suppress;
static PyObject *__pyx_n_s_ParserElement_transformString;
static PyObject *__pyx_n_s_ParserElement_tryParse;
static PyObject *__pyx_n_s_ParserElement_validate;
static PyObject *__pyx_n_s_PositionToken;
static PyObject *__pyx_n_s_PositionToken___init;
static PyObject *__pyx_kp_u_Python_style_comment;
static PyObject *__pyx_n_s_QuotedString;
static PyObject *__pyx_n_u_QuotedString;
static PyObject *__pyx_n_s_QuotedString___init;
static PyObject *__pyx_n_s_QuotedString___init___locals_gen;
static PyObject *__pyx_n_s_QuotedString___str;
static PyObject *__pyx_n_s_QuotedString_parseImpl;
static PyObject *__pyx_n_s_RIGHT;
static PyObject *__pyx_n_s_RLock;
static PyObject *__pyx_kp_u_Re_s;
static PyObject *__pyx_n_s_RecursiveGrammarException;
static PyObject *__pyx_n_u_RecursiveGrammarException;
static PyObject *__pyx_n_s_RecursiveGrammarException___init;
static PyObject *__pyx_n_s_RecursiveGrammarException___str;
static PyObject *__pyx_kp_u_RecursiveGrammarException_s;
static PyObject *__pyx_n_s_Regex;
static PyObject *__pyx_n_u_Regex;
static PyObject *__pyx_n_s_Regex___init;
static PyObject *__pyx_n_s_Regex___str;
static PyObject *__pyx_kp_u_Regex_may_only_be_constructed_wi;
static PyObject *__pyx_n_s_Regex_parseImpl;
static PyObject *__pyx_kp_s_Repetition_of_one_or_more_of_th;
static PyObject *__pyx_kp_s_Requires_all_given_C_ParseExpre;
static PyObject *__pyx_kp_s_Requires_all_given_C_ParseExpre_2;
static PyObject *__pyx_kp_s_Requires_that_at_least_one_C_Pa;
static PyObject *__pyx_kp_s_Requires_that_at_least_one_C_Pa_2;
static PyObject *__pyx_kp_u_SPC;
static PyObject *__pyx_n_s_SkipTo;
static PyObject *__pyx_n_u_SkipTo;
static PyObject *__pyx_n_s_SkipTo___init;
static PyObject *__pyx_n_s_SkipTo_parseImpl;
static PyObject *__pyx_kp_s_Special_matching_class_for_matc;
static PyObject *__pyx_n_s_StringEnd;
static PyObject *__pyx_n_u_StringEnd;
static PyObject *__pyx_n_s_StringEnd___init;
static PyObject *__pyx_n_s_StringEnd_parseImpl;
static PyObject *__pyx_n_s_StringStart;
static PyObject *__pyx_n_u_StringStart;
static PyObject *__pyx_n_s_StringStart___init;
static PyObject *__pyx_n_s_StringStart_parseImpl;
static PyObject *__pyx_kp_s_Structured_parse_results_to_pro;
static PyObject *__pyx_n_s_Suppress;
static PyObject *__pyx_n_u_Suppress;
static PyObject *__pyx_n_s_Suppress_postParse;
static PyObject *__pyx_n_s_Suppress_suppress;
static PyObject *__pyx_n_s_SyntaxError;
static PyObject *__pyx_n_s_SyntaxWarning;
static PyObject *__pyx_kp_u_TAB;
static PyObject *__pyx_kp_u_Text_not_in_expected_column;
static PyObject *__pyx_n_s_Token;
static PyObject *__pyx_n_u_Token;
static PyObject *__pyx_n_s_TokenConverter;
static PyObject *__pyx_n_u_TokenConverter;
static PyObject *__pyx_n_s_TokenConverter___init;
static PyObject *__pyx_n_s_Token___init;
static PyObject *__pyx_kp_s_Token_for_matching_strings_that;
static PyObject *__pyx_kp_s_Token_for_matching_strings_that_2;
static PyObject *__pyx_kp_s_Token_for_matching_words_compos;
static PyObject *__pyx_kp_s_Token_for_matching_words_compos_2;
static PyObject *__pyx_kp_s_Token_for_skipping_over_all_und;
static PyObject *__pyx_kp_s_Token_to_advance_to_a_specific;
static PyObject *__pyx_kp_s_Token_to_exactly_match_a_specif;
static PyObject *__pyx_kp_s_Token_to_exactly_match_a_specif_2;
static PyObject *__pyx_kp_s_Token_to_match_a_specified_stri;
static PyObject *__pyx_n_s_TypeError;
static PyObject *__pyx_n_s_UNDENT;
static PyObject *__pyx_n_s_UNICODE;
static PyObject *__pyx_n_u_UNINDENT;
static PyObject *__pyx_n_s_UUID;
static PyObject *__pyx_n_u_UUID;
static PyObject *__pyx_n_s_UnboundedCache;
static PyObject *__pyx_kp_u_Unmatchable_token;
static PyObject *__pyx_n_s_ValueError;
static PyObject *__pyx_n_s_WRAP_CALL_LINE_NUM;
static PyObject *__pyx_kp_u_W_s;
static PyObject *__pyx_kp_u_W_s_2;
static PyObject *__pyx_kp_u_W_s_3;
static PyObject *__pyx_kp_u_W_s_s;
static PyObject *__pyx_n_s_White;
static PyObject *__pyx_n_u_White;
static PyObject *__pyx_n_s_White___init;
static PyObject *__pyx_n_s_White___init___locals_genexpr;
static PyObject *__pyx_n_s_White_parseImpl;
static PyObject *__pyx_n_s_Word;
static PyObject *__pyx_n_u_Word;
static PyObject *__pyx_n_s_WordEnd;
static PyObject *__pyx_n_u_WordEnd;
static PyObject *__pyx_n_s_WordEnd___init;
static PyObject *__pyx_n_s_WordEnd_parseImpl;
static PyObject *__pyx_n_s_WordStart;
static PyObject *__pyx_n_u_WordStart;
static PyObject *__pyx_n_s_WordStart___init;
static PyObject *__pyx_n_s_WordStart_parseImpl;
static PyObject *__pyx_n_s_Word___init;
static PyObject *__pyx_n_s_Word___init___locals_genexpr;
static PyObject *__pyx_n_s_Word___str;
static PyObject *__pyx_n_s_Word___str___locals_charsAsStr;
static PyObject *__pyx_n_s_Word_parseImpl;
static PyObject *__pyx_kp_s_Wrapper_for_parse_actions_to_en;
static PyObject *__pyx_kp_u_Y_m_d;
static PyObject *__pyx_kp_u_Y_m_dT_H_M_S_f;
static PyObject *__pyx_n_s_ZeroOrMore;
static PyObject *__pyx_n_u_ZeroOrMore;
static PyObject *__pyx_n_s_ZeroOrMore___init;
static PyObject *__pyx_n_s_ZeroOrMore___str;
static PyObject *__pyx_n_s_ZeroOrMore_parseImpl;
static PyObject *__pyx_kp_u__10;
static PyObject *__pyx_kp_u__102;
static PyObject *__pyx_kp_u__108;
static PyObject *__pyx_kp_u__111;
static PyObject *__pyx_kp_u__112;
static PyObject *__pyx_kp_u__113;
static PyObject *__pyx_kp_u__115;
static PyObject *__pyx_kp_u__119;
static PyObject *__pyx_kp_u__123;
static PyObject *__pyx_kp_u__124;
static PyObject *__pyx_kp_u__125;
static PyObject *__pyx_kp_u__127;
static PyObject *__pyx_kp_u__129;
static PyObject *__pyx_kp_u__132;
static PyObject *__pyx_kp_u__133;
static PyObject *__pyx_kp_u__146;
static PyObject *__pyx_kp_u__16;
static PyObject *__pyx_kp_u__166;
static PyObject *__pyx_kp_u__167;
static PyObject *__pyx_kp_u__17;
static PyObject *__pyx_kp_u__170;
static PyObject *__pyx_kp_u__18;
static PyObject *__pyx_kp_u__182;
static PyObject *__pyx_kp_u__195;
static PyObject *__pyx_kp_u__205;
static PyObject *__pyx_kp_u__21;
static PyObject *__pyx_kp_u__22;
static PyObject *__pyx_kp_u__23;
static PyObject *__pyx_kp_u__24;
static PyObject *__pyx_kp_u__25;
static PyObject *__pyx_kp_u__26;
static PyObject *__pyx_kp_u__355;
static PyObject *__pyx_kp_u__38;
static PyObject *__pyx_kp_u__508;
static PyObject *__pyx_kp_u__6;
static PyObject *__pyx_n_s__653;
static PyObject *__pyx_n_u__653;
static PyObject *__pyx_kp_u__7;
static PyObject *__pyx_kp_u__8;
static PyObject *__pyx_kp_u__82;
static PyObject *__pyx_kp_u__823;
static PyObject *__pyx_kp_u__826;
static PyObject *__pyx_kp_u__84;
static PyObject *__pyx_kp_u__85;
static PyObject *__pyx_kp_u__857;
static PyObject *__pyx_kp_u__860;
static PyObject *__pyx_kp_u__873;
static PyObject *__pyx_kp_u__875;
static PyObject *__pyx_kp_u__876;
static PyObject *__pyx_kp_u__88;
static PyObject *__pyx_kp_u__880;
static PyObject *__pyx_kp_u__882;
static PyObject *__pyx_kp_u__886;
static PyObject *__pyx_kp_u__893;
static PyObject *__pyx_kp_u__896;
static PyObject *__pyx_kp_u__9;
static PyObject *__pyx_kp_u__92;
static PyObject *__pyx_kp_u__921;
static PyObject *__pyx_kp_u__93;
static PyObject *__pyx_kp_u__94;
static PyObject *__pyx_kp_u__95;
static PyObject *__pyx_kp_u__96;
static PyObject *__pyx_kp_u__97;
static PyObject *__pyx_kp_u__98;
static PyObject *__pyx_kp_u__99;
static PyObject *__pyx_n_s_a;
static PyObject *__pyx_n_s_add;
static PyObject *__pyx_n_s_addCondition;
static PyObject *__pyx_n_s_addParseAction;
static PyObject *__pyx_n_s_addoffset;
static PyObject *__pyx_n_s_adjacent;
static PyObject *__pyx_n_s_all;
static PyObject *__pyx_n_s_allResults;
static PyObject *__pyx_n_s_all_2;
static PyObject *__pyx_n_s_alphanums;
static PyObject *__pyx_n_u_alphanums;
static PyObject *__pyx_n_s_alphas;
static PyObject *__pyx_n_u_alphas;
static PyObject *__pyx_n_s_alphas8bit;
static PyObject *__pyx_n_u_alphas8bit;
static PyObject *__pyx_kp_u_amp_gt_lt_quot_apos;
static PyObject *__pyx_n_s_aname;
static PyObject *__pyx_n_s_and;
static PyObject *__pyx_n_s_any;
static PyObject *__pyx_n_s_anyCloseTag;
static PyObject *__pyx_n_u_anyCloseTag;
static PyObject *__pyx_n_s_anyOpenTag;
static PyObject *__pyx_n_u_anyOpenTag;
static PyObject *__pyx_kp_u_any_tag;
static PyObject *__pyx_n_s_append;
static PyObject *__pyx_n_s_args;
static PyObject *__pyx_n_s_arity;
static PyObject *__pyx_n_s_arrayExpr;
static PyObject *__pyx_n_u_arrayLen;
static PyObject *__pyx_n_s_asDict;
static PyObject *__pyx_n_s_asKeyword;
static PyObject *__pyx_n_s_asList;
static PyObject *__pyx_n_s_asString;
static PyObject *__pyx_n_s_asStringList;
static PyObject *__pyx_n_s_asXML;
static PyObject *__pyx_kp_u_as_column_list_and_dotted_table;
static PyObject *__pyx_n_s_ascii_lowercase;
static PyObject *__pyx_n_s_ascii_uppercase;
static PyObject *__pyx_kp_u_at_loc;
static PyObject *__pyx_n_s_attrDict;
static PyObject *__pyx_n_s_attrName;
static PyObject *__pyx_n_s_attrValue;
static PyObject *__pyx_kp_u_attribute_s_has_value_s_must_be;
static PyObject *__pyx_n_s_attrs;
static PyObject *__pyx_kp_u_b;
static PyObject *__pyx_n_s_b_2;
static PyObject *__pyx_n_s_baseExpr;
static PyObject *__pyx_kp_s_base_exception_class_for_all_par;
static PyObject *__pyx_n_s_basestring;
static PyObject *__pyx_n_s_blockStatementExpr;
static PyObject *__pyx_n_s_body;
static PyObject *__pyx_n_u_body;
static PyObject *__pyx_n_s_bodyChars;
static PyObject *__pyx_n_s_bodyCharsOrig;
static PyObject *__pyx_n_s_bodychars;
static PyObject *__pyx_n_s_bool;
static PyObject *__pyx_n_s_breakFlag;
static PyObject *__pyx_n_s_breaker;
static PyObject *__pyx_n_s_bslash;
static PyObject *__pyx_n_s_builtin;
static PyObject *__pyx_n_s_c;
static PyObject *__pyx_n_s_cPyparsing;
static PyObject *__pyx_kp_u_cPyparsing_pyx;
static PyObject *__pyx_n_s_cStyleComment;
static PyObject *__pyx_n_u_cStyleComment;
static PyObject *__pyx_n_s_cache;
static PyObject *__pyx_n_s_cache_len;
static PyObject *__pyx_n_s_cache_size_limit;
static PyObject *__pyx_n_s_call;
static PyObject *__pyx_n_s_callDuringTry;
static PyObject *__pyx_n_u_callDuringTry;
static PyObject *__pyx_n_s_callPreParse;
static PyObject *__pyx_n_s_callPreparse;
static PyObject *__pyx_n_s_callable;
static PyObject *__pyx_n_s_called;
static PyObject *__pyx_n_s_canParseNext;
static PyObject *__pyx_kp_u_cannot_multiply_ParserElement_an;
static PyObject *__pyx_kp_u_cannot_multiply_ParserElement_an_2;
static PyObject *__pyx_kp_u_cannot_multiply_ParserElement_by;
static PyObject *__pyx_kp_u_cannot_multiply_ParserElement_by_2;
static PyObject *__pyx_kp_u_cannot_specify_a_minimum_length;
static PyObject *__pyx_kp_u_cannot_specify_a_minimum_length_2;
static PyObject *__pyx_n_s_caseless;
static PyObject *__pyx_n_s_caselessmatch;
static PyObject *__pyx_n_s_charRange;
static PyObject *__pyx_n_s_chars;
static PyObject *__pyx_n_s_charsAsStr;
static PyObject *__pyx_n_s_checkPeerIndent;
static PyObject *__pyx_n_s_checkRecursion;
static PyObject *__pyx_n_s_checkSubIndent;
static PyObject *__pyx_n_s_checkUnindent;
static PyObject *__pyx_n_s_check_ender;
static PyObject *__pyx_n_s_chr;
static PyObject *__pyx_n_s_class;
static PyObject *__pyx_n_u_class;
static PyObject *__pyx_n_u_class_2;
static PyObject *__pyx_n_s_classattr;
static PyObject *__pyx_n_s_classname;
static PyObject *__pyx_n_s_clear;
static PyObject *__pyx_n_s_close;
static PyObject *__pyx_n_s_closeTag;
static PyObject *__pyx_n_s_closer;
static PyObject *__pyx_n_s_cls;
static PyObject *__pyx_n_s_col;
static PyObject *__pyx_n_u_col;
static PyObject *__pyx_n_s_collections;
static PyObject *__pyx_n_s_colno;
static PyObject *__pyx_n_s_column;
static PyObject *__pyx_n_u_column;
static PyObject *__pyx_n_s_columnName;
static PyObject *__pyx_n_s_columnNameList;
static PyObject *__pyx_n_s_columnSpec;
static PyObject *__pyx_n_u_columns;
static PyObject *__pyx_n_s_combine;
static PyObject *__pyx_n_u_commaItem;
static PyObject *__pyx_n_s_commaSeparatedList;
static PyObject *__pyx_n_u_commaSeparatedList;
static PyObject *__pyx_kp_u_comma_separated_list;
static PyObject *__pyx_n_s_comma_separated_list_2;
static PyObject *__pyx_n_u_command;
static PyObject *__pyx_n_s_commasepitem;
static PyObject *__pyx_n_s_comment;
static PyObject *__pyx_kp_u_comment_2;
static PyObject *__pyx_n_s_comments;
static PyObject *__pyx_n_s_commonHTMLEntity;
static PyObject *__pyx_n_u_commonHTMLEntity;
static PyObject *__pyx_kp_u_common_HTML_entity;
static PyObject *__pyx_n_s_compile;
static PyObject *__pyx_n_s_compiledREtype;
static PyObject *__pyx_n_s_contains;
static PyObject *__pyx_n_s_content;
static PyObject *__pyx_n_s_convertToDate;
static PyObject *__pyx_n_s_convertToDatetime;
static PyObject *__pyx_n_s_convertToFloat;
static PyObject *__pyx_n_s_convertToInteger;
static PyObject *__pyx_n_s_convertWhitespaceEscapes;
static PyObject *__pyx_n_s_copy;
static PyObject *__pyx_n_s_copyDefaultWhiteChars;
static PyObject *__pyx_n_s_copyTokenToRepeater;
static PyObject *__pyx_n_s_count;
static PyObject *__pyx_n_s_countFieldParseAction;
static PyObject *__pyx_n_s_countedArray;
static PyObject *__pyx_n_u_countedArray;
static PyObject *__pyx_n_s_countedArray_locals_countFieldPa;
static PyObject *__pyx_n_s_countedArray_locals_lambda;
static PyObject *__pyx_n_s_cppStyleComment;
static PyObject *__pyx_n_u_cppStyleComment;
static PyObject *__pyx_n_s_cpy;
static PyObject *__pyx_n_s_cur;
static PyObject *__pyx_n_s_curCol;
static PyObject *__pyx_n_s_cvt_fn;
static PyObject *__pyx_n_s_d;
static PyObject *__pyx_kp_u_d_2;
static PyObject *__pyx_kp_u_d_d;
static PyObject *__pyx_kp_u_d_d_2;
static PyObject *__pyx_kp_u_d_d_eE_d;
static PyObject *__pyx_kp_u_d_eE_d_d_eE_d;
static PyObject *__pyx_n_s_data;
static PyObject *__pyx_n_s_date;
static PyObject *__pyx_n_s_datetime;
static PyObject *__pyx_n_s_dblQuotedString;
static PyObject *__pyx_n_u_dblQuotedString;
static PyObject *__pyx_n_s_dblSlashComment;
static PyObject *__pyx_n_u_dblSlashComment;
static PyObject *__pyx_n_s_debug;
static PyObject *__pyx_n_s_debugActions;
static PyObject *__pyx_n_s_debugging;
static PyObject *__pyx_n_s_decode;
static PyObject *__pyx_n_s_default;
static PyObject *__pyx_n_u_default;
static PyObject *__pyx_n_s_defaultExceptionDebugAction;
static PyObject *__pyx_n_s_defaultStartDebugAction;
static PyObject *__pyx_n_s_defaultSuccessDebugAction;
static PyObject *__pyx_n_s_defaultValue;
static PyObject *__pyx_n_s_defaultvalue;
static PyObject *__pyx_n_s_delim;
static PyObject *__pyx_n_s_delimitedList;
static PyObject *__pyx_n_u_delimitedList;
static PyObject *__pyx_n_s_delitem;
static PyObject *__pyx_n_s_depth;
static PyObject *__pyx_n_s_deque;
static PyObject *__pyx_n_s_dictOf;
static PyObject *__pyx_n_u_dictOf;
static PyObject *__pyx_n_s_dictvalue;
static PyObject *__pyx_n_s_dir;
static PyObject *__pyx_n_s_dlName;
static PyObject *__pyx_n_s_doActions;
static PyObject *__pyx_n_s_doc;
static PyObject *__pyx_n_s_doctag;
static PyObject *__pyx_n_s_downcaseTokens;
static PyObject *__pyx_n_u_downcaseTokens;
static PyObject *__pyx_n_s_dummy;
static PyObject *__pyx_n_s_dump;
static PyObject *__pyx_n_s_e;
static PyObject *__pyx_n_s_e2;
static PyObject *__pyx_n_s_elem;
static PyObject *__pyx_n_s_empty;
static PyObject *__pyx_n_u_empty;
static PyObject *__pyx_n_s_enablePackrat;
static PyObject *__pyx_n_s_end;
static PyObject *__pyx_n_u_end;
static PyObject *__pyx_n_s_endQuoteChar;
static PyObject *__pyx_n_s_endQuoteCharLen;
static PyObject *__pyx_kp_u_endQuoteChar_cannot_be_the_empty;
static PyObject *__pyx_n_s_ender;
static PyObject *__pyx_n_s_endloc;
static PyObject *__pyx_n_s_endlocMarker;
static PyObject *__pyx_n_s_endswith;
static PyObject *__pyx_n_s_enter;
static PyObject *__pyx_kp_u_entering_s_line_s_d_r;
static PyObject *__pyx_n_s_entity;
static PyObject *__pyx_n_s_enumerate;
static PyObject *__pyx_n_s_eq;
static PyObject *__pyx_n_s_err;
static PyObject *__pyx_n_s_errmsg;
static PyObject *__pyx_n_s_error;
static PyObject *__pyx_n_s_errorStop;
static PyObject *__pyx_n_s_escChar;
static PyObject *__pyx_n_s_escCharReplacePattern;
static PyObject *__pyx_n_s_escQuote;
static PyObject *__pyx_n_s_escape;
static PyObject *__pyx_n_s_escapeRegexRangeChars;
static PyObject *__pyx_n_s_escapedHexChar;
static PyObject *__pyx_n_s_escapedOctChar;
static PyObject *__pyx_n_s_escapedPunc;
static PyObject *__pyx_n_s_exact;
static PyObject *__pyx_n_s_exc;
static PyObject *__pyx_n_s_exc_info;
static PyObject *__pyx_n_s_exc_type;
static PyObject *__pyx_n_s_exception;
static PyObject *__pyx_n_u_exception;
static PyObject *__pyx_n_s_exceptionAction;
static PyObject *__pyx_kp_s_exception_thrown_by_L_ParserElem;
static PyObject *__pyx_n_s_excludeChars;
static PyObject *__pyx_n_s_exit;
static PyObject *__pyx_n_s_expanded;
static PyObject *__pyx_n_s_expandtabs;
static PyObject *__pyx_n_s_expr;
static PyObject *__pyx_n_s_expr_parse;
static PyObject *__pyx_n_s_exprs;
static PyObject *__pyx_n_s_exprsFound;
static PyObject *__pyx_n_s_exprtokens;
static PyObject *__pyx_n_s_extend;
static PyObject *__pyx_n_s_extractText;
static PyObject *__pyx_n_s_extract_tb;
static PyObject *__pyx_kp_u_f;
static PyObject *__pyx_n_s_f_2;
static PyObject *__pyx_n_s_failAction;
static PyObject *__pyx_n_s_failOn;
static PyObject *__pyx_n_u_failOn;
static PyObject *__pyx_n_s_failed;
static PyObject *__pyx_kp_u_failed_user_defined_condition;
static PyObject *__pyx_n_s_failureTests;
static PyObject *__pyx_n_s_fatal;
static PyObject *__pyx_n_u_fatal;
static PyObject *__pyx_kp_u_ffff;
static PyObject *__pyx_n_s_file_contents;
static PyObject *__pyx_n_s_file_or_filename;
static PyObject *__pyx_n_s_filename;
static PyObject *__pyx_n_s_finalResults;
static PyObject *__pyx_n_s_find;
static PyObject *__pyx_n_s_firstMatchChar;
static PyObject *__pyx_n_s_firstQuoteChar;
static PyObject *__pyx_n_s_flag;
static PyObject *__pyx_n_s_flags;
static PyObject *__pyx_n_s_flatten;
static PyObject *__pyx_n_s_fmt;
static PyObject *__pyx_n_s_fn;
static PyObject *__pyx_n_s_fname;
static PyObject *__pyx_n_s_fns;
static PyObject *__pyx_n_s_fnumber;
static PyObject *__pyx_n_u_fnumber;
static PyObject *__pyx_n_s_formatted;
static PyObject *__pyx_n_s_foundArity;
static PyObject *__pyx_n_s_fraction;
static PyObject *__pyx_n_u_fraction;
static PyObject *__pyx_kp_u_fraction_or_mixed_integer_fracti;
static PyObject *__pyx_n_s_frame_summary;
static PyObject *__pyx_n_s_frames;
static PyObject *__pyx_n_s_from;
static PyObject *__pyx_n_s_fromToken;
static PyObject *__pyx_n_u_from_2;
static PyObject *__pyx_n_s_from_exception;
static PyObject *__pyx_n_s_from_symbols;
static PyObject *__pyx_n_s_full;
static PyObject *__pyx_n_s_fullDump;
static PyObject *__pyx_kp_u_full_IPv6_address;
static PyObject *__pyx_n_s_full_ipv6_address;
static PyObject *__pyx_n_s_func;
static PyObject *__pyx_n_s_func_name;
static PyObject *__pyx_kp_u_g_1;
static PyObject *__pyx_n_s_generatorType;
static PyObject *__pyx_n_s_genexpr;
static PyObject *__pyx_n_s_get;
static PyObject *__pyx_n_s_getName;
static PyObject *__pyx_n_s_getattr;
static PyObject *__pyx_n_s_getitem;
static PyObject *__pyx_n_s_getnewargs;
static PyObject *__pyx_n_s_getstate;
static PyObject *__pyx_n_s_group;
static PyObject *__pyx_n_s_groupdict;
static PyObject *__pyx_kp_u_gt_lt_amp_nbsp_quot_apos;
static PyObject *__pyx_n_s_hasIgnoreExprs;
static PyObject *__pyx_n_s_hash;
static PyObject *__pyx_n_s_haskeys;
static PyObject *__pyx_kp_u_hex_integer;
static PyObject *__pyx_n_s_hex_integer_2;
static PyObject *__pyx_n_u_hex_integer_2;
static PyObject *__pyx_n_s_hexnums;
static PyObject *__pyx_n_u_hexnums;
static PyObject *__pyx_kp_s_home_travis_build_evhub_cpypars;
static PyObject *__pyx_n_s_htmlComment;
static PyObject *__pyx_n_u_htmlComment;
static PyObject *__pyx_n_s_htmlEntityMap;
static PyObject *__pyx_n_s_html_stripper;
static PyObject *__pyx_n_s_i;
static PyObject *__pyx_n_s_iadd;
static PyObject *__pyx_n_s_id;
static PyObject *__pyx_n_s_ident;
static PyObject *__pyx_n_s_identChars;
static PyObject *__pyx_n_s_identifier;
static PyObject *__pyx_n_u_identifier;
static PyObject *__pyx_kp_u_if_numterms_3_opExpr_must_be_a_t;
static PyObject *__pyx_n_s_ignore;
static PyObject *__pyx_n_u_ignore;
static PyObject *__pyx_n_s_ignoreExpr;
static PyObject *__pyx_n_s_ignoreExprs;
static PyObject *__pyx_n_s_ikey;
static PyObject *__pyx_kp_u_illegal_nesting;
static PyObject *__pyx_n_s_ilshift;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_inAccumNames;
static PyObject *__pyx_n_u_include;
static PyObject *__pyx_n_s_includeMatch;
static PyObject *__pyx_n_s_includeSeparators;
static PyObject *__pyx_n_s_indent;
static PyObject *__pyx_n_s_indentStack;
static PyObject *__pyx_n_s_indentedBlock;
static PyObject *__pyx_n_u_indentedBlock;
static PyObject *__pyx_n_s_indentedBlock_locals_checkPeerIn;
static PyObject *__pyx_n_s_indentedBlock_locals_checkSubInd;
static PyObject *__pyx_n_s_indentedBlock_locals_checkUninde;
static PyObject *__pyx_kp_u_indented_block;
static PyObject *__pyx_n_s_index;
static PyObject *__pyx_n_s_indices;
static PyObject *__pyx_n_s_infixNotation;
static PyObject *__pyx_n_u_infixNotation;
static PyObject *__pyx_n_s_init;
static PyObject *__pyx_n_s_initChars;
static PyObject *__pyx_n_s_initCharsOrig;
static PyObject *__pyx_n_s_initExprGroups;
static PyObject *__pyx_n_s_inlineLiteralsUsing;
static PyObject *__pyx_n_s_insStr;
static PyObject *__pyx_n_s_insert;
static PyObject *__pyx_n_s_instring;
static PyObject *__pyx_n_s_instrlen;
static PyObject *__pyx_n_s_intExpr;
static PyObject *__pyx_n_s_integer;
static PyObject *__pyx_n_u_integer;
static PyObject *__pyx_kp_u_invalid_pattern_s_passed_to_Rege;
static PyObject *__pyx_n_s_invert;
static PyObject *__pyx_n_s_ior;
static PyObject *__pyx_n_s_ipv4_address;
static PyObject *__pyx_n_s_ipv6_address;
static PyObject *__pyx_n_s_ipv6_part;
static PyObject *__pyx_n_s_isequal;
static PyObject *__pyx_n_s_isinstance;
static PyObject *__pyx_n_s_iso8601_date;
static PyObject *__pyx_n_s_iso8601_datetime;
static PyObject *__pyx_n_s_isspace;
static PyObject *__pyx_n_s_item;
static PyObject *__pyx_n_s_item_fn;
static PyObject *__pyx_n_s_items;
static PyObject *__pyx_n_s_itemseq;
static PyObject *__pyx_n_s_iter;
static PyObject *__pyx_n_s_iteritems;
static PyObject *__pyx_n_s_iteritems_2;
static PyObject *__pyx_n_s_iterkeys;
static PyObject *__pyx_n_u_iterkeys;
static PyObject *__pyx_n_s_iterkeys_2;
static PyObject *__pyx_n_s_itervalues;
static PyObject *__pyx_n_s_itervalues_2;
static PyObject *__pyx_n_s_ixor;
static PyObject *__pyx_n_s_j;
static PyObject *__pyx_n_s_javaStyleComment;
static PyObject *__pyx_n_u_javaStyleComment;
static PyObject *__pyx_n_s_joinString;
static PyObject *__pyx_kp_s_just_like_L_ParseFatalException;
static PyObject *__pyx_n_s_k;
static PyObject *__pyx_n_s_keepMatching;
static PyObject *__pyx_n_s_keepTabs;
static PyObject *__pyx_n_s_key;
static PyObject *__pyx_n_s_key_fifo;
static PyObject *__pyx_n_s_keys;
static PyObject *__pyx_n_s_kwargs;
static PyObject *__pyx_n_s_l;
static PyObject *__pyx_n_s_lambda;
static PyObject *__pyx_n_s_last;
static PyObject *__pyx_n_s_lastCR;
static PyObject *__pyx_n_s_lastE;
static PyObject *__pyx_n_s_lastExpr;
static PyObject *__pyx_n_s_leaveWhitespace;
static PyObject *__pyx_kp_u_leaving_s_exception_s;
static PyObject *__pyx_kp_u_leaving_s_ret_r;
static PyObject *__pyx_n_s_len;
static PyObject *__pyx_kp_u_len_2;
static PyObject *__pyx_n_s_len_3;
static PyObject *__pyx_n_s_limit;
static PyObject *__pyx_n_s_line;
static PyObject *__pyx_n_u_line;
static PyObject *__pyx_n_s_lineEnd;
static PyObject *__pyx_n_u_lineEnd;
static PyObject *__pyx_n_s_lineStart;
static PyObject *__pyx_n_u_lineStart;
static PyObject *__pyx_n_s_line_column;
static PyObject *__pyx_n_s_line_str;
static PyObject *__pyx_n_s_lineno;
static PyObject *__pyx_n_u_lineno;
static PyObject *__pyx_kp_u_lineno_col_line;
static PyObject *__pyx_n_s_listAllMatches;
static PyObject *__pyx_n_s_literalStringClass;
static PyObject *__pyx_n_s_loc;
static PyObject *__pyx_n_s_loc2;
static PyObject *__pyx_n_s_locMarker;
static PyObject *__pyx_n_s_locatedExpr;
static PyObject *__pyx_n_u_locatedExpr;
static PyObject *__pyx_n_s_locatedExpr_locals_lambda;
static PyObject *__pyx_n_s_locator;
static PyObject *__pyx_n_s_locn;
static PyObject *__pyx_n_u_locn_end;
static PyObject *__pyx_n_u_locn_start;
static PyObject *__pyx_n_s_lookup;
static PyObject *__pyx_n_s_lookup_2;
static PyObject *__pyx_n_s_lower;
static PyObject *__pyx_n_s_lpar;
static PyObject *__pyx_n_s_lshift;
static PyObject *__pyx_n_s_lstrip;
static PyObject *__pyx_n_s_mac_address;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_u_main;
static PyObject *__pyx_n_s_makeHTMLTags;
static PyObject *__pyx_n_u_makeHTMLTags;
static PyObject *__pyx_n_s_makeOptionalList;
static PyObject *__pyx_n_s_makeTags;
static PyObject *__pyx_n_s_makeTags_locals_genexpr;
static PyObject *__pyx_n_s_makeTags_locals_lambda;
static PyObject *__pyx_n_s_makeXMLTags;
static PyObject *__pyx_n_u_makeXMLTags;
static PyObject *__pyx_n_s_map;
static PyObject *__pyx_n_s_markInputline;
static PyObject *__pyx_n_s_markerString;
static PyObject *__pyx_n_s_masks;
static PyObject *__pyx_n_s_mat;
static PyObject *__pyx_n_s_match;
static PyObject *__pyx_n_s_matchExpr;
static PyObject *__pyx_n_s_matchLen;
static PyObject *__pyx_n_s_matchOnlyAtCol;
static PyObject *__pyx_n_u_matchOnlyAtCol;
static PyObject *__pyx_n_s_matchOnlyAtCol_locals_verifyCol;
static PyObject *__pyx_n_s_matchOrder;
static PyObject *__pyx_n_s_matchPreviousExpr;
static PyObject *__pyx_n_u_matchPreviousExpr;
static PyObject *__pyx_n_s_matchPreviousExpr_locals_copyTok;
static PyObject *__pyx_n_s_matchPreviousExpr_locals_copyTok_2;
static PyObject *__pyx_n_s_matchPreviousLiteral;
static PyObject *__pyx_n_u_matchPreviousLiteral;
static PyObject *__pyx_n_s_matchPreviousLiteral_locals_copy;
static PyObject *__pyx_n_s_matchPreviousLiteral_locals_copy_2;
static PyObject *__pyx_n_s_matchString;
static PyObject *__pyx_n_s_matchTokens;
static PyObject *__pyx_n_s_matchWhite;
static PyObject *__pyx_n_s_match_string;
static PyObject *__pyx_n_s_match_stringloc;
static PyObject *__pyx_kp_u_matched_token_not_at_column_d;
static PyObject *__pyx_n_s_matches;
static PyObject *__pyx_n_s_max;
static PyObject *__pyx_n_s_maxExcLoc;
static PyObject *__pyx_n_s_maxException;
static PyObject *__pyx_n_s_maxLen;
static PyObject *__pyx_n_s_maxMatches;
static PyObject *__pyx_n_s_maxMismatches;
static PyObject *__pyx_n_s_maxSpecified;
static PyObject *__pyx_n_s_maxargs;
static PyObject *__pyx_n_s_maxlen;
static PyObject *__pyx_n_s_maxloc;
static PyObject *__pyx_n_s_maxsize;
static PyObject *__pyx_n_s_maxsplit;
static PyObject *__pyx_n_s_mayIndexError;
static PyObject *__pyx_n_s_mayReturnEmpty;
static PyObject *__pyx_n_u_message;
static PyObject *__pyx_n_s_metaclass;
static PyObject *__pyx_n_s_methodCall;
static PyObject *__pyx_n_s_min;
static PyObject *__pyx_n_s_minElements;
static PyObject *__pyx_n_s_minLen;
static PyObject *__pyx_n_s_mismatches;
static PyObject *__pyx_n_u_mismatches;
static PyObject *__pyx_n_s_missing;
static PyObject *__pyx_kp_u_mixed_IPv6_address;
static PyObject *__pyx_n_s_mixed_integer;
static PyObject *__pyx_n_s_mixed_ipv6_address;
static PyObject *__pyx_n_s_modal;
static PyObject *__pyx_n_s_modalResults;
static PyObject *__pyx_n_s_module;
static PyObject *__pyx_n_s_msg;
static PyObject *__pyx_n_s_mul;
static PyObject *__pyx_n_s_multiline;
static PyObject *__pyx_n_s_multioptionals;
static PyObject *__pyx_n_s_multirequired;
static PyObject *__pyx_n_s_mustMatchTheseTokens;
static PyObject *__pyx_n_s_mylen;
static PyObject *__pyx_n_s_n;
static PyObject *__pyx_kp_u_n_2;
static PyObject *__pyx_kp_u_n_n;
static PyObject *__pyx_kp_u_n_r_x_x_0_9a_fA_F;
static PyObject *__pyx_kp_u_n_r_x_x_0_9a_fA_F_2;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_n_u_name;
static PyObject *__pyx_n_s_name_2;
static PyObject *__pyx_n_u_name_2;
static PyObject *__pyx_n_s_namedItems;
static PyObject *__pyx_n_s_namedItemsOnly;
static PyObject *__pyx_n_s_namespace;
static PyObject *__pyx_n_s_ne;
static PyObject *__pyx_n_u_negate;
static PyObject *__pyx_n_s_nestedExpr;
static PyObject *__pyx_n_u_nestedExpr;
static PyObject *__pyx_n_s_nestedExpr_locals_lambda;
static PyObject *__pyx_kp_u_nested_s_s_expression;
static PyObject *__pyx_n_s_new;
static PyObject *__pyx_n_s_newloc;
static PyObject *__pyx_n_s_newself;
static PyObject *__pyx_n_s_nextCR;
static PyObject *__pyx_n_s_nextLevelIndent;
static PyObject *__pyx_n_s_nextLoc;
static PyObject *__pyx_n_s_nextloc;
static PyObject *__pyx_n_s_nl;
static PyObject *__pyx_kp_u_no_defined_alternatives_to_match;
static PyObject *__pyx_kp_u_no_matching_attribute;
static PyObject *__pyx_n_s_nonzero;
static PyObject *__pyx_n_s_notChars;
static PyObject *__pyx_kp_u_not_a_peer_entry;
static PyObject *__pyx_kp_u_not_a_subentry;
static PyObject *__pyx_kp_u_not_an_unindent;
static PyObject *__pyx_n_s_not_ender;
static PyObject *__pyx_n_s_not_in_cache;
static PyObject *__pyx_n_s_notchars;
static PyObject *__pyx_n_s_nullDebugAction;
static PyObject *__pyx_n_u_nullDebugAction;
static PyObject *__pyx_kp_u_null_string_passed_to_Keyword_us;
static PyObject *__pyx_kp_u_null_string_passed_to_Literal_us;
static PyObject *__pyx_kp_u_null_string_passed_to_Regex_use;
static PyObject *__pyx_n_s_number;
static PyObject *__pyx_n_s_nums;
static PyObject *__pyx_n_u_nums;
static PyObject *__pyx_n_s_obj;
static PyObject *__pyx_n_s_object;
static PyObject *__pyx_n_s_occurrences;
static PyObject *__pyx_n_s_offset;
static PyObject *__pyx_n_s_oneOf;
static PyObject *__pyx_n_u_oneOf;
static PyObject *__pyx_n_s_oneOf_locals_genexpr;
static PyObject *__pyx_n_s_oneOf_locals_lambda;
static PyObject *__pyx_n_s_opAssoc;
static PyObject *__pyx_n_u_opAssoc;
static PyObject *__pyx_n_s_opExpr;
static PyObject *__pyx_n_s_opExpr1;
static PyObject *__pyx_n_s_opExpr2;
static PyObject *__pyx_n_s_opList;
static PyObject *__pyx_n_s_open;
static PyObject *__pyx_n_s_openTag;
static PyObject *__pyx_n_s_opener;
static PyObject *__pyx_kp_u_opening_and_closing_arguments_mu;
static PyObject *__pyx_kp_u_opening_and_closing_strings_cann;
static PyObject *__pyx_n_s_operDef;
static PyObject *__pyx_n_s_operatorPrecedence;
static PyObject *__pyx_n_u_operatorPrecedence;
static PyObject *__pyx_kp_u_operator_must_be_unary_1_binary;
static PyObject *__pyx_kp_u_operator_must_indicate_right_or;
static PyObject *__pyx_n_s_opt1;
static PyObject *__pyx_n_s_opt1map;
static PyObject *__pyx_n_s_opt2;
static PyObject *__pyx_n_s_optElements;
static PyObject *__pyx_n_s_optionalNotMatched;
static PyObject *__pyx_n_s_optionals;
static PyObject *__pyx_n_s_or;
static PyObject *__pyx_n_s_ordereddict;
static PyObject *__pyx_n_u_original;
static PyObject *__pyx_n_s_originalParseMethod;
static PyObject *__pyx_n_u_originalParseMethod;
static PyObject *__pyx_n_s_originalTextFor;
static PyObject *__pyx_n_u_originalTextFor;
static PyObject *__pyx_n_s_originalTextFor_locals_extractTe;
static PyObject *__pyx_n_s_originalTextFor_locals_lambda;
static PyObject *__pyx_n_s_original_end;
static PyObject *__pyx_n_u_original_end;
static PyObject *__pyx_n_s_original_start;
static PyObject *__pyx_n_u_original_start;
static PyObject *__pyx_n_s_os;
static PyObject *__pyx_n_s_os_path;
static PyObject *__pyx_n_s_other;
static PyObject *__pyx_n_s_otherdictitems;
static PyObject *__pyx_n_s_otheritems;
static PyObject *__pyx_n_s_out;
static PyObject *__pyx_n_s_overlap;
static PyObject *__pyx_n_s_p;
static PyObject *__pyx_n_s_p1;
static PyObject *__pyx_n_s_p2;
static PyObject *__pyx_n_s_pa;
static PyObject *__pyx_n_s_paArgs;
static PyObject *__pyx_n_s_packratEnabled;
static PyObject *__pyx_n_s_packrat_cache;
static PyObject *__pyx_n_s_packrat_cache_lock;
static PyObject *__pyx_n_s_packrat_cache_stats;
static PyObject *__pyx_n_s_par;
static PyObject *__pyx_n_s_parse;
static PyObject *__pyx_n_s_parseAction;
static PyObject *__pyx_n_s_parseAll;
static PyObject *__pyx_n_s_parseCache;
static PyObject *__pyx_n_s_parseElementClass;
static PyObject *__pyx_n_s_parseElementList;
static PyObject *__pyx_n_s_parseElementTrace;
static PyObject *__pyx_n_s_parseFile;
static PyObject *__pyx_n_s_parseFn;
static PyObject *__pyx_n_s_parseImpl;
static PyObject *__pyx_n_s_parseMethod;
static PyObject *__pyx_n_s_parseNoCache;
static PyObject *__pyx_n_s_parseString;
static PyObject *__pyx_n_s_parseWithTabs;
static PyObject *__pyx_kp_u_parse_action;
static PyObject *__pyx_n_s_parserElement;
static PyObject *__pyx_n_s_pattern;
static PyObject *__pyx_n_s_pdb;
static PyObject *__pyx_n_s_pe;
static PyObject *__pyx_n_s_pop;
static PyObject *__pyx_kp_u_pop_got_an_unexpected_keyword_ar;
static PyObject *__pyx_n_s_popitem;
static PyObject *__pyx_n_s_popleft;
static PyObject *__pyx_n_s_position;
static PyObject *__pyx_n_s_postParse;
static PyObject *__pyx_n_s_pprint;
static PyObject *__pyx_n_s_preParse;
static PyObject *__pyx_n_s_preloc;
static PyObject *__pyx_n_s_prepare;
static PyObject *__pyx_n_s_preparseFn;
static PyObject *__pyx_kp_u_prev;
static PyObject *__pyx_n_s_print;
static PyObject *__pyx_n_s_printResults;
static PyObject *__pyx_n_s_printable;
static PyObject *__pyx_n_s_printables;
static PyObject *__pyx_n_u_printables;
static PyObject *__pyx_n_s_printablesLessRAbrack;
static PyObject *__pyx_n_s_pstr;
static PyObject *__pyx_n_s_punc8bit;
static PyObject *__pyx_n_u_punc8bit;
static PyObject *__pyx_n_s_py_str;
static PyObject *__pyx_n_s_pyparsing_common;
static PyObject *__pyx_n_u_pyparsing_common;
static PyObject *__pyx_n_s_pyparsing_common_convertToDate;
static PyObject *__pyx_n_s_pyparsing_common_convertToDate_l;
static PyObject *__pyx_n_s_pyparsing_common_convertToDateti;
static PyObject *__pyx_n_s_pyparsing_common_convertToDateti_2;
static PyObject *__pyx_n_s_pyparsing_common_lambda;
static PyObject *__pyx_n_s_pyparsing_common_lambda_locals_g;
static PyObject *__pyx_n_s_pyparsing_common_stripHTMLTags;
static PyObject *__pyx_n_s_pythonStyleComment;
static PyObject *__pyx_n_u_pythonStyleComment;
static PyObject *__pyx_n_s_qualname;
static PyObject *__pyx_n_s_quoteChar;
static PyObject *__pyx_n_s_quoteCharLen;
static PyObject *__pyx_kp_u_quoteChar_cannot_be_the_empty_st;
static PyObject *__pyx_n_s_quotedString;
static PyObject *__pyx_n_u_quotedString;
static PyObject *__pyx_kp_u_quotedString_using_single_or_dou;
static PyObject *__pyx_kp_u_quoted_string_starting_with_s_en;
static PyObject *__pyx_n_u_r;
static PyObject *__pyx_kp_u_r_2;
static PyObject *__pyx_n_s_radd;
static PyObject *__pyx_n_s_rand;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_re;
static PyObject *__pyx_n_s_reBracketExpr;
static PyObject *__pyx_n_s_reString;
static PyObject *__pyx_n_s_read;
static PyObject *__pyx_n_s_real;
static PyObject *__pyx_kp_u_real_number;
static PyObject *__pyx_kp_u_real_number_with_scientific_nota;
static PyObject *__pyx_n_s_ref;
static PyObject *__pyx_n_s_register;
static PyObject *__pyx_n_s_remove;
static PyObject *__pyx_n_s_removeQuotes;
static PyObject *__pyx_n_u_removeQuotes;
static PyObject *__pyx_n_s_removed;
static PyObject *__pyx_n_s_rep;
static PyObject *__pyx_n_s_replStr;
static PyObject *__pyx_n_s_replace;
static PyObject *__pyx_n_s_replaceHTMLEntity;
static PyObject *__pyx_n_u_replaceHTMLEntity;
static PyObject *__pyx_n_s_replaceWith;
static PyObject *__pyx_n_u_replaceWith;
static PyObject *__pyx_n_s_replaceWith_locals_lambda;
static PyObject *__pyx_n_s_repr;
static PyObject *__pyx_n_s_repr_2;
static PyObject *__pyx_n_s_repr_3;
static PyObject *__pyx_n_s_req;
static PyObject *__pyx_n_s_required;
static PyObject *__pyx_n_s_res;
static PyObject *__pyx_n_s_resTag;
static PyObject *__pyx_n_s_reset;
static PyObject *__pyx_n_s_resetCache;
static PyObject *__pyx_n_s_resname;
static PyObject *__pyx_n_s_restOfLine;
static PyObject *__pyx_n_u_restOfLine;
static PyObject *__pyx_kp_u_rest_of_line;
static PyObject *__pyx_n_s_result;
static PyObject *__pyx_n_s_resultlist;
static PyObject *__pyx_n_s_results;
static PyObject *__pyx_n_s_resultsName;
static PyObject *__pyx_n_s_ret;
static PyObject *__pyx_n_s_retTokens;
static PyObject *__pyx_n_s_retToks;
static PyObject *__pyx_n_s_retobj;
static PyObject *__pyx_n_s_returnString;
static PyObject *__pyx_n_s_reversed;
static PyObject *__pyx_n_s_reversed_2;
static PyObject *__pyx_n_s_rfind;
static PyObject *__pyx_n_s_rightLeftAssoc;
static PyObject *__pyx_n_s_rmul;
static PyObject *__pyx_n_s_rne;
static PyObject *__pyx_n_s_ror;
static PyObject *__pyx_n_s_rpar;
static PyObject *__pyx_n_s_rstrip;
static PyObject *__pyx_n_s_rsub;
static PyObject *__pyx_n_s_runTests;
static PyObject *__pyx_n_s_rxor;
static PyObject *__pyx_n_s_s;
static PyObject *__pyx_kp_u_s_10;
static PyObject *__pyx_kp_u_s_2;
static PyObject *__pyx_kp_u_s_3;
static PyObject *__pyx_kp_u_s_4;
static PyObject *__pyx_kp_u_s_5;
static PyObject *__pyx_kp_u_s_6;
static PyObject *__pyx_kp_u_s_7;
static PyObject *__pyx_kp_u_s_8;
static PyObject *__pyx_kp_u_s_9;
static PyObject *__pyx_kp_u_s_S;
static PyObject *__pyx_kp_u_s_at_char_d_line_d_col_d;
static PyObject *__pyx_kp_u_s_class;
static PyObject *__pyx_n_s_s_m;
static PyObject *__pyx_kp_u_s_s;
static PyObject *__pyx_kp_u_s_s_2;
static PyObject *__pyx_kp_u_s_s_3;
static PyObject *__pyx_kp_u_s_s_4;
static PyObject *__pyx_kp_u_s_s_5;
static PyObject *__pyx_kp_u_s_s_d_s_s_s;
static PyObject *__pyx_kp_u_s_s_n_r_s;
static PyObject *__pyx_kp_u_s_s_s;
static PyObject *__pyx_kp_u_s_s_s_2;
static PyObject *__pyx_kp_u_s_s_term;
static PyObject *__pyx_kp_u_s_term;
static PyObject *__pyx_n_s_saveAsList;
static PyObject *__pyx_n_s_savelist;
static PyObject *__pyx_n_s_scanString;
static PyObject *__pyx_n_s_sci_real;
static PyObject *__pyx_n_s_se;
static PyObject *__pyx_n_s_searchString;
static PyObject *__pyx_kp_u_second_tuple_value_must_be_great;
static PyObject *__pyx_n_u_select;
static PyObject *__pyx_n_s_selectToken;
static PyObject *__pyx_n_s_self;
static PyObject *__pyx_n_s_selfTag;
static PyObject *__pyx_n_s_self_expr_parse;
static PyObject *__pyx_n_s_self_failOn_canParseNext;
static PyObject *__pyx_n_s_self_ignoreExpr_tryParse;
static PyObject *__pyx_n_s_self_skip_ignorables;
static PyObject *__pyx_n_s_send;
static PyObject *__pyx_n_s_sep;
static PyObject *__pyx_n_s_set;
static PyObject *__pyx_n_s_setBreak;
static PyObject *__pyx_n_s_setDebug;
static PyObject *__pyx_n_s_setDebugActions;
static PyObject *__pyx_n_s_setDefaultKeywordChars;
static PyObject *__pyx_n_s_setDefaultWhitespaceChars;
static PyObject *__pyx_n_s_setFailAction;
static PyObject *__pyx_n_s_setName;
static PyObject *__pyx_n_s_setOffset;
static PyObject *__pyx_n_s_setParseAction;
static PyObject *__pyx_n_s_setResultsName;
static PyObject *__pyx_n_s_setWhitespaceChars;
static PyObject *__pyx_n_s_set_trace;
static PyObject *__pyx_n_s_setitem;
static PyObject *__pyx_n_s_setstate;
static PyObject *__pyx_n_s_sglQuotedString;
static PyObject *__pyx_n_u_sglQuotedString;
static PyObject *__pyx_kp_u_short_IPv6_address;
static PyObject *__pyx_n_s_short_ipv6_address;
static PyObject *__pyx_kp_u_signed_integer;
static PyObject *__pyx_n_s_signed_integer_2;
static PyObject *__pyx_n_s_simpleSQL;
static PyObject *__pyx_n_s_singleArgBuiltins;
static PyObject *__pyx_n_s_singleChar;
static PyObject *__pyx_n_s_size;
static PyObject *__pyx_n_s_skipIgnorables;
static PyObject *__pyx_n_s_skipWhitespace;
static PyObject *__pyx_n_s_skipresult;
static PyObject *__pyx_n_s_skiptext;
static PyObject *__pyx_n_s_smExpr;
static PyObject *__pyx_n_s_sort;
static PyObject *__pyx_n_s_sorted;
static PyObject *__pyx_n_s_split;
static PyObject *__pyx_n_s_splitlines;
static PyObject *__pyx_n_s_splits;
static PyObject *__pyx_n_s_srange;
static PyObject *__pyx_n_u_srange;
static PyObject *__pyx_n_s_srange_locals__expanded;
static PyObject *__pyx_n_s_srange_locals__expanded_locals_g;
static PyObject *__pyx_n_s_srange_locals_genexpr;
static PyObject *__pyx_n_s_src;
static PyObject *__pyx_n_s_sre_constants;
static PyObject *__pyx_n_s_stacklevel;
static PyObject *__pyx_n_s_start;
static PyObject *__pyx_n_u_start;
static PyObject *__pyx_n_s_startAction;
static PyObject *__pyx_n_s_startloc;
static PyObject *__pyx_n_s_startswith;
static PyObject *__pyx_n_s_state;
static PyObject *__pyx_n_s_staticmethod;
static PyObject *__pyx_n_s_stderr;
static PyObject *__pyx_n_s_stopOn;
static PyObject *__pyx_n_s_str;
static PyObject *__pyx_n_s_strRepr;
static PyObject *__pyx_n_s_str_2;
static PyObject *__pyx_n_s_streamline;
static PyObject *__pyx_n_s_streamlined;
static PyObject *__pyx_n_s_strg;
static PyObject *__pyx_n_s_string;
static PyObject *__pyx_n_s_stringEnd;
static PyObject *__pyx_n_u_stringEnd;
static PyObject *__pyx_n_s_stringStart;
static PyObject *__pyx_n_u_stringStart;
static PyObject *__pyx_kp_u_string_enclosed_in_double_quotes;
static PyObject *__pyx_kp_u_string_enclosed_in_single_quotes;
static PyObject *__pyx_n_s_strip;
static PyObject *__pyx_n_s_stripHTMLTags;
static PyObject *__pyx_n_s_strptime;
static PyObject *__pyx_n_s_strs;
static PyObject *__pyx_n_s_sub;
static PyObject *__pyx_n_s_subRecCheckList;
static PyObject *__pyx_n_s_sub_2;
static PyObject *__pyx_n_s_success;
static PyObject *__pyx_n_s_successAction;
static PyObject *__pyx_n_s_sum;
static PyObject *__pyx_kp_u_sum_len_sorted_reversed_list_tup;
static PyObject *__pyx_n_s_super;
static PyObject *__pyx_n_s_suppress;
static PyObject *__pyx_n_s_symbols;
static PyObject *__pyx_n_s_sys;
static PyObject *__pyx_n_s_system_version;
static PyObject *__pyx_n_s_t;
static PyObject *__pyx_kp_u_t_2;
static PyObject *__pyx_n_s_tableName;
static PyObject *__pyx_n_s_tableNameList;
static PyObject *__pyx_n_u_tables;
static PyObject *__pyx_n_s_tag;
static PyObject *__pyx_n_u_tag;
static PyObject *__pyx_n_s_tagAttrName;
static PyObject *__pyx_n_s_tagAttrValue;
static PyObject *__pyx_n_s_tagStr;
static PyObject *__pyx_n_s_tb;
static PyObject *__pyx_n_s_tb_info;
static PyObject *__pyx_n_s_tb_info_synth;
static PyObject *__pyx_n_s_termName;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_testString;
static PyObject *__pyx_n_s_tests;
static PyObject *__pyx_n_s_tflat;
static PyObject *__pyx_n_s_theseTokens;
static PyObject *__pyx_n_s_thisExpr;
static PyObject *__pyx_n_s_thisFunc;
static PyObject *__pyx_n_s_thiscol;
static PyObject *__pyx_n_s_thread;
static PyObject *__pyx_n_s_threading;
static PyObject *__pyx_n_s_throw;
static PyObject *__pyx_n_s_throwException;
static PyObject *__pyx_n_s_title;
static PyObject *__pyx_n_s_tmp;
static PyObject *__pyx_n_s_tmpExprs;
static PyObject *__pyx_n_s_tmpLoc;
static PyObject *__pyx_n_s_tmpOpt;
static PyObject *__pyx_n_s_tmpReqd;
static PyObject *__pyx_n_s_tmploc;
static PyObject *__pyx_n_s_tmptokens;
static PyObject *__pyx_n_s_to;
static PyObject *__pyx_n_s_toItem;
static PyObject *__pyx_n_s_to_symbols;
static PyObject *__pyx_n_s_tok;
static PyObject *__pyx_n_s_tokenMap;
static PyObject *__pyx_n_u_tokenMap;
static PyObject *__pyx_n_s_tokenMap_locals_pa;
static PyObject *__pyx_n_s_tokenlist;
static PyObject *__pyx_n_s_tokens;
static PyObject *__pyx_n_s_tokensStart;
static PyObject *__pyx_n_s_toklist;
static PyObject *__pyx_n_s_toks;
static PyObject *__pyx_n_s_traceParseAction;
static PyObject *__pyx_n_u_traceParseAction;
static PyObject *__pyx_n_s_traceParseAction_locals_z;
static PyObject *__pyx_n_s_traceback;
static PyObject *__pyx_n_s_traceback_2;
static PyObject *__pyx_n_s_transformString;
static PyObject *__pyx_n_s_trim_arity;
static PyObject *__pyx_n_s_trim_arity_locals_extract_tb;
static PyObject *__pyx_n_s_trim_arity_locals_lambda;
static PyObject *__pyx_n_s_trim_arity_locals_wrapper;
static PyObject *__pyx_n_s_tryParse;
static PyObject *__pyx_n_s_try_not_ender;
static PyObject *__pyx_n_s_tup;
static PyObject *__pyx_n_s_types;
static PyObject *__pyx_n_u_u;
static PyObject *__pyx_n_s_ungroup;
static PyObject *__pyx_n_u_ungroup;
static PyObject *__pyx_n_s_ungroup_locals_lambda;
static PyObject *__pyx_n_s_unichr;
static PyObject *__pyx_n_s_unicodeString;
static PyObject *__pyx_n_u_unicodeString;
static PyObject *__pyx_kp_u_unicode_string_literal;
static PyObject *__pyx_n_s_unquoteResults;
static PyObject *__pyx_n_s_upcaseTokens;
static PyObject *__pyx_n_u_upcaseTokens;
static PyObject *__pyx_n_s_update;
static PyObject *__pyx_n_s_upper;
static PyObject *__pyx_n_s_useRegex;
static PyObject *__pyx_kp_s_user_throwable_exception_thrown;
static PyObject *__pyx_n_s_ustr;
static PyObject *__pyx_n_u_utf8;
static PyObject *__pyx_n_s_uuid;
static PyObject *__pyx_n_s_v;
static PyObject *__pyx_n_s_validate;
static PyObject *__pyx_n_s_validateTrace;
static PyObject *__pyx_n_s_value;
static PyObject *__pyx_n_u_value;
static PyObject *__pyx_n_s_values;
static PyObject *__pyx_n_s_vars;
static PyObject *__pyx_n_s_ve;
static PyObject *__pyx_n_s_verbose_stacktrace;
static PyObject *__pyx_n_s_verifyCol;
static PyObject *__pyx_n_s_version;
static PyObject *__pyx_n_s_version_info;
static PyObject *__pyx_n_s_vlist;
static PyObject *__pyx_n_s_vv;
static PyObject *__pyx_kp_u_w;
static PyObject *__pyx_n_s_warn;
static PyObject *__pyx_n_s_warnings;
static PyObject *__pyx_n_s_weakref;
static PyObject *__pyx_n_s_whiteChars;
static PyObject *__pyx_n_s_whiteStrs;
static PyObject *__pyx_n_s_whitespace;
static PyObject *__pyx_n_s_withAttribute;
static PyObject *__pyx_n_u_withAttribute;
static PyObject *__pyx_n_s_withAttribute___new;
static PyObject *__pyx_n_s_withAttribute___new___locals_pa;
static PyObject *__pyx_n_s_withClass;
static PyObject *__pyx_n_u_withClass;
static PyObject *__pyx_n_s_wkref;
static PyObject *__pyx_n_s_wordChars;
static PyObject *__pyx_n_s_wrapper;
static PyObject *__pyx_n_s_write;
static PyObject *__pyx_n_s_ws;
static PyObject *__pyx_n_s_ws_map;
static PyObject *__pyx_n_s_wschar;
static PyObject *__pyx_n_s_wslit;
static PyObject *__pyx_n_s_wt;
static PyObject *__pyx_n_s_xml;
static PyObject *__pyx_n_s_xmlBodyText;
static PyObject *__pyx_n_s_xml_escape;
static PyObject *__pyx_n_s_xml_escape_locals_genexpr;
static PyObject *__pyx_n_s_xor;
static PyObject *__pyx_n_s_xrange;
static PyObject *__pyx_n_s_z;
static PyObject *__pyx_n_s_zip;
static PyObject *__pyx_pf_10cPyparsing_72genexpr(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_75genexpr(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_lambda_funcdef_10cPyparsing_lambda40(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_10cPyparsing_lambda41(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_10cPyparsing_lambda42(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_10cPyparsing_lambda46(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_10cPyparsing_lambda47(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_repr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_obj); /* proto */
static PyObject *__pyx_pf_10cPyparsing_2_ustr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_obj); /* proto */
static PyObject *__pyx_pf_10cPyparsing_11_xml_escape_genexpr(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4_xml_escape(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_data); /* proto */
static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_pstr, PyObject *__pyx_v_loc, PyObject *__pyx_v_msg, PyObject *__pyx_v_elem); /* proto */
static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException_2_from_exception(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_pe); /* proto */
static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException_4__getattr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_aname); /* proto */
static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException_6__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException_8__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException_10markInputline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_markerString); /* proto */
static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException_12__dir__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_25RecursiveGrammarException___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parseElementList); /* proto */
static PyObject *__pyx_pf_10cPyparsing_25RecursiveGrammarException_2__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_23_ParseResultsWithOffset___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_p1, PyObject *__pyx_v_p2); /* proto */
static PyObject *__pyx_pf_10cPyparsing_23_ParseResultsWithOffset_2__getitem__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_i); /* proto */
static PyObject *__pyx_pf_10cPyparsing_23_ParseResultsWithOffset_4__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_23_ParseResultsWithOffset_6setOffset(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_i); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults___new__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_toklist, CYTHON_UNUSED PyObject *__pyx_v_name, CYTHON_UNUSED PyObject *__pyx_v_asList, CYTHON_UNUSED PyObject *__pyx_v_modal); /* proto */
static PyObject *__pyx_pf_10cPyparsing_83__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_2__init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_toklist, PyObject *__pyx_v_name, PyObject *__pyx_v_asList, PyObject *__pyx_v_modal, PyObject *__pyx_v_isinstance); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_4__getitem__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_i); /* proto */
static PyObject *__pyx_pf_10cPyparsing_85__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_6__setitem__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_k, PyObject *__pyx_v_v, PyObject *__pyx_v_isinstance); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_8__delitem__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_i); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_10__contains__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_k); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_12__len__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_14__bool__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_16__iter__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_18__reversed__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_20_iterkeys(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_11_itervalues_genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_22_itervalues(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_10_iteritems_genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_24_iteritems(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_26keys(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_28values(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_30items(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_32haskeys(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_34pop(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_36get(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_defaultValue); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_38insert(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_insStr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_40append(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_item); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_42extend(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_itemseq); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_44clear(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_46__getattr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_48__add__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_8__iadd___addoffset(PyObject *__pyx_self, PyObject *__pyx_v_a); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_50__iadd__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_52__radd__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_54__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_7__str___genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_56__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_58_asStringList(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_sep); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_60asList(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_6asDict_toItem(PyObject *__pyx_self, PyObject *__pyx_v_obj); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_6asDict_2genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_62asDict(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_64copy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_5asXML_genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_66asXML(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_doctag, PyObject *__pyx_v_namedItemsOnly, PyObject *__pyx_v_indent, PyObject *__pyx_v_formatted); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_68__lookup(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_sub); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_70getName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_4dump_genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_4dump_3genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_72dump(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_indent, PyObject *__pyx_v_depth, PyObject *__pyx_v_full); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_74pprint(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_76__getstate__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_78__setstate__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_state); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_80__getnewargs__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12ParseResults_82__dir__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_6col(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_loc, PyObject *__pyx_v_strg); /* proto */
static PyObject *__pyx_pf_10cPyparsing_8lineno(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_loc, PyObject *__pyx_v_strg); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10line(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_loc, PyObject *__pyx_v_strg); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12_defaultStartDebugAction(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_expr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_14_defaultSuccessDebugAction(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_startloc, CYTHON_UNUSED PyObject *__pyx_v_endloc, PyObject *__pyx_v_expr, PyObject *__pyx_v_toks); /* proto */
static PyObject *__pyx_pf_10cPyparsing_16_defaultExceptionDebugAction(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_expr, PyObject *__pyx_v_exc); /* proto */
static PyObject *__pyx_pf_10cPyparsing_18nullDebugAction(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_10cPyparsing_11_trim_arity_extract_tb(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tb, PyObject *__pyx_v_limit); /* proto */
static PyObject *__pyx_pf_10cPyparsing_11_trim_arity_2wrapper(PyObject *__pyx_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda10(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_20_trim_arity(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_func, PyObject *__pyx_v_maxargs); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_setDefaultWhitespaceChars(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_chars); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_2inlineLiteralsUsing(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_4__init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_savelist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_6copy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_8setName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_10setResultsName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_listAllMatches); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_8setBreak_breaker(PyObject *__pyx_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions, PyObject *__pyx_v_callPreParse); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_12setBreak(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_breakFlag); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_14setParseAction(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_fns, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_16addParseAction(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_fns, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_12addCondition_pa(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_18addCondition(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_fns, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_20setFailAction(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_fn); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_22_skipIgnorables(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_24preParse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_26parseImpl(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_28postParse(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED int __pyx_v_loc, PyObject *__pyx_v_tokenlist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_30_parseNoCache(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, PyObject *__pyx_v_doActions, PyObject *__pyx_v_callPreParse); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_32tryParse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_34canParseNext(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15_UnboundedCache_8__init___get(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15_UnboundedCache_8__init___2set(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15_UnboundedCache_8__init___4clear(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15_UnboundedCache_8__init___6cache_len(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15_UnboundedCache___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_8__init___get(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_8__init___2set(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_8__init___4clear(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_8__init___6cache_len(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_FifoCache___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_size); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_8__init___8get(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_8__init___10set(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_8__init___12clear(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_8__init___14cache_len(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_2__init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_size); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_36_parseCache(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, PyObject *__pyx_v_doActions, PyObject *__pyx_v_callPreParse); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_38resetCache(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_40enablePackrat(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cache_size_limit); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_42parseString(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_parseAll); /* proto */
static PyObject *__pyx_pf_10cPyparsing_87__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_44scanString(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_maxMatches, PyObject *__pyx_v_overlap); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_47transformString(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring); /* proto */
static PyObject *__pyx_pf_10cPyparsing_89__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_49searchString(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_maxMatches); /* proto */
static PyObject *__pyx_pf_10cPyparsing_91__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_51split(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_maxsplit, PyObject *__pyx_v_includeSeparators); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_54__add__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_56__radd__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_58__sub__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_60__rsub__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_7__mul___makeOptionalList(PyObject *__pyx_self, PyObject *__pyx_v_n); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_62__mul__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_64__rmul__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_66__or__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_68__ror__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_70__xor__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_72__rxor__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_74__and__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_76__rand__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_78__invert__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_80__call__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_82suppress(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_84leaveWhitespace(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_86setWhitespaceChars(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_chars); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_88parseWithTabs(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_90ignore(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_92setDebugActions(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_startAction, PyObject *__pyx_v_successAction, PyObject *__pyx_v_exceptionAction); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_94setDebug(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_flag); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_96__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_98__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_100streamline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_102checkRecursion(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_parseElementList); /* proto */
static PyObject *__pyx_pf_10cPyparsing_93__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_104validate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_validateTrace); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_106parseFile(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_file_or_filename, PyObject *__pyx_v_parseAll); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_108__eq__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_110__ne__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_112__hash__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_114__req__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_116__rne__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_118matches(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_testString, PyObject *__pyx_v_parseAll); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13ParserElement_120runTests(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_tests, PyObject *__pyx_v_parseAll, PyObject *__pyx_v_comment, PyObject *__pyx_v_fullDump, PyObject *__pyx_v_printResults, PyObject *__pyx_v_failureTests); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5Token___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5Empty___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7NoMatch___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7NoMatch_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Literal___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_matchString); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Literal_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Keyword___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_matchString, PyObject *__pyx_v_identChars, PyObject *__pyx_v_caseless); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Keyword_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Keyword_4copy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Keyword_6setDefaultKeywordChars(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_chars); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15CaselessLiteral___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_matchString); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15CaselessLiteral_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15CaselessKeyword___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_matchString, PyObject *__pyx_v_identChars); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15CaselessKeyword_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10CloseMatch___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_match_string, PyObject *__pyx_v_maxMismatches); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10CloseMatch_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Word_8__init___genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Word_8__init___3genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Word___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_initChars, PyObject *__pyx_v_bodyChars, PyObject *__pyx_v_min, PyObject *__pyx_v_max, PyObject *__pyx_v_exact, PyObject *__pyx_v_asKeyword, PyObject *__pyx_v_excludeChars); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Word_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Word_7__str___charsAsStr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Word_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5Regex___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_pattern, PyObject *__pyx_v_flags); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5Regex_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5Regex_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12QuotedString_8__init___genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12QuotedString___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_quoteChar, PyObject *__pyx_v_escChar, PyObject *__pyx_v_escQuote, PyObject *__pyx_v_multiline, PyObject *__pyx_v_unquoteResults, PyObject *__pyx_v_endQuoteChar, PyObject *__pyx_v_convertWhitespaceEscapes); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12QuotedString_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12QuotedString_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10CharsNotIn___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_notChars, PyObject *__pyx_v_min, PyObject *__pyx_v_max, PyObject *__pyx_v_exact); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10CharsNotIn_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10CharsNotIn_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5White_8__init___genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5White_8__init___3genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5White___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_ws, PyObject *__pyx_v_min, PyObject *__pyx_v_max, PyObject *__pyx_v_exact); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5White_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_14_PositionToken___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10GoToColumn___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_colno); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10GoToColumn_2preParse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10GoToColumn_4parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_9LineStart___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_9LineStart_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7LineEnd___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7LineEnd_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_11StringStart___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_11StringStart_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_9StringEnd___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_9StringEnd_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_95__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_9WordStart___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_wordChars); /* proto */
static PyObject *__pyx_pf_10cPyparsing_9WordStart_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_97__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7WordEnd___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_wordChars); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7WordEnd_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_8__init___genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15ParseExpression___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exprs, PyObject *__pyx_v_savelist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_2__getitem__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_i); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_4append(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_6leaveWhitespace(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_8ignore(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_10__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_12streamline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_14setResultsName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_listAllMatches); /* proto */
static PyObject *__pyx_pf_10cPyparsing_99__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_16validate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_validateTrace); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_18copy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_ErrorStop___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_10cPyparsing_3And_8__init___genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_3And___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exprs, PyObject *__pyx_v_savelist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_3And_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_3And_4__iadd__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_3And_6checkRecursion(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parseElementList); /* proto */
static PyObject *__pyx_pf_10cPyparsing_3And_7__str___genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_3And_8__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_2Or_8__init___genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_2Or___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exprs, PyObject *__pyx_v_savelist); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda20(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_x); /* proto */
static PyObject *__pyx_pf_10cPyparsing_2Or_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_2Or_4__ixor__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_2Or_7__str___genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_2Or_6__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_2Or_8checkRecursion(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parseElementList); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_8__init___genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10MatchFirst___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exprs, PyObject *__pyx_v_savelist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_4__ior__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_7__str___genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_6__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_8checkRecursion(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parseElementList); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Each_8__init___genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Each___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exprs, PyObject *__pyx_v_savelist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Each_9parseImpl_genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Each_9parseImpl_3genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Each_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Each_7__str___genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Each_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Each_6checkRecursion(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parseElementList); /* proto */
static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_savelist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_4leaveWhitespace(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_6ignore(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_8streamline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_10checkRecursion(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parseElementList); /* proto */
static PyObject *__pyx_pf_10cPyparsing_101__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_12validate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_validateTrace); /* proto */
static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_14__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10FollowedBy___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10FollowedBy_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_6NotAny___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_6NotAny_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_6NotAny_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_14_MultipleMatch___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_stopOn); /* proto */
static PyObject *__pyx_pf_10cPyparsing_14_MultipleMatch_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_9OneOrMore___str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10ZeroOrMore___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_stopOn); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10ZeroOrMore_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10ZeroOrMore_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_NullToken___bool__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_10_NullToken_2__str__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_103__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_8Optional___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_default); /* proto */
static PyObject *__pyx_pf_10cPyparsing_8Optional_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_8Optional_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_6SkipTo___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_10cPyparsing_6SkipTo_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, PyObject *__pyx_v_doActions); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Forward___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Forward_2__lshift__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Forward_4__ilshift__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Forward_6leaveWhitespace(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Forward_8streamline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_105__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Forward_10validate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_validateTrace); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Forward_12__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Forward_14copy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_17_ForwardNoRecurse___str__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_14TokenConverter___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, CYTHON_UNUSED PyObject *__pyx_v_savelist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Combine___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_joinString, PyObject *__pyx_v_adjacent); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Combine_2ignore(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_10cPyparsing_7Combine_4postParse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_loc, PyObject *__pyx_v_tokenlist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5Group___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5Group_2postParse(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_loc, PyObject *__pyx_v_tokenlist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Dict___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_4Dict_2postParse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_loc, PyObject *__pyx_v_tokenlist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_8Suppress_postParse(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_tokenlist); /* proto */
static PyObject *__pyx_pf_10cPyparsing_8Suppress_2suppress(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_8OnlyOnce___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_methodCall); /* proto */
static PyObject *__pyx_pf_10cPyparsing_8OnlyOnce_2__call__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_8OnlyOnce_4reset(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_16traceParseAction_z(PyObject *__pyx_self, PyObject *__pyx_v_paArgs); /* proto */
static PyObject *__pyx_pf_10cPyparsing_22traceParseAction(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_f); /* proto */
static PyObject *__pyx_pf_10cPyparsing_24delimitedList(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_delim, PyObject *__pyx_v_combine); /* proto */
static PyObject *__pyx_pf_10cPyparsing_12countedArray_countFieldParseAction(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda28(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_26countedArray(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_intExpr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_28_flatten(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_L); /* proto */
static PyObject *__pyx_pf_10cPyparsing_20matchPreviousLiteral_19copyTokenToRepeater_genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_20matchPreviousLiteral_copyTokenToRepeater(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_30matchPreviousLiteral(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_17matchPreviousExpr_19copyTokenToRepeater_mustMatchTheseTokens(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_17matchPreviousExpr_copyTokenToRepeater(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_32matchPreviousExpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_34_escapeRegexRangeChars(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda30(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_a, PyObject *__pyx_v_b); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda31(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_a, PyObject *__pyx_v_b); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda32(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_a, PyObject *__pyx_v_b); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda33(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_a, PyObject *__pyx_v_b); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5oneOf_4genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5oneOf_7genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_5oneOf_10genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_36oneOf(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_strs, PyObject *__pyx_v_caseless, PyObject *__pyx_v_useRegex); /* proto */
static PyObject *__pyx_pf_10cPyparsing_38dictOf(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15originalTextFor_extractText(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_15originalTextFor_2extractText(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda37(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_40originalTextFor(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_asString); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda38(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_42ungroup(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda39(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, PyObject *__pyx_v_l, CYTHON_UNUSED PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_44locatedExpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_6srange_9_expanded_genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_6srange__expanded(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_p); /* proto */
static PyObject *__pyx_pf_10cPyparsing_6srange_2genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_10cPyparsing_46srange(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s); /* proto */
static PyObject *__pyx_pf_10cPyparsing_14matchOnlyAtCol_verifyCol(PyObject *__pyx_self, PyObject *__pyx_v_strg, PyObject *__pyx_v_locn, CYTHON_UNUSED PyObject *__pyx_v_toks); /* proto */
static PyObject *__pyx_pf_10cPyparsing_48matchOnlyAtCol(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_n); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda45(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, CYTHON_UNUSED PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_50replaceWith(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_replStr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_52removeQuotes(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_8tokenMap_pa(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_54tokenMap(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_func, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda48(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_9_makeTags_1genexpr(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda50(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_56_makeTags(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tagStr, PyObject *__pyx_v_xml); /* proto */
static PyObject *__pyx_pf_10cPyparsing_58makeHTMLTags(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tagStr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_60makeXMLTags(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tagStr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13withAttribute_7__new___pa(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, PyObject *__pyx_v_tokens); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13withAttribute___new__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_args, PyObject *__pyx_v_attrDict); /* proto */
static PyObject *__pyx_pf_10cPyparsing_62withClass(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_classname, PyObject *__pyx_v_namespace); /* proto */
static PyObject *__pyx_pf_10cPyparsing_64infixNotation(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_baseExpr, PyObject *__pyx_v_opList, PyObject *__pyx_v_lpar, PyObject *__pyx_v_rpar); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda51(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda52(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda53(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda54(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_66nestedExpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_opener, PyObject *__pyx_v_closer, PyObject *__pyx_v_content, PyObject *__pyx_v_ignoreExpr); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13indentedBlock_checkPeerIndent(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, CYTHON_UNUSED PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13indentedBlock_2checkSubIndent(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, CYTHON_UNUSED PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_13indentedBlock_4checkUnindent(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, CYTHON_UNUSED PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_68indentedBlock(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_blockStatementExpr, PyObject *__pyx_v_indentStack, PyObject *__pyx_v_indent); /* proto */
static PyObject *__pyx_pf_10cPyparsing_70replaceHTMLEntity(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda55(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_16pyparsing_common_8lambda56_genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda58(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda59(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_16pyparsing_common_13convertToDate_cvt_fn(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_16pyparsing_common_convertToDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_fmt); /* proto */
static PyObject *__pyx_pf_10cPyparsing_16pyparsing_common_17convertToDatetime_cvt_fn(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_10cPyparsing_16pyparsing_common_2convertToDatetime(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_fmt); /* proto */
static PyObject *__pyx_pf_10cPyparsing_16pyparsing_common_4stripHTMLTags(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_tokens); /* proto */
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct__genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_1_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_2_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_3__itervalues(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_4_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_5__iteritems(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_6_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_7___iadd__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_8___str__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_9_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_10_asDict(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_11_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_12_asXML(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_13_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_14_dump(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_15_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_16_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_17__trim_arity(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_18_setBreak(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_19_addCondition(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_20___init__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_21___init__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_22___init__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_23_scanString(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_24_split(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_25___mul__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_26___init__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_27_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_28_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_29___init__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_30_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_31___init__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_32_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_33_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_34___init__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_35_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_36___init__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_37_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_38___str__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_39_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_40___init__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_41_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_42___str__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_43_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_44___init__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_45_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_46___str__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_47_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_48___init__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_49_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_50_parseImpl(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_51_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_52_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_53___str__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_54_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_55_traceParseAction(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_56_countedArray(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_59_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_62_oneOf(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_63_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_64_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_65_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_66_srange(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_67__expanded(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_68_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_69_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_71_replaceWith(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_72_tokenMap(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_73_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_74___new__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_75_indentedBlock(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_77_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_78_convertToDate(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_79_convertToDatetime(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_items = {0, &__pyx_n_s_items, 0, 0, 0};
static __Pyx_CachedCFunction __pyx_umethod_PyList_Type_pop = {0, &__pyx_n_s_pop, 0, 0, 0};
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_2;
static PyObject *__pyx_int_3;
static PyObject *__pyx_int_4;
static PyObject *__pyx_int_5;
static PyObject *__pyx_int_6;
static PyObject *__pyx_int_7;
static PyObject *__pyx_int_8;
static PyObject *__pyx_int_16;
static PyObject *__pyx_int_92;
static PyObject *__pyx_int_128;
static PyObject *__pyx_int_1056;
static PyObject *__pyx_int_neg_1;
static PyObject *__pyx_k__187;
static PyObject *__pyx_k__188;
static PyObject *__pyx_k__196;
static PyObject *__pyx_tuple_;
static PyObject *__pyx_slice__3;
static PyObject *__pyx_tuple__2;
static PyObject *__pyx_tuple__4;
static PyObject *__pyx_tuple__5;
static PyObject *__pyx_slice__11;
static PyObject *__pyx_slice__12;
static PyObject *__pyx_slice__13;
static PyObject *__pyx_slice__27;
static PyObject *__pyx_slice__28;
static PyObject *__pyx_slice__36;
static PyObject *__pyx_slice__37;
static PyObject *__pyx_slice__40;
static PyObject *__pyx_slice__73;
static PyObject *__pyx_slice__75;
static PyObject *__pyx_slice__87;
static PyObject *__pyx_tuple__14;
static PyObject *__pyx_tuple__19;
static PyObject *__pyx_tuple__29;
static PyObject *__pyx_tuple__30;
static PyObject *__pyx_tuple__32;
static PyObject *__pyx_tuple__33;
static PyObject *__pyx_tuple__35;
static PyObject *__pyx_tuple__39;
static PyObject *__pyx_tuple__41;
static PyObject *__pyx_tuple__43;
static PyObject *__pyx_tuple__44;
static PyObject *__pyx_tuple__46;
static PyObject *__pyx_tuple__48;
static PyObject *__pyx_tuple__50;
static PyObject *__pyx_tuple__52;
static PyObject *__pyx_tuple__54;
static PyObject *__pyx_tuple__55;
static PyObject *__pyx_tuple__57;
static PyObject *__pyx_tuple__59;
static PyObject *__pyx_tuple__61;
static PyObject *__pyx_tuple__63;
static PyObject *__pyx_tuple__65;
static PyObject *__pyx_tuple__67;
static PyObject *__pyx_tuple__69;
static PyObject *__pyx_tuple__71;
static PyObject *__pyx_tuple__72;
static PyObject *__pyx_tuple__74;
static PyObject *__pyx_tuple__76;
static PyObject *__pyx_tuple__77;
static PyObject *__pyx_tuple__78;
static PyObject *__pyx_tuple__79;
static PyObject *__pyx_tuple__81;
static PyObject *__pyx_tuple__83;
static PyObject *__pyx_tuple__86;
static PyObject *__pyx_tuple__89;
static PyObject *__pyx_tuple__91;
static PyObject *__pyx_slice__101;
static PyObject *__pyx_slice__104;
static PyObject *__pyx_slice__105;
static PyObject *__pyx_slice__106;
static PyObject *__pyx_slice__107;
static PyObject *__pyx_slice__109;
static PyObject *__pyx_slice__110;
static PyObject *__pyx_slice__114;
static PyObject *__pyx_slice__116;
static PyObject *__pyx_slice__117;
static PyObject *__pyx_slice__118;
static PyObject *__pyx_slice__120;
static PyObject *__pyx_slice__121;
static PyObject *__pyx_slice__122;
static PyObject *__pyx_slice__126;
static PyObject *__pyx_slice__128;
static PyObject *__pyx_slice__149;
static PyObject *__pyx_slice__163;
static PyObject *__pyx_slice__190;
static PyObject *__pyx_tuple__100;
static PyObject *__pyx_tuple__103;
static PyObject *__pyx_tuple__130;
static PyObject *__pyx_tuple__134;
static PyObject *__pyx_tuple__136;
static PyObject *__pyx_tuple__137;
static PyObject *__pyx_tuple__139;
static PyObject *__pyx_tuple__140;
static PyObject *__pyx_tuple__142;
static PyObject *__pyx_tuple__144;
static PyObject *__pyx_tuple__145;
static PyObject *__pyx_tuple__147;
static PyObject *__pyx_tuple__148;
static PyObject *__pyx_tuple__150;
static PyObject *__pyx_tuple__151;
static PyObject *__pyx_tuple__152;
static PyObject *__pyx_tuple__154;
static PyObject *__pyx_tuple__156;
static PyObject *__pyx_tuple__157;
static PyObject *__pyx_tuple__158;
static PyObject *__pyx_tuple__159;
static PyObject *__pyx_tuple__161;
static PyObject *__pyx_tuple__164;
static PyObject *__pyx_tuple__168;
static PyObject *__pyx_tuple__169;
static PyObject *__pyx_tuple__171;
static PyObject *__pyx_tuple__172;
static PyObject *__pyx_tuple__173;
static PyObject *__pyx_tuple__174;
static PyObject *__pyx_tuple__175;
static PyObject *__pyx_tuple__176;
static PyObject *__pyx_tuple__177;
static PyObject *__pyx_tuple__178;
static PyObject *__pyx_tuple__179;
static PyObject *__pyx_tuple__180;
static PyObject *__pyx_tuple__181;
static PyObject *__pyx_tuple__183;
static PyObject *__pyx_tuple__184;
static PyObject *__pyx_tuple__185;
static PyObject *__pyx_tuple__189;
static PyObject *__pyx_tuple__191;
static PyObject *__pyx_tuple__192;
static PyObject *__pyx_tuple__193;
static PyObject *__pyx_tuple__194;
static PyObject *__pyx_tuple__197;
static PyObject *__pyx_tuple__198;
static PyObject *__pyx_tuple__199;
static PyObject *__pyx_tuple__201;
static PyObject *__pyx_tuple__203;
static PyObject *__pyx_tuple__206;
static PyObject *__pyx_tuple__207;
static PyObject *__pyx_tuple__208;
static PyObject *__pyx_tuple__209;
static PyObject *__pyx_tuple__210;
static PyObject *__pyx_tuple__211;
static PyObject *__pyx_tuple__213;
static PyObject *__pyx_tuple__215;
static PyObject *__pyx_tuple__217;
static PyObject *__pyx_tuple__219;
static PyObject *__pyx_tuple__221;
static PyObject *__pyx_tuple__222;
static PyObject *__pyx_tuple__224;
static PyObject *__pyx_tuple__225;
static PyObject *__pyx_tuple__227;
static PyObject *__pyx_tuple__229;
static PyObject *__pyx_tuple__231;
static PyObject *__pyx_tuple__233;
static PyObject *__pyx_tuple__235;
static PyObject *__pyx_tuple__236;
static PyObject *__pyx_tuple__238;
static PyObject *__pyx_tuple__240;
static PyObject *__pyx_tuple__242;
static PyObject *__pyx_tuple__244;
static PyObject *__pyx_tuple__246;
static PyObject *__pyx_tuple__248;
static PyObject *__pyx_tuple__250;
static PyObject *__pyx_tuple__252;
static PyObject *__pyx_tuple__253;
static PyObject *__pyx_tuple__255;
static PyObject *__pyx_tuple__257;
static PyObject *__pyx_tuple__259;
static PyObject *__pyx_tuple__261;
static PyObject *__pyx_tuple__263;
static PyObject *__pyx_tuple__265;
static PyObject *__pyx_tuple__267;
static PyObject *__pyx_tuple__269;
static PyObject *__pyx_tuple__271;
static PyObject *__pyx_tuple__273;
static PyObject *__pyx_tuple__275;
static PyObject *__pyx_tuple__277;
static PyObject *__pyx_tuple__279;
static PyObject *__pyx_tuple__281;
static PyObject *__pyx_tuple__283;
static PyObject *__pyx_tuple__285;
static PyObject *__pyx_tuple__287;
static PyObject *__pyx_tuple__289;
static PyObject *__pyx_tuple__290;
static PyObject *__pyx_tuple__292;
static PyObject *__pyx_tuple__294;
static PyObject *__pyx_tuple__296;
static PyObject *__pyx_tuple__298;
static PyObject *__pyx_tuple__300;
static PyObject *__pyx_tuple__302;
static PyObject *__pyx_tuple__304;
static PyObject *__pyx_tuple__306;
static PyObject *__pyx_tuple__308;
static PyObject *__pyx_tuple__310;
static PyObject *__pyx_tuple__312;
static PyObject *__pyx_tuple__313;
static PyObject *__pyx_tuple__315;
static PyObject *__pyx_tuple__317;
static PyObject *__pyx_tuple__319;
static PyObject *__pyx_tuple__321;
static PyObject *__pyx_tuple__322;
static PyObject *__pyx_tuple__324;
static PyObject *__pyx_tuple__326;
static PyObject *__pyx_tuple__328;
static PyObject *__pyx_tuple__329;
static PyObject *__pyx_tuple__331;
static PyObject *__pyx_tuple__333;
static PyObject *__pyx_tuple__335;
static PyObject *__pyx_tuple__337;
static PyObject *__pyx_tuple__339;
static PyObject *__pyx_tuple__341;
static PyObject *__pyx_tuple__343;
static PyObject *__pyx_tuple__345;
static PyObject *__pyx_tuple__347;
static PyObject *__pyx_tuple__349;
static PyObject *__pyx_tuple__351;
static PyObject *__pyx_tuple__353;
static PyObject *__pyx_tuple__356;
static PyObject *__pyx_tuple__358;
static PyObject *__pyx_tuple__360;
static PyObject *__pyx_tuple__362;
static PyObject *__pyx_tuple__363;
static PyObject *__pyx_tuple__365;
static PyObject *__pyx_tuple__367;
static PyObject *__pyx_tuple__369;
static PyObject *__pyx_tuple__370;
static PyObject *__pyx_tuple__372;
static PyObject *__pyx_tuple__373;
static PyObject *__pyx_tuple__375;
static PyObject *__pyx_tuple__377;
static PyObject *__pyx_tuple__379;
static PyObject *__pyx_tuple__381;
static PyObject *__pyx_tuple__383;
static PyObject *__pyx_tuple__385;
static PyObject *__pyx_tuple__387;
static PyObject *__pyx_tuple__388;
static PyObject *__pyx_tuple__390;
static PyObject *__pyx_tuple__392;
static PyObject *__pyx_tuple__393;
static PyObject *__pyx_tuple__395;
static PyObject *__pyx_tuple__397;
static PyObject *__pyx_tuple__399;
static PyObject *__pyx_tuple__401;
static PyObject *__pyx_tuple__403;
static PyObject *__pyx_tuple__405;
static PyObject *__pyx_tuple__407;
static PyObject *__pyx_tuple__409;
static PyObject *__pyx_tuple__410;
static PyObject *__pyx_tuple__412;
static PyObject *__pyx_tuple__413;
static PyObject *__pyx_tuple__415;
static PyObject *__pyx_tuple__417;
static PyObject *__pyx_tuple__419;
static PyObject *__pyx_tuple__421;
static PyObject *__pyx_tuple__423;
static PyObject *__pyx_tuple__425;
static PyObject *__pyx_tuple__427;
static PyObject *__pyx_tuple__429;
static PyObject *__pyx_tuple__431;
static PyObject *__pyx_tuple__433;
static PyObject *__pyx_tuple__435;
static PyObject *__pyx_tuple__437;
static PyObject *__pyx_tuple__439;
static PyObject *__pyx_tuple__441;
static PyObject *__pyx_tuple__443;
static PyObject *__pyx_tuple__445;
static PyObject *__pyx_tuple__447;
static PyObject *__pyx_tuple__449;
static PyObject *__pyx_tuple__450;
static PyObject *__pyx_tuple__452;
static PyObject *__pyx_tuple__454;
static PyObject *__pyx_tuple__456;
static PyObject *__pyx_tuple__458;
static PyObject *__pyx_tuple__460;
static PyObject *__pyx_tuple__462;
static PyObject *__pyx_tuple__464;
static PyObject *__pyx_tuple__465;
static PyObject *__pyx_tuple__467;
static PyObject *__pyx_tuple__469;
static PyObject *__pyx_tuple__471;
static PyObject *__pyx_tuple__473;
static PyObject *__pyx_tuple__475;
static PyObject *__pyx_tuple__477;
static PyObject *__pyx_tuple__478;
static PyObject *__pyx_tuple__480;
static PyObject *__pyx_tuple__482;
static PyObject *__pyx_tuple__484;
static PyObject *__pyx_tuple__486;
static PyObject *__pyx_tuple__488;
static PyObject *__pyx_tuple__490;
static PyObject *__pyx_tuple__491;
static PyObject *__pyx_tuple__493;
static PyObject *__pyx_tuple__494;
static PyObject *__pyx_tuple__496;
static PyObject *__pyx_tuple__498;
static PyObject *__pyx_tuple__500;
static PyObject *__pyx_tuple__502;
static PyObject *__pyx_tuple__503;
static PyObject *__pyx_tuple__505;
static PyObject *__pyx_tuple__507;
static PyObject *__pyx_tuple__509;
static PyObject *__pyx_tuple__511;
static PyObject *__pyx_tuple__512;
static PyObject *__pyx_tuple__514;
static PyObject *__pyx_tuple__515;
static PyObject *__pyx_tuple__517;
static PyObject *__pyx_tuple__519;
static PyObject *__pyx_tuple__521;
static PyObject *__pyx_tuple__523;
static PyObject *__pyx_tuple__524;
static PyObject *__pyx_tuple__526;
static PyObject *__pyx_tuple__527;
static PyObject *__pyx_tuple__529;
static PyObject *__pyx_tuple__530;
static PyObject *__pyx_tuple__532;
static PyObject *__pyx_tuple__533;
static PyObject *__pyx_tuple__535;
static PyObject *__pyx_tuple__536;
static PyObject *__pyx_tuple__538;
static PyObject *__pyx_tuple__539;
static PyObject *__pyx_tuple__541;
static PyObject *__pyx_tuple__542;
static PyObject *__pyx_tuple__544;
static PyObject *__pyx_tuple__545;
static PyObject *__pyx_tuple__547;
static PyObject *__pyx_tuple__548;
static PyObject *__pyx_tuple__550;
static PyObject *__pyx_tuple__551;
static PyObject *__pyx_tuple__553;
static PyObject *__pyx_tuple__555;
static PyObject *__pyx_tuple__556;
static PyObject *__pyx_tuple__558;
static PyObject *__pyx_tuple__559;
static PyObject *__pyx_tuple__561;
static PyObject *__pyx_tuple__563;
static PyObject *__pyx_tuple__564;
static PyObject *__pyx_tuple__566;
static PyObject *__pyx_tuple__567;
static PyObject *__pyx_tuple__569;
static PyObject *__pyx_tuple__571;
static PyObject *__pyx_tuple__572;
static PyObject *__pyx_tuple__574;
static PyObject *__pyx_tuple__575;
static PyObject *__pyx_tuple__577;
static PyObject *__pyx_tuple__579;
static PyObject *__pyx_tuple__581;
static PyObject *__pyx_tuple__583;
static PyObject *__pyx_tuple__584;
static PyObject *__pyx_tuple__586;
static PyObject *__pyx_tuple__588;
static PyObject *__pyx_tuple__589;
static PyObject *__pyx_tuple__591;
static PyObject *__pyx_tuple__593;
static PyObject *__pyx_tuple__594;
static PyObject *__pyx_tuple__596;
static PyObject *__pyx_tuple__598;
static PyObject *__pyx_tuple__599;
static PyObject *__pyx_tuple__601;
static PyObject *__pyx_tuple__603;
static PyObject *__pyx_tuple__604;
static PyObject *__pyx_tuple__606;
static PyObject *__pyx_tuple__608;
static PyObject *__pyx_tuple__609;
static PyObject *__pyx_tuple__611;
static PyObject *__pyx_tuple__613;
static PyObject *__pyx_tuple__614;
static PyObject *__pyx_tuple__616;
static PyObject *__pyx_tuple__617;
static PyObject *__pyx_tuple__619;
static PyObject *__pyx_tuple__621;
static PyObject *__pyx_tuple__623;
static PyObject *__pyx_tuple__625;
static PyObject *__pyx_tuple__627;
static PyObject *__pyx_tuple__629;
static PyObject *__pyx_tuple__631;
static PyObject *__pyx_tuple__632;
static PyObject *__pyx_tuple__634;
static PyObject *__pyx_tuple__636;
static PyObject *__pyx_tuple__638;
static PyObject *__pyx_tuple__640;
static PyObject *__pyx_tuple__641;
static PyObject *__pyx_tuple__643;
static PyObject *__pyx_tuple__644;
static PyObject *__pyx_tuple__646;
static PyObject *__pyx_tuple__648;
static PyObject *__pyx_tuple__650;
static PyObject *__pyx_tuple__652;
static PyObject *__pyx_tuple__654;
static PyObject *__pyx_tuple__656;
static PyObject *__pyx_tuple__657;
static PyObject *__pyx_tuple__659;
static PyObject *__pyx_tuple__661;
static PyObject *__pyx_tuple__663;
static PyObject *__pyx_tuple__665;
static PyObject *__pyx_tuple__666;
static PyObject *__pyx_tuple__668;
static PyObject *__pyx_tuple__669;
static PyObject *__pyx_tuple__671;
static PyObject *__pyx_tuple__673;
static PyObject *__pyx_tuple__675;
static PyObject *__pyx_tuple__677;
static PyObject *__pyx_tuple__678;
static PyObject *__pyx_tuple__680;
static PyObject *__pyx_tuple__681;
static PyObject *__pyx_tuple__683;
static PyObject *__pyx_tuple__685;
static PyObject *__pyx_tuple__687;
static PyObject *__pyx_tuple__688;
static PyObject *__pyx_tuple__690;
static PyObject *__pyx_tuple__691;
static PyObject *__pyx_tuple__693;
static PyObject *__pyx_tuple__695;
static PyObject *__pyx_tuple__697;
static PyObject *__pyx_tuple__699;
static PyObject *__pyx_tuple__701;
static PyObject *__pyx_tuple__703;
static PyObject *__pyx_tuple__705;
static PyObject *__pyx_tuple__707;
static PyObject *__pyx_tuple__708;
static PyObject *__pyx_tuple__710;
static PyObject *__pyx_tuple__712;
static PyObject *__pyx_tuple__713;
static PyObject *__pyx_tuple__715;
static PyObject *__pyx_tuple__717;
static PyObject *__pyx_tuple__718;
static PyObject *__pyx_tuple__720;
static PyObject *__pyx_tuple__721;
static PyObject *__pyx_tuple__723;
static PyObject *__pyx_tuple__725;
static PyObject *__pyx_tuple__726;
static PyObject *__pyx_tuple__728;
static PyObject *__pyx_tuple__729;
static PyObject *__pyx_tuple__731;
static PyObject *__pyx_tuple__733;
static PyObject *__pyx_tuple__735;
static PyObject *__pyx_tuple__737;
static PyObject *__pyx_tuple__739;
static PyObject *__pyx_tuple__740;
static PyObject *__pyx_tuple__742;
static PyObject *__pyx_tuple__744;
static PyObject *__pyx_tuple__746;
static PyObject *__pyx_tuple__747;
static PyObject *__pyx_tuple__749;
static PyObject *__pyx_tuple__750;
static PyObject *__pyx_tuple__752;
static PyObject *__pyx_tuple__754;
static PyObject *__pyx_tuple__756;
static PyObject *__pyx_tuple__758;
static PyObject *__pyx_tuple__760;
static PyObject *__pyx_tuple__762;
static PyObject *__pyx_tuple__764;
static PyObject *__pyx_tuple__766;
static PyObject *__pyx_tuple__768;
static PyObject *__pyx_tuple__769;
static PyObject *__pyx_tuple__771;
static PyObject *__pyx_tuple__772;
static PyObject *__pyx_tuple__774;
static PyObject *__pyx_tuple__776;
static PyObject *__pyx_tuple__778;
static PyObject *__pyx_tuple__780;
static PyObject *__pyx_tuple__782;
static PyObject *__pyx_tuple__784;
static PyObject *__pyx_tuple__786;
static PyObject *__pyx_tuple__788;
static PyObject *__pyx_tuple__790;
static PyObject *__pyx_tuple__792;
static PyObject *__pyx_tuple__794;
static PyObject *__pyx_tuple__796;
static PyObject *__pyx_tuple__798;
static PyObject *__pyx_tuple__800;
static PyObject *__pyx_tuple__802;
static PyObject *__pyx_tuple__804;
static PyObject *__pyx_tuple__806;
static PyObject *__pyx_tuple__808;
static PyObject *__pyx_tuple__810;
static PyObject *__pyx_tuple__812;
static PyObject *__pyx_tuple__814;
static PyObject *__pyx_tuple__816;
static PyObject *__pyx_tuple__818;
static PyObject *__pyx_tuple__819;
static PyObject *__pyx_tuple__820;
static PyObject *__pyx_tuple__821;
static PyObject *__pyx_tuple__822;
static PyObject *__pyx_tuple__824;
static PyObject *__pyx_tuple__825;
static PyObject *__pyx_tuple__827;
static PyObject *__pyx_tuple__828;
static PyObject *__pyx_tuple__829;
static PyObject *__pyx_tuple__830;
static PyObject *__pyx_tuple__831;
static PyObject *__pyx_tuple__832;
static PyObject *__pyx_tuple__834;
static PyObject *__pyx_tuple__836;
static PyObject *__pyx_tuple__838;
static PyObject *__pyx_tuple__840;
static PyObject *__pyx_tuple__842;
static PyObject *__pyx_tuple__844;
static PyObject *__pyx_tuple__846;
static PyObject *__pyx_tuple__848;
static PyObject *__pyx_tuple__850;
static PyObject *__pyx_tuple__852;
static PyObject *__pyx_tuple__853;
static PyObject *__pyx_tuple__854;
static PyObject *__pyx_tuple__856;
static PyObject *__pyx_tuple__858;
static PyObject *__pyx_tuple__859;
static PyObject *__pyx_tuple__861;
static PyObject *__pyx_tuple__862;
static PyObject *__pyx_tuple__863;
static PyObject *__pyx_tuple__864;
static PyObject *__pyx_tuple__865;
static PyObject *__pyx_tuple__866;
static PyObject *__pyx_tuple__867;
static PyObject *__pyx_tuple__869;
static PyObject *__pyx_tuple__871;
static PyObject *__pyx_tuple__872;
static PyObject *__pyx_tuple__874;
static PyObject *__pyx_tuple__877;
static PyObject *__pyx_tuple__878;
static PyObject *__pyx_tuple__881;
static PyObject *__pyx_tuple__883;
static PyObject *__pyx_tuple__884;
static PyObject *__pyx_tuple__885;
static PyObject *__pyx_tuple__887;
static PyObject *__pyx_tuple__888;
static PyObject *__pyx_tuple__889;
static PyObject *__pyx_tuple__890;
static PyObject *__pyx_tuple__891;
static PyObject *__pyx_tuple__892;
static PyObject *__pyx_tuple__894;
static PyObject *__pyx_tuple__895;
static PyObject *__pyx_tuple__897;
static PyObject *__pyx_tuple__898;
static PyObject *__pyx_tuple__899;
static PyObject *__pyx_tuple__900;
static PyObject *__pyx_tuple__901;
static PyObject *__pyx_tuple__902;
static PyObject *__pyx_tuple__903;
static PyObject *__pyx_tuple__904;
static PyObject *__pyx_tuple__905;
static PyObject *__pyx_tuple__906;
static PyObject *__pyx_tuple__907;
static PyObject *__pyx_tuple__908;
static PyObject *__pyx_tuple__909;
static PyObject *__pyx_tuple__910;
static PyObject *__pyx_tuple__911;
static PyObject *__pyx_tuple__912;
static PyObject *__pyx_tuple__913;
static PyObject *__pyx_tuple__914;
static PyObject *__pyx_tuple__915;
static PyObject *__pyx_tuple__916;
static PyObject *__pyx_tuple__917;
static PyObject *__pyx_tuple__918;
static PyObject *__pyx_tuple__919;
static PyObject *__pyx_tuple__920;
static PyObject *__pyx_tuple__922;
static PyObject *__pyx_tuple__923;
static PyObject *__pyx_tuple__924;
static PyObject *__pyx_tuple__925;
static PyObject *__pyx_tuple__926;
static PyObject *__pyx_tuple__927;
static PyObject *__pyx_tuple__928;
static PyObject *__pyx_tuple__929;
static PyObject *__pyx_tuple__931;
static PyObject *__pyx_tuple__932;
static PyObject *__pyx_tuple__934;
static PyObject *__pyx_tuple__935;
static PyObject *__pyx_tuple__936;
static PyObject *__pyx_tuple__937;
static PyObject *__pyx_tuple__938;
static PyObject *__pyx_tuple__939;
static PyObject *__pyx_tuple__940;
static PyObject *__pyx_tuple__941;
static PyObject *__pyx_tuple__943;
static PyObject *__pyx_tuple__944;
static PyObject *__pyx_tuple__945;
static PyObject *__pyx_tuple__946;
static PyObject *__pyx_tuple__947;
static PyObject *__pyx_tuple__948;
static PyObject *__pyx_tuple__949;
static PyObject *__pyx_tuple__950;
static PyObject *__pyx_tuple__951;
static PyObject *__pyx_tuple__952;
static PyObject *__pyx_tuple__953;
static PyObject *__pyx_tuple__954;
static PyObject *__pyx_tuple__955;
static PyObject *__pyx_tuple__956;
static PyObject *__pyx_tuple__957;
static PyObject *__pyx_tuple__958;
static PyObject *__pyx_codeobj__15;
static PyObject *__pyx_codeobj__20;
static PyObject *__pyx_codeobj__31;
static PyObject *__pyx_codeobj__34;
static PyObject *__pyx_codeobj__42;
static PyObject *__pyx_codeobj__45;
static PyObject *__pyx_codeobj__47;
static PyObject *__pyx_codeobj__49;
static PyObject *__pyx_codeobj__51;
static PyObject *__pyx_codeobj__53;
static PyObject *__pyx_codeobj__56;
static PyObject *__pyx_codeobj__58;
static PyObject *__pyx_codeobj__60;
static PyObject *__pyx_codeobj__62;
static PyObject *__pyx_codeobj__64;
static PyObject *__pyx_codeobj__66;
static PyObject *__pyx_codeobj__68;
static PyObject *__pyx_codeobj__70;
static PyObject *__pyx_codeobj__80;
static PyObject *__pyx_codeobj__90;
static PyObject *__pyx_codeobj__131;
static PyObject *__pyx_codeobj__135;
static PyObject *__pyx_codeobj__138;
static PyObject *__pyx_codeobj__141;
static PyObject *__pyx_codeobj__143;
static PyObject *__pyx_codeobj__153;
static PyObject *__pyx_codeobj__155;
static PyObject *__pyx_codeobj__160;
static PyObject *__pyx_codeobj__162;
static PyObject *__pyx_codeobj__165;
static PyObject *__pyx_codeobj__186;
static PyObject *__pyx_codeobj__200;
static PyObject *__pyx_codeobj__202;
static PyObject *__pyx_codeobj__204;
static PyObject *__pyx_codeobj__212;
static PyObject *__pyx_codeobj__214;
static PyObject *__pyx_codeobj__216;
static PyObject *__pyx_codeobj__218;
static PyObject *__pyx_codeobj__220;
static PyObject *__pyx_codeobj__223;
static PyObject *__pyx_codeobj__226;
static PyObject *__pyx_codeobj__228;
static PyObject *__pyx_codeobj__230;
static PyObject *__pyx_codeobj__232;
static PyObject *__pyx_codeobj__234;
static PyObject *__pyx_codeobj__237;
static PyObject *__pyx_codeobj__239;
static PyObject *__pyx_codeobj__241;
static PyObject *__pyx_codeobj__243;
static PyObject *__pyx_codeobj__245;
static PyObject *__pyx_codeobj__247;
static PyObject *__pyx_codeobj__249;
static PyObject *__pyx_codeobj__251;
static PyObject *__pyx_codeobj__254;
static PyObject *__pyx_codeobj__256;
static PyObject *__pyx_codeobj__258;
static PyObject *__pyx_codeobj__260;
static PyObject *__pyx_codeobj__262;
static PyObject *__pyx_codeobj__264;
static PyObject *__pyx_codeobj__266;
static PyObject *__pyx_codeobj__268;
static PyObject *__pyx_codeobj__270;
static PyObject *__pyx_codeobj__272;
static PyObject *__pyx_codeobj__274;
static PyObject *__pyx_codeobj__276;
static PyObject *__pyx_codeobj__278;
static PyObject *__pyx_codeobj__280;
static PyObject *__pyx_codeobj__282;
static PyObject *__pyx_codeobj__284;
static PyObject *__pyx_codeobj__286;
static PyObject *__pyx_codeobj__288;
static PyObject *__pyx_codeobj__291;
static PyObject *__pyx_codeobj__293;
static PyObject *__pyx_codeobj__295;
static PyObject *__pyx_codeobj__297;
static PyObject *__pyx_codeobj__299;
static PyObject *__pyx_codeobj__301;
static PyObject *__pyx_codeobj__303;
static PyObject *__pyx_codeobj__305;
static PyObject *__pyx_codeobj__307;
static PyObject *__pyx_codeobj__309;
static PyObject *__pyx_codeobj__311;
static PyObject *__pyx_codeobj__314;
static PyObject *__pyx_codeobj__316;
static PyObject *__pyx_codeobj__318;
static PyObject *__pyx_codeobj__320;
static PyObject *__pyx_codeobj__323;
static PyObject *__pyx_codeobj__325;
static PyObject *__pyx_codeobj__327;
static PyObject *__pyx_codeobj__330;
static PyObject *__pyx_codeobj__332;
static PyObject *__pyx_codeobj__334;
static PyObject *__pyx_codeobj__336;
static PyObject *__pyx_codeobj__338;
static PyObject *__pyx_codeobj__340;
static PyObject *__pyx_codeobj__342;
static PyObject *__pyx_codeobj__344;
static PyObject *__pyx_codeobj__346;
static PyObject *__pyx_codeobj__348;
static PyObject *__pyx_codeobj__350;
static PyObject *__pyx_codeobj__352;
static PyObject *__pyx_codeobj__354;
static PyObject *__pyx_codeobj__357;
static PyObject *__pyx_codeobj__359;
static PyObject *__pyx_codeobj__361;
static PyObject *__pyx_codeobj__364;
static PyObject *__pyx_codeobj__366;
static PyObject *__pyx_codeobj__368;
static PyObject *__pyx_codeobj__371;
static PyObject *__pyx_codeobj__374;
static PyObject *__pyx_codeobj__376;
static PyObject *__pyx_codeobj__378;
static PyObject *__pyx_codeobj__380;
static PyObject *__pyx_codeobj__382;
static PyObject *__pyx_codeobj__384;
static PyObject *__pyx_codeobj__386;
static PyObject *__pyx_codeobj__389;
static PyObject *__pyx_codeobj__391;
static PyObject *__pyx_codeobj__394;
static PyObject *__pyx_codeobj__396;
static PyObject *__pyx_codeobj__398;
static PyObject *__pyx_codeobj__400;
static PyObject *__pyx_codeobj__402;
static PyObject *__pyx_codeobj__404;
static PyObject *__pyx_codeobj__406;
static PyObject *__pyx_codeobj__408;
static PyObject *__pyx_codeobj__411;
static PyObject *__pyx_codeobj__414;
static PyObject *__pyx_codeobj__416;
static PyObject *__pyx_codeobj__418;
static PyObject *__pyx_codeobj__420;
static PyObject *__pyx_codeobj__422;
static PyObject *__pyx_codeobj__424;
static PyObject *__pyx_codeobj__426;
static PyObject *__pyx_codeobj__428;
static PyObject *__pyx_codeobj__430;
static PyObject *__pyx_codeobj__432;
static PyObject *__pyx_codeobj__434;
static PyObject *__pyx_codeobj__436;
static PyObject *__pyx_codeobj__438;
static PyObject *__pyx_codeobj__440;
static PyObject *__pyx_codeobj__442;
static PyObject *__pyx_codeobj__444;
static PyObject *__pyx_codeobj__446;
static PyObject *__pyx_codeobj__448;
static PyObject *__pyx_codeobj__451;
static PyObject *__pyx_codeobj__453;
static PyObject *__pyx_codeobj__455;
static PyObject *__pyx_codeobj__457;
static PyObject *__pyx_codeobj__459;
static PyObject *__pyx_codeobj__461;
static PyObject *__pyx_codeobj__463;
static PyObject *__pyx_codeobj__466;
static PyObject *__pyx_codeobj__468;
static PyObject *__pyx_codeobj__470;
static PyObject *__pyx_codeobj__472;
static PyObject *__pyx_codeobj__474;
static PyObject *__pyx_codeobj__476;
static PyObject *__pyx_codeobj__479;
static PyObject *__pyx_codeobj__481;
static PyObject *__pyx_codeobj__483;
static PyObject *__pyx_codeobj__485;
static PyObject *__pyx_codeobj__487;
static PyObject *__pyx_codeobj__489;
static PyObject *__pyx_codeobj__492;
static PyObject *__pyx_codeobj__495;
static PyObject *__pyx_codeobj__497;
static PyObject *__pyx_codeobj__499;
static PyObject *__pyx_codeobj__501;
static PyObject *__pyx_codeobj__504;
static PyObject *__pyx_codeobj__506;
static PyObject *__pyx_codeobj__510;
static PyObject *__pyx_codeobj__513;
static PyObject *__pyx_codeobj__516;
static PyObject *__pyx_codeobj__518;
static PyObject *__pyx_codeobj__520;
static PyObject *__pyx_codeobj__522;
static PyObject *__pyx_codeobj__525;
static PyObject *__pyx_codeobj__528;
static PyObject *__pyx_codeobj__531;
static PyObject *__pyx_codeobj__534;
static PyObject *__pyx_codeobj__537;
static PyObject *__pyx_codeobj__540;
static PyObject *__pyx_codeobj__543;
static PyObject *__pyx_codeobj__546;
static PyObject *__pyx_codeobj__549;
static PyObject *__pyx_codeobj__552;
static PyObject *__pyx_codeobj__554;
static PyObject *__pyx_codeobj__557;
static PyObject *__pyx_codeobj__560;
static PyObject *__pyx_codeobj__562;
static PyObject *__pyx_codeobj__565;
static PyObject *__pyx_codeobj__568;
static PyObject *__pyx_codeobj__570;
static PyObject *__pyx_codeobj__573;
static PyObject *__pyx_codeobj__576;
static PyObject *__pyx_codeobj__578;
static PyObject *__pyx_codeobj__580;
static PyObject *__pyx_codeobj__582;
static PyObject *__pyx_codeobj__585;
static PyObject *__pyx_codeobj__587;
static PyObject *__pyx_codeobj__590;
static PyObject *__pyx_codeobj__592;
static PyObject *__pyx_codeobj__595;
static PyObject *__pyx_codeobj__597;
static PyObject *__pyx_codeobj__600;
static PyObject *__pyx_codeobj__602;
static PyObject *__pyx_codeobj__605;
static PyObject *__pyx_codeobj__607;
static PyObject *__pyx_codeobj__610;
static PyObject *__pyx_codeobj__612;
static PyObject *__pyx_codeobj__615;
static PyObject *__pyx_codeobj__618;
static PyObject *__pyx_codeobj__620;
static PyObject *__pyx_codeobj__622;
static PyObject *__pyx_codeobj__624;
static PyObject *__pyx_codeobj__626;
static PyObject *__pyx_codeobj__628;
static PyObject *__pyx_codeobj__630;
static PyObject *__pyx_codeobj__633;
static PyObject *__pyx_codeobj__635;
static PyObject *__pyx_codeobj__637;
static PyObject *__pyx_codeobj__639;
static PyObject *__pyx_codeobj__642;
static PyObject *__pyx_codeobj__645;
static PyObject *__pyx_codeobj__647;
static PyObject *__pyx_codeobj__649;
static PyObject *__pyx_codeobj__651;
static PyObject *__pyx_codeobj__655;
static PyObject *__pyx_codeobj__658;
static PyObject *__pyx_codeobj__660;
static PyObject *__pyx_codeobj__662;
static PyObject *__pyx_codeobj__664;
static PyObject *__pyx_codeobj__667;
static PyObject *__pyx_codeobj__670;
static PyObject *__pyx_codeobj__672;
static PyObject *__pyx_codeobj__674;
static PyObject *__pyx_codeobj__676;
static PyObject *__pyx_codeobj__679;
static PyObject *__pyx_codeobj__682;
static PyObject *__pyx_codeobj__684;
static PyObject *__pyx_codeobj__686;
static PyObject *__pyx_codeobj__689;
static PyObject *__pyx_codeobj__692;
static PyObject *__pyx_codeobj__694;
static PyObject *__pyx_codeobj__696;
static PyObject *__pyx_codeobj__698;
static PyObject *__pyx_codeobj__700;
static PyObject *__pyx_codeobj__702;
static PyObject *__pyx_codeobj__704;
static PyObject *__pyx_codeobj__706;
static PyObject *__pyx_codeobj__709;
static PyObject *__pyx_codeobj__711;
static PyObject *__pyx_codeobj__714;
static PyObject *__pyx_codeobj__716;
static PyObject *__pyx_codeobj__719;
static PyObject *__pyx_codeobj__722;
static PyObject *__pyx_codeobj__724;
static PyObject *__pyx_codeobj__727;
static PyObject *__pyx_codeobj__730;
static PyObject *__pyx_codeobj__732;
static PyObject *__pyx_codeobj__734;
static PyObject *__pyx_codeobj__736;
static PyObject *__pyx_codeobj__738;
static PyObject *__pyx_codeobj__741;
static PyObject *__pyx_codeobj__743;
static PyObject *__pyx_codeobj__745;
static PyObject *__pyx_codeobj__748;
static PyObject *__pyx_codeobj__751;
static PyObject *__pyx_codeobj__753;
static PyObject *__pyx_codeobj__755;
static PyObject *__pyx_codeobj__757;
static PyObject *__pyx_codeobj__759;
static PyObject *__pyx_codeobj__761;
static PyObject *__pyx_codeobj__763;
static PyObject *__pyx_codeobj__765;
static PyObject *__pyx_codeobj__767;
static PyObject *__pyx_codeobj__770;
static PyObject *__pyx_codeobj__773;
static PyObject *__pyx_codeobj__775;
static PyObject *__pyx_codeobj__777;
static PyObject *__pyx_codeobj__779;
static PyObject *__pyx_codeobj__781;
static PyObject *__pyx_codeobj__783;
static PyObject *__pyx_codeobj__785;
static PyObject *__pyx_codeobj__787;
static PyObject *__pyx_codeobj__789;
static PyObject *__pyx_codeobj__791;
static PyObject *__pyx_codeobj__793;
static PyObject *__pyx_codeobj__795;
static PyObject *__pyx_codeobj__797;
static PyObject *__pyx_codeobj__799;
static PyObject *__pyx_codeobj__801;
static PyObject *__pyx_codeobj__803;
static PyObject *__pyx_codeobj__805;
static PyObject *__pyx_codeobj__807;
static PyObject *__pyx_codeobj__809;
static PyObject *__pyx_codeobj__811;
static PyObject *__pyx_codeobj__813;
static PyObject *__pyx_codeobj__815;
static PyObject *__pyx_codeobj__817;
static PyObject *__pyx_codeobj__833;
static PyObject *__pyx_codeobj__835;
static PyObject *__pyx_codeobj__837;
static PyObject *__pyx_codeobj__839;
static PyObject *__pyx_codeobj__841;
static PyObject *__pyx_codeobj__843;
static PyObject *__pyx_codeobj__845;
static PyObject *__pyx_codeobj__847;
static PyObject *__pyx_codeobj__849;
static PyObject *__pyx_codeobj__851;
static PyObject *__pyx_codeobj__855;
static PyObject *__pyx_codeobj__868;
static PyObject *__pyx_codeobj__870;
static PyObject *__pyx_codeobj__879;
static PyObject *__pyx_codeobj__930;
static PyObject *__pyx_codeobj__933;
static PyObject *__pyx_codeobj__942;
static PyObject *__pyx_gb_10cPyparsing_74generator2(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":158
 *             continue
 * 
 * _generatorType = type((y for y in range(1)))             # <<<<<<<<<<<<<<
 * 
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_72genexpr(CYTHON_UNUSED PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct__genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct__genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 158, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_74generator2, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 158, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_74generator2(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 158, __pyx_L1_error)
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_range); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple_, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 158, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 158, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_2); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 158, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 158, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_2); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 158, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 158, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      }
    } else {
      __pyx_t_2 = __pyx_t_4(__pyx_t_1);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 158, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_y);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_y, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_y);
    __pyx_r = __pyx_cur_scope->__pyx_v_y;
    __Pyx_XGIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_3;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_4;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_1);
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_4 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 158, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_77generator4(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":181
 * alphanums = alphas + nums
 * _bslash = chr(92)
 * printables = "".join(c for c in string.printable if c not in string.whitespace)             # <<<<<<<<<<<<<<
 * 
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_75genexpr(CYTHON_UNUSED PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_2_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_2_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 181, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_77generator4, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 181, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_77generator4(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 181, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_string); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_printable); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 181, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 181, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_2); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 181, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 181, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_2); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 181, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 181, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      }
    } else {
      __pyx_t_2 = __pyx_t_4(__pyx_t_1);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 181, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_c);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_c, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_string); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 181, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_whitespace); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 181, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_cur_scope->__pyx_v_c, __pyx_t_5, Py_NE)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 181, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_7 = (__pyx_t_6 != 0);
    if (__pyx_t_7) {
      if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_cur_scope->__pyx_v_c))) __PYX_ERR(0, 181, __pyx_L1_error)
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4831
 * stringEnd = StringEnd().setName("stringEnd")
 * 
 * _escapedPunc = Word(_bslash, r"\[]-*.$+^?()~ ", exact=2).setParseAction(lambda s, l, t: t[0][1])             # <<<<<<<<<<<<<<
 * _escapedHexChar = Regex(r"\\0?[xX][0-9a-fA-F]+").setParseAction(lambda s, l, t: unichr(int(t[0].lstrip(r'\0x'), 16)))
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_78lambda40(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_78lambda40 = {"lambda40", (PyCFunction)__pyx_pw_10cPyparsing_78lambda40, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_78lambda40(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda40 (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("lambda40", 1, 3, 3, 1); __PYX_ERR(0, 4831, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("lambda40", 1, 3, 3, 2); __PYX_ERR(0, 4831, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "lambda40") < 0)) __PYX_ERR(0, 4831, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda40", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4831, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.lambda40", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_10cPyparsing_lambda40(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_10cPyparsing_lambda40(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("lambda40", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.lambda40", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4832
 * 
 * _escapedPunc = Word(_bslash, r"\[]-*.$+^?()~ ", exact=2).setParseAction(lambda s, l, t: t[0][1])
 * _escapedHexChar = Regex(r"\\0?[xX][0-9a-fA-F]+").setParseAction(lambda s, l, t: unichr(int(t[0].lstrip(r'\0x'), 16)))             # <<<<<<<<<<<<<<
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | Word(printables, excludeChars=r'\]', exact=1) | Regex(r"\w", re.UNICODE)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_79lambda41(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_79lambda41 = {"lambda41", (PyCFunction)__pyx_pw_10cPyparsing_79lambda41, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_79lambda41(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda41 (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("lambda41", 1, 3, 3, 1); __PYX_ERR(0, 4832, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("lambda41", 1, 3, 3, 2); __PYX_ERR(0, 4832, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "lambda41") < 0)) __PYX_ERR(0, 4832, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda41", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4832, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.lambda41", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_10cPyparsing_lambda41(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_10cPyparsing_lambda41(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("lambda41", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_unichr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_lstrip); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __Pyx_INCREF(__pyx_int_16);
  __Pyx_GIVEREF(__pyx_int_16);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_int_16);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)(&PyInt_Type)), __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4832, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4832, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4832, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4832, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4832, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.lambda41", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4833
 * _escapedPunc = Word(_bslash, r"\[]-*.$+^?()~ ", exact=2).setParseAction(lambda s, l, t: t[0][1])
 * _escapedHexChar = Regex(r"\\0?[xX][0-9a-fA-F]+").setParseAction(lambda s, l, t: unichr(int(t[0].lstrip(r'\0x'), 16)))
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))             # <<<<<<<<<<<<<<
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | Word(printables, excludeChars=r'\]', exact=1) | Regex(r"\w", re.UNICODE)
 * _charRange = Group(_singleChar + Suppress("-") + _singleChar)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_80lambda42(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_80lambda42 = {"lambda42", (PyCFunction)__pyx_pw_10cPyparsing_80lambda42, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_80lambda42(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda42 (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("lambda42", 1, 3, 3, 1); __PYX_ERR(0, 4833, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("lambda42", 1, 3, 3, 2); __PYX_ERR(0, 4833, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "lambda42") < 0)) __PYX_ERR(0, 4833, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda42", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4833, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.lambda42", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_10cPyparsing_lambda42(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_10cPyparsing_lambda42(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("lambda42", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_unichr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_t_3, 1, 0, NULL, NULL, &__pyx_slice__3, 1, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4);
  __Pyx_INCREF(__pyx_int_8);
  __Pyx_GIVEREF(__pyx_int_8);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_8);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)(&PyInt_Type)), __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4833, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4833, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4833, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4833, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4833, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.lambda42", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4950
 * 
 * 
 * upcaseTokens = tokenMap(lambda t: _ustr(t).upper())             # <<<<<<<<<<<<<<
 * """(Deprecated) Helper parse action to convert tokens to upper case. Deprecated in favor of L{pyparsing_common.upcaseTokens}"""
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_81lambda46(PyObject *__pyx_self, PyObject *__pyx_v_t); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_81lambda46 = {"lambda46", (PyCFunction)__pyx_pw_10cPyparsing_81lambda46, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_81lambda46(PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda46 (wrapper)", 0);
  __pyx_r = __pyx_lambda_funcdef_10cPyparsing_lambda46(__pyx_self, ((PyObject *)__pyx_v_t));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_10cPyparsing_lambda46(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("lambda46", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_t); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4950, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_t};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4950, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_t};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4950, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4950, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_INCREF(__pyx_v_t);
      __Pyx_GIVEREF(__pyx_v_t);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_t);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4950, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_upper); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4950, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4950, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.lambda46", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4953
 * """(Deprecated) Helper parse action to convert tokens to upper case. Deprecated in favor of L{pyparsing_common.upcaseTokens}"""
 * 
 * downcaseTokens = tokenMap(lambda t: _ustr(t).lower())             # <<<<<<<<<<<<<<
 * """(Deprecated) Helper parse action to convert tokens to lower case. Deprecated in favor of L{pyparsing_common.downcaseTokens}"""
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_82lambda47(PyObject *__pyx_self, PyObject *__pyx_v_t); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_82lambda47 = {"lambda47", (PyCFunction)__pyx_pw_10cPyparsing_82lambda47, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_82lambda47(PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda47 (wrapper)", 0);
  __pyx_r = __pyx_lambda_funcdef_10cPyparsing_lambda47(__pyx_self, ((PyObject *)__pyx_v_t));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_10cPyparsing_lambda47(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("lambda47", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_t); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4953, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_t};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4953, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_t};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4953, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4953, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_INCREF(__pyx_v_t);
      __Pyx_GIVEREF(__pyx_v_t);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_t);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4953, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_lower); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4953, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4953, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.lambda47", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":118
 * 
 *     _repr = repr
 *     def repr(obj):             # <<<<<<<<<<<<<<
 *         if isinstance(obj, unicode):
 *             return _repr(obj).lstrip("u")
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_1repr(PyObject *__pyx_self, PyObject *__pyx_v_obj); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_1repr = {"repr", (PyCFunction)__pyx_pw_10cPyparsing_1repr, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_1repr(PyObject *__pyx_self, PyObject *__pyx_v_obj) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("repr (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_repr(__pyx_self, ((PyObject *)__pyx_v_obj));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_repr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_obj) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("repr", 0);

  /* "cPyparsing.pyx":119
 *     _repr = repr
 *     def repr(obj):
 *         if isinstance(obj, unicode):             # <<<<<<<<<<<<<<
 *             return _repr(obj).lstrip("u")
 *         else:
 */
  __pyx_t_1 = PyUnicode_Check(__pyx_v_obj); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":120
 *     def repr(obj):
 *         if isinstance(obj, unicode):
 *             return _repr(obj).lstrip("u")             # <<<<<<<<<<<<<<
 *         else:
 *             return _repr(obj)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_repr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_obj); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 120, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_obj};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 120, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_obj};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 120, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 120, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_INCREF(__pyx_v_obj);
        __Pyx_GIVEREF(__pyx_v_obj);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_obj);
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 120, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_lstrip); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":119
 *     _repr = repr
 *     def repr(obj):
 *         if isinstance(obj, unicode):             # <<<<<<<<<<<<<<
 *             return _repr(obj).lstrip("u")
 *         else:
 */
  }

  /* "cPyparsing.pyx":122
 *             return _repr(obj).lstrip("u")
 *         else:
 *             return _repr(obj)             # <<<<<<<<<<<<<<
 * 
 *     str = unicode
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_repr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 122, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_obj); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 122, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_obj};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 122, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_obj};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 122, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      {
        __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 122, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_v_obj);
        __Pyx_GIVEREF(__pyx_v_obj);
        PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_obj);
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 122, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":118
 * 
 *     _repr = repr
 *     def repr(obj):             # <<<<<<<<<<<<<<
 *         if isinstance(obj, unicode):
 *             return _repr(obj).lstrip("u")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.repr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":125
 * 
 *     str = unicode
 *     def _ustr(obj):             # <<<<<<<<<<<<<<
 *         if isinstance(obj, py_str):
 *             obj = obj.decode("utf8")
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_3_ustr(PyObject *__pyx_self, PyObject *__pyx_v_obj); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_3_ustr = {"_ustr", (PyCFunction)__pyx_pw_10cPyparsing_3_ustr, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_3_ustr(PyObject *__pyx_self, PyObject *__pyx_v_obj) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_ustr (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_2_ustr(__pyx_self, ((PyObject *)__pyx_v_obj));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_2_ustr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_obj) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("_ustr", 0);
  __Pyx_INCREF(__pyx_v_obj);

  /* "cPyparsing.pyx":126
 *     str = unicode
 *     def _ustr(obj):
 *         if isinstance(obj, py_str):             # <<<<<<<<<<<<<<
 *             obj = obj.decode("utf8")
 *         return unicode(obj)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_py_str); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_obj, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":127
 *     def _ustr(obj):
 *         if isinstance(obj, py_str):
 *             obj = obj.decode("utf8")             # <<<<<<<<<<<<<<
 *         return unicode(obj)
 *     # def _ustr(obj):
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj, __pyx_n_s_decode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 127, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__5, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 127, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_obj, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":126
 *     str = unicode
 *     def _ustr(obj):
 *         if isinstance(obj, py_str):             # <<<<<<<<<<<<<<
 *             obj = obj.decode("utf8")
 *         return unicode(obj)
 */
  }

  /* "cPyparsing.pyx":128
 *         if isinstance(obj, py_str):
 *             obj = obj.decode("utf8")
 *         return unicode(obj)             # <<<<<<<<<<<<<<
 *     # def _ustr(obj):
 *     #     """Drop-in replacement for str(obj) that tries to be Unicode friendly. It first tries
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_obj);
  __Pyx_GIVEREF(__pyx_v_obj);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_obj);
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)(&PyUnicode_Type)), __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":125
 * 
 *     str = unicode
 *     def _ustr(obj):             # <<<<<<<<<<<<<<
 *         if isinstance(obj, py_str):
 *             obj = obj.decode("utf8")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing._ustr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_obj);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":161
 * 
 * 
 * def _xml_escape(data):             # <<<<<<<<<<<<<<
 *     """Escape &, <, >, ", ', etc. in a string of data."""
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5_xml_escape(PyObject *__pyx_self, PyObject *__pyx_v_data); /*proto*/
static char __pyx_doc_10cPyparsing_4_xml_escape[] = "Escape &, <, >, \", ', etc. in a string of data.";
static PyMethodDef __pyx_mdef_10cPyparsing_5_xml_escape = {"_xml_escape", (PyCFunction)__pyx_pw_10cPyparsing_5_xml_escape, METH_O, __pyx_doc_10cPyparsing_4_xml_escape};
static PyObject *__pyx_pw_10cPyparsing_5_xml_escape(PyObject *__pyx_self, PyObject *__pyx_v_data) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_xml_escape (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_4_xml_escape(__pyx_self, ((PyObject *)__pyx_v_data));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_11_xml_escape_2generator3(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":166
 *     # ampersand must be replaced first
 *     from_symbols = '&><"\''
 *     to_symbols = ('&' + s + ';' for s in "amp gt lt quot apos".split())             # <<<<<<<<<<<<<<
 *     for from_, to_ in zip(from_symbols, to_symbols):
 *         data = data.replace(from_, to_)
 */

static PyObject *__pyx_pf_10cPyparsing_11_xml_escape_genexpr(CYTHON_UNUSED PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_1_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_1_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 166, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_11_xml_escape_2generator3, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_xml_escape_locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 166, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing._xml_escape.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_11_xml_escape_2generator3(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 166, __pyx_L1_error)
  __pyx_t_1 = PyUnicode_Split(__pyx_kp_u_amp_gt_lt_quot_apos, ((PyObject *)NULL), -1L); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 166, __pyx_L1_error)
    #else
    __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 166, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    #endif
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_s);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_s, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Add(__pyx_kp_u__6, __pyx_cur_scope->__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 166, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyNumber_Add(__pyx_t_1, __pyx_kp_u__7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 166, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    __Pyx_XGIVEREF(__pyx_t_2);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_3;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_2);
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_1;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 166, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":161
 * 
 * 
 * def _xml_escape(data):             # <<<<<<<<<<<<<<
 *     """Escape &, <, >, ", ', etc. in a string of data."""
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_4_xml_escape(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_data) {
  PyObject *__pyx_v_from_symbols = NULL;
  PyObject *__pyx_v_to_symbols = NULL;
  PyObject *__pyx_v_from_ = NULL;
  PyObject *__pyx_v_to_ = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("_xml_escape", 0);
  __Pyx_INCREF(__pyx_v_data);

  /* "cPyparsing.pyx":165
 * 
 *     # ampersand must be replaced first
 *     from_symbols = '&><"\''             # <<<<<<<<<<<<<<
 *     to_symbols = ('&' + s + ';' for s in "amp gt lt quot apos".split())
 *     for from_, to_ in zip(from_symbols, to_symbols):
 */
  __Pyx_INCREF(__pyx_kp_u__8);
  __pyx_v_from_symbols = __pyx_kp_u__8;

  /* "cPyparsing.pyx":166
 *     # ampersand must be replaced first
 *     from_symbols = '&><"\''
 *     to_symbols = ('&' + s + ';' for s in "amp gt lt quot apos".split())             # <<<<<<<<<<<<<<
 *     for from_, to_ in zip(from_symbols, to_symbols):
 *         data = data.replace(from_, to_)
 */
  __pyx_t_1 = __pyx_pf_10cPyparsing_11_xml_escape_genexpr(NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_to_symbols = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":167
 *     from_symbols = '&><"\''
 *     to_symbols = ('&' + s + ';' for s in "amp gt lt quot apos".split())
 *     for from_, to_ in zip(from_symbols, to_symbols):             # <<<<<<<<<<<<<<
 *         data = data.replace(from_, to_)
 *     return data
 */
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_from_symbols);
  __Pyx_GIVEREF(__pyx_v_from_symbols);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_from_symbols);
  __Pyx_INCREF(__pyx_v_to_symbols);
  __Pyx_GIVEREF(__pyx_v_to_symbols);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_to_symbols);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_zip, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 167, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 167, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_2); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 167, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 167, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_2); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 167, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 167, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      }
    } else {
      __pyx_t_2 = __pyx_t_4(__pyx_t_1);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 167, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
      PyObject* sequence = __pyx_t_2;
      #if !CYTHON_COMPILING_IN_PYPY
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 167, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      #else
      __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 167, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 167, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 167, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_8 = Py_TYPE(__pyx_t_7)->tp_iternext;
      index = 0; __pyx_t_5 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < 0) __PYX_ERR(0, 167, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 167, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_from_, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_to_, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "cPyparsing.pyx":168
 *     to_symbols = ('&' + s + ';' for s in "amp gt lt quot apos".split())
 *     for from_, to_ in zip(from_symbols, to_symbols):
 *         data = data.replace(from_, to_)             # <<<<<<<<<<<<<<
 *     return data
 * 
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_data, __pyx_n_s_replace); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 168, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = NULL;
    __pyx_t_9 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_9 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_from_, __pyx_v_to_};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 168, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_from_, __pyx_v_to_};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 168, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 168, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__pyx_t_5) {
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
      }
      __Pyx_INCREF(__pyx_v_from_);
      __Pyx_GIVEREF(__pyx_v_from_);
      PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_9, __pyx_v_from_);
      __Pyx_INCREF(__pyx_v_to_);
      __Pyx_GIVEREF(__pyx_v_to_);
      PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_9, __pyx_v_to_);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 168, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF_SET(__pyx_v_data, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":167
 *     from_symbols = '&><"\''
 *     to_symbols = ('&' + s + ';' for s in "amp gt lt quot apos".split())
 *     for from_, to_ in zip(from_symbols, to_symbols):             # <<<<<<<<<<<<<<
 *         data = data.replace(from_, to_)
 *     return data
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":169
 *     for from_, to_ in zip(from_symbols, to_symbols):
 *         data = data.replace(from_, to_)
 *     return data             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_data);
  __pyx_r = __pyx_v_data;
  goto __pyx_L0;

  /* "cPyparsing.pyx":161
 * 
 * 
 * def _xml_escape(data):             # <<<<<<<<<<<<<<
 *     """Escape &, <, >, ", ', etc. in a string of data."""
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing._xml_escape", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_from_symbols);
  __Pyx_XDECREF(__pyx_v_to_symbols);
  __Pyx_XDECREF(__pyx_v_from_);
  __Pyx_XDECREF(__pyx_v_to_);
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":189
 *     # constructor as small and fast as possible
 * 
 *     def __init__(self, pstr, loc=0, msg=None, elem=None):             # <<<<<<<<<<<<<<
 *         self.loc = loc
 *         if msg is None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_18ParseBaseException_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_18ParseBaseException_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_pstr = 0;
  PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_msg = 0;
  PyObject *__pyx_v_elem = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_pstr,&__pyx_n_s_loc,&__pyx_n_s_msg,&__pyx_n_s_elem,0};
    PyObject* values[5] = {0,0,0,0,0};
    values[2] = ((PyObject *)((PyObject *)__pyx_int_0));
    values[3] = ((PyObject *)((PyObject *)Py_None));
    values[4] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_pstr)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 5, 1); __PYX_ERR(0, 189, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_msg);
          if (value) { values[3] = value; kw_args--; }
        }
        case  4:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_elem);
          if (value) { values[4] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 189, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_pstr = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_msg = values[3];
    __pyx_v_elem = values[4];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 5, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 189, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseBaseException.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_18ParseBaseException___init__(__pyx_self, __pyx_v_self, __pyx_v_pstr, __pyx_v_loc, __pyx_v_msg, __pyx_v_elem);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_pstr, PyObject *__pyx_v_loc, PyObject *__pyx_v_msg, PyObject *__pyx_v_elem) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":190
 * 
 *     def __init__(self, pstr, loc=0, msg=None, elem=None):
 *         self.loc = loc             # <<<<<<<<<<<<<<
 *         if msg is None:
 *             self.msg = pstr
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_loc, __pyx_v_loc) < 0) __PYX_ERR(0, 190, __pyx_L1_error)

  /* "cPyparsing.pyx":191
 *     def __init__(self, pstr, loc=0, msg=None, elem=None):
 *         self.loc = loc
 *         if msg is None:             # <<<<<<<<<<<<<<
 *             self.msg = pstr
 *             self.pstr = ""
 */
  __pyx_t_1 = (__pyx_v_msg == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":192
 *         self.loc = loc
 *         if msg is None:
 *             self.msg = pstr             # <<<<<<<<<<<<<<
 *             self.pstr = ""
 *         else:
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_msg, __pyx_v_pstr) < 0) __PYX_ERR(0, 192, __pyx_L1_error)

    /* "cPyparsing.pyx":193
 *         if msg is None:
 *             self.msg = pstr
 *             self.pstr = ""             # <<<<<<<<<<<<<<
 *         else:
 *             self.msg = msg
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_pstr, __pyx_kp_u__9) < 0) __PYX_ERR(0, 193, __pyx_L1_error)

    /* "cPyparsing.pyx":191
 *     def __init__(self, pstr, loc=0, msg=None, elem=None):
 *         self.loc = loc
 *         if msg is None:             # <<<<<<<<<<<<<<
 *             self.msg = pstr
 *             self.pstr = ""
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":195
 *             self.pstr = ""
 *         else:
 *             self.msg = msg             # <<<<<<<<<<<<<<
 *             self.pstr = pstr
 *         self.parserElement = elem
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_msg, __pyx_v_msg) < 0) __PYX_ERR(0, 195, __pyx_L1_error)

    /* "cPyparsing.pyx":196
 *         else:
 *             self.msg = msg
 *             self.pstr = pstr             # <<<<<<<<<<<<<<
 *         self.parserElement = elem
 *         self.args = (pstr, loc, msg)
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_pstr, __pyx_v_pstr) < 0) __PYX_ERR(0, 196, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":197
 *             self.msg = msg
 *             self.pstr = pstr
 *         self.parserElement = elem             # <<<<<<<<<<<<<<
 *         self.args = (pstr, loc, msg)
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_parserElement, __pyx_v_elem) < 0) __PYX_ERR(0, 197, __pyx_L1_error)

  /* "cPyparsing.pyx":198
 *             self.pstr = pstr
 *         self.parserElement = elem
 *         self.args = (pstr, loc, msg)             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_pstr);
  __Pyx_GIVEREF(__pyx_v_pstr);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_pstr);
  __Pyx_INCREF(__pyx_v_loc);
  __Pyx_GIVEREF(__pyx_v_loc);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_loc);
  __Pyx_INCREF(__pyx_v_msg);
  __Pyx_GIVEREF(__pyx_v_msg);
  PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_msg);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_args, __pyx_t_3) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":189
 *     # constructor as small and fast as possible
 * 
 *     def __init__(self, pstr, loc=0, msg=None, elem=None):             # <<<<<<<<<<<<<<
 *         self.loc = loc
 *         if msg is None:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParseBaseException.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":201
 * 
 *     @classmethod
 *     def _from_exception(cls, pe):             # <<<<<<<<<<<<<<
 *         """
 *         internal factory method to simplify creating one type of ParseException
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_3_from_exception(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_18ParseBaseException_2_from_exception[] = "\n        internal factory method to simplify creating one type of ParseException\n        from another - avoids having __init__ signature conflicts among subclasses\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_18ParseBaseException_3_from_exception = {"_from_exception", (PyCFunction)__pyx_pw_10cPyparsing_18ParseBaseException_3_from_exception, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_18ParseBaseException_2_from_exception};
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_3_from_exception(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_cls = 0;
  PyObject *__pyx_v_pe = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_from_exception (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cls,&__pyx_n_s_pe,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_cls)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_pe)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_from_exception", 1, 2, 2, 1); __PYX_ERR(0, 201, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "_from_exception") < 0)) __PYX_ERR(0, 201, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_cls = values[0];
    __pyx_v_pe = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_from_exception", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 201, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseBaseException._from_exception", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_18ParseBaseException_2_from_exception(__pyx_self, __pyx_v_cls, __pyx_v_pe);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException_2_from_exception(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_pe) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("_from_exception", 0);

  /* "cPyparsing.pyx":206
 *         from another - avoids having __init__ signature conflicts among subclasses
 *         """
 *         return cls(pe.pstr, pe.loc, pe.msg, pe.parserElement)             # <<<<<<<<<<<<<<
 * 
 *     def __getattr__(self, aname):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_pe, __pyx_n_s_pstr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_pe, __pyx_n_s_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_pe, __pyx_n_s_msg); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_pe, __pyx_n_s_parserElement); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_cls);
  __pyx_t_6 = __pyx_v_cls; __pyx_t_7 = NULL;
  __pyx_t_8 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_8 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_6)) {
    PyObject *__pyx_temp[5] = {__pyx_t_7, __pyx_t_2, __pyx_t_3, __pyx_t_4, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_8, 4+__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 206, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
    PyObject *__pyx_temp[5] = {__pyx_t_7, __pyx_t_2, __pyx_t_3, __pyx_t_4, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_8, 4+__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 206, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else
  #endif
  {
    __pyx_t_9 = PyTuple_New(4+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (__pyx_t_7) {
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_8, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_9, 3+__pyx_t_8, __pyx_t_5);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;
    __pyx_t_4 = 0;
    __pyx_t_5 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":201
 * 
 *     @classmethod
 *     def _from_exception(cls, pe):             # <<<<<<<<<<<<<<
 *         """
 *         internal factory method to simplify creating one type of ParseException
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.ParseBaseException._from_exception", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":208
 *         return cls(pe.pstr, pe.loc, pe.msg, pe.parserElement)
 * 
 *     def __getattr__(self, aname):             # <<<<<<<<<<<<<<
 *         """supported attributes by name are:
 *             - lineno - returns the line number of the exception text
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_5__getattr__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_18ParseBaseException_4__getattr__[] = "supported attributes by name are:\n            - lineno - returns the line number of the exception text\n            - col - returns the column number of the exception text\n            - line - returns the line containing the exception text\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_18ParseBaseException_5__getattr__ = {"__getattr__", (PyCFunction)__pyx_pw_10cPyparsing_18ParseBaseException_5__getattr__, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_18ParseBaseException_4__getattr__};
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_5__getattr__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_aname = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getattr__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_aname,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_aname)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__getattr__", 1, 2, 2, 1); __PYX_ERR(0, 208, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__getattr__") < 0)) __PYX_ERR(0, 208, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_aname = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__getattr__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 208, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseBaseException.__getattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_18ParseBaseException_4__getattr__(__pyx_self, __pyx_v_self, __pyx_v_aname);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException_4__getattr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_aname) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("__getattr__", 0);

  /* "cPyparsing.pyx":214
 *             - line - returns the line containing the exception text
 *         """
 *         if(aname == "lineno"):             # <<<<<<<<<<<<<<
 *             return lineno(self.loc, self.pstr)
 *         elif(aname in ("col", "column")):
 */
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_aname, __pyx_n_u_lineno, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 214, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":215
 *         """
 *         if(aname == "lineno"):
 *             return lineno(self.loc, self.pstr)             # <<<<<<<<<<<<<<
 *         elif(aname in ("col", "column")):
 *             return col(self.loc, self.pstr)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_lineno); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_pstr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_t_4, __pyx_t_5};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 215, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_t_4, __pyx_t_5};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 215, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    {
      __pyx_t_8 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 215, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (__pyx_t_6) {
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6); __pyx_t_6 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_t_5);
      __pyx_t_4 = 0;
      __pyx_t_5 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_8, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 215, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":214
 *             - line - returns the line containing the exception text
 *         """
 *         if(aname == "lineno"):             # <<<<<<<<<<<<<<
 *             return lineno(self.loc, self.pstr)
 *         elif(aname in ("col", "column")):
 */
  }

  /* "cPyparsing.pyx":216
 *         if(aname == "lineno"):
 *             return lineno(self.loc, self.pstr)
 *         elif(aname in ("col", "column")):             # <<<<<<<<<<<<<<
 *             return col(self.loc, self.pstr)
 *         elif(aname == "line"):
 */
  __Pyx_INCREF(__pyx_v_aname);
  __pyx_t_2 = __pyx_v_aname;
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_col, Py_EQ)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 216, __pyx_L1_error)
  if (!__pyx_t_9) {
  } else {
    __pyx_t_1 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_column, Py_EQ)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 216, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_9;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_9 = (__pyx_t_1 != 0);
  if (__pyx_t_9) {

    /* "cPyparsing.pyx":217
 *             return lineno(self.loc, self.pstr)
 *         elif(aname in ("col", "column")):
 *             return col(self.loc, self.pstr)             # <<<<<<<<<<<<<<
 *         elif(aname == "line"):
 *             return line(self.loc, self.pstr)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_col); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 217, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_loc); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 217, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_pstr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 217, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = NULL;
    __pyx_t_7 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_t_8, __pyx_t_5};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 217, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_t_8, __pyx_t_5};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 217, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 217, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__pyx_t_4) {
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_8);
      PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_7, __pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_7, __pyx_t_5);
      __pyx_t_8 = 0;
      __pyx_t_5 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 217, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":216
 *         if(aname == "lineno"):
 *             return lineno(self.loc, self.pstr)
 *         elif(aname in ("col", "column")):             # <<<<<<<<<<<<<<
 *             return col(self.loc, self.pstr)
 *         elif(aname == "line"):
 */
  }

  /* "cPyparsing.pyx":218
 *         elif(aname in ("col", "column")):
 *             return col(self.loc, self.pstr)
 *         elif(aname == "line"):             # <<<<<<<<<<<<<<
 *             return line(self.loc, self.pstr)
 *         else:
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_aname, __pyx_n_u_line, Py_EQ)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 218, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "cPyparsing.pyx":219
 *             return col(self.loc, self.pstr)
 *         elif(aname == "line"):
 *             return line(self.loc, self.pstr)             # <<<<<<<<<<<<<<
 *         else:
 *             raise AttributeError(aname)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_line); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 219, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_loc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 219, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_pstr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 219, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_8 = NULL;
    __pyx_t_7 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_t_6, __pyx_t_5};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 219, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_t_6, __pyx_t_5};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 219, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 219, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (__pyx_t_8) {
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_8); __pyx_t_8 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_7, __pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_7, __pyx_t_5);
      __pyx_t_6 = 0;
      __pyx_t_5 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 219, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":218
 *         elif(aname in ("col", "column")):
 *             return col(self.loc, self.pstr)
 *         elif(aname == "line"):             # <<<<<<<<<<<<<<
 *             return line(self.loc, self.pstr)
 *         else:
 */
  }

  /* "cPyparsing.pyx":221
 *             return line(self.loc, self.pstr)
 *         else:
 *             raise AttributeError(aname)             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  /*else*/ {
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_aname);
    __Pyx_GIVEREF(__pyx_v_aname);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_aname);
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_AttributeError, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 221, __pyx_L1_error)
  }

  /* "cPyparsing.pyx":208
 *         return cls(pe.pstr, pe.loc, pe.msg, pe.parserElement)
 * 
 *     def __getattr__(self, aname):             # <<<<<<<<<<<<<<
 *         """supported attributes by name are:
 *             - lineno - returns the line number of the exception text
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing.ParseBaseException.__getattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":223
 *             raise AttributeError(aname)
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "%s (at char %d), (line:%d, col:%d)" % \
 *             (self.msg, self.loc, self.lineno, self.column)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_7__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_18ParseBaseException_7__str__ = {"__str__", (PyCFunction)__pyx_pw_10cPyparsing_18ParseBaseException_7__str__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_7__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_18ParseBaseException_6__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException_6__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "cPyparsing.pyx":224
 * 
 *     def __str__(self):
 *         return "%s (at char %d), (line:%d, col:%d)" % \             # <<<<<<<<<<<<<<
 *             (self.msg, self.loc, self.lineno, self.column)
 * 
 */
  __Pyx_XDECREF(__pyx_r);

  /* "cPyparsing.pyx":225
 *     def __str__(self):
 *         return "%s (at char %d), (line:%d, col:%d)" % \
 *             (self.msg, self.loc, self.lineno, self.column)             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_msg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_lineno); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_column); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_t_4);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":224
 * 
 *     def __str__(self):
 *         return "%s (at char %d), (line:%d, col:%d)" % \             # <<<<<<<<<<<<<<
 *             (self.msg, self.loc, self.lineno, self.column)
 * 
 */
  __pyx_t_4 = PyUnicode_Format(__pyx_kp_u_s_at_char_d_line_d_col_d, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":223
 *             raise AttributeError(aname)
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "%s (at char %d), (line:%d, col:%d)" % \
 *             (self.msg, self.loc, self.lineno, self.column)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ParseBaseException.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":227
 *             (self.msg, self.loc, self.lineno, self.column)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return _ustr(self)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_9__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_18ParseBaseException_9__repr__ = {"__repr__", (PyCFunction)__pyx_pw_10cPyparsing_18ParseBaseException_9__repr__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_9__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_18ParseBaseException_8__repr__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException_8__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "cPyparsing.pyx":228
 * 
 *     def __repr__(self):
 *         return _ustr(self)             # <<<<<<<<<<<<<<
 * 
 *     def markInputline(self, markerString=">!<"):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 228, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 228, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 228, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 228, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_self);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 228, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":227
 *             (self.msg, self.loc, self.lineno, self.column)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return _ustr(self)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParseBaseException.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":230
 *         return _ustr(self)
 * 
 *     def markInputline(self, markerString=">!<"):             # <<<<<<<<<<<<<<
 *         """Extracts the exception line from the input string, and marks
 *            the location of the exception with a special symbol.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_11markInputline(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_18ParseBaseException_10markInputline[] = "Extracts the exception line from the input string, and marks\n           the location of the exception with a special symbol.\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_18ParseBaseException_11markInputline = {"markInputline", (PyCFunction)__pyx_pw_10cPyparsing_18ParseBaseException_11markInputline, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_18ParseBaseException_10markInputline};
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_11markInputline(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_markerString = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("markInputline (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_markerString,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)((PyObject*)__pyx_kp_u__10));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_markerString);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "markInputline") < 0)) __PYX_ERR(0, 230, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_markerString = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("markInputline", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 230, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseBaseException.markInputline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_18ParseBaseException_10markInputline(__pyx_self, __pyx_v_self, __pyx_v_markerString);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException_10markInputline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_markerString) {
  PyObject *__pyx_v_line_str = NULL;
  PyObject *__pyx_v_line_column = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("markInputline", 0);

  /* "cPyparsing.pyx":234
 *            the location of the exception with a special symbol.
 *         """
 *         line_str = self.line             # <<<<<<<<<<<<<<
 *         line_column = self.column - 1
 *         if markerString:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_line); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_line_str = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":235
 *         """
 *         line_str = self.line
 *         line_column = self.column - 1             # <<<<<<<<<<<<<<
 *         if markerString:
 *             line_str = "".join((line_str[:line_column],
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_column); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_SubtractObjC(__pyx_t_1, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_line_column = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":236
 *         line_str = self.line
 *         line_column = self.column - 1
 *         if markerString:             # <<<<<<<<<<<<<<
 *             line_str = "".join((line_str[:line_column],
 *                                 markerString, line_str[line_column:]))
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_markerString); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 236, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":237
 *         line_column = self.column - 1
 *         if markerString:
 *             line_str = "".join((line_str[:line_column],             # <<<<<<<<<<<<<<
 *                                 markerString, line_str[line_column:]))
 *         return line_str.strip()
 */
    __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_line_str, 0, 0, NULL, &__pyx_v_line_column, NULL, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 237, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "cPyparsing.pyx":238
 *         if markerString:
 *             line_str = "".join((line_str[:line_column],
 *                                 markerString, line_str[line_column:]))             # <<<<<<<<<<<<<<
 *         return line_str.strip()
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_line_str, 0, 0, &__pyx_v_line_column, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "cPyparsing.pyx":237
 *         line_column = self.column - 1
 *         if markerString:
 *             line_str = "".join((line_str[:line_column],             # <<<<<<<<<<<<<<
 *                                 markerString, line_str[line_column:]))
 *         return line_str.strip()
 */
    __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 237, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2);
    __Pyx_INCREF(__pyx_v_markerString);
    __Pyx_GIVEREF(__pyx_v_markerString);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_markerString);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_1 = 0;
    __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__9, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 237, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_line_str, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":236
 *         line_str = self.line
 *         line_column = self.column - 1
 *         if markerString:             # <<<<<<<<<<<<<<
 *             line_str = "".join((line_str[:line_column],
 *                                 markerString, line_str[line_column:]))
 */
  }

  /* "cPyparsing.pyx":239
 *             line_str = "".join((line_str[:line_column],
 *                                 markerString, line_str[line_column:]))
 *         return line_str.strip()             # <<<<<<<<<<<<<<
 * 
 *     def __dir__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_line_str, __pyx_n_s_strip); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 239, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 239, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":230
 *         return _ustr(self)
 * 
 *     def markInputline(self, markerString=">!<"):             # <<<<<<<<<<<<<<
 *         """Extracts the exception line from the input string, and marks
 *            the location of the exception with a special symbol.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParseBaseException.markInputline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_line_str);
  __Pyx_XDECREF(__pyx_v_line_column);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":241
 *         return line_str.strip()
 * 
 *     def __dir__(self):             # <<<<<<<<<<<<<<
 *         return "lineno col line".split() + dir(type(self))
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_13__dir__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_18ParseBaseException_13__dir__ = {"__dir__", (PyCFunction)__pyx_pw_10cPyparsing_18ParseBaseException_13__dir__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_18ParseBaseException_13__dir__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dir__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_18ParseBaseException_12__dir__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_18ParseBaseException_12__dir__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("__dir__", 0);

  /* "cPyparsing.pyx":242
 * 
 *     def __dir__(self):
 *         return "lineno col line".split() + dir(type(self))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyUnicode_Split(__pyx_kp_u_lineno_col_line, ((PyObject *)NULL), -1L); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Dir(((PyObject *)Py_TYPE(__pyx_v_self))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":241
 *         return line_str.strip()
 * 
 *     def __dir__(self):             # <<<<<<<<<<<<<<
 *         return "lineno col line".split() + dir(type(self))
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParseBaseException.__dir__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":296
 *     """exception thrown by L{ParserElement.validate} if the grammar could be improperly recursive"""
 * 
 *     def __init__(self, parseElementList):             # <<<<<<<<<<<<<<
 *         self.parseElementTrace = parseElementList
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_25RecursiveGrammarException_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_25RecursiveGrammarException_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_25RecursiveGrammarException_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_25RecursiveGrammarException_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_parseElementList = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_parseElementList,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_parseElementList)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 296, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 296, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_parseElementList = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 296, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.RecursiveGrammarException.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_25RecursiveGrammarException___init__(__pyx_self, __pyx_v_self, __pyx_v_parseElementList);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_25RecursiveGrammarException___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parseElementList) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":297
 * 
 *     def __init__(self, parseElementList):
 *         self.parseElementTrace = parseElementList             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_parseElementTrace, __pyx_v_parseElementList) < 0) __PYX_ERR(0, 297, __pyx_L1_error)

  /* "cPyparsing.pyx":296
 *     """exception thrown by L{ParserElement.validate} if the grammar could be improperly recursive"""
 * 
 *     def __init__(self, parseElementList):             # <<<<<<<<<<<<<<
 *         self.parseElementTrace = parseElementList
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.RecursiveGrammarException.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":299
 *         self.parseElementTrace = parseElementList
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "RecursiveGrammarException: %s" % self.parseElementTrace
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_25RecursiveGrammarException_3__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_25RecursiveGrammarException_3__str__ = {"__str__", (PyCFunction)__pyx_pw_10cPyparsing_25RecursiveGrammarException_3__str__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_25RecursiveGrammarException_3__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_25RecursiveGrammarException_2__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_25RecursiveGrammarException_2__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "cPyparsing.pyx":300
 * 
 *     def __str__(self):
 *         return "RecursiveGrammarException: %s" % self.parseElementTrace             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseElementTrace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyUnicode_Format(__pyx_kp_u_RecursiveGrammarException_s, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":299
 *         self.parseElementTrace = parseElementList
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "RecursiveGrammarException: %s" % self.parseElementTrace
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.RecursiveGrammarException.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":304
 * 
 * class _ParseResultsWithOffset(object):
 *     def __init__(self, p1, p2):             # <<<<<<<<<<<<<<
 *         self.tup = (p1, p2)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_23_ParseResultsWithOffset_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_23_ParseResultsWithOffset_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_23_ParseResultsWithOffset_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_23_ParseResultsWithOffset_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_p1 = 0;
  PyObject *__pyx_v_p2 = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_p1,&__pyx_n_s_p2,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_p1)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, 1); __PYX_ERR(0, 304, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_p2)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, 2); __PYX_ERR(0, 304, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 304, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_p1 = values[1];
    __pyx_v_p2 = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 304, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing._ParseResultsWithOffset.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_23_ParseResultsWithOffset___init__(__pyx_self, __pyx_v_self, __pyx_v_p1, __pyx_v_p2);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_23_ParseResultsWithOffset___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_p1, PyObject *__pyx_v_p2) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":305
 * class _ParseResultsWithOffset(object):
 *     def __init__(self, p1, p2):
 *         self.tup = (p1, p2)             # <<<<<<<<<<<<<<
 * 
 *     def __getitem__(self, i):
 */
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_p1);
  __Pyx_GIVEREF(__pyx_v_p1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_p1);
  __Pyx_INCREF(__pyx_v_p2);
  __Pyx_GIVEREF(__pyx_v_p2);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_p2);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_tup, __pyx_t_1) < 0) __PYX_ERR(0, 305, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":304
 * 
 * class _ParseResultsWithOffset(object):
 *     def __init__(self, p1, p2):             # <<<<<<<<<<<<<<
 *         self.tup = (p1, p2)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing._ParseResultsWithOffset.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":307
 *         self.tup = (p1, p2)
 * 
 *     def __getitem__(self, i):             # <<<<<<<<<<<<<<
 *         return self.tup[i]
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_23_ParseResultsWithOffset_3__getitem__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_23_ParseResultsWithOffset_3__getitem__ = {"__getitem__", (PyCFunction)__pyx_pw_10cPyparsing_23_ParseResultsWithOffset_3__getitem__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_23_ParseResultsWithOffset_3__getitem__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_i = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_i,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_i)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__getitem__", 1, 2, 2, 1); __PYX_ERR(0, 307, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__getitem__") < 0)) __PYX_ERR(0, 307, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_i = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__getitem__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 307, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing._ParseResultsWithOffset.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_23_ParseResultsWithOffset_2__getitem__(__pyx_self, __pyx_v_self, __pyx_v_i);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_23_ParseResultsWithOffset_2__getitem__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_i) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "cPyparsing.pyx":308
 * 
 *     def __getitem__(self, i):
 *         return self.tup[i]             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_tup); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetItem(__pyx_t_1, __pyx_v_i); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":307
 *         self.tup = (p1, p2)
 * 
 *     def __getitem__(self, i):             # <<<<<<<<<<<<<<
 *         return self.tup[i]
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing._ParseResultsWithOffset.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":310
 *         return self.tup[i]
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return repr(self.tup[0])
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_23_ParseResultsWithOffset_5__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_23_ParseResultsWithOffset_5__repr__ = {"__repr__", (PyCFunction)__pyx_pw_10cPyparsing_23_ParseResultsWithOffset_5__repr__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_23_ParseResultsWithOffset_5__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_23_ParseResultsWithOffset_4__repr__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_23_ParseResultsWithOffset_4__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "cPyparsing.pyx":311
 * 
 *     def __repr__(self):
 *         return repr(self.tup[0])             # <<<<<<<<<<<<<<
 * 
 *     def setOffset(self, i):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_repr_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_tup); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_3, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 311, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 311, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 311, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 311, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 311, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":310
 *         return self.tup[i]
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return repr(self.tup[0])
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing._ParseResultsWithOffset.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":313
 *         return repr(self.tup[0])
 * 
 *     def setOffset(self, i):             # <<<<<<<<<<<<<<
 *         self.tup = (self.tup[0], i)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_23_ParseResultsWithOffset_7setOffset(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_23_ParseResultsWithOffset_7setOffset = {"setOffset", (PyCFunction)__pyx_pw_10cPyparsing_23_ParseResultsWithOffset_7setOffset, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_23_ParseResultsWithOffset_7setOffset(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_i = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setOffset (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_i,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_i)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("setOffset", 1, 2, 2, 1); __PYX_ERR(0, 313, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "setOffset") < 0)) __PYX_ERR(0, 313, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_i = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setOffset", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 313, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing._ParseResultsWithOffset.setOffset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_23_ParseResultsWithOffset_6setOffset(__pyx_self, __pyx_v_self, __pyx_v_i);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_23_ParseResultsWithOffset_6setOffset(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_i) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("setOffset", 0);

  /* "cPyparsing.pyx":314
 * 
 *     def setOffset(self, i):
 *         self.tup = (self.tup[0], i)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_tup); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_i);
  __Pyx_GIVEREF(__pyx_v_i);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_i);
  __pyx_t_2 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_tup, __pyx_t_1) < 0) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":313
 *         return repr(self.tup[0])
 * 
 *     def setOffset(self, i):             # <<<<<<<<<<<<<<
 *         self.tup = (self.tup[0], i)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing._ParseResultsWithOffset.setOffset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":356
 *         - year: 1999
 *     """
 *     def __new__(cls, toklist=None, name=None, asList=True, modal=True):             # <<<<<<<<<<<<<<
 *         if isinstance(toklist, cls):
 *             return toklist
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_1__new__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_1__new__ = {"__new__", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_1__new__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_1__new__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_cls = 0;
  PyObject *__pyx_v_toklist = 0;
  CYTHON_UNUSED PyObject *__pyx_v_name = 0;
  CYTHON_UNUSED PyObject *__pyx_v_asList = 0;
  CYTHON_UNUSED PyObject *__pyx_v_modal = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__new__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cls,&__pyx_n_s_toklist,&__pyx_n_s_name,&__pyx_n_s_asList,&__pyx_n_s_modal,0};
    PyObject* values[5] = {0,0,0,0,0};
    values[1] = ((PyObject *)((PyObject *)Py_None));
    values[2] = ((PyObject *)((PyObject *)Py_None));
    values[3] = ((PyObject *)((PyObject *)Py_True));
    values[4] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_cls)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_toklist);
          if (value) { values[1] = value; kw_args--; }
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_asList);
          if (value) { values[3] = value; kw_args--; }
        }
        case  4:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_modal);
          if (value) { values[4] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__new__") < 0)) __PYX_ERR(0, 356, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_cls = values[0];
    __pyx_v_toklist = values[1];
    __pyx_v_name = values[2];
    __pyx_v_asList = values[3];
    __pyx_v_modal = values[4];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__new__", 0, 1, 5, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 356, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.__new__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults___new__(__pyx_self, __pyx_v_cls, __pyx_v_toklist, __pyx_v_name, __pyx_v_asList, __pyx_v_modal);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults___new__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_toklist, CYTHON_UNUSED PyObject *__pyx_v_name, CYTHON_UNUSED PyObject *__pyx_v_asList, CYTHON_UNUSED PyObject *__pyx_v_modal) {
  PyObject *__pyx_v_retobj = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("__new__", 0);

  /* "cPyparsing.pyx":357
 *     """
 *     def __new__(cls, toklist=None, name=None, asList=True, modal=True):
 *         if isinstance(toklist, cls):             # <<<<<<<<<<<<<<
 *             return toklist
 *         retobj = object.__new__(cls)
 */
  __pyx_t_1 = PyObject_IsInstance(__pyx_v_toklist, __pyx_v_cls); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 357, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":358
 *     def __new__(cls, toklist=None, name=None, asList=True, modal=True):
 *         if isinstance(toklist, cls):
 *             return toklist             # <<<<<<<<<<<<<<
 *         retobj = object.__new__(cls)
 *         retobj.__doinit = True
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_toklist);
    __pyx_r = __pyx_v_toklist;
    goto __pyx_L0;

    /* "cPyparsing.pyx":357
 *     """
 *     def __new__(cls, toklist=None, name=None, asList=True, modal=True):
 *         if isinstance(toklist, cls):             # <<<<<<<<<<<<<<
 *             return toklist
 *         retobj = object.__new__(cls)
 */
  }

  /* "cPyparsing.pyx":359
 *         if isinstance(toklist, cls):
 *             return toklist
 *         retobj = object.__new__(cls)             # <<<<<<<<<<<<<<
 *         retobj.__doinit = True
 *         return retobj
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_builtin_object, __pyx_n_s_new); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (!__pyx_t_5) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_cls); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 359, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_cls};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 359, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_cls};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 359, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 359, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
      __Pyx_INCREF(__pyx_v_cls);
      __Pyx_GIVEREF(__pyx_v_cls);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_cls);
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 359, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_retobj = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":360
 *             return toklist
 *         retobj = object.__new__(cls)
 *         retobj.__doinit = True             # <<<<<<<<<<<<<<
 *         return retobj
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_retobj, __pyx_n_s_ParseResults__doinit, Py_True) < 0) __PYX_ERR(0, 360, __pyx_L1_error)

  /* "cPyparsing.pyx":361
 *         retobj = object.__new__(cls)
 *         retobj.__doinit = True
 *         return retobj             # <<<<<<<<<<<<<<
 * 
 *     # Performance tuning: we construct a *lot* of these, so keep this
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_retobj);
  __pyx_r = __pyx_v_retobj;
  goto __pyx_L0;

  /* "cPyparsing.pyx":356
 *         - year: 1999
 *     """
 *     def __new__(cls, toklist=None, name=None, asList=True, modal=True):             # <<<<<<<<<<<<<<
 *         if isinstance(toklist, cls):
 *             return toklist
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__new__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_retobj);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":365
 *     # Performance tuning: we construct a *lot* of these, so keep this
 *     # constructor as small and fast as possible
 *     def __init__(self, toklist=None, name=None, asList=True, modal=True, isinstance=isinstance):             # <<<<<<<<<<<<<<
 *         if self.__doinit:
 *             self.__doinit = False
 */

static PyObject *__pyx_pf_10cPyparsing_83__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)Py_None));
  __Pyx_GIVEREF(((PyObject *)Py_None));
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_None));
  __Pyx_INCREF(((PyObject *)Py_None));
  __Pyx_GIVEREF(((PyObject *)Py_None));
  PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)Py_None));
  __Pyx_INCREF(((PyObject *)Py_True));
  __Pyx_GIVEREF(((PyObject *)Py_True));
  PyTuple_SET_ITEM(__pyx_t_1, 2, ((PyObject *)Py_True));
  __Pyx_INCREF(((PyObject *)Py_True));
  __Pyx_GIVEREF(((PyObject *)Py_True));
  PyTuple_SET_ITEM(__pyx_t_1, 3, ((PyObject *)Py_True));
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self)->__pyx_arg_isinstance);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self)->__pyx_arg_isinstance);
  PyTuple_SET_ITEM(__pyx_t_1, 4, __Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self)->__pyx_arg_isinstance);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_3__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_3__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_3__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_3__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_toklist = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_asList = 0;
  PyObject *__pyx_v_modal = 0;
  PyObject *__pyx_v_isinstance = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_toklist,&__pyx_n_s_name,&__pyx_n_s_asList,&__pyx_n_s_modal,&__pyx_n_s_isinstance,0};
    PyObject* values[6] = {0,0,0,0,0,0};
    __pyx_defaults *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self);
    values[1] = ((PyObject *)((PyObject *)Py_None));
    values[2] = ((PyObject *)((PyObject *)Py_None));
    values[3] = ((PyObject *)((PyObject *)Py_True));
    values[4] = ((PyObject *)((PyObject *)Py_True));
    values[5] = __pyx_dynamic_args->__pyx_arg_isinstance;
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_toklist);
          if (value) { values[1] = value; kw_args--; }
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_asList);
          if (value) { values[3] = value; kw_args--; }
        }
        case  4:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_modal);
          if (value) { values[4] = value; kw_args--; }
        }
        case  5:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_isinstance);
          if (value) { values[5] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 365, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_toklist = values[1];
    __pyx_v_name = values[2];
    __pyx_v_asList = values[3];
    __pyx_v_modal = values[4];
    __pyx_v_isinstance = values[5];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 6, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 365, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_2__init__(__pyx_self, __pyx_v_self, __pyx_v_toklist, __pyx_v_name, __pyx_v_asList, __pyx_v_modal, __pyx_v_isinstance);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_2__init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_toklist, PyObject *__pyx_v_name, PyObject *__pyx_v_asList, PyObject *__pyx_v_modal, PyObject *__pyx_v_isinstance) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);
  __Pyx_INCREF(__pyx_v_toklist);
  __Pyx_INCREF(__pyx_v_name);

  /* "cPyparsing.pyx":366
 *     # constructor as small and fast as possible
 *     def __init__(self, toklist=None, name=None, asList=True, modal=True, isinstance=isinstance):
 *         if self.__doinit:             # <<<<<<<<<<<<<<
 *             self.__doinit = False
 *             self.__name = None
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__doinit); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 366, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":367
 *     def __init__(self, toklist=None, name=None, asList=True, modal=True, isinstance=isinstance):
 *         if self.__doinit:
 *             self.__doinit = False             # <<<<<<<<<<<<<<
 *             self.__name = None
 *             self.__parent = None
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__doinit, Py_False) < 0) __PYX_ERR(0, 367, __pyx_L1_error)

    /* "cPyparsing.pyx":368
 *         if self.__doinit:
 *             self.__doinit = False
 *             self.__name = None             # <<<<<<<<<<<<<<
 *             self.__parent = None
 *             self.__accumNames = {}
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__name, Py_None) < 0) __PYX_ERR(0, 368, __pyx_L1_error)

    /* "cPyparsing.pyx":369
 *             self.__doinit = False
 *             self.__name = None
 *             self.__parent = None             # <<<<<<<<<<<<<<
 *             self.__accumNames = {}
 *             self.__asList = asList
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__parent, Py_None) < 0) __PYX_ERR(0, 369, __pyx_L1_error)

    /* "cPyparsing.pyx":370
 *             self.__name = None
 *             self.__parent = None
 *             self.__accumNames = {}             # <<<<<<<<<<<<<<
 *             self.__asList = asList
 *             self.__modal = modal
 */
    __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 370, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__accumNames, __pyx_t_1) < 0) __PYX_ERR(0, 370, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":371
 *             self.__parent = None
 *             self.__accumNames = {}
 *             self.__asList = asList             # <<<<<<<<<<<<<<
 *             self.__modal = modal
 *             if toklist is None:
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__asList, __pyx_v_asList) < 0) __PYX_ERR(0, 371, __pyx_L1_error)

    /* "cPyparsing.pyx":372
 *             self.__accumNames = {}
 *             self.__asList = asList
 *             self.__modal = modal             # <<<<<<<<<<<<<<
 *             if toklist is None:
 *                 toklist = []
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__modal, __pyx_v_modal) < 0) __PYX_ERR(0, 372, __pyx_L1_error)

    /* "cPyparsing.pyx":373
 *             self.__asList = asList
 *             self.__modal = modal
 *             if toklist is None:             # <<<<<<<<<<<<<<
 *                 toklist = []
 *             if isinstance(toklist, list):
 */
    __pyx_t_2 = (__pyx_v_toklist == Py_None);
    __pyx_t_3 = (__pyx_t_2 != 0);
    if (__pyx_t_3) {

      /* "cPyparsing.pyx":374
 *             self.__modal = modal
 *             if toklist is None:
 *                 toklist = []             # <<<<<<<<<<<<<<
 *             if isinstance(toklist, list):
 *                 self.__toklist = toklist[:]
 */
      __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 374, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_toklist, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "cPyparsing.pyx":373
 *             self.__asList = asList
 *             self.__modal = modal
 *             if toklist is None:             # <<<<<<<<<<<<<<
 *                 toklist = []
 *             if isinstance(toklist, list):
 */
    }

    /* "cPyparsing.pyx":375
 *             if toklist is None:
 *                 toklist = []
 *             if isinstance(toklist, list):             # <<<<<<<<<<<<<<
 *                 self.__toklist = toklist[:]
 *             elif isinstance(toklist, _generatorType):
 */
    __Pyx_INCREF(__pyx_v_isinstance);
    __pyx_t_4 = __pyx_v_isinstance; __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_toklist, ((PyObject *)(&PyList_Type))};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 375, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_toklist, ((PyObject *)(&PyList_Type))};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 375, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 375, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__pyx_t_5) {
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
      }
      __Pyx_INCREF(__pyx_v_toklist);
      __Pyx_GIVEREF(__pyx_v_toklist);
      PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_toklist);
      __Pyx_INCREF(((PyObject *)(&PyList_Type)));
      __Pyx_GIVEREF(((PyObject *)(&PyList_Type)));
      PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, ((PyObject *)(&PyList_Type)));
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 375, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 375, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_3) {

      /* "cPyparsing.pyx":376
 *                 toklist = []
 *             if isinstance(toklist, list):
 *                 self.__toklist = toklist[:]             # <<<<<<<<<<<<<<
 *             elif isinstance(toklist, _generatorType):
 *                 self.__toklist = list(toklist)
 */
      __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_toklist, 0, 0, NULL, NULL, &__pyx_slice__11, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 376, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist, __pyx_t_1) < 0) __PYX_ERR(0, 376, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":375
 *             if toklist is None:
 *                 toklist = []
 *             if isinstance(toklist, list):             # <<<<<<<<<<<<<<
 *                 self.__toklist = toklist[:]
 *             elif isinstance(toklist, _generatorType):
 */
      goto __pyx_L5;
    }

    /* "cPyparsing.pyx":377
 *             if isinstance(toklist, list):
 *                 self.__toklist = toklist[:]
 *             elif isinstance(toklist, _generatorType):             # <<<<<<<<<<<<<<
 *                 self.__toklist = list(toklist)
 *             else:
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_generatorType); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_isinstance);
    __pyx_t_7 = __pyx_v_isinstance; __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_6 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_toklist, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 377, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_toklist, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 377, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    {
      __pyx_t_8 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 377, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (__pyx_t_5) {
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_5); __pyx_t_5 = NULL;
      }
      __Pyx_INCREF(__pyx_v_toklist);
      __Pyx_GIVEREF(__pyx_v_toklist);
      PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_6, __pyx_v_toklist);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_6, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 377, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 377, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_3) {

      /* "cPyparsing.pyx":378
 *                 self.__toklist = toklist[:]
 *             elif isinstance(toklist, _generatorType):
 *                 self.__toklist = list(toklist)             # <<<<<<<<<<<<<<
 *             else:
 *                 self.__toklist = [toklist]
 */
      __pyx_t_1 = PySequence_List(__pyx_v_toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 378, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist, __pyx_t_1) < 0) __PYX_ERR(0, 378, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":377
 *             if isinstance(toklist, list):
 *                 self.__toklist = toklist[:]
 *             elif isinstance(toklist, _generatorType):             # <<<<<<<<<<<<<<
 *                 self.__toklist = list(toklist)
 *             else:
 */
      goto __pyx_L5;
    }

    /* "cPyparsing.pyx":380
 *                 self.__toklist = list(toklist)
 *             else:
 *                 self.__toklist = [toklist]             # <<<<<<<<<<<<<<
 *             self.__tokdict = dict()
 * 
 */
    /*else*/ {
      __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 380, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_v_toklist);
      __Pyx_GIVEREF(__pyx_v_toklist);
      PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_toklist);
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist, __pyx_t_1) < 0) __PYX_ERR(0, 380, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_L5:;

    /* "cPyparsing.pyx":381
 *             else:
 *                 self.__toklist = [toklist]
 *             self.__tokdict = dict()             # <<<<<<<<<<<<<<
 * 
 *         if name is not None and name:
 */
    __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 381, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict, __pyx_t_1) < 0) __PYX_ERR(0, 381, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":366
 *     # constructor as small and fast as possible
 *     def __init__(self, toklist=None, name=None, asList=True, modal=True, isinstance=isinstance):
 *         if self.__doinit:             # <<<<<<<<<<<<<<
 *             self.__doinit = False
 *             self.__name = None
 */
  }

  /* "cPyparsing.pyx":383
 *             self.__tokdict = dict()
 * 
 *         if name is not None and name:             # <<<<<<<<<<<<<<
 *             if not modal:
 *                 self.__accumNames[name] = 0
 */
  __pyx_t_2 = (__pyx_v_name != Py_None);
  __pyx_t_9 = (__pyx_t_2 != 0);
  if (__pyx_t_9) {
  } else {
    __pyx_t_3 = __pyx_t_9;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_v_name); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 383, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_9;
  __pyx_L7_bool_binop_done:;
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":384
 * 
 *         if name is not None and name:
 *             if not modal:             # <<<<<<<<<<<<<<
 *                 self.__accumNames[name] = 0
 *             if isinstance(name, int):
 */
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_modal); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 384, __pyx_L1_error)
    __pyx_t_9 = ((!__pyx_t_3) != 0);
    if (__pyx_t_9) {

      /* "cPyparsing.pyx":385
 *         if name is not None and name:
 *             if not modal:
 *                 self.__accumNames[name] = 0             # <<<<<<<<<<<<<<
 *             if isinstance(name, int):
 *                 name = _ustr(name)  # will always return a str, but use _ustr for consistency
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__accumNames); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 385, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (unlikely(PyObject_SetItem(__pyx_t_1, __pyx_v_name, __pyx_int_0) < 0)) __PYX_ERR(0, 385, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":384
 * 
 *         if name is not None and name:
 *             if not modal:             # <<<<<<<<<<<<<<
 *                 self.__accumNames[name] = 0
 *             if isinstance(name, int):
 */
    }

    /* "cPyparsing.pyx":386
 *             if not modal:
 *                 self.__accumNames[name] = 0
 *             if isinstance(name, int):             # <<<<<<<<<<<<<<
 *                 name = _ustr(name)  # will always return a str, but use _ustr for consistency
 *             self.__name = name
 */
    __Pyx_INCREF(__pyx_v_isinstance);
    __pyx_t_7 = __pyx_v_isinstance; __pyx_t_8 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_6 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_name, ((PyObject *)(&PyInt_Type))};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 386, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_name, ((PyObject *)(&PyInt_Type))};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 386, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 386, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (__pyx_t_8) {
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_8); __pyx_t_8 = NULL;
      }
      __Pyx_INCREF(__pyx_v_name);
      __Pyx_GIVEREF(__pyx_v_name);
      PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_6, __pyx_v_name);
      __Pyx_INCREF(((PyObject *)(&PyInt_Type)));
      __Pyx_GIVEREF(((PyObject *)(&PyInt_Type)));
      PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_6, ((PyObject *)(&PyInt_Type)));
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 386, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_9) {

      /* "cPyparsing.pyx":387
 *                 self.__accumNames[name] = 0
 *             if isinstance(name, int):
 *                 name = _ustr(name)  # will always return a str, but use _ustr for consistency             # <<<<<<<<<<<<<<
 *             self.__name = name
 *             if not (isinstance(toklist, (type(None), basestring, list)) and toklist in (None, '', [])):
 */
      __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 387, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      if (!__pyx_t_4) {
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 387, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_7)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_name};
          __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 387, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_1);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_name};
          __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 387, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_1);
        } else
        #endif
        {
          __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 387, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_4); __pyx_t_4 = NULL;
          __Pyx_INCREF(__pyx_v_name);
          __Pyx_GIVEREF(__pyx_v_name);
          PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_v_name);
          __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 387, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF_SET(__pyx_v_name, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "cPyparsing.pyx":386
 *             if not modal:
 *                 self.__accumNames[name] = 0
 *             if isinstance(name, int):             # <<<<<<<<<<<<<<
 *                 name = _ustr(name)  # will always return a str, but use _ustr for consistency
 *             self.__name = name
 */
    }

    /* "cPyparsing.pyx":388
 *             if isinstance(name, int):
 *                 name = _ustr(name)  # will always return a str, but use _ustr for consistency
 *             self.__name = name             # <<<<<<<<<<<<<<
 *             if not (isinstance(toklist, (type(None), basestring, list)) and toklist in (None, '', [])):
 *                 if isinstance(toklist, basestring):
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__name, __pyx_v_name) < 0) __PYX_ERR(0, 388, __pyx_L1_error)

    /* "cPyparsing.pyx":389
 *                 name = _ustr(name)  # will always return a str, but use _ustr for consistency
 *             self.__name = name
 *             if not (isinstance(toklist, (type(None), basestring, list)) and toklist in (None, '', [])):             # <<<<<<<<<<<<<<
 *                 if isinstance(toklist, basestring):
 *                     toklist = [toklist]
 */
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 389, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = PyTuple_New(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 389, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_INCREF(((PyObject *)Py_TYPE(Py_None)));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(Py_None)));
    PyTuple_SET_ITEM(__pyx_t_8, 0, ((PyObject *)Py_TYPE(Py_None)));
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_7);
    __Pyx_INCREF(((PyObject *)(&PyList_Type)));
    __Pyx_GIVEREF(((PyObject *)(&PyList_Type)));
    PyTuple_SET_ITEM(__pyx_t_8, 2, ((PyObject *)(&PyList_Type)));
    __pyx_t_7 = 0;
    __Pyx_INCREF(__pyx_v_isinstance);
    __pyx_t_7 = __pyx_v_isinstance; __pyx_t_4 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_6 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_toklist, __pyx_t_8};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 389, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_toklist, __pyx_t_8};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 389, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 389, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__pyx_t_4) {
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      }
      __Pyx_INCREF(__pyx_v_toklist);
      __Pyx_GIVEREF(__pyx_v_toklist);
      PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_6, __pyx_v_toklist);
      __Pyx_GIVEREF(__pyx_t_8);
      PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_6, __pyx_t_8);
      __pyx_t_8 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 389, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 389, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_3) {
    } else {
      __pyx_t_9 = __pyx_t_3;
      goto __pyx_L12_bool_binop_done;
    }
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 389, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_toklist);
    __pyx_t_7 = __pyx_v_toklist;
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_7, Py_None, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 389, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 389, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (!__pyx_t_2) {
    } else {
      __pyx_t_3 = __pyx_t_2;
      goto __pyx_L14_bool_binop_done;
    }
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_kp_u__9, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 389, __pyx_L1_error)
    if (!__pyx_t_2) {
    } else {
      __pyx_t_3 = __pyx_t_2;
      goto __pyx_L14_bool_binop_done;
    }
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_7, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 389, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 389, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_3 = __pyx_t_2;
    __pyx_L14_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = (__pyx_t_3 != 0);
    __pyx_t_9 = __pyx_t_2;
    __pyx_L12_bool_binop_done:;
    __pyx_t_2 = ((!__pyx_t_9) != 0);
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":390
 *             self.__name = name
 *             if not (isinstance(toklist, (type(None), basestring, list)) and toklist in (None, '', [])):
 *                 if isinstance(toklist, basestring):             # <<<<<<<<<<<<<<
 *                     toklist = [toklist]
 *                 if asList:
 */
      __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 390, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_v_isinstance);
      __pyx_t_5 = __pyx_v_isinstance; __pyx_t_8 = NULL;
      __pyx_t_6 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_6 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_toklist, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 390, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_toklist, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 390, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_4 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 390, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        if (__pyx_t_8) {
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_8); __pyx_t_8 = NULL;
        }
        __Pyx_INCREF(__pyx_v_toklist);
        __Pyx_GIVEREF(__pyx_v_toklist);
        PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_6, __pyx_v_toklist);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_6, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 390, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 390, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_2) {

        /* "cPyparsing.pyx":391
 *             if not (isinstance(toklist, (type(None), basestring, list)) and toklist in (None, '', [])):
 *                 if isinstance(toklist, basestring):
 *                     toklist = [toklist]             # <<<<<<<<<<<<<<
 *                 if asList:
 *                     if isinstance(toklist, ParseResults):
 */
        __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 391, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_v_toklist);
        __Pyx_GIVEREF(__pyx_v_toklist);
        PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_toklist);
        __Pyx_DECREF_SET(__pyx_v_toklist, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "cPyparsing.pyx":390
 *             self.__name = name
 *             if not (isinstance(toklist, (type(None), basestring, list)) and toklist in (None, '', [])):
 *                 if isinstance(toklist, basestring):             # <<<<<<<<<<<<<<
 *                     toklist = [toklist]
 *                 if asList:
 */
      }

      /* "cPyparsing.pyx":392
 *                 if isinstance(toklist, basestring):
 *                     toklist = [toklist]
 *                 if asList:             # <<<<<<<<<<<<<<
 *                     if isinstance(toklist, ParseResults):
 *                         self[name] = _ParseResultsWithOffset(toklist.copy(), 0)
 */
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_asList); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 392, __pyx_L1_error)
      if (__pyx_t_2) {

        /* "cPyparsing.pyx":393
 *                     toklist = [toklist]
 *                 if asList:
 *                     if isinstance(toklist, ParseResults):             # <<<<<<<<<<<<<<
 *                         self[name] = _ParseResultsWithOffset(toklist.copy(), 0)
 *                     else:
 */
        __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 393, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_v_isinstance);
        __pyx_t_4 = __pyx_v_isinstance; __pyx_t_7 = NULL;
        __pyx_t_6 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_v_toklist, __pyx_t_5};
          __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 393, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_v_toklist, __pyx_t_5};
          __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 393, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        {
          __pyx_t_8 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 393, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          if (__pyx_t_7) {
            __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_7); __pyx_t_7 = NULL;
          }
          __Pyx_INCREF(__pyx_v_toklist);
          __Pyx_GIVEREF(__pyx_v_toklist);
          PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_6, __pyx_v_toklist);
          __Pyx_GIVEREF(__pyx_t_5);
          PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_6, __pyx_t_5);
          __pyx_t_5 = 0;
          __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 393, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 393, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_2) {

          /* "cPyparsing.pyx":394
 *                 if asList:
 *                     if isinstance(toklist, ParseResults):
 *                         self[name] = _ParseResultsWithOffset(toklist.copy(), 0)             # <<<<<<<<<<<<<<
 *                     else:
 *                         self[name] = _ParseResultsWithOffset(ParseResults(toklist[0]), 0)
 */
          __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResultsWithOffset); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 394, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_toklist, __pyx_n_s_copy); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 394, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_7 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
            __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
            if (likely(__pyx_t_7)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
              __Pyx_INCREF(__pyx_t_7);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_5, function);
            }
          }
          if (__pyx_t_7) {
            __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 394, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          } else {
            __pyx_t_8 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 394, __pyx_L1_error)
          }
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = NULL;
          __pyx_t_6 = 0;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_5)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_5);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
              __pyx_t_6 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_4)) {
            PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_t_8, __pyx_int_0};
            __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 394, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
            PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_t_8, __pyx_int_0};
            __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 394, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          } else
          #endif
          {
            __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 394, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            if (__pyx_t_5) {
              __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
            }
            __Pyx_GIVEREF(__pyx_t_8);
            PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_t_8);
            __Pyx_INCREF(__pyx_int_0);
            __Pyx_GIVEREF(__pyx_int_0);
            PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_int_0);
            __pyx_t_8 = 0;
            __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 394, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          }
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(PyObject_SetItem(__pyx_v_self, __pyx_v_name, __pyx_t_1) < 0)) __PYX_ERR(0, 394, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "cPyparsing.pyx":393
 *                     toklist = [toklist]
 *                 if asList:
 *                     if isinstance(toklist, ParseResults):             # <<<<<<<<<<<<<<
 *                         self[name] = _ParseResultsWithOffset(toklist.copy(), 0)
 *                     else:
 */
          goto __pyx_L19;
        }

        /* "cPyparsing.pyx":396
 *                         self[name] = _ParseResultsWithOffset(toklist.copy(), 0)
 *                     else:
 *                         self[name] = _ParseResultsWithOffset(ParseResults(toklist[0]), 0)             # <<<<<<<<<<<<<<
 *                     self[name].__name = name
 *                 else:
 */
        /*else*/ {
          __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResultsWithOffset); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 396, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 396, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_toklist, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 396, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_10 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
            __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_8);
            if (likely(__pyx_t_10)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
              __Pyx_INCREF(__pyx_t_10);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_8, function);
            }
          }
          if (!__pyx_t_10) {
            __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 396, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_GOTREF(__pyx_t_7);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_8)) {
              PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_5};
              __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 396, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
              PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_5};
              __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 396, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            } else
            #endif
            {
              __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 396, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_11);
              __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_10); __pyx_t_10 = NULL;
              __Pyx_GIVEREF(__pyx_t_5);
              PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_t_5);
              __pyx_t_5 = 0;
              __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 396, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_8 = NULL;
          __pyx_t_6 = 0;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_8)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_8);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
              __pyx_t_6 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_4)) {
            PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_t_7, __pyx_int_0};
            __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 396, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
            PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_t_7, __pyx_int_0};
            __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 396, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          } else
          #endif
          {
            __pyx_t_11 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 396, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_11);
            if (__pyx_t_8) {
              __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_8); __pyx_t_8 = NULL;
            }
            __Pyx_GIVEREF(__pyx_t_7);
            PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_6, __pyx_t_7);
            __Pyx_INCREF(__pyx_int_0);
            __Pyx_GIVEREF(__pyx_int_0);
            PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_6, __pyx_int_0);
            __pyx_t_7 = 0;
            __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 396, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          }
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(PyObject_SetItem(__pyx_v_self, __pyx_v_name, __pyx_t_1) < 0)) __PYX_ERR(0, 396, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        __pyx_L19:;

        /* "cPyparsing.pyx":397
 *                     else:
 *                         self[name] = _ParseResultsWithOffset(ParseResults(toklist[0]), 0)
 *                     self[name].__name = name             # <<<<<<<<<<<<<<
 *                 else:
 *                     try:
 */
        __pyx_t_1 = PyObject_GetItem(__pyx_v_self, __pyx_v_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 397, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_n_s_ParseResults__name, __pyx_v_name) < 0) __PYX_ERR(0, 397, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "cPyparsing.pyx":392
 *                 if isinstance(toklist, basestring):
 *                     toklist = [toklist]
 *                 if asList:             # <<<<<<<<<<<<<<
 *                     if isinstance(toklist, ParseResults):
 *                         self[name] = _ParseResultsWithOffset(toklist.copy(), 0)
 */
        goto __pyx_L18;
      }

      /* "cPyparsing.pyx":399
 *                     self[name].__name = name
 *                 else:
 *                     try:             # <<<<<<<<<<<<<<
 *                         self[name] = toklist[0]
 *                     except (KeyError, TypeError, IndexError):
 */
      /*else*/ {
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_14);
          /*try:*/ {

            /* "cPyparsing.pyx":400
 *                 else:
 *                     try:
 *                         self[name] = toklist[0]             # <<<<<<<<<<<<<<
 *                     except (KeyError, TypeError, IndexError):
 *                         self[name] = toklist
 */
            __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_toklist, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 400, __pyx_L20_error)
            __Pyx_GOTREF(__pyx_t_1);
            if (unlikely(PyObject_SetItem(__pyx_v_self, __pyx_v_name, __pyx_t_1) < 0)) __PYX_ERR(0, 400, __pyx_L20_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

            /* "cPyparsing.pyx":399
 *                     self[name].__name = name
 *                 else:
 *                     try:             # <<<<<<<<<<<<<<
 *                         self[name] = toklist[0]
 *                     except (KeyError, TypeError, IndexError):
 */
          }
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          goto __pyx_L27_try_end;
          __pyx_L20_error:;
          __Pyx_PyThreadState_assign
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "cPyparsing.pyx":401
 *                     try:
 *                         self[name] = toklist[0]
 *                     except (KeyError, TypeError, IndexError):             # <<<<<<<<<<<<<<
 *                         self[name] = toklist
 * 
 */
          __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError) || __Pyx_PyErr_ExceptionMatches(__pyx_builtin_TypeError) || __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
          if (__pyx_t_6) {
            __Pyx_AddTraceback("cPyparsing.ParseResults.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_4, &__pyx_t_11) < 0) __PYX_ERR(0, 401, __pyx_L22_except_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_GOTREF(__pyx_t_11);

            /* "cPyparsing.pyx":402
 *                         self[name] = toklist[0]
 *                     except (KeyError, TypeError, IndexError):
 *                         self[name] = toklist             # <<<<<<<<<<<<<<
 * 
 *     def __getitem__(self, i):
 */
            if (unlikely(PyObject_SetItem(__pyx_v_self, __pyx_v_name, __pyx_v_toklist) < 0)) __PYX_ERR(0, 402, __pyx_L22_except_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            goto __pyx_L21_exception_handled;
          }
          goto __pyx_L22_except_error;
          __pyx_L22_except_error:;

          /* "cPyparsing.pyx":399
 *                     self[name].__name = name
 *                 else:
 *                     try:             # <<<<<<<<<<<<<<
 *                         self[name] = toklist[0]
 *                     except (KeyError, TypeError, IndexError):
 */
          __Pyx_PyThreadState_assign
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
          goto __pyx_L1_error;
          __pyx_L21_exception_handled:;
          __Pyx_PyThreadState_assign
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
          __pyx_L27_try_end:;
        }
      }
      __pyx_L18:;

      /* "cPyparsing.pyx":389
 *                 name = _ustr(name)  # will always return a str, but use _ustr for consistency
 *             self.__name = name
 *             if not (isinstance(toklist, (type(None), basestring, list)) and toklist in (None, '', [])):             # <<<<<<<<<<<<<<
 *                 if isinstance(toklist, basestring):
 *                     toklist = [toklist]
 */
    }

    /* "cPyparsing.pyx":383
 *             self.__tokdict = dict()
 * 
 *         if name is not None and name:             # <<<<<<<<<<<<<<
 *             if not modal:
 *                 self.__accumNames[name] = 0
 */
  }

  /* "cPyparsing.pyx":365
 *     # Performance tuning: we construct a *lot* of these, so keep this
 *     # constructor as small and fast as possible
 *     def __init__(self, toklist=None, name=None, asList=True, modal=True, isinstance=isinstance):             # <<<<<<<<<<<<<<
 *         if self.__doinit:
 *             self.__doinit = False
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_toklist);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":404
 *                         self[name] = toklist
 * 
 *     def __getitem__(self, i):             # <<<<<<<<<<<<<<
 *         if isinstance(i, (int, slice)):
 *             return self.__toklist[i]
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_5__getitem__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_5__getitem__ = {"__getitem__", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_5__getitem__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_5__getitem__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_i = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_i,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_i)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__getitem__", 1, 2, 2, 1); __PYX_ERR(0, 404, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__getitem__") < 0)) __PYX_ERR(0, 404, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_i = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__getitem__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 404, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_4__getitem__(__pyx_self, __pyx_v_self, __pyx_v_i);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_4__getitem__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_i) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  Py_ssize_t __pyx_t_9;
  PyObject *(*__pyx_t_10)(PyObject *);
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "cPyparsing.pyx":405
 * 
 *     def __getitem__(self, i):
 *         if isinstance(i, (int, slice)):             # <<<<<<<<<<<<<<
 *             return self.__toklist[i]
 *         else:
 */
  __pyx_t_2 = PyInt_Check(__pyx_v_i); 
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = PySlice_Check(__pyx_v_i); 
  __pyx_t_2 = (__pyx_t_3 != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":406
 *     def __getitem__(self, i):
 *         if isinstance(i, (int, slice)):
 *             return self.__toklist[i]             # <<<<<<<<<<<<<<
 *         else:
 *             if i not in self.__accumNames:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 406, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyObject_GetItem(__pyx_t_4, __pyx_v_i); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 406, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":405
 * 
 *     def __getitem__(self, i):
 *         if isinstance(i, (int, slice)):             # <<<<<<<<<<<<<<
 *             return self.__toklist[i]
 *         else:
 */
  }

  /* "cPyparsing.pyx":408
 *             return self.__toklist[i]
 *         else:
 *             if i not in self.__accumNames:             # <<<<<<<<<<<<<<
 *                 return self.__tokdict[i][-1][0]
 *             else:
 */
  /*else*/ {
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__accumNames); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_i, __pyx_t_5, Py_NE)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 408, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (__pyx_t_1) {

      /* "cPyparsing.pyx":409
 *         else:
 *             if i not in self.__accumNames:
 *                 return self.__tokdict[i][-1][0]             # <<<<<<<<<<<<<<
 *             else:
 *                 return ParseResults([v[0] for v in self.__tokdict[i]])
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 409, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = PyObject_GetItem(__pyx_t_5, __pyx_v_i); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 409, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_t_4, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 409, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_5, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 409, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L0;

      /* "cPyparsing.pyx":408
 *             return self.__toklist[i]
 *         else:
 *             if i not in self.__accumNames:             # <<<<<<<<<<<<<<
 *                 return self.__tokdict[i][-1][0]
 *             else:
 */
    }

    /* "cPyparsing.pyx":411
 *                 return self.__tokdict[i][-1][0]
 *             else:
 *                 return ParseResults([v[0] for v in self.__tokdict[i]])             # <<<<<<<<<<<<<<
 * 
 *     def __setitem__(self, k, v, isinstance=isinstance):
 */
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 411, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      { /* enter inner scope */
        PyObject *__pyx_8genexpr3__pyx_v_v = NULL;
        __pyx_t_6 = PyList_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 411, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 411, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = PyObject_GetItem(__pyx_t_7, __pyx_v_i); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 411, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (likely(PyList_CheckExact(__pyx_t_8)) || PyTuple_CheckExact(__pyx_t_8)) {
          __pyx_t_7 = __pyx_t_8; __Pyx_INCREF(__pyx_t_7); __pyx_t_9 = 0;
          __pyx_t_10 = NULL;
        } else {
          __pyx_t_9 = -1; __pyx_t_7 = PyObject_GetIter(__pyx_t_8); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 411, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_10 = Py_TYPE(__pyx_t_7)->tp_iternext; if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 411, __pyx_L9_error)
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        for (;;) {
          if (likely(!__pyx_t_10)) {
            if (likely(PyList_CheckExact(__pyx_t_7))) {
              if (__pyx_t_9 >= PyList_GET_SIZE(__pyx_t_7)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_8 = PyList_GET_ITEM(__pyx_t_7, __pyx_t_9); __Pyx_INCREF(__pyx_t_8); __pyx_t_9++; if (unlikely(0 < 0)) __PYX_ERR(0, 411, __pyx_L9_error)
              #else
              __pyx_t_8 = PySequence_ITEM(__pyx_t_7, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 411, __pyx_L9_error)
              __Pyx_GOTREF(__pyx_t_8);
              #endif
            } else {
              if (__pyx_t_9 >= PyTuple_GET_SIZE(__pyx_t_7)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_8 = PyTuple_GET_ITEM(__pyx_t_7, __pyx_t_9); __Pyx_INCREF(__pyx_t_8); __pyx_t_9++; if (unlikely(0 < 0)) __PYX_ERR(0, 411, __pyx_L9_error)
              #else
              __pyx_t_8 = PySequence_ITEM(__pyx_t_7, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 411, __pyx_L9_error)
              __Pyx_GOTREF(__pyx_t_8);
              #endif
            }
          } else {
            __pyx_t_8 = __pyx_t_10(__pyx_t_7);
            if (unlikely(!__pyx_t_8)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(0, 411, __pyx_L9_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_8);
          }
          __Pyx_XDECREF_SET(__pyx_8genexpr3__pyx_v_v, __pyx_t_8);
          __pyx_t_8 = 0;
          __pyx_t_8 = __Pyx_GetItemInt(__pyx_8genexpr3__pyx_v_v, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 411, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_8);
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_6, (PyObject*)__pyx_t_8))) __PYX_ERR(0, 411, __pyx_L9_error)
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_8genexpr3__pyx_v_v);
        goto __pyx_L12_exit_scope;
        __pyx_L9_error:;
        __Pyx_XDECREF(__pyx_8genexpr3__pyx_v_v);
        goto __pyx_L1_error;
        __pyx_L12_exit_scope:;
      } /* exit inner scope */
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (!__pyx_t_7) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 411, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_6};
          __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 411, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_6};
          __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 411, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        } else
        #endif
        {
          __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 411, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_7); __pyx_t_7 = NULL;
          __Pyx_GIVEREF(__pyx_t_6);
          PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_6);
          __pyx_t_6 = 0;
          __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_8, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 411, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L0;
    }
  }

  /* "cPyparsing.pyx":404
 *                         self[name] = toklist
 * 
 *     def __getitem__(self, i):             # <<<<<<<<<<<<<<
 *         if isinstance(i, (int, slice)):
 *             return self.__toklist[i]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":413
 *                 return ParseResults([v[0] for v in self.__tokdict[i]])
 * 
 *     def __setitem__(self, k, v, isinstance=isinstance):             # <<<<<<<<<<<<<<
 *         if isinstance(v, _ParseResultsWithOffset):
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [v]
 */

static PyObject *__pyx_pf_10cPyparsing_85__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_self)->__pyx_arg_isinstance);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_self)->__pyx_arg_isinstance);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_self)->__pyx_arg_isinstance);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_7__setitem__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_7__setitem__ = {"__setitem__", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_7__setitem__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_7__setitem__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_k = 0;
  PyObject *__pyx_v_v = 0;
  PyObject *__pyx_v_isinstance = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setitem__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_k,&__pyx_n_s_v,&__pyx_n_s_isinstance,0};
    PyObject* values[4] = {0,0,0,0};
    __pyx_defaults1 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_self);
    values[3] = __pyx_dynamic_args->__pyx_arg_isinstance;
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_k)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__setitem__", 0, 3, 4, 1); __PYX_ERR(0, 413, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_v)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__setitem__", 0, 3, 4, 2); __PYX_ERR(0, 413, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_isinstance);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__setitem__") < 0)) __PYX_ERR(0, 413, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_k = values[1];
    __pyx_v_v = values[2];
    __pyx_v_isinstance = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setitem__", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 413, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.__setitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_6__setitem__(__pyx_self, __pyx_v_self, __pyx_v_k, __pyx_v_v, __pyx_v_isinstance);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_6__setitem__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_k, PyObject *__pyx_v_v, PyObject *__pyx_v_isinstance) {
  PyObject *__pyx_v_sub = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("__setitem__", 0);

  /* "cPyparsing.pyx":414
 * 
 *     def __setitem__(self, k, v, isinstance=isinstance):
 *         if isinstance(v, _ParseResultsWithOffset):             # <<<<<<<<<<<<<<
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [v]
 *             sub = v[0]
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResultsWithOffset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_isinstance);
  __pyx_t_3 = __pyx_v_isinstance; __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_v, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 414, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_v, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 414, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  {
    __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 414, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_INCREF(__pyx_v_v);
    __Pyx_GIVEREF(__pyx_v_v);
    PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_v_v);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 414, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 414, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_7) {

    /* "cPyparsing.pyx":415
 *     def __setitem__(self, k, v, isinstance=isinstance):
 *         if isinstance(v, _ParseResultsWithOffset):
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [v]             # <<<<<<<<<<<<<<
 *             sub = v[0]
 *         elif isinstance(k, (int, slice)):
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_get); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = NULL;
    __pyx_t_5 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_5 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_k, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 415, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_k, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 415, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (__pyx_t_2) {
        __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2); __pyx_t_2 = NULL;
      }
      __Pyx_INCREF(__pyx_v_k);
      __Pyx_GIVEREF(__pyx_v_k);
      PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_5, __pyx_v_k);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_5, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_v_v);
    __Pyx_GIVEREF(__pyx_v_v);
    PyList_SET_ITEM(__pyx_t_6, 0, __pyx_v_v);
    __pyx_t_4 = PyNumber_Add(__pyx_t_1, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (unlikely(PyObject_SetItem(__pyx_t_6, __pyx_v_k, __pyx_t_4) < 0)) __PYX_ERR(0, 415, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":416
 *         if isinstance(v, _ParseResultsWithOffset):
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [v]
 *             sub = v[0]             # <<<<<<<<<<<<<<
 *         elif isinstance(k, (int, slice)):
 *             self.__toklist[k] = v
 */
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_v, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 416, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_sub = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":414
 * 
 *     def __setitem__(self, k, v, isinstance=isinstance):
 *         if isinstance(v, _ParseResultsWithOffset):             # <<<<<<<<<<<<<<
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [v]
 *             sub = v[0]
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":417
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [v]
 *             sub = v[0]
 *         elif isinstance(k, (int, slice)):             # <<<<<<<<<<<<<<
 *             self.__toklist[k] = v
 *             sub = v
 */
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 417, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(((PyObject *)(&PyInt_Type)));
  __Pyx_GIVEREF(((PyObject *)(&PyInt_Type)));
  PyTuple_SET_ITEM(__pyx_t_6, 0, ((PyObject *)(&PyInt_Type)));
  __Pyx_INCREF(((PyObject *)(&PySlice_Type)));
  __Pyx_GIVEREF(((PyObject *)(&PySlice_Type)));
  PyTuple_SET_ITEM(__pyx_t_6, 1, ((PyObject *)(&PySlice_Type)));
  __Pyx_INCREF(__pyx_v_isinstance);
  __pyx_t_1 = __pyx_v_isinstance; __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_1)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_k, __pyx_t_6};
    __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 417, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_k, __pyx_t_6};
    __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 417, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else
  #endif
  {
    __pyx_t_2 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 417, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_k);
    __Pyx_GIVEREF(__pyx_v_k);
    PyTuple_SET_ITEM(__pyx_t_2, 0+__pyx_t_5, __pyx_v_k);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_2, 1+__pyx_t_5, __pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 417, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 417, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_7) {

    /* "cPyparsing.pyx":418
 *             sub = v[0]
 *         elif isinstance(k, (int, slice)):
 *             self.__toklist[k] = v             # <<<<<<<<<<<<<<
 *             sub = v
 *         else:
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 418, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (unlikely(PyObject_SetItem(__pyx_t_4, __pyx_v_k, __pyx_v_v) < 0)) __PYX_ERR(0, 418, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":419
 *         elif isinstance(k, (int, slice)):
 *             self.__toklist[k] = v
 *             sub = v             # <<<<<<<<<<<<<<
 *         else:
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [_ParseResultsWithOffset(v, 0)]
 */
    __Pyx_INCREF(__pyx_v_v);
    __pyx_v_sub = __pyx_v_v;

    /* "cPyparsing.pyx":417
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [v]
 *             sub = v[0]
 *         elif isinstance(k, (int, slice)):             # <<<<<<<<<<<<<<
 *             self.__toklist[k] = v
 *             sub = v
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":421
 *             sub = v
 *         else:
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [_ParseResultsWithOffset(v, 0)]             # <<<<<<<<<<<<<<
 *             sub = v
 *         if isinstance(sub, ParseResults):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 421, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 421, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 421, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = NULL;
    __pyx_t_5 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_v_k, __pyx_t_1};
      __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 421, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_v_k, __pyx_t_1};
      __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 421, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    {
      __pyx_t_3 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 421, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (__pyx_t_6) {
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_6); __pyx_t_6 = NULL;
      }
      __Pyx_INCREF(__pyx_v_k);
      __Pyx_GIVEREF(__pyx_v_k);
      PyTuple_SET_ITEM(__pyx_t_3, 0+__pyx_t_5, __pyx_v_k);
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_3, 1+__pyx_t_5, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 421, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResultsWithOffset); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 421, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = NULL;
    __pyx_t_5 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_v_v, __pyx_int_0};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 421, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_v_v, __pyx_int_0};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 421, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 421, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__pyx_t_1) {
        __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1); __pyx_t_1 = NULL;
      }
      __Pyx_INCREF(__pyx_v_v);
      __Pyx_GIVEREF(__pyx_v_v);
      PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_v_v);
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_GIVEREF(__pyx_int_0);
      PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_int_0);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 421, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 421, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_2);
    PyList_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Add(__pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 421, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 421, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (unlikely(PyObject_SetItem(__pyx_t_3, __pyx_v_k, __pyx_t_2) < 0)) __PYX_ERR(0, 421, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":422
 *         else:
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [_ParseResultsWithOffset(v, 0)]
 *             sub = v             # <<<<<<<<<<<<<<
 *         if isinstance(sub, ParseResults):
 *             sub.__parent = wkref(self)
 */
    __Pyx_INCREF(__pyx_v_v);
    __pyx_v_sub = __pyx_v_v;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":423
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [_ParseResultsWithOffset(v, 0)]
 *             sub = v
 *         if isinstance(sub, ParseResults):             # <<<<<<<<<<<<<<
 *             sub.__parent = wkref(self)
 * 
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_isinstance);
  __pyx_t_4 = __pyx_v_isinstance; __pyx_t_6 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_4)) {
    PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_v_sub, __pyx_t_3};
    __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 423, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
    PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_v_sub, __pyx_t_3};
    __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 423, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  {
    __pyx_t_1 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 423, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__pyx_t_6) {
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_6); __pyx_t_6 = NULL;
    }
    __Pyx_INCREF(__pyx_v_sub);
    __Pyx_GIVEREF(__pyx_v_sub);
    PyTuple_SET_ITEM(__pyx_t_1, 0+__pyx_t_5, __pyx_v_sub);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_1, 1+__pyx_t_5, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 423, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 423, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_7) {

    /* "cPyparsing.pyx":424
 *             sub = v
 *         if isinstance(sub, ParseResults):
 *             sub.__parent = wkref(self)             # <<<<<<<<<<<<<<
 * 
 *     def __delitem__(self, i):
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_wkref); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 424, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_1) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 424, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_v_self};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 424, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_v_self};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 424, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      {
        __pyx_t_3 = PyTuple_New(1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 424, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1); __pyx_t_1 = NULL;
        __Pyx_INCREF(__pyx_v_self);
        __Pyx_GIVEREF(__pyx_v_self);
        PyTuple_SET_ITEM(__pyx_t_3, 0+1, __pyx_v_self);
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 424, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_sub, __pyx_n_s_ParseResults__parent, __pyx_t_2) < 0) __PYX_ERR(0, 424, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":423
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [_ParseResultsWithOffset(v, 0)]
 *             sub = v
 *         if isinstance(sub, ParseResults):             # <<<<<<<<<<<<<<
 *             sub.__parent = wkref(self)
 * 
 */
  }

  /* "cPyparsing.pyx":413
 *                 return ParseResults([v[0] for v in self.__tokdict[i]])
 * 
 *     def __setitem__(self, k, v, isinstance=isinstance):             # <<<<<<<<<<<<<<
 *         if isinstance(v, _ParseResultsWithOffset):
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [v]
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__setitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sub);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":426
 *             sub.__parent = wkref(self)
 * 
 *     def __delitem__(self, i):             # <<<<<<<<<<<<<<
 *         if isinstance(i, (int, slice)):
 *             mylen = len(self.__toklist)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_9__delitem__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_9__delitem__ = {"__delitem__", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_9__delitem__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_9__delitem__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_i = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__delitem__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_i,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_i)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__delitem__", 1, 2, 2, 1); __PYX_ERR(0, 426, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__delitem__") < 0)) __PYX_ERR(0, 426, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_i = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__delitem__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 426, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.__delitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_8__delitem__(__pyx_self, __pyx_v_self, __pyx_v_i);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_8__delitem__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_i) {
  Py_ssize_t __pyx_v_mylen;
  PyObject *__pyx_v_removed = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_occurrences = NULL;
  PyObject *__pyx_v_j = NULL;
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_position = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  int __pyx_t_13;
  int __pyx_t_14;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  PyObject *(*__pyx_t_17)(PyObject *);
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *(*__pyx_t_20)(PyObject *);
  PyObject *__pyx_t_21 = NULL;
  __Pyx_RefNannySetupContext("__delitem__", 0);
  __Pyx_INCREF(__pyx_v_i);

  /* "cPyparsing.pyx":427
 * 
 *     def __delitem__(self, i):
 *         if isinstance(i, (int, slice)):             # <<<<<<<<<<<<<<
 *             mylen = len(self.__toklist)
 *             del self.__toklist[i]
 */
  __pyx_t_2 = PyInt_Check(__pyx_v_i); 
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = PySlice_Check(__pyx_v_i); 
  __pyx_t_2 = (__pyx_t_3 != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":428
 *     def __delitem__(self, i):
 *         if isinstance(i, (int, slice)):
 *             mylen = len(self.__toklist)             # <<<<<<<<<<<<<<
 *             del self.__toklist[i]
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 428, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyObject_Length(__pyx_t_4); if (unlikely(__pyx_t_5 == -1)) __PYX_ERR(0, 428, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_mylen = __pyx_t_5;

    /* "cPyparsing.pyx":429
 *         if isinstance(i, (int, slice)):
 *             mylen = len(self.__toklist)
 *             del self.__toklist[i]             # <<<<<<<<<<<<<<
 * 
 *             # convert int to slice
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 429, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (unlikely(PyObject_DelItem(__pyx_t_4, __pyx_v_i) < 0)) __PYX_ERR(0, 429, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":432
 * 
 *             # convert int to slice
 *             if isinstance(i, int):             # <<<<<<<<<<<<<<
 *                 if i < 0:
 *                     i += mylen
 */
    __pyx_t_2 = PyInt_Check(__pyx_v_i); 
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (__pyx_t_1) {

      /* "cPyparsing.pyx":433
 *             # convert int to slice
 *             if isinstance(i, int):
 *                 if i < 0:             # <<<<<<<<<<<<<<
 *                     i += mylen
 *                 i = slice(i, i + 1)
 */
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_i, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 433, __pyx_L1_error)
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 433, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_1) {

        /* "cPyparsing.pyx":434
 *             if isinstance(i, int):
 *                 if i < 0:
 *                     i += mylen             # <<<<<<<<<<<<<<
 *                 i = slice(i, i + 1)
 *             # get removed indices
 */
        __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_mylen); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 434, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_6 = PyNumber_InPlaceAdd(__pyx_v_i, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 434, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF_SET(__pyx_v_i, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "cPyparsing.pyx":433
 *             # convert int to slice
 *             if isinstance(i, int):
 *                 if i < 0:             # <<<<<<<<<<<<<<
 *                     i += mylen
 *                 i = slice(i, i + 1)
 */
      }

      /* "cPyparsing.pyx":435
 *                 if i < 0:
 *                     i += mylen
 *                 i = slice(i, i + 1)             # <<<<<<<<<<<<<<
 *             # get removed indices
 *             removed = list(range(*i.indices(mylen)))
 */
      __pyx_t_6 = __Pyx_PyInt_AddObjC(__pyx_v_i, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 435, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_4 = PySlice_New(__pyx_v_i, __pyx_t_6, Py_None); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 435, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF_SET(__pyx_v_i, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "cPyparsing.pyx":432
 * 
 *             # convert int to slice
 *             if isinstance(i, int):             # <<<<<<<<<<<<<<
 *                 if i < 0:
 *                     i += mylen
 */
    }

    /* "cPyparsing.pyx":437
 *                 i = slice(i, i + 1)
 *             # get removed indices
 *             removed = list(range(*i.indices(mylen)))             # <<<<<<<<<<<<<<
 *             removed.reverse()
 *             # fixup indices in token dictionary
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_range); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 437, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_i, __pyx_n_s_indices); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 437, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = PyInt_FromSsize_t(__pyx_v_mylen); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 437, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    if (!__pyx_t_9) {
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 437, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_6);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_8};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 437, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_8};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 437, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 437, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_9); __pyx_t_9 = NULL;
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 437, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PySequence_Tuple(__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 437, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 437, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PySequence_List(__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 437, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_removed = ((PyObject*)__pyx_t_7);
    __pyx_t_7 = 0;

    /* "cPyparsing.pyx":438
 *             # get removed indices
 *             removed = list(range(*i.indices(mylen)))
 *             removed.reverse()             # <<<<<<<<<<<<<<
 *             # fixup indices in token dictionary
 *             for name, occurrences in self.__tokdict.items():
 */
    __pyx_t_11 = PyList_Reverse(__pyx_v_removed); if (unlikely(__pyx_t_11 == -1)) __PYX_ERR(0, 438, __pyx_L1_error)

    /* "cPyparsing.pyx":440
 *             removed.reverse()
 *             # fixup indices in token dictionary
 *             for name, occurrences in self.__tokdict.items():             # <<<<<<<<<<<<<<
 *                 for j in removed:
 *                     for k, (value, position) in enumerate(occurrences):
 */
    __pyx_t_5 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 440, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (unlikely(__pyx_t_6 == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "items");
      __PYX_ERR(0, 440, __pyx_L1_error)
    }
    __pyx_t_4 = __Pyx_dict_iterator(__pyx_t_6, 0, __pyx_n_s_items, (&__pyx_t_12), (&__pyx_t_13)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 440, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7);
    __pyx_t_7 = __pyx_t_4;
    __pyx_t_4 = 0;
    while (1) {
      __pyx_t_14 = __Pyx_dict_iter_next(__pyx_t_7, __pyx_t_12, &__pyx_t_5, &__pyx_t_4, &__pyx_t_6, NULL, __pyx_t_13);
      if (unlikely(__pyx_t_14 == 0)) break;
      if (unlikely(__pyx_t_14 == -1)) __PYX_ERR(0, 440, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_4);
      __pyx_t_4 = 0;
      __Pyx_XDECREF_SET(__pyx_v_occurrences, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "cPyparsing.pyx":441
 *             # fixup indices in token dictionary
 *             for name, occurrences in self.__tokdict.items():
 *                 for j in removed:             # <<<<<<<<<<<<<<
 *                     for k, (value, position) in enumerate(occurrences):
 *                         occurrences[k] = _ParseResultsWithOffset(value, position - (position > j))
 */
      __pyx_t_6 = __pyx_v_removed; __Pyx_INCREF(__pyx_t_6); __pyx_t_15 = 0;
      for (;;) {
        if (__pyx_t_15 >= PyList_GET_SIZE(__pyx_t_6)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_15); __Pyx_INCREF(__pyx_t_4); __pyx_t_15++; if (unlikely(0 < 0)) __PYX_ERR(0, 441, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_6, __pyx_t_15); __pyx_t_15++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 441, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
        __Pyx_XDECREF_SET(__pyx_v_j, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "cPyparsing.pyx":442
 *             for name, occurrences in self.__tokdict.items():
 *                 for j in removed:
 *                     for k, (value, position) in enumerate(occurrences):             # <<<<<<<<<<<<<<
 *                         occurrences[k] = _ParseResultsWithOffset(value, position - (position > j))
 *         else:
 */
        __Pyx_INCREF(__pyx_int_0);
        __pyx_t_4 = __pyx_int_0;
        if (likely(PyList_CheckExact(__pyx_v_occurrences)) || PyTuple_CheckExact(__pyx_v_occurrences)) {
          __pyx_t_10 = __pyx_v_occurrences; __Pyx_INCREF(__pyx_t_10); __pyx_t_16 = 0;
          __pyx_t_17 = NULL;
        } else {
          __pyx_t_16 = -1; __pyx_t_10 = PyObject_GetIter(__pyx_v_occurrences); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 442, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_17 = Py_TYPE(__pyx_t_10)->tp_iternext; if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 442, __pyx_L1_error)
        }
        for (;;) {
          if (likely(!__pyx_t_17)) {
            if (likely(PyList_CheckExact(__pyx_t_10))) {
              if (__pyx_t_16 >= PyList_GET_SIZE(__pyx_t_10)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_8 = PyList_GET_ITEM(__pyx_t_10, __pyx_t_16); __Pyx_INCREF(__pyx_t_8); __pyx_t_16++; if (unlikely(0 < 0)) __PYX_ERR(0, 442, __pyx_L1_error)
              #else
              __pyx_t_8 = PySequence_ITEM(__pyx_t_10, __pyx_t_16); __pyx_t_16++; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 442, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_8);
              #endif
            } else {
              if (__pyx_t_16 >= PyTuple_GET_SIZE(__pyx_t_10)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_8 = PyTuple_GET_ITEM(__pyx_t_10, __pyx_t_16); __Pyx_INCREF(__pyx_t_8); __pyx_t_16++; if (unlikely(0 < 0)) __PYX_ERR(0, 442, __pyx_L1_error)
              #else
              __pyx_t_8 = PySequence_ITEM(__pyx_t_10, __pyx_t_16); __pyx_t_16++; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 442, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_8);
              #endif
            }
          } else {
            __pyx_t_8 = __pyx_t_17(__pyx_t_10);
            if (unlikely(!__pyx_t_8)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(0, 442, __pyx_L1_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_8);
          }
          if ((likely(PyTuple_CheckExact(__pyx_t_8))) || (PyList_CheckExact(__pyx_t_8))) {
            PyObject* sequence = __pyx_t_8;
            #if !CYTHON_COMPILING_IN_PYPY
            Py_ssize_t size = Py_SIZE(sequence);
            #else
            Py_ssize_t size = PySequence_Size(sequence);
            #endif
            if (unlikely(size != 2)) {
              if (size > 2) __Pyx_RaiseTooManyValuesError(2);
              else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
              __PYX_ERR(0, 442, __pyx_L1_error)
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            if (likely(PyTuple_CheckExact(sequence))) {
              __pyx_t_9 = PyTuple_GET_ITEM(sequence, 0); 
              __pyx_t_18 = PyTuple_GET_ITEM(sequence, 1); 
            } else {
              __pyx_t_9 = PyList_GET_ITEM(sequence, 0); 
              __pyx_t_18 = PyList_GET_ITEM(sequence, 1); 
            }
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(__pyx_t_18);
            #else
            __pyx_t_9 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 442, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            __pyx_t_18 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 442, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_18);
            #endif
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          } else {
            Py_ssize_t index = -1;
            __pyx_t_19 = PyObject_GetIter(__pyx_t_8); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 442, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_19);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            __pyx_t_20 = Py_TYPE(__pyx_t_19)->tp_iternext;
            index = 0; __pyx_t_9 = __pyx_t_20(__pyx_t_19); if (unlikely(!__pyx_t_9)) goto __pyx_L14_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_9);
            index = 1; __pyx_t_18 = __pyx_t_20(__pyx_t_19); if (unlikely(!__pyx_t_18)) goto __pyx_L14_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_18);
            if (__Pyx_IternextUnpackEndCheck(__pyx_t_20(__pyx_t_19), 2) < 0) __PYX_ERR(0, 442, __pyx_L1_error)
            __pyx_t_20 = NULL;
            __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
            goto __pyx_L15_unpacking_done;
            __pyx_L14_unpacking_failed:;
            __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
            __pyx_t_20 = NULL;
            if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
            __PYX_ERR(0, 442, __pyx_L1_error)
            __pyx_L15_unpacking_done:;
          }
          __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_9);
          __pyx_t_9 = 0;
          __Pyx_XDECREF_SET(__pyx_v_position, __pyx_t_18);
          __pyx_t_18 = 0;
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_XDECREF_SET(__pyx_v_k, __pyx_t_4);
          __pyx_t_8 = __Pyx_PyInt_AddObjC(__pyx_t_4, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 442, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_4);
          __pyx_t_4 = __pyx_t_8;
          __pyx_t_8 = 0;

          /* "cPyparsing.pyx":443
 *                 for j in removed:
 *                     for k, (value, position) in enumerate(occurrences):
 *                         occurrences[k] = _ParseResultsWithOffset(value, position - (position > j))             # <<<<<<<<<<<<<<
 *         else:
 *             del self.__tokdict[i]
 */
          __pyx_t_18 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResultsWithOffset); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 443, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_18);
          __pyx_t_9 = PyObject_RichCompare(__pyx_v_position, __pyx_v_j, Py_GT); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 443, __pyx_L1_error)
          __pyx_t_19 = PyNumber_Subtract(__pyx_v_position, __pyx_t_9); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 443, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_9 = NULL;
          __pyx_t_14 = 0;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_18))) {
            __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_18);
            if (likely(__pyx_t_9)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_18);
              __Pyx_INCREF(__pyx_t_9);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_18, function);
              __pyx_t_14 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_18)) {
            PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_v_value, __pyx_t_19};
            __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_18, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 443, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_18)) {
            PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_v_value, __pyx_t_19};
            __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_18, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 443, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
          } else
          #endif
          {
            __pyx_t_21 = PyTuple_New(2+__pyx_t_14); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 443, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_21);
            if (__pyx_t_9) {
              __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_21, 0, __pyx_t_9); __pyx_t_9 = NULL;
            }
            __Pyx_INCREF(__pyx_v_value);
            __Pyx_GIVEREF(__pyx_v_value);
            PyTuple_SET_ITEM(__pyx_t_21, 0+__pyx_t_14, __pyx_v_value);
            __Pyx_GIVEREF(__pyx_t_19);
            PyTuple_SET_ITEM(__pyx_t_21, 1+__pyx_t_14, __pyx_t_19);
            __pyx_t_19 = 0;
            __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_18, __pyx_t_21, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 443, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
          }
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          if (unlikely(PyObject_SetItem(__pyx_v_occurrences, __pyx_v_k, __pyx_t_8) < 0)) __PYX_ERR(0, 443, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "cPyparsing.pyx":442
 *             for name, occurrences in self.__tokdict.items():
 *                 for j in removed:
 *                     for k, (value, position) in enumerate(occurrences):             # <<<<<<<<<<<<<<
 *                         occurrences[k] = _ParseResultsWithOffset(value, position - (position > j))
 *         else:
 */
        }
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "cPyparsing.pyx":441
 *             # fixup indices in token dictionary
 *             for name, occurrences in self.__tokdict.items():
 *                 for j in removed:             # <<<<<<<<<<<<<<
 *                     for k, (value, position) in enumerate(occurrences):
 *                         occurrences[k] = _ParseResultsWithOffset(value, position - (position > j))
 */
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":427
 * 
 *     def __delitem__(self, i):
 *         if isinstance(i, (int, slice)):             # <<<<<<<<<<<<<<
 *             mylen = len(self.__toklist)
 *             del self.__toklist[i]
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":445
 *                         occurrences[k] = _ParseResultsWithOffset(value, position - (position > j))
 *         else:
 *             del self.__tokdict[i]             # <<<<<<<<<<<<<<
 * 
 *     def __contains__(self, k):
 */
  /*else*/ {
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 445, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (unlikely(PyObject_DelItem(__pyx_t_7, __pyx_v_i) < 0)) __PYX_ERR(0, 445, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":426
 *             sub.__parent = wkref(self)
 * 
 *     def __delitem__(self, i):             # <<<<<<<<<<<<<<
 *         if isinstance(i, (int, slice)):
 *             mylen = len(self.__toklist)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_XDECREF(__pyx_t_21);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__delitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_removed);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_occurrences);
  __Pyx_XDECREF(__pyx_v_j);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_position);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":447
 *             del self.__tokdict[i]
 * 
 *     def __contains__(self, k):             # <<<<<<<<<<<<<<
 *         return k in self.__tokdict
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_11__contains__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_11__contains__ = {"__contains__", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_11__contains__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_11__contains__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_k = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__contains__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_k,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_k)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__contains__", 1, 2, 2, 1); __PYX_ERR(0, 447, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__contains__") < 0)) __PYX_ERR(0, 447, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_k = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__contains__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 447, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.__contains__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_10__contains__(__pyx_self, __pyx_v_self, __pyx_v_k);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_10__contains__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_k) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("__contains__", 0);

  /* "cPyparsing.pyx":448
 * 
 *     def __contains__(self, k):
 *         return k in self.__tokdict             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self): return len(self.__toklist)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_k, __pyx_t_1, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 448, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":447
 *             del self.__tokdict[i]
 * 
 *     def __contains__(self, k):             # <<<<<<<<<<<<<<
 *         return k in self.__tokdict
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__contains__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":450
 *         return k in self.__tokdict
 * 
 *     def __len__(self): return len(self.__toklist)             # <<<<<<<<<<<<<<
 * 
 *     def __bool__(self): return (not not self.__toklist)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_13__len__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_13__len__ = {"__len__", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_13__len__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_13__len__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_12__len__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_12__len__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  __Pyx_RefNannySetupContext("__len__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 450, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__len__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":452
 *     def __len__(self): return len(self.__toklist)
 * 
 *     def __bool__(self): return (not not self.__toklist)             # <<<<<<<<<<<<<<
 *     __nonzero__ = __bool__
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_15__bool__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_15__bool__ = {"__bool__", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_15__bool__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_15__bool__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__bool__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_14__bool__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_14__bool__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("__bool__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 452, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyBool_FromLong((!((!__pyx_t_2) != 0))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__bool__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":455
 *     __nonzero__ = __bool__
 * 
 *     def __iter__(self): return iter(self.__toklist)             # <<<<<<<<<<<<<<
 * 
 *     def __reversed__(self): return iter(self.__toklist[::-1])
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_17__iter__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_17__iter__ = {"__iter__", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_17__iter__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_17__iter__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_16__iter__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_16__iter__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__iter__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":457
 *     def __iter__(self): return iter(self.__toklist)
 * 
 *     def __reversed__(self): return iter(self.__toklist[::-1])             # <<<<<<<<<<<<<<
 * 
 *     def _iterkeys(self):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_19__reversed__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_19__reversed__ = {"__reversed__", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_19__reversed__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_19__reversed__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reversed__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_18__reversed__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_18__reversed__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__reversed__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetItem(__pyx_t_1, __pyx_slice__12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__reversed__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":459
 *     def __reversed__(self): return iter(self.__toklist[::-1])
 * 
 *     def _iterkeys(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self.__tokdict, "iterkeys"):
 *             return self.__tokdict.iterkeys()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_21_iterkeys(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_21_iterkeys = {"_iterkeys", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_21_iterkeys, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_21_iterkeys(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_iterkeys (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_20_iterkeys(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_20_iterkeys(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("_iterkeys", 0);

  /* "cPyparsing.pyx":460
 * 
 *     def _iterkeys(self):
 *         if hasattr(self.__tokdict, "iterkeys"):             # <<<<<<<<<<<<<<
 *             return self.__tokdict.iterkeys()
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_HasAttr(__pyx_t_1, __pyx_n_u_iterkeys); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 460, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":461
 *     def _iterkeys(self):
 *         if hasattr(self.__tokdict, "iterkeys"):
 *             return self.__tokdict.iterkeys()             # <<<<<<<<<<<<<<
 *         else:
 *             return iter(self.__tokdict)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_iterkeys); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 461, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 461, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":460
 * 
 *     def _iterkeys(self):
 *         if hasattr(self.__tokdict, "iterkeys"):             # <<<<<<<<<<<<<<
 *             return self.__tokdict.iterkeys()
 *         else:
 */
  }

  /* "cPyparsing.pyx":463
 *             return self.__tokdict.iterkeys()
 *         else:
 *             return iter(self.__tokdict)             # <<<<<<<<<<<<<<
 * 
 *     def _itervalues(self):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 463, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 463, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":459
 *     def __reversed__(self): return iter(self.__toklist[::-1])
 * 
 *     def _iterkeys(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self.__tokdict, "iterkeys"):
 *             return self.__tokdict.iterkeys()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ParseResults._iterkeys", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":465
 *             return iter(self.__tokdict)
 * 
 *     def _itervalues(self):             # <<<<<<<<<<<<<<
 *         return (self[k] for k in self._iterkeys())
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_23_itervalues(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_23_itervalues = {"_itervalues", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_23_itervalues, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_23_itervalues(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_itervalues (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_22_itervalues(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_12ParseResults_11_itervalues_2generator5(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":466
 * 
 *     def _itervalues(self):
 *         return (self[k] for k in self._iterkeys())             # <<<<<<<<<<<<<<
 * 
 *     def _iteritems(self):
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_11_itervalues_genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_4_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_4_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 466, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_3__itervalues *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_12ParseResults_11_itervalues_2generator5, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_ParseResults__itervalues_locals, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 466, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults._itervalues.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_12ParseResults_11_itervalues_2generator5(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 466, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 466, __pyx_L1_error) }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_n_s_iterkeys_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 466, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 466, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 466, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 466, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 466, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 466, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 466, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 466, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 466, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_k);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_k, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 466, __pyx_L1_error) }
    __pyx_t_1 = PyObject_GetItem(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_k); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 466, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    __Pyx_XGIVEREF(__pyx_t_2);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_4;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_5;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_2);
    __pyx_t_4 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_5 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 466, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":465
 *             return iter(self.__tokdict)
 * 
 *     def _itervalues(self):             # <<<<<<<<<<<<<<
 *         return (self[k] for k in self._iterkeys())
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_22_itervalues(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_3__itervalues *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("_itervalues", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_3__itervalues *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_3__itervalues(__pyx_ptype_10cPyparsing___pyx_scope_struct_3__itervalues, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_3__itervalues *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 465, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);

  /* "cPyparsing.pyx":466
 * 
 *     def _itervalues(self):
 *         return (self[k] for k in self._iterkeys())             # <<<<<<<<<<<<<<
 * 
 *     def _iteritems(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_pf_10cPyparsing_12ParseResults_11_itervalues_genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":465
 *             return iter(self.__tokdict)
 * 
 *     def _itervalues(self):             # <<<<<<<<<<<<<<
 *         return (self[k] for k in self._iterkeys())
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParseResults._itervalues", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":468
 *         return (self[k] for k in self._iterkeys())
 * 
 *     def _iteritems(self):             # <<<<<<<<<<<<<<
 *         return ((k, self[k]) for k in self._iterkeys())
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_25_iteritems(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_25_iteritems = {"_iteritems", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_25_iteritems, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_25_iteritems(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_iteritems (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_24_iteritems(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_12ParseResults_10_iteritems_2generator6(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":469
 * 
 *     def _iteritems(self):
 *         return ((k, self[k]) for k in self._iterkeys())             # <<<<<<<<<<<<<<
 * 
 *     if PY_3:
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_10_iteritems_genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_6_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_6_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 469, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__iteritems *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_12ParseResults_10_iteritems_2generator6, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_ParseResults__iteritems_locals_g, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 469, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults._iteritems.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_12ParseResults_10_iteritems_2generator6(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 469, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 469, __pyx_L1_error) }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_n_s_iterkeys_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 469, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 469, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 469, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 469, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 469, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 469, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 469, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 469, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 469, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_k);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_k, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 469, __pyx_L1_error) }
    __pyx_t_1 = PyObject_GetItem(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_k); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 469, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 469, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_k);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_k);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_cur_scope->__pyx_v_k);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    __Pyx_XGIVEREF(__pyx_t_2);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_4;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_5;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_2);
    __pyx_t_4 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_5 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 469, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":468
 *         return (self[k] for k in self._iterkeys())
 * 
 *     def _iteritems(self):             # <<<<<<<<<<<<<<
 *         return ((k, self[k]) for k in self._iterkeys())
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_24_iteritems(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__iteritems *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("_iteritems", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__iteritems *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_5__iteritems(__pyx_ptype_10cPyparsing___pyx_scope_struct_5__iteritems, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__iteritems *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 468, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);

  /* "cPyparsing.pyx":469
 * 
 *     def _iteritems(self):
 *         return ((k, self[k]) for k in self._iterkeys())             # <<<<<<<<<<<<<<
 * 
 *     if PY_3:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_pf_10cPyparsing_12ParseResults_10_iteritems_genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":468
 *         return (self[k] for k in self._iterkeys())
 * 
 *     def _iteritems(self):             # <<<<<<<<<<<<<<
 *         return ((k, self[k]) for k in self._iterkeys())
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParseResults._iteritems", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":491
 *         """Returns an iterator of all named result key-value tuples (Python 2.x only)."""
 * 
 *         def keys(self):             # <<<<<<<<<<<<<<
 *             """Returns all named result keys (as a list in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.iterkeys())
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_27keys(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_10cPyparsing_12ParseResults_26keys[] = "Returns all named result keys (as a list in Python 2.x, as an iterator in Python 3.x).";
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_27keys = {"keys", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_27keys, METH_O, __pyx_doc_10cPyparsing_12ParseResults_26keys};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_27keys(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("keys (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_26keys(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_26keys(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("keys", 0);

  /* "cPyparsing.pyx":493
 *         def keys(self):
 *             """Returns all named result keys (as a list in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.iterkeys())             # <<<<<<<<<<<<<<
 * 
 *         def values(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_iterkeys); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 493, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 493, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PySequence_List(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":491
 *         """Returns an iterator of all named result key-value tuples (Python 2.x only)."""
 * 
 *         def keys(self):             # <<<<<<<<<<<<<<
 *             """Returns all named result keys (as a list in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.iterkeys())
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParseResults.keys", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":495
 *             return list(self.iterkeys())
 * 
 *         def values(self):             # <<<<<<<<<<<<<<
 *             """Returns all named result values (as a list in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.itervalues())
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_29values(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_10cPyparsing_12ParseResults_28values[] = "Returns all named result values (as a list in Python 2.x, as an iterator in Python 3.x).";
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_29values = {"values", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_29values, METH_O, __pyx_doc_10cPyparsing_12ParseResults_28values};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_29values(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("values (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_28values(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_28values(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("values", 0);

  /* "cPyparsing.pyx":497
 *         def values(self):
 *             """Returns all named result values (as a list in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.itervalues())             # <<<<<<<<<<<<<<
 * 
 *         def items(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_itervalues); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 497, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 497, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PySequence_List(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":495
 *             return list(self.iterkeys())
 * 
 *         def values(self):             # <<<<<<<<<<<<<<
 *             """Returns all named result values (as a list in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.itervalues())
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParseResults.values", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":499
 *             return list(self.itervalues())
 * 
 *         def items(self):             # <<<<<<<<<<<<<<
 *             """Returns all named result key-values (as a list of tuples in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.iteritems())
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_31items(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_10cPyparsing_12ParseResults_30items[] = "Returns all named result key-values (as a list of tuples in Python 2.x, as an iterator in Python 3.x).";
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_31items = {"items", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_31items, METH_O, __pyx_doc_10cPyparsing_12ParseResults_30items};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_31items(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("items (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_30items(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_30items(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("items", 0);

  /* "cPyparsing.pyx":501
 *         def items(self):
 *             """Returns all named result key-values (as a list of tuples in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.iteritems())             # <<<<<<<<<<<<<<
 * 
 *     def haskeys(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_iteritems); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 501, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 501, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PySequence_List(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":499
 *             return list(self.itervalues())
 * 
 *         def items(self):             # <<<<<<<<<<<<<<
 *             """Returns all named result key-values (as a list of tuples in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.iteritems())
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParseResults.items", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":503
 *             return list(self.iteritems())
 * 
 *     def haskeys(self):             # <<<<<<<<<<<<<<
 *         """Since keys() returns an iterator, this method is helpful in bypassing
 *            code that looks for the existence of any defined results names."""
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_33haskeys(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_10cPyparsing_12ParseResults_32haskeys[] = "Since keys() returns an iterator, this method is helpful in bypassing\n           code that looks for the existence of any defined results names.";
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_33haskeys = {"haskeys", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_33haskeys, METH_O, __pyx_doc_10cPyparsing_12ParseResults_32haskeys};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_33haskeys(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("haskeys (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_32haskeys(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_32haskeys(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("haskeys", 0);

  /* "cPyparsing.pyx":506
 *         """Since keys() returns an iterator, this method is helpful in bypassing
 *            code that looks for the existence of any defined results names."""
 *         return bool(self.__tokdict)             # <<<<<<<<<<<<<<
 * 
 *     def pop(self, *args, **kwargs):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyBool_FromLong((!(!__pyx_t_2))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":503
 *             return list(self.iteritems())
 * 
 *     def haskeys(self):             # <<<<<<<<<<<<<<
 *         """Since keys() returns an iterator, this method is helpful in bypassing
 *            code that looks for the existence of any defined results names."""
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParseResults.haskeys", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":508
 *         return bool(self.__tokdict)
 * 
 *     def pop(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Removes and returns item at specified index (default=C{last}).
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_35pop(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_12ParseResults_34pop[] = "\n        Removes and returns item at specified index (default=C{last}).\n        Supports both C{list} and C{dict} semantics for C{pop()}. If passed no\n        argument or an integer argument, it will use C{list} semantics\n        and pop tokens from the list of parsed tokens. If passed a\n        non-integer argument (most likely a string), it will use C{dict}\n        semantics and pop the corresponding value from any defined\n        results names. A second default return value argument is\n        supported, just as in C{dict.pop()}.\n\n        Example::\n            def remove_first(tokens):\n                tokens.pop(0)\n            print(OneOrMore(Word(nums)).parseString(\"0 123 321\")) # -> ['0', '123', '321']\n            print(OneOrMore(Word(nums)).addParseAction(remove_first).parseString(\"0 123 321\")) # -> ['123', '321']\n\n            label = Word(alphas)\n            patt = label(\"LABEL\") + OneOrMore(Word(nums))\n            print(patt.parseString(\"AAB 123 321\").dump())\n\n            # Use pop() in a parse action to remove named result (note that corresponding value is not\n            # removed from list form of results)\n            def remove_LABEL(tokens):\n                tokens.pop(\"LABEL\")\n                return tokens\n            patt.addParseAction(remove_LABEL)\n            print(patt.parseString(\"AAB 123 321\").dump())\n        prints::\n            ['AAB', '123', '321']\n            - LABEL: AAB\n\n            ['AAB', '123', '321']\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_35pop = {"pop", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_35pop, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_34pop};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_35pop(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pop (wrapper)", 0);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  if (PyTuple_GET_SIZE(__pyx_args) > 1) {
    __pyx_v_args = PyTuple_GetSlice(__pyx_args, 1, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v_args)) {
      __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
      __Pyx_RefNannyFinishContext();
      return NULL;
    }
    __Pyx_GOTREF(__pyx_v_args);
  } else {
    __pyx_v_args = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 1) ? pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, __pyx_v_kwargs, values, used_pos_args, "pop") < 0)) __PYX_ERR(0, 508, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pop", 0, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 508, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("cPyparsing.ParseResults.pop", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_34pop(__pyx_self, __pyx_v_self, __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_34pop(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_v = NULL;
  PyObject *__pyx_v_index = NULL;
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_v_defaultvalue = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_t_10;
  __Pyx_RefNannySetupContext("pop", 0);
  __Pyx_INCREF(__pyx_v_args);

  /* "cPyparsing.pyx":542
 *             ['AAB', '123', '321']
 *         """
 *         if not args:             # <<<<<<<<<<<<<<
 *             args = [-1]
 *         for k, v in kwargs.items():
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_args); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 542, __pyx_L1_error)
  __pyx_t_2 = ((!__pyx_t_1) != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":543
 *         """
 *         if not args:
 *             args = [-1]             # <<<<<<<<<<<<<<
 *         for k, v in kwargs.items():
 *             if k == 'default':
 */
    __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 543, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_int_neg_1);
    __Pyx_GIVEREF(__pyx_int_neg_1);
    PyList_SET_ITEM(__pyx_t_3, 0, __pyx_int_neg_1);
    __Pyx_DECREF_SET(__pyx_v_args, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":542
 *             ['AAB', '123', '321']
 *         """
 *         if not args:             # <<<<<<<<<<<<<<
 *             args = [-1]
 *         for k, v in kwargs.items():
 */
  }

  /* "cPyparsing.pyx":544
 *         if not args:
 *             args = [-1]
 *         for k, v in kwargs.items():             # <<<<<<<<<<<<<<
 *             if k == 'default':
 *                 args = (args[0], v)
 */
  __pyx_t_4 = 0;
  __pyx_t_7 = __Pyx_dict_iterator(__pyx_v_kwargs, 1, __pyx_n_s_items, (&__pyx_t_5), (&__pyx_t_6)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_3);
  __pyx_t_3 = __pyx_t_7;
  __pyx_t_7 = 0;
  while (1) {
    __pyx_t_9 = __Pyx_dict_iter_next(__pyx_t_3, __pyx_t_5, &__pyx_t_4, &__pyx_t_7, &__pyx_t_8, NULL, __pyx_t_6);
    if (unlikely(__pyx_t_9 == 0)) break;
    if (unlikely(__pyx_t_9 == -1)) __PYX_ERR(0, 544, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_XDECREF_SET(__pyx_v_k, __pyx_t_7);
    __pyx_t_7 = 0;
    __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "cPyparsing.pyx":545
 *             args = [-1]
 *         for k, v in kwargs.items():
 *             if k == 'default':             # <<<<<<<<<<<<<<
 *                 args = (args[0], v)
 *             else:
 */
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_default, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 545, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":546
 *         for k, v in kwargs.items():
 *             if k == 'default':
 *                 args = (args[0], v)             # <<<<<<<<<<<<<<
 *             else:
 *                 raise TypeError("pop() got an unexpected keyword argument '%s'" % k)
 */
      __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_args, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 546, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 546, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_8);
      PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_8);
      __Pyx_INCREF(__pyx_v_v);
      __Pyx_GIVEREF(__pyx_v_v);
      PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_v_v);
      __pyx_t_8 = 0;
      __Pyx_DECREF_SET(__pyx_v_args, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "cPyparsing.pyx":545
 *             args = [-1]
 *         for k, v in kwargs.items():
 *             if k == 'default':             # <<<<<<<<<<<<<<
 *                 args = (args[0], v)
 *             else:
 */
      goto __pyx_L6;
    }

    /* "cPyparsing.pyx":548
 *                 args = (args[0], v)
 *             else:
 *                 raise TypeError("pop() got an unexpected keyword argument '%s'" % k)             # <<<<<<<<<<<<<<
 *         if (isinstance(args[0], int) or
 *             len(args) == 1 or
 */
    /*else*/ {
      __pyx_t_7 = PyUnicode_Format(__pyx_kp_u_pop_got_an_unexpected_keyword_ar, __pyx_v_k); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 548, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 548, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_7);
      __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_t_8, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 548, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_Raise(__pyx_t_7, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __PYX_ERR(0, 548, __pyx_L1_error)
    }
    __pyx_L6:;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":549
 *             else:
 *                 raise TypeError("pop() got an unexpected keyword argument '%s'" % k)
 *         if (isinstance(args[0], int) or             # <<<<<<<<<<<<<<
 *             len(args) == 1 or
 *                 args[0] in self):
 */
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_args, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyInt_Check(__pyx_t_3); 
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_10 = (__pyx_t_1 != 0);
  if (!__pyx_t_10) {
  } else {
    __pyx_t_2 = __pyx_t_10;
    goto __pyx_L8_bool_binop_done;
  }

  /* "cPyparsing.pyx":550
 *                 raise TypeError("pop() got an unexpected keyword argument '%s'" % k)
 *         if (isinstance(args[0], int) or
 *             len(args) == 1 or             # <<<<<<<<<<<<<<
 *                 args[0] in self):
 *             index = args[0]
 */
  __pyx_t_5 = PyObject_Length(__pyx_v_args); if (unlikely(__pyx_t_5 == -1)) __PYX_ERR(0, 550, __pyx_L1_error)
  __pyx_t_10 = ((__pyx_t_5 == 1) != 0);
  if (!__pyx_t_10) {
  } else {
    __pyx_t_2 = __pyx_t_10;
    goto __pyx_L8_bool_binop_done;
  }

  /* "cPyparsing.pyx":551
 *         if (isinstance(args[0], int) or
 *             len(args) == 1 or
 *                 args[0] in self):             # <<<<<<<<<<<<<<
 *             index = args[0]
 *             ret = self[index]
 */
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_args, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_10 = (__Pyx_PySequence_ContainsTF(__pyx_t_3, __pyx_v_self, Py_EQ)); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = (__pyx_t_10 != 0);
  __pyx_t_2 = __pyx_t_1;
  __pyx_L8_bool_binop_done:;

  /* "cPyparsing.pyx":549
 *             else:
 *                 raise TypeError("pop() got an unexpected keyword argument '%s'" % k)
 *         if (isinstance(args[0], int) or             # <<<<<<<<<<<<<<
 *             len(args) == 1 or
 *                 args[0] in self):
 */
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":552
 *             len(args) == 1 or
 *                 args[0] in self):
 *             index = args[0]             # <<<<<<<<<<<<<<
 *             ret = self[index]
 *             del self[index]
 */
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_args, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 552, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_index = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":553
 *                 args[0] in self):
 *             index = args[0]
 *             ret = self[index]             # <<<<<<<<<<<<<<
 *             del self[index]
 *             return ret
 */
    __pyx_t_3 = PyObject_GetItem(__pyx_v_self, __pyx_v_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 553, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_ret = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":554
 *             index = args[0]
 *             ret = self[index]
 *             del self[index]             # <<<<<<<<<<<<<<
 *             return ret
 *         else:
 */
    if (unlikely(PyObject_DelItem(__pyx_v_self, __pyx_v_index) < 0)) __PYX_ERR(0, 554, __pyx_L1_error)

    /* "cPyparsing.pyx":555
 *             ret = self[index]
 *             del self[index]
 *             return ret             # <<<<<<<<<<<<<<
 *         else:
 *             defaultvalue = args[1]
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_ret);
    __pyx_r = __pyx_v_ret;
    goto __pyx_L0;

    /* "cPyparsing.pyx":549
 *             else:
 *                 raise TypeError("pop() got an unexpected keyword argument '%s'" % k)
 *         if (isinstance(args[0], int) or             # <<<<<<<<<<<<<<
 *             len(args) == 1 or
 *                 args[0] in self):
 */
  }

  /* "cPyparsing.pyx":557
 *             return ret
 *         else:
 *             defaultvalue = args[1]             # <<<<<<<<<<<<<<
 *             return defaultvalue
 * 
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_args, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 557, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_defaultvalue = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":558
 *         else:
 *             defaultvalue = args[1]
 *             return defaultvalue             # <<<<<<<<<<<<<<
 * 
 *     def get(self, key, defaultValue=None):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_defaultvalue);
    __pyx_r = __pyx_v_defaultvalue;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":508
 *         return bool(self.__tokdict)
 * 
 *     def pop(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Removes and returns item at specified index (default=C{last}).
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing.ParseResults.pop", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_defaultvalue);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":560
 *             return defaultvalue
 * 
 *     def get(self, key, defaultValue=None):             # <<<<<<<<<<<<<<
 *         """
 *         Returns named result matching the given key, or if there is no
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_37get(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_12ParseResults_36get[] = "\n        Returns named result matching the given key, or if there is no\n        such name, then returns the given C{defaultValue} or C{None} if no\n        C{defaultValue} is specified.\n\n        Similar to C{dict.get()}.\n\n        Example::\n            integer = Word(nums)\n            date_str = integer(\"year\") + '/' + integer(\"month\") + '/' + integer(\"day\")\n\n            result = date_str.parseString(\"1999/12/31\")\n            print(result.get(\"year\")) # -> '1999'\n            print(result.get(\"hour\", \"not specified\")) # -> 'not specified'\n            print(result.get(\"hour\")) # -> None\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_37get = {"get", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_37get, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_36get};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_37get(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_key = 0;
  PyObject *__pyx_v_defaultValue = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_key,&__pyx_n_s_defaultValue,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_key)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get", 0, 2, 3, 1); __PYX_ERR(0, 560, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_defaultValue);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get") < 0)) __PYX_ERR(0, 560, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_key = values[1];
    __pyx_v_defaultValue = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 560, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_36get(__pyx_self, __pyx_v_self, __pyx_v_key, __pyx_v_defaultValue);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_36get(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_defaultValue) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("get", 0);

  /* "cPyparsing.pyx":577
 *             print(result.get("hour")) # -> None
 *         """
 *         if key in self:             # <<<<<<<<<<<<<<
 *             return self[key]
 *         else:
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_v_key, __pyx_v_self, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 577, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":578
 *         """
 *         if key in self:
 *             return self[key]             # <<<<<<<<<<<<<<
 *         else:
 *             return defaultValue
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = PyObject_GetItem(__pyx_v_self, __pyx_v_key); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 578, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":577
 *             print(result.get("hour")) # -> None
 *         """
 *         if key in self:             # <<<<<<<<<<<<<<
 *             return self[key]
 *         else:
 */
  }

  /* "cPyparsing.pyx":580
 *             return self[key]
 *         else:
 *             return defaultValue             # <<<<<<<<<<<<<<
 * 
 *     def insert(self, index, insStr):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_defaultValue);
    __pyx_r = __pyx_v_defaultValue;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":560
 *             return defaultvalue
 * 
 *     def get(self, key, defaultValue=None):             # <<<<<<<<<<<<<<
 *         """
 *         Returns named result matching the given key, or if there is no
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParseResults.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":582
 *             return defaultValue
 * 
 *     def insert(self, index, insStr):             # <<<<<<<<<<<<<<
 *         """
 *         Inserts new element at location index in the list of parsed tokens.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_39insert(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_12ParseResults_38insert[] = "\n        Inserts new element at location index in the list of parsed tokens.\n\n        Similar to C{list.insert()}.\n\n        Example::\n            print(OneOrMore(Word(nums)).parseString(\"0 123 321\")) # -> ['0', '123', '321']\n\n            # use a parse action to insert the parse location in the front of the parsed results\n            def insert_locn(locn, tokens):\n                tokens.insert(0, locn)\n            print(OneOrMore(Word(nums)).addParseAction(insert_locn).parseString(\"0 123 321\")) # -> [0, '0', '123', '321']\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_39insert = {"insert", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_39insert, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_38insert};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_39insert(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_index = 0;
  PyObject *__pyx_v_insStr = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("insert (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_index,&__pyx_n_s_insStr,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_index)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("insert", 1, 3, 3, 1); __PYX_ERR(0, 582, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_insStr)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("insert", 1, 3, 3, 2); __PYX_ERR(0, 582, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "insert") < 0)) __PYX_ERR(0, 582, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_index = values[1];
    __pyx_v_insStr = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("insert", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 582, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.insert", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_38insert(__pyx_self, __pyx_v_self, __pyx_v_index, __pyx_v_insStr);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_38insert(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_insStr) {
  CYTHON_UNUSED PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_occurrences = NULL;
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_position = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  PyObject *(*__pyx_t_10)(PyObject *);
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *(*__pyx_t_14)(PyObject *);
  PyObject *__pyx_t_15 = NULL;
  __Pyx_RefNannySetupContext("insert", 0);

  /* "cPyparsing.pyx":596
 *             print(OneOrMore(Word(nums)).addParseAction(insert_locn).parseString("0 123 321")) # -> [0, '0', '123', '321']
 *         """
 *         self.__toklist.insert(index, insStr)             # <<<<<<<<<<<<<<
 *         # fixup indices in token dictionary
 *         for name, occurrences in self.__tokdict.items():
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_insert); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_index, __pyx_v_insStr};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 596, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_index, __pyx_v_insStr};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 596, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 596, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_2) {
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2); __pyx_t_2 = NULL;
    }
    __Pyx_INCREF(__pyx_v_index);
    __Pyx_GIVEREF(__pyx_v_index);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_index);
    __Pyx_INCREF(__pyx_v_insStr);
    __Pyx_GIVEREF(__pyx_v_insStr);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_insStr);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 596, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":598
 *         self.__toklist.insert(index, insStr)
 *         # fixup indices in token dictionary
 *         for name, occurrences in self.__tokdict.items():             # <<<<<<<<<<<<<<
 *             for k, (value, position) in enumerate(occurrences):
 *                 occurrences[k] = _ParseResultsWithOffset(value, position + (position > index))
 */
  __pyx_t_6 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (unlikely(__pyx_t_3 == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "items");
    __PYX_ERR(0, 598, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_dict_iterator(__pyx_t_3, 0, __pyx_n_s_items, (&__pyx_t_7), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_8 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_7, &__pyx_t_6, &__pyx_t_5, &__pyx_t_3, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_8 == 0)) break;
    if (unlikely(__pyx_t_8 == -1)) __PYX_ERR(0, 598, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_occurrences, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":599
 *         # fixup indices in token dictionary
 *         for name, occurrences in self.__tokdict.items():
 *             for k, (value, position) in enumerate(occurrences):             # <<<<<<<<<<<<<<
 *                 occurrences[k] = _ParseResultsWithOffset(value, position + (position > index))
 * 
 */
    __Pyx_INCREF(__pyx_int_0);
    __pyx_t_3 = __pyx_int_0;
    if (likely(PyList_CheckExact(__pyx_v_occurrences)) || PyTuple_CheckExact(__pyx_v_occurrences)) {
      __pyx_t_5 = __pyx_v_occurrences; __Pyx_INCREF(__pyx_t_5); __pyx_t_9 = 0;
      __pyx_t_10 = NULL;
    } else {
      __pyx_t_9 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_v_occurrences); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 599, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_10 = Py_TYPE(__pyx_t_5)->tp_iternext; if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 599, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_10)) {
        if (likely(PyList_CheckExact(__pyx_t_5))) {
          if (__pyx_t_9 >= PyList_GET_SIZE(__pyx_t_5)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_9); __Pyx_INCREF(__pyx_t_2); __pyx_t_9++; if (unlikely(0 < 0)) __PYX_ERR(0, 599, __pyx_L1_error)
          #else
          __pyx_t_2 = PySequence_ITEM(__pyx_t_5, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 599, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          if (__pyx_t_9 >= PyTuple_GET_SIZE(__pyx_t_5)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_9); __Pyx_INCREF(__pyx_t_2); __pyx_t_9++; if (unlikely(0 < 0)) __PYX_ERR(0, 599, __pyx_L1_error)
          #else
          __pyx_t_2 = PySequence_ITEM(__pyx_t_5, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 599, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        }
      } else {
        __pyx_t_2 = __pyx_t_10(__pyx_t_5);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 599, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
        PyObject* sequence = __pyx_t_2;
        #if !CYTHON_COMPILING_IN_PYPY
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 599, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_11 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_12 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_11 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_12 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(__pyx_t_12);
        #else
        __pyx_t_11 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 599, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_12 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 599, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        #endif
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_13 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 599, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_14 = Py_TYPE(__pyx_t_13)->tp_iternext;
        index = 0; __pyx_t_11 = __pyx_t_14(__pyx_t_13); if (unlikely(!__pyx_t_11)) goto __pyx_L7_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_11);
        index = 1; __pyx_t_12 = __pyx_t_14(__pyx_t_13); if (unlikely(!__pyx_t_12)) goto __pyx_L7_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_12);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_14(__pyx_t_13), 2) < 0) __PYX_ERR(0, 599, __pyx_L1_error)
        __pyx_t_14 = NULL;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        goto __pyx_L8_unpacking_done;
        __pyx_L7_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __pyx_t_14 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 599, __pyx_L1_error)
        __pyx_L8_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_11);
      __pyx_t_11 = 0;
      __Pyx_XDECREF_SET(__pyx_v_position, __pyx_t_12);
      __pyx_t_12 = 0;
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_XDECREF_SET(__pyx_v_k, __pyx_t_3);
      __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_t_3, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 599, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3);
      __pyx_t_3 = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "cPyparsing.pyx":600
 *         for name, occurrences in self.__tokdict.items():
 *             for k, (value, position) in enumerate(occurrences):
 *                 occurrences[k] = _ParseResultsWithOffset(value, position + (position > index))             # <<<<<<<<<<<<<<
 * 
 *     def append(self, item):
 */
      __pyx_t_12 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResultsWithOffset); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 600, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_11 = PyObject_RichCompare(__pyx_v_position, __pyx_v_index, Py_GT); __Pyx_XGOTREF(__pyx_t_11); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 600, __pyx_L1_error)
      __pyx_t_13 = PyNumber_Add(__pyx_v_position, __pyx_t_11); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 600, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_11 = NULL;
      __pyx_t_8 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_12);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_12, function);
          __pyx_t_8 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_12)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_v_value, __pyx_t_13};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 600, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_v_value, __pyx_t_13};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 600, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      } else
      #endif
      {
        __pyx_t_15 = PyTuple_New(2+__pyx_t_8); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 600, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_v_value);
        __Pyx_GIVEREF(__pyx_v_value);
        PyTuple_SET_ITEM(__pyx_t_15, 0+__pyx_t_8, __pyx_v_value);
        __Pyx_GIVEREF(__pyx_t_13);
        PyTuple_SET_ITEM(__pyx_t_15, 1+__pyx_t_8, __pyx_t_13);
        __pyx_t_13 = 0;
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_15, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 600, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      }
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (unlikely(PyObject_SetItem(__pyx_v_occurrences, __pyx_v_k, __pyx_t_2) < 0)) __PYX_ERR(0, 600, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "cPyparsing.pyx":599
 *         # fixup indices in token dictionary
 *         for name, occurrences in self.__tokdict.items():
 *             for k, (value, position) in enumerate(occurrences):             # <<<<<<<<<<<<<<
 *                 occurrences[k] = _ParseResultsWithOffset(value, position + (position > index))
 * 
 */
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":582
 *             return defaultValue
 * 
 *     def insert(self, index, insStr):             # <<<<<<<<<<<<<<
 *         """
 *         Inserts new element at location index in the list of parsed tokens.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("cPyparsing.ParseResults.insert", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_occurrences);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_position);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":602
 *                 occurrences[k] = _ParseResultsWithOffset(value, position + (position > index))
 * 
 *     def append(self, item):             # <<<<<<<<<<<<<<
 *         """
 *         Add single element to end of ParseResults list of elements.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_41append(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_12ParseResults_40append[] = "\n        Add single element to end of ParseResults list of elements.\n\n        Example::\n            print(OneOrMore(Word(nums)).parseString(\"0 123 321\")) # -> ['0', '123', '321']\n\n            # use a parse action to compute the sum of the parsed integers, and add it to the end\n            def append_sum(tokens):\n                tokens.append(sum(map(int, tokens)))\n            print(OneOrMore(Word(nums)).addParseAction(append_sum).parseString(\"0 123 321\")) # -> ['0', '123', '321', 444]\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_41append = {"append", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_41append, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_40append};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_41append(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_item = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("append (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_item,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_item)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("append", 1, 2, 2, 1); __PYX_ERR(0, 602, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "append") < 0)) __PYX_ERR(0, 602, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_item = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("append", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 602, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_40append(__pyx_self, __pyx_v_self, __pyx_v_item);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_40append(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_item) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("append", 0);

  /* "cPyparsing.pyx":614
 *             print(OneOrMore(Word(nums)).addParseAction(append_sum).parseString("0 123 321")) # -> ['0', '123', '321', 444]
 *         """
 *         self.__toklist.append(item)             # <<<<<<<<<<<<<<
 * 
 *     def extend(self, itemseq):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_v_item); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 614, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":602
 *                 occurrences[k] = _ParseResultsWithOffset(value, position + (position > index))
 * 
 *     def append(self, item):             # <<<<<<<<<<<<<<
 *         """
 *         Add single element to end of ParseResults list of elements.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParseResults.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":616
 *         self.__toklist.append(item)
 * 
 *     def extend(self, itemseq):             # <<<<<<<<<<<<<<
 *         """
 *         Add sequence of elements to end of ParseResults list of elements.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_43extend(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_12ParseResults_42extend[] = "\n        Add sequence of elements to end of ParseResults list of elements.\n\n        Example::\n            patt = OneOrMore(Word(alphas))\n\n            # use a parse action to append the reverse of the matched strings, to make a palindrome\n            def make_palindrome(tokens):\n                tokens.extend(reversed([t[::-1] for t in tokens]))\n                return ''.join(tokens)\n            print(patt.addParseAction(make_palindrome).parseString(\"lskdj sdlkjf lksd\")) # -> 'lskdjsdlkjflksddsklfjkldsjdksl'\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_43extend = {"extend", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_43extend, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_42extend};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_43extend(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_itemseq = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("extend (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_itemseq,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_itemseq)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("extend", 1, 2, 2, 1); __PYX_ERR(0, 616, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "extend") < 0)) __PYX_ERR(0, 616, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_itemseq = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("extend", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 616, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_42extend(__pyx_self, __pyx_v_self, __pyx_v_itemseq);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_42extend(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_itemseq) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("extend", 0);
  __Pyx_INCREF(__pyx_v_self);

  /* "cPyparsing.pyx":629
 *             print(patt.addParseAction(make_palindrome).parseString("lskdj sdlkjf lksd")) # -> 'lskdjsdlkjflksddsklfjkldsjdksl'
 *         """
 *         if isinstance(itemseq, ParseResults):             # <<<<<<<<<<<<<<
 *             self += itemseq
 *         else:
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_itemseq, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 629, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":630
 *         """
 *         if isinstance(itemseq, ParseResults):
 *             self += itemseq             # <<<<<<<<<<<<<<
 *         else:
 *             self.__toklist.extend(itemseq)
 */
    __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_self, __pyx_v_itemseq); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 630, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_self, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":629
 *             print(patt.addParseAction(make_palindrome).parseString("lskdj sdlkjf lksd")) # -> 'lskdjsdlkjflksddsklfjkldsjdksl'
 *         """
 *         if isinstance(itemseq, ParseResults):             # <<<<<<<<<<<<<<
 *             self += itemseq
 *         else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":632
 *             self += itemseq
 *         else:
 *             self.__toklist.extend(itemseq)             # <<<<<<<<<<<<<<
 * 
 *     def clear(self):
 */
  /*else*/ {
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 632, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_extend); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 632, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_itemseq); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 632, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_itemseq};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 632, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_itemseq};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 632, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 632, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_itemseq);
        __Pyx_GIVEREF(__pyx_v_itemseq);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_itemseq);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 632, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":616
 *         self.__toklist.append(item)
 * 
 *     def extend(self, itemseq):             # <<<<<<<<<<<<<<
 *         """
 *         Add sequence of elements to end of ParseResults list of elements.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParseResults.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_self);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":634
 *             self.__toklist.extend(itemseq)
 * 
 *     def clear(self):             # <<<<<<<<<<<<<<
 *         """
 *         Clear all elements and results names.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_45clear(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_10cPyparsing_12ParseResults_44clear[] = "\n        Clear all elements and results names.\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_45clear = {"clear", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_45clear, METH_O, __pyx_doc_10cPyparsing_12ParseResults_44clear};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_45clear(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("clear (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_44clear(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_44clear(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("clear", 0);

  /* "cPyparsing.pyx":638
 *         Clear all elements and results names.
 *         """
 *         del self.__toklist[:]             # <<<<<<<<<<<<<<
 *         self.__tokdict.clear()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_DelSlice(__pyx_t_1, 0, 0, NULL, NULL, &__pyx_slice__13, 0, 0, 1) < 0) __PYX_ERR(0, 638, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":639
 *         """
 *         del self.__toklist[:]
 *         self.__tokdict.clear()             # <<<<<<<<<<<<<<
 * 
 *     def __getattr__(self, name):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_clear); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 639, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 639, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":634
 *             self.__toklist.extend(itemseq)
 * 
 *     def clear(self):             # <<<<<<<<<<<<<<
 *         """
 *         Clear all elements and results names.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParseResults.clear", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":641
 *         self.__tokdict.clear()
 * 
 *     def __getattr__(self, name):             # <<<<<<<<<<<<<<
 *         try:
 *             return self[name]
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_47__getattr__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_47__getattr__ = {"__getattr__", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_47__getattr__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_47__getattr__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getattr__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_name,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__getattr__", 1, 2, 2, 1); __PYX_ERR(0, 641, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__getattr__") < 0)) __PYX_ERR(0, 641, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_name = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__getattr__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 641, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.__getattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_46__getattr__(__pyx_self, __pyx_v_self, __pyx_v_name);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_46__getattr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("__getattr__", 0);

  /* "cPyparsing.pyx":642
 * 
 *     def __getattr__(self, name):
 *         try:             # <<<<<<<<<<<<<<
 *             return self[name]
 *         except KeyError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":643
 *     def __getattr__(self, name):
 *         try:
 *             return self[name]             # <<<<<<<<<<<<<<
 *         except KeyError:
 *             return ""
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = PyObject_GetItem(__pyx_v_self, __pyx_v_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 643, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":642
 * 
 *     def __getattr__(self, name):
 *         try:             # <<<<<<<<<<<<<<
 *             return self[name]
 *         except KeyError:
 */
    }
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":644
 *         try:
 *             return self[name]
 *         except KeyError:             # <<<<<<<<<<<<<<
 *             return ""
 * 
 */
    __pyx_t_5 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
    if (__pyx_t_5) {
      __Pyx_AddTraceback("cPyparsing.ParseResults.__getattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(0, 644, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "cPyparsing.pyx":645
 *             return self[name]
 *         except KeyError:
 *             return ""             # <<<<<<<<<<<<<<
 * 
 *         # if name in self.__tokdict:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__9);
      __pyx_r = __pyx_kp_u__9;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cPyparsing.pyx":642
 * 
 *     def __getattr__(self, name):
 *         try:             # <<<<<<<<<<<<<<
 *             return self[name]
 *         except KeyError:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":641
 *         self.__tokdict.clear()
 * 
 *     def __getattr__(self, name):             # <<<<<<<<<<<<<<
 *         try:
 *             return self[name]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__getattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":655
 *         #     return ""
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         ret = self.copy()
 *         ret += other
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_49__add__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_49__add__ = {"__add__", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_49__add__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_49__add__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__add__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__add__", 1, 2, 2, 1); __PYX_ERR(0, 655, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__add__") < 0)) __PYX_ERR(0, 655, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__add__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 655, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.__add__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_48__add__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_48__add__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("__add__", 0);

  /* "cPyparsing.pyx":656
 * 
 *     def __add__(self, other):
 *         ret = self.copy()             # <<<<<<<<<<<<<<
 *         ret += other
 *         return ret
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_copy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 656, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 656, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_ret = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":657
 *     def __add__(self, other):
 *         ret = self.copy()
 *         ret += other             # <<<<<<<<<<<<<<
 *         return ret
 * 
 */
  __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_ret, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF_SET(__pyx_v_ret, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":658
 *         ret = self.copy()
 *         ret += other
 *         return ret             # <<<<<<<<<<<<<<
 * 
 *     def __iadd__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ret);
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "cPyparsing.pyx":655
 *         #     return ""
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         ret = self.copy()
 *         ret += other
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__add__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":660
 *         return ret
 * 
 *     def __iadd__(self, other):             # <<<<<<<<<<<<<<
 *         if other.__tokdict:
 *             offset = len(self.__toklist)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_51__iadd__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_51__iadd__ = {"__iadd__", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_51__iadd__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_51__iadd__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iadd__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__iadd__", 1, 2, 2, 1); __PYX_ERR(0, 660, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__iadd__") < 0)) __PYX_ERR(0, 660, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__iadd__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 660, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.__iadd__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_50__iadd__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":664
 *             offset = len(self.__toklist)
 * 
 *             def addoffset(a): return offset if a < 0 else a + offset             # <<<<<<<<<<<<<<
 *             otheritems = other.__tokdict.items()
 *             otherdictitems = [(k, _ParseResultsWithOffset(v[0], addoffset(v[1])))
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_8__iadd___1addoffset(PyObject *__pyx_self, PyObject *__pyx_v_a); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_8__iadd___1addoffset = {"addoffset", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_8__iadd___1addoffset, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_8__iadd___1addoffset(PyObject *__pyx_self, PyObject *__pyx_v_a) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("addoffset (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_8__iadd___addoffset(__pyx_self, ((PyObject *)__pyx_v_a));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_8__iadd___addoffset(PyObject *__pyx_self, PyObject *__pyx_v_a) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_7___iadd__ *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_7___iadd__ *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("addoffset", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_7___iadd__ *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_a, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 664, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 664, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_cur_scope->__pyx_v_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 664, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __pyx_t_2;
    __pyx_t_2 = 0;
  } else {
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_cur_scope->__pyx_v_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 664, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyNumber_Add(__pyx_v_a, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 664, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_1 = __pyx_t_4;
    __pyx_t_4 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__iadd__.addoffset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":660
 *         return ret
 * 
 *     def __iadd__(self, other):             # <<<<<<<<<<<<<<
 *         if other.__tokdict:
 *             offset = len(self.__toklist)
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_50__iadd__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_7___iadd__ *__pyx_cur_scope;
  PyObject *__pyx_v_addoffset = 0;
  PyObject *__pyx_v_otheritems = NULL;
  PyObject *__pyx_v_otherdictitems = NULL;
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *(*__pyx_t_10)(PyObject *);
  Py_ssize_t __pyx_t_11;
  PyObject *(*__pyx_t_12)(PyObject *);
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_t_17;
  __Pyx_RefNannySetupContext("__iadd__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_7___iadd__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_7___iadd__(__pyx_ptype_10cPyparsing___pyx_scope_struct_7___iadd__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_7___iadd__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 660, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }

  /* "cPyparsing.pyx":661
 * 
 *     def __iadd__(self, other):
 *         if other.__tokdict:             # <<<<<<<<<<<<<<
 *             offset = len(self.__toklist)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":662
 *     def __iadd__(self, other):
 *         if other.__tokdict:
 *             offset = len(self.__toklist)             # <<<<<<<<<<<<<<
 * 
 *             def addoffset(a): return offset if a < 0 else a + offset
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 662, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_3 == -1)) __PYX_ERR(0, 662, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_cur_scope->__pyx_v_offset = __pyx_t_3;

    /* "cPyparsing.pyx":664
 *             offset = len(self.__toklist)
 * 
 *             def addoffset(a): return offset if a < 0 else a + offset             # <<<<<<<<<<<<<<
 *             otheritems = other.__tokdict.items()
 *             otherdictitems = [(k, _ParseResultsWithOffset(v[0], addoffset(v[1])))
 */
    __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_8__iadd___1addoffset, 0, __pyx_n_s_ParseResults___iadd___locals_add, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__15)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 664, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_addoffset = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":665
 * 
 *             def addoffset(a): return offset if a < 0 else a + offset
 *             otheritems = other.__tokdict.items()             # <<<<<<<<<<<<<<
 *             otherdictitems = [(k, _ParseResultsWithOffset(v[0], addoffset(v[1])))
 *                               for (k, vlist) in otheritems for v in vlist]
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 665, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_items); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 665, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 665, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 665, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_otheritems = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":666
 *             def addoffset(a): return offset if a < 0 else a + offset
 *             otheritems = other.__tokdict.items()
 *             otherdictitems = [(k, _ParseResultsWithOffset(v[0], addoffset(v[1])))             # <<<<<<<<<<<<<<
 *                               for (k, vlist) in otheritems for v in vlist]
 *             for k, v in otherdictitems:
 */
    { /* enter inner scope */
      PyObject *__pyx_8genexpr6__pyx_v_k = NULL;
      PyObject *__pyx_8genexpr6__pyx_v_vlist = NULL;
      PyObject *__pyx_8genexpr6__pyx_v_v = NULL;
      __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 666, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_1);

      /* "cPyparsing.pyx":667
 *             otheritems = other.__tokdict.items()
 *             otherdictitems = [(k, _ParseResultsWithOffset(v[0], addoffset(v[1])))
 *                               for (k, vlist) in otheritems for v in vlist]             # <<<<<<<<<<<<<<
 *             for k, v in otherdictitems:
 *                 self[k] = v
 */
      if (likely(PyList_CheckExact(__pyx_v_otheritems)) || PyTuple_CheckExact(__pyx_v_otheritems)) {
        __pyx_t_5 = __pyx_v_otheritems; __Pyx_INCREF(__pyx_t_5); __pyx_t_3 = 0;
        __pyx_t_6 = NULL;
      } else {
        __pyx_t_3 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_v_otheritems); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 667, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 667, __pyx_L6_error)
      }
      for (;;) {
        if (likely(!__pyx_t_6)) {
          if (likely(PyList_CheckExact(__pyx_t_5))) {
            if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_5)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_3); __Pyx_INCREF(__pyx_t_4); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 667, __pyx_L6_error)
            #else
            __pyx_t_4 = PySequence_ITEM(__pyx_t_5, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 667, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          } else {
            if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_5)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_3); __Pyx_INCREF(__pyx_t_4); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 667, __pyx_L6_error)
            #else
            __pyx_t_4 = PySequence_ITEM(__pyx_t_5, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 667, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          }
        } else {
          __pyx_t_4 = __pyx_t_6(__pyx_t_5);
          if (unlikely(!__pyx_t_4)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 667, __pyx_L6_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_4);
        }
        if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
          PyObject* sequence = __pyx_t_4;
          #if !CYTHON_COMPILING_IN_PYPY
          Py_ssize_t size = Py_SIZE(sequence);
          #else
          Py_ssize_t size = PySequence_Size(sequence);
          #endif
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 667, __pyx_L6_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_7 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_8 = PyTuple_GET_ITEM(sequence, 1); 
          } else {
            __pyx_t_7 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_8 = PyList_GET_ITEM(sequence, 1); 
          }
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          #else
          __pyx_t_7 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 667, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_8 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 667, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_8);
          #endif
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_9 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 667, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_10 = Py_TYPE(__pyx_t_9)->tp_iternext;
          index = 0; __pyx_t_7 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_7)) goto __pyx_L9_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_7);
          index = 1; __pyx_t_8 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_8)) goto __pyx_L9_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_8);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_10(__pyx_t_9), 2) < 0) __PYX_ERR(0, 667, __pyx_L6_error)
          __pyx_t_10 = NULL;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          goto __pyx_L10_unpacking_done;
          __pyx_L9_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_10 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 667, __pyx_L6_error)
          __pyx_L10_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_8genexpr6__pyx_v_k, __pyx_t_7);
        __pyx_t_7 = 0;
        __Pyx_XDECREF_SET(__pyx_8genexpr6__pyx_v_vlist, __pyx_t_8);
        __pyx_t_8 = 0;
        if (likely(PyList_CheckExact(__pyx_8genexpr6__pyx_v_vlist)) || PyTuple_CheckExact(__pyx_8genexpr6__pyx_v_vlist)) {
          __pyx_t_4 = __pyx_8genexpr6__pyx_v_vlist; __Pyx_INCREF(__pyx_t_4); __pyx_t_11 = 0;
          __pyx_t_12 = NULL;
        } else {
          __pyx_t_11 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_8genexpr6__pyx_v_vlist); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 667, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_12 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 667, __pyx_L6_error)
        }
        for (;;) {
          if (likely(!__pyx_t_12)) {
            if (likely(PyList_CheckExact(__pyx_t_4))) {
              if (__pyx_t_11 >= PyList_GET_SIZE(__pyx_t_4)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_8 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_11); __Pyx_INCREF(__pyx_t_8); __pyx_t_11++; if (unlikely(0 < 0)) __PYX_ERR(0, 667, __pyx_L6_error)
              #else
              __pyx_t_8 = PySequence_ITEM(__pyx_t_4, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 667, __pyx_L6_error)
              __Pyx_GOTREF(__pyx_t_8);
              #endif
            } else {
              if (__pyx_t_11 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_8 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_11); __Pyx_INCREF(__pyx_t_8); __pyx_t_11++; if (unlikely(0 < 0)) __PYX_ERR(0, 667, __pyx_L6_error)
              #else
              __pyx_t_8 = PySequence_ITEM(__pyx_t_4, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 667, __pyx_L6_error)
              __Pyx_GOTREF(__pyx_t_8);
              #endif
            }
          } else {
            __pyx_t_8 = __pyx_t_12(__pyx_t_4);
            if (unlikely(!__pyx_t_8)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(0, 667, __pyx_L6_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_8);
          }
          __Pyx_XDECREF_SET(__pyx_8genexpr6__pyx_v_v, __pyx_t_8);
          __pyx_t_8 = 0;

          /* "cPyparsing.pyx":666
 *             def addoffset(a): return offset if a < 0 else a + offset
 *             otheritems = other.__tokdict.items()
 *             otherdictitems = [(k, _ParseResultsWithOffset(v[0], addoffset(v[1])))             # <<<<<<<<<<<<<<
 *                               for (k, vlist) in otheritems for v in vlist]
 *             for k, v in otherdictitems:
 */
          __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResultsWithOffset); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 666, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_9 = __Pyx_GetItemInt(__pyx_8genexpr6__pyx_v_v, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 666, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_13 = __Pyx_GetItemInt(__pyx_8genexpr6__pyx_v_v, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 666, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_14 = __pyx_pf_10cPyparsing_12ParseResults_8__iadd___addoffset(__pyx_v_addoffset, __pyx_t_13); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 666, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_13 = NULL;
          __pyx_t_15 = 0;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_7);
            if (likely(__pyx_t_13)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
              __Pyx_INCREF(__pyx_t_13);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_7, function);
              __pyx_t_15 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_7)) {
            PyObject *__pyx_temp[3] = {__pyx_t_13, __pyx_t_9, __pyx_t_14};
            __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_15, 2+__pyx_t_15); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 666, __pyx_L6_error)
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
            PyObject *__pyx_temp[3] = {__pyx_t_13, __pyx_t_9, __pyx_t_14};
            __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_15, 2+__pyx_t_15); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 666, __pyx_L6_error)
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          } else
          #endif
          {
            __pyx_t_16 = PyTuple_New(2+__pyx_t_15); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 666, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_16);
            if (__pyx_t_13) {
              __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_t_13); __pyx_t_13 = NULL;
            }
            __Pyx_GIVEREF(__pyx_t_9);
            PyTuple_SET_ITEM(__pyx_t_16, 0+__pyx_t_15, __pyx_t_9);
            __Pyx_GIVEREF(__pyx_t_14);
            PyTuple_SET_ITEM(__pyx_t_16, 1+__pyx_t_15, __pyx_t_14);
            __pyx_t_9 = 0;
            __pyx_t_14 = 0;
            __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_16, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 666, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          }
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 666, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_INCREF(__pyx_8genexpr6__pyx_v_k);
          __Pyx_GIVEREF(__pyx_8genexpr6__pyx_v_k);
          PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_8genexpr6__pyx_v_k);
          __Pyx_GIVEREF(__pyx_t_8);
          PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_8);
          __pyx_t_8 = 0;
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_7))) __PYX_ERR(0, 666, __pyx_L6_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

          /* "cPyparsing.pyx":667
 *             otheritems = other.__tokdict.items()
 *             otherdictitems = [(k, _ParseResultsWithOffset(v[0], addoffset(v[1])))
 *                               for (k, vlist) in otheritems for v in vlist]             # <<<<<<<<<<<<<<
 *             for k, v in otherdictitems:
 *                 self[k] = v
 */
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_8genexpr6__pyx_v_k);
      __Pyx_XDECREF(__pyx_8genexpr6__pyx_v_vlist);
      __Pyx_XDECREF(__pyx_8genexpr6__pyx_v_v);
      goto __pyx_L13_exit_scope;
      __pyx_L6_error:;
      __Pyx_XDECREF(__pyx_8genexpr6__pyx_v_k);
      __Pyx_XDECREF(__pyx_8genexpr6__pyx_v_vlist);
      __Pyx_XDECREF(__pyx_8genexpr6__pyx_v_v);
      goto __pyx_L1_error;
      __pyx_L13_exit_scope:;
    } /* exit inner scope */
    __pyx_v_otherdictitems = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":668
 *             otherdictitems = [(k, _ParseResultsWithOffset(v[0], addoffset(v[1])))
 *                               for (k, vlist) in otheritems for v in vlist]
 *             for k, v in otherdictitems:             # <<<<<<<<<<<<<<
 *                 self[k] = v
 *                 if isinstance(v[0], ParseResults):
 */
    __pyx_t_1 = __pyx_v_otherdictitems; __Pyx_INCREF(__pyx_t_1); __pyx_t_3 = 0;
    for (;;) {
      if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_5 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 668, __pyx_L1_error)
      #else
      __pyx_t_5 = PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 668, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      #endif
      if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
        PyObject* sequence = __pyx_t_5;
        #if !CYTHON_COMPILING_IN_PYPY
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 668, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_7);
        #else
        __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 668, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 668, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_8 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 668, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_10 = Py_TYPE(__pyx_t_8)->tp_iternext;
        index = 0; __pyx_t_4 = __pyx_t_10(__pyx_t_8); if (unlikely(!__pyx_t_4)) goto __pyx_L16_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_4);
        index = 1; __pyx_t_7 = __pyx_t_10(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L16_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_7);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_10(__pyx_t_8), 2) < 0) __PYX_ERR(0, 668, __pyx_L1_error)
        __pyx_t_10 = NULL;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L17_unpacking_done;
        __pyx_L16_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_10 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 668, __pyx_L1_error)
        __pyx_L17_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_k, __pyx_t_4);
      __pyx_t_4 = 0;
      __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "cPyparsing.pyx":669
 *                               for (k, vlist) in otheritems for v in vlist]
 *             for k, v in otherdictitems:
 *                 self[k] = v             # <<<<<<<<<<<<<<
 *                 if isinstance(v[0], ParseResults):
 *                     v[0].__parent = wkref(self)
 */
      if (unlikely(PyObject_SetItem(__pyx_v_self, __pyx_v_k, __pyx_v_v) < 0)) __PYX_ERR(0, 669, __pyx_L1_error)

      /* "cPyparsing.pyx":670
 *             for k, v in otherdictitems:
 *                 self[k] = v
 *                 if isinstance(v[0], ParseResults):             # <<<<<<<<<<<<<<
 *                     v[0].__parent = wkref(self)
 * 
 */
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_v, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 670, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 670, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_2 = PyObject_IsInstance(__pyx_t_5, __pyx_t_7); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 670, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_17 = (__pyx_t_2 != 0);
      if (__pyx_t_17) {

        /* "cPyparsing.pyx":671
 *                 self[k] = v
 *                 if isinstance(v[0], ParseResults):
 *                     v[0].__parent = wkref(self)             # <<<<<<<<<<<<<<
 * 
 *         self.__toklist += other.__toklist
 */
        __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_wkref); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 671, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
          }
        }
        if (!__pyx_t_4) {
          __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_self); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 671, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_5)) {
            PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_self};
            __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 671, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_GOTREF(__pyx_t_7);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
            PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_self};
            __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 671, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_GOTREF(__pyx_t_7);
          } else
          #endif
          {
            __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 671, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_4); __pyx_t_4 = NULL;
            __Pyx_INCREF(__pyx_v_self);
            __Pyx_GIVEREF(__pyx_v_self);
            PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_v_self);
            __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_8, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 671, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_v, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 671, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        if (__Pyx_PyObject_SetAttrStr(__pyx_t_5, __pyx_n_s_ParseResults__parent, __pyx_t_7) < 0) __PYX_ERR(0, 671, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "cPyparsing.pyx":670
 *             for k, v in otherdictitems:
 *                 self[k] = v
 *                 if isinstance(v[0], ParseResults):             # <<<<<<<<<<<<<<
 *                     v[0].__parent = wkref(self)
 * 
 */
      }

      /* "cPyparsing.pyx":668
 *             otherdictitems = [(k, _ParseResultsWithOffset(v[0], addoffset(v[1])))
 *                               for (k, vlist) in otheritems for v in vlist]
 *             for k, v in otherdictitems:             # <<<<<<<<<<<<<<
 *                 self[k] = v
 *                 if isinstance(v[0], ParseResults):
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":661
 * 
 *     def __iadd__(self, other):
 *         if other.__tokdict:             # <<<<<<<<<<<<<<
 *             offset = len(self.__toklist)
 * 
 */
  }

  /* "cPyparsing.pyx":673
 *                     v[0].__parent = wkref(self)
 * 
 *         self.__toklist += other.__toklist             # <<<<<<<<<<<<<<
 *         self.__accumNames.update(other.__accumNames)
 *         return self
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = PyNumber_InPlaceAdd(__pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist, __pyx_t_7) < 0) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":674
 * 
 *         self.__toklist += other.__toklist
 *         self.__accumNames.update(other.__accumNames)             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__accumNames); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_update); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_ParseResults__accumNames); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (!__pyx_t_8) {
    __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 674, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_7);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_5};
      __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 674, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_5};
      __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 674, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 674, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_8); __pyx_t_8 = NULL;
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_t_5);
      __pyx_t_5 = 0;
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_4, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 674, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":675
 *         self.__toklist += other.__toklist
 *         self.__accumNames.update(other.__accumNames)
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def __radd__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":660
 *         return ret
 * 
 *     def __iadd__(self, other):             # <<<<<<<<<<<<<<
 *         if other.__tokdict:
 *             offset = len(self.__toklist)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__iadd__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_addoffset);
  __Pyx_XDECREF(__pyx_v_otheritems);
  __Pyx_XDECREF(__pyx_v_otherdictitems);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":677
 *         return self
 * 
 *     def __radd__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, int) and other == 0:
 *             # useful for merging many ParseResults using sum() builtin
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_53__radd__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_53__radd__ = {"__radd__", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_53__radd__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_53__radd__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__radd__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__radd__", 1, 2, 2, 1); __PYX_ERR(0, 677, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__radd__") < 0)) __PYX_ERR(0, 677, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__radd__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 677, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.__radd__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_52__radd__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_52__radd__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("__radd__", 0);

  /* "cPyparsing.pyx":678
 * 
 *     def __radd__(self, other):
 *         if isinstance(other, int) and other == 0:             # <<<<<<<<<<<<<<
 *             # useful for merging many ParseResults using sum() builtin
 *             return self.copy()
 */
  __pyx_t_2 = PyInt_Check(__pyx_v_other); 
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyInt_EqObjC(__pyx_v_other, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 678, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":680
 *         if isinstance(other, int) and other == 0:
 *             # useful for merging many ParseResults using sum() builtin
 *             return self.copy()             # <<<<<<<<<<<<<<
 *         else:
 *             # this may raise a TypeError - so be it
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_copy); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 680, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (__pyx_t_6) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 680, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else {
      __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 680, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":678
 * 
 *     def __radd__(self, other):
 *         if isinstance(other, int) and other == 0:             # <<<<<<<<<<<<<<
 *             # useful for merging many ParseResults using sum() builtin
 *             return self.copy()
 */
  }

  /* "cPyparsing.pyx":683
 *         else:
 *             # this may raise a TypeError - so be it
 *             return other + self             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = PyNumber_Add(__pyx_v_other, __pyx_v_self); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 683, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":677
 *         return self
 * 
 *     def __radd__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, int) and other == 0:
 *             # useful for merging many ParseResults using sum() builtin
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__radd__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":685
 *             return other + self
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "(%s, %s)" % (repr(self.__toklist), repr(self.__tokdict))
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_55__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_55__repr__ = {"__repr__", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_55__repr__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_55__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_54__repr__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_54__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "cPyparsing.pyx":686
 * 
 *     def __repr__(self):
 *         return "(%s, %s)" % (repr(self.__toklist), repr(self.__tokdict))             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_repr_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 686, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 686, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 686, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 686, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 686, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_repr_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 686, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 686, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 686, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 686, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 686, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = PyUnicode_Format(__pyx_kp_u_s_s, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":685
 *             return other + self
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "(%s, %s)" % (repr(self.__toklist), repr(self.__tokdict))
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":688
 *         return "(%s, %s)" % (repr(self.__toklist), repr(self.__tokdict))
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_57__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_57__str__ = {"__str__", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_57__str__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_57__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_56__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_12ParseResults_7__str___2generator7(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":689
 * 
 *     def __str__(self):
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'             # <<<<<<<<<<<<<<
 * 
 *     def _asStringList(self, sep=''):
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_7__str___genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_9_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_9_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_9_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_9_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_9_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 689, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_8___str__ *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_12ParseResults_7__str___2generator7, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_ParseResults___str___locals_gene, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 689, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.__str__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_12ParseResults_7__str___2generator7(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_9_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_9_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 689, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 689, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 689, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 689, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 689, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 689, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 689, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 689, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 689, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_i);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_i, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 689, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = PyObject_IsInstance(__pyx_cur_scope->__pyx_v_i, __pyx_t_5); if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 689, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if ((__pyx_t_6 != 0)) {
      __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 689, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      if (!__pyx_t_8) {
        __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_cur_scope->__pyx_v_i); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 689, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_7)) {
          PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_cur_scope->__pyx_v_i};
          __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 689, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_GOTREF(__pyx_t_5);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
          PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_cur_scope->__pyx_v_i};
          __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 689, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_GOTREF(__pyx_t_5);
        } else
        #endif
        {
          __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 689, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
          __Pyx_INCREF(__pyx_cur_scope->__pyx_v_i);
          __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_i);
          PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_cur_scope->__pyx_v_i);
          __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_9, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 689, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_1 = __pyx_t_5;
      __pyx_t_5 = 0;
    } else {
      __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_repr_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 689, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      if (!__pyx_t_9) {
        __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_cur_scope->__pyx_v_i); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 689, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_7)) {
          PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_cur_scope->__pyx_v_i};
          __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 689, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_GOTREF(__pyx_t_5);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
          PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_cur_scope->__pyx_v_i};
          __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 689, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_GOTREF(__pyx_t_5);
        } else
        #endif
        {
          __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 689, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_9); __pyx_t_9 = NULL;
          __Pyx_INCREF(__pyx_cur_scope->__pyx_v_i);
          __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_i);
          PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_cur_scope->__pyx_v_i);
          __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 689, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_1 = __pyx_t_5;
      __pyx_t_5 = 0;
    }
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_1))) __PYX_ERR(0, 689, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":688
 *         return "(%s, %s)" % (repr(self.__toklist), repr(self.__tokdict))
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_56__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_8___str__ *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__str__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_8___str__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_8___str__(__pyx_ptype_10cPyparsing___pyx_scope_struct_8___str__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_8___str__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 688, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);

  /* "cPyparsing.pyx":689
 * 
 *     def __str__(self):
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'             # <<<<<<<<<<<<<<
 * 
 *     def _asStringList(self, sep=''):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_pf_10cPyparsing_12ParseResults_7__str___genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__17, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_kp_u__16, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_t_2, __pyx_kp_u__18); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":688
 *         return "(%s, %s)" % (repr(self.__toklist), repr(self.__tokdict))
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":691
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'
 * 
 *     def _asStringList(self, sep=''):             # <<<<<<<<<<<<<<
 *         out = []
 *         for item in self.__toklist:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_59_asStringList(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_59_asStringList = {"_asStringList", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_59_asStringList, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_59_asStringList(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_sep = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_asStringList (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_sep,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)((PyObject*)__pyx_kp_u__9));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_sep);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "_asStringList") < 0)) __PYX_ERR(0, 691, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_sep = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_asStringList", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 691, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults._asStringList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_58_asStringList(__pyx_self, __pyx_v_self, __pyx_v_sep);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_58_asStringList(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_sep) {
  PyObject *__pyx_v_out = NULL;
  PyObject *__pyx_v_item = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  __Pyx_RefNannySetupContext("_asStringList", 0);

  /* "cPyparsing.pyx":692
 * 
 *     def _asStringList(self, sep=''):
 *         out = []             # <<<<<<<<<<<<<<
 *         for item in self.__toklist:
 *             if out and sep:
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_out = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":693
 *     def _asStringList(self, sep=''):
 *         out = []
 *         for item in self.__toklist:             # <<<<<<<<<<<<<<
 *             if out and sep:
 *                 out.append(sep)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 693, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 693, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 693, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 693, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 693, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 693, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 693, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_item, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":694
 *         out = []
 *         for item in self.__toklist:
 *             if out and sep:             # <<<<<<<<<<<<<<
 *                 out.append(sep)
 *             if isinstance(item, ParseResults):
 */
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_out); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 694, __pyx_L1_error)
    if (__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_sep); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 694, __pyx_L1_error)
    __pyx_t_5 = __pyx_t_6;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_5) {

      /* "cPyparsing.pyx":695
 *         for item in self.__toklist:
 *             if out and sep:
 *                 out.append(sep)             # <<<<<<<<<<<<<<
 *             if isinstance(item, ParseResults):
 *                 out += item._asStringList()
 */
      __pyx_t_7 = __Pyx_PyObject_Append(__pyx_v_out, __pyx_v_sep); if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 695, __pyx_L1_error)

      /* "cPyparsing.pyx":694
 *         out = []
 *         for item in self.__toklist:
 *             if out and sep:             # <<<<<<<<<<<<<<
 *                 out.append(sep)
 *             if isinstance(item, ParseResults):
 */
    }

    /* "cPyparsing.pyx":696
 *             if out and sep:
 *                 out.append(sep)
 *             if isinstance(item, ParseResults):             # <<<<<<<<<<<<<<
 *                 out += item._asStringList()
 *             else:
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 696, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyObject_IsInstance(__pyx_v_item, __pyx_t_1); if (unlikely(__pyx_t_5 == -1)) __PYX_ERR(0, 696, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {

      /* "cPyparsing.pyx":697
 *                 out.append(sep)
 *             if isinstance(item, ParseResults):
 *                 out += item._asStringList()             # <<<<<<<<<<<<<<
 *             else:
 *                 out.append(_ustr(item))
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_item, __pyx_n_s_asStringList); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 697, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      if (__pyx_t_9) {
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 697, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else {
        __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 697, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = PyNumber_InPlaceAdd(__pyx_v_out, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 697, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF_SET(__pyx_v_out, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "cPyparsing.pyx":696
 *             if out and sep:
 *                 out.append(sep)
 *             if isinstance(item, ParseResults):             # <<<<<<<<<<<<<<
 *                 out += item._asStringList()
 *             else:
 */
      goto __pyx_L8;
    }

    /* "cPyparsing.pyx":699
 *                 out += item._asStringList()
 *             else:
 *                 out.append(_ustr(item))             # <<<<<<<<<<<<<<
 *         return out
 * 
 */
    /*else*/ {
      __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 699, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      if (!__pyx_t_9) {
        __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_item); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 699, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_1)) {
          PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_v_item};
          __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 699, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_GOTREF(__pyx_t_8);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
          PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_v_item};
          __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 699, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_GOTREF(__pyx_t_8);
        } else
        #endif
        {
          __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 699, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_9); __pyx_t_9 = NULL;
          __Pyx_INCREF(__pyx_v_item);
          __Pyx_GIVEREF(__pyx_v_item);
          PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_v_item);
          __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_10, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 699, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_7 = __Pyx_PyObject_Append(__pyx_v_out, __pyx_t_8); if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 699, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __pyx_L8:;

    /* "cPyparsing.pyx":693
 *     def _asStringList(self, sep=''):
 *         out = []
 *         for item in self.__toklist:             # <<<<<<<<<<<<<<
 *             if out and sep:
 *                 out.append(sep)
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":700
 *             else:
 *                 out.append(_ustr(item))
 *         return out             # <<<<<<<<<<<<<<
 * 
 *     def asList(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_out);
  __pyx_r = __pyx_v_out;
  goto __pyx_L0;

  /* "cPyparsing.pyx":691
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'
 * 
 *     def _asStringList(self, sep=''):             # <<<<<<<<<<<<<<
 *         out = []
 *         for item in self.__toklist:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("cPyparsing.ParseResults._asStringList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_out);
  __Pyx_XDECREF(__pyx_v_item);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":702
 *         return out
 * 
 *     def asList(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the parse results as a nested list of matching tokens, all converted to strings.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_61asList(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_10cPyparsing_12ParseResults_60asList[] = "\n        Returns the parse results as a nested list of matching tokens, all converted to strings.\n\n        Example::\n            patt = OneOrMore(Word(alphas))\n            result = patt.parseString(\"sldkj lsdkj sldkj\")\n            # even though the result prints in string-like form, it is actually a pyparsing ParseResults\n            print(type(result), result) # -> <class 'pyparsing.ParseResults'> ['sldkj', 'lsdkj', 'sldkj']\n\n            # Use asList() to create an actual list\n            result_list = result.asList()\n            print(type(result_list), result_list) # -> <class 'list'> ['sldkj', 'lsdkj', 'sldkj']\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_61asList = {"asList", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_61asList, METH_O, __pyx_doc_10cPyparsing_12ParseResults_60asList};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_61asList(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("asList (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_60asList(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_60asList(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("asList", 0);

  /* "cPyparsing.pyx":716
 *             print(type(result_list), result_list) # -> <class 'list'> ['sldkj', 'lsdkj', 'sldkj']
 *         """
 *         return [res.asList() if isinstance(res, ParseResults) else res for res in self.__toklist]             # <<<<<<<<<<<<<<
 * 
 *     def asDict(self):
 */
  __Pyx_XDECREF(__pyx_r);
  { /* enter inner scope */
    PyObject *__pyx_8genexpr8__pyx_v_res = NULL;
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 716, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 716, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
      __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
      __pyx_t_5 = NULL;
    } else {
      __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 716, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 716, __pyx_L5_error)
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (likely(!__pyx_t_5)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_3)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 716, __pyx_L5_error)
          #else
          __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 716, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 716, __pyx_L5_error)
          #else
          __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 716, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        }
      } else {
        __pyx_t_2 = __pyx_t_5(__pyx_t_3);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 716, __pyx_L5_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_8genexpr8__pyx_v_res, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 716, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = PyObject_IsInstance(__pyx_8genexpr8__pyx_v_res, __pyx_t_6); if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 716, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if ((__pyx_t_7 != 0)) {
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_8genexpr8__pyx_v_res, __pyx_n_s_asList); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 716, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_9 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
          }
        }
        if (__pyx_t_9) {
          __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 716, __pyx_L5_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        } else {
          __pyx_t_6 = __Pyx_PyObject_CallNoArg(__pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 716, __pyx_L5_error)
        }
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_2 = __pyx_t_6;
        __pyx_t_6 = 0;
      } else {
        __Pyx_INCREF(__pyx_8genexpr8__pyx_v_res);
        __pyx_t_2 = __pyx_8genexpr8__pyx_v_res;
      }
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_2))) __PYX_ERR(0, 716, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_8genexpr8__pyx_v_res);
    goto __pyx_L8_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_8genexpr8__pyx_v_res);
    goto __pyx_L1_error;
    __pyx_L8_exit_scope:;
  } /* exit inner scope */
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":702
 *         return out
 * 
 *     def asList(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the parse results as a nested list of matching tokens, all converted to strings.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.ParseResults.asList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":718
 *         return [res.asList() if isinstance(res, ParseResults) else res for res in self.__toklist]
 * 
 *     def asDict(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the named parse results as a nested dictionary.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_63asDict(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_10cPyparsing_12ParseResults_62asDict[] = "\n        Returns the named parse results as a nested dictionary.\n\n        Example::\n            integer = Word(nums)\n            date_str = integer(\"year\") + '/' + integer(\"month\") + '/' + integer(\"day\")\n\n            result = date_str.parseString('12/31/1999')\n            print(type(result), repr(result)) # -> <class 'pyparsing.ParseResults'> (['12', '/', '31', '/', '1999'], {'day': [('1999', 4)], 'year': [('12', 0)], 'month': [('31', 2)]})\n\n            result_dict = result.asDict()\n            print(type(result_dict), repr(result_dict)) # -> <class 'dict'> {'day': '1999', 'year': '12', 'month': '31'}\n\n            # even though a ParseResults supports dict-like access, sometime you just need to have a dict\n            import json\n            print(json.dumps(result)) # -> Exception: TypeError: ... is not JSON serializable\n            print(json.dumps(result.asDict())) # -> {\"month\": \"31\", \"day\": \"1999\", \"year\": \"12\"}\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_63asDict = {"asDict", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_63asDict, METH_O, __pyx_doc_10cPyparsing_12ParseResults_62asDict};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_63asDict(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("asDict (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_62asDict(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":742
 *             item_fn = self.iteritems
 * 
 *         def toItem(obj):             # <<<<<<<<<<<<<<
 *             if isinstance(obj, ParseResults):
 *                 if obj.haskeys():
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_6asDict_1toItem(PyObject *__pyx_self, PyObject *__pyx_v_obj); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_6asDict_1toItem = {"toItem", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_6asDict_1toItem, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_6asDict_1toItem(PyObject *__pyx_self, PyObject *__pyx_v_obj) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("toItem (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_6asDict_toItem(__pyx_self, ((PyObject *)__pyx_v_obj));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_6asDict_toItem(PyObject *__pyx_self, PyObject *__pyx_v_obj) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_asDict *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_asDict *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  __Pyx_RefNannySetupContext("toItem", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_asDict *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":743
 * 
 *         def toItem(obj):
 *             if isinstance(obj, ParseResults):             # <<<<<<<<<<<<<<
 *                 if obj.haskeys():
 *                     return obj.asDict()
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_obj, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 743, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":744
 *         def toItem(obj):
 *             if isinstance(obj, ParseResults):
 *                 if obj.haskeys():             # <<<<<<<<<<<<<<
 *                     return obj.asDict()
 *                 else:
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj, __pyx_n_s_haskeys); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 744, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (__pyx_t_5) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 744, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 744, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 744, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_3) {

      /* "cPyparsing.pyx":745
 *             if isinstance(obj, ParseResults):
 *                 if obj.haskeys():
 *                     return obj.asDict()             # <<<<<<<<<<<<<<
 *                 else:
 *                     return [toItem(v) for v in obj]
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj, __pyx_n_s_asDict); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 745, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      if (__pyx_t_5) {
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 745, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else {
        __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 745, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "cPyparsing.pyx":744
 *         def toItem(obj):
 *             if isinstance(obj, ParseResults):
 *                 if obj.haskeys():             # <<<<<<<<<<<<<<
 *                     return obj.asDict()
 *                 else:
 */
    }

    /* "cPyparsing.pyx":747
 *                     return obj.asDict()
 *                 else:
 *                     return [toItem(v) for v in obj]             # <<<<<<<<<<<<<<
 *             else:
 *                 return obj
 */
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      { /* enter inner scope */
        PyObject *__pyx_8genexpr9__pyx_v_v = NULL;
        __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 747, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_1);
        if (likely(PyList_CheckExact(__pyx_v_obj)) || PyTuple_CheckExact(__pyx_v_obj)) {
          __pyx_t_4 = __pyx_v_obj; __Pyx_INCREF(__pyx_t_4); __pyx_t_6 = 0;
          __pyx_t_7 = NULL;
        } else {
          __pyx_t_6 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_v_obj); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 747, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_7 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 747, __pyx_L7_error)
        }
        for (;;) {
          if (likely(!__pyx_t_7)) {
            if (likely(PyList_CheckExact(__pyx_t_4))) {
              if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_4)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_5 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_6); __Pyx_INCREF(__pyx_t_5); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 747, __pyx_L7_error)
              #else
              __pyx_t_5 = PySequence_ITEM(__pyx_t_4, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 747, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_5);
              #endif
            } else {
              if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_6); __Pyx_INCREF(__pyx_t_5); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 747, __pyx_L7_error)
              #else
              __pyx_t_5 = PySequence_ITEM(__pyx_t_4, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 747, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_5);
              #endif
            }
          } else {
            __pyx_t_5 = __pyx_t_7(__pyx_t_4);
            if (unlikely(!__pyx_t_5)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(0, 747, __pyx_L7_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_5);
          }
          __Pyx_XDECREF_SET(__pyx_8genexpr9__pyx_v_v, __pyx_t_5);
          __pyx_t_5 = 0;
          if (unlikely(!__pyx_cur_scope->__pyx_v_toItem)) { __Pyx_RaiseClosureNameError("toItem"); __PYX_ERR(0, 747, __pyx_L7_error) }
          __pyx_t_5 = __pyx_pf_10cPyparsing_12ParseResults_6asDict_toItem(__pyx_cur_scope->__pyx_v_toItem, __pyx_8genexpr9__pyx_v_v); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 747, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_5);
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_5))) __PYX_ERR(0, 747, __pyx_L7_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_8genexpr9__pyx_v_v);
        goto __pyx_L10_exit_scope;
        __pyx_L7_error:;
        __Pyx_XDECREF(__pyx_8genexpr9__pyx_v_v);
        goto __pyx_L1_error;
        __pyx_L10_exit_scope:;
      } /* exit inner scope */
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;
    }

    /* "cPyparsing.pyx":743
 * 
 *         def toItem(obj):
 *             if isinstance(obj, ParseResults):             # <<<<<<<<<<<<<<
 *                 if obj.haskeys():
 *                     return obj.asDict()
 */
  }

  /* "cPyparsing.pyx":749
 *                     return [toItem(v) for v in obj]
 *             else:
 *                 return obj             # <<<<<<<<<<<<<<
 * 
 *         return dict((k, toItem(v)) for k, v in item_fn())
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_obj);
    __pyx_r = __pyx_v_obj;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":742
 *             item_fn = self.iteritems
 * 
 *         def toItem(obj):             # <<<<<<<<<<<<<<
 *             if isinstance(obj, ParseResults):
 *                 if obj.haskeys():
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ParseResults.asDict.toItem", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_12ParseResults_6asDict_4generator8(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":751
 *                 return obj
 * 
 *         return dict((k, toItem(v)) for k, v in item_fn())             # <<<<<<<<<<<<<<
 * 
 *     def copy(self):
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_6asDict_2genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_11_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_11_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 751, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_asDict *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_12ParseResults_6asDict_4generator8, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_ParseResults_asDict_locals_genex, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 751, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.asDict.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_12ParseResults_6asDict_4generator8(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 751, __pyx_L1_error)
  __pyx_r = PyDict_New(); if (unlikely(!__pyx_r)) __PYX_ERR(0, 751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_item_fn)) { __Pyx_RaiseClosureNameError("item_fn"); __PYX_ERR(0, 751, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_item_fn);
  __pyx_t_2 = __pyx_cur_scope->__pyx_outer_scope->__pyx_v_item_fn; __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 751, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 751, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 751, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 751, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 751, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 751, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 751, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 751, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 751, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
      PyObject* sequence = __pyx_t_1;
      #if !CYTHON_COMPILING_IN_PYPY
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 751, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      #else
      __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 751, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 751, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 751, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_8 = Py_TYPE(__pyx_t_7)->tp_iternext;
      index = 0; __pyx_t_3 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_3)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < 0) __PYX_ERR(0, 751, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 751, __pyx_L1_error)
      __pyx_L7_unpacking_done:;
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_k);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_k, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_v);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_v, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_t_6 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_toItem)) { __Pyx_RaiseClosureNameError("toItem"); __PYX_ERR(0, 751, __pyx_L1_error) }
    __pyx_t_1 = __pyx_pf_10cPyparsing_12ParseResults_6asDict_toItem(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_toItem, __pyx_cur_scope->__pyx_v_v); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 751, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely(PyDict_SetItem(__pyx_r, (PyObject*)__pyx_cur_scope->__pyx_v_k, (PyObject*)__pyx_t_1))) __PYX_ERR(0, 751, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":718
 *         return [res.asList() if isinstance(res, ParseResults) else res for res in self.__toklist]
 * 
 *     def asDict(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the named parse results as a nested dictionary.
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_62asDict(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_asDict *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("asDict", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_asDict *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_10_asDict(__pyx_ptype_10cPyparsing___pyx_scope_struct_10_asDict, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_asDict *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 718, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }

  /* "cPyparsing.pyx":737
 *             print(json.dumps(result.asDict())) # -> {"month": "31", "day": "1999", "year": "12"}
 *         """
 *         if PY_3:             # <<<<<<<<<<<<<<
 *             item_fn = self.items
 *         else:
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_PY_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 737, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":738
 *         """
 *         if PY_3:
 *             item_fn = self.items             # <<<<<<<<<<<<<<
 *         else:
 *             item_fn = self.iteritems
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_items); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 738, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_v_item_fn = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":737
 *             print(json.dumps(result.asDict())) # -> {"month": "31", "day": "1999", "year": "12"}
 *         """
 *         if PY_3:             # <<<<<<<<<<<<<<
 *             item_fn = self.items
 *         else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":740
 *             item_fn = self.items
 *         else:
 *             item_fn = self.iteritems             # <<<<<<<<<<<<<<
 * 
 *         def toItem(obj):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_iteritems); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 740, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_v_item_fn = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":742
 *             item_fn = self.iteritems
 * 
 *         def toItem(obj):             # <<<<<<<<<<<<<<
 *             if isinstance(obj, ParseResults):
 *                 if obj.haskeys():
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_6asDict_1toItem, 0, __pyx_n_s_ParseResults_asDict_locals_toIte, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__20)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_toItem = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":751
 *                 return obj
 * 
 *         return dict((k, toItem(v)) for k, v in item_fn())             # <<<<<<<<<<<<<<
 * 
 *     def copy(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_pf_10cPyparsing_12ParseResults_6asDict_2genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":718
 *         return [res.asList() if isinstance(res, ParseResults) else res for res in self.__toklist]
 * 
 *     def asDict(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the named parse results as a nested dictionary.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParseResults.asDict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":753
 *         return dict((k, toItem(v)) for k, v in item_fn())
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns a new copy of a C{ParseResults} object.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_65copy(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_10cPyparsing_12ParseResults_64copy[] = "\n        Returns a new copy of a C{ParseResults} object.\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_65copy = {"copy", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_65copy, METH_O, __pyx_doc_10cPyparsing_12ParseResults_64copy};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_65copy(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_64copy(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_64copy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("copy", 0);

  /* "cPyparsing.pyx":757
 *         Returns a new copy of a C{ParseResults} object.
 *         """
 *         ret = ParseResults(self.__toklist)             # <<<<<<<<<<<<<<
 *         ret.__tokdict = self.__tokdict.copy()
 *         ret.__parent = self.__parent
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 757, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 757, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 757, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 757, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 757, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_ret = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":758
 *         """
 *         ret = ParseResults(self.__toklist)
 *         ret.__tokdict = self.__tokdict.copy()             # <<<<<<<<<<<<<<
 *         ret.__parent = self.__parent
 *         ret.__accumNames.update(self.__accumNames)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 758, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_copy); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 758, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 758, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 758, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_ret, __pyx_n_s_ParseResults__tokdict, __pyx_t_1) < 0) __PYX_ERR(0, 758, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":759
 *         ret = ParseResults(self.__toklist)
 *         ret.__tokdict = self.__tokdict.copy()
 *         ret.__parent = self.__parent             # <<<<<<<<<<<<<<
 *         ret.__accumNames.update(self.__accumNames)
 *         ret.__name = self.__name
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__parent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_ret, __pyx_n_s_ParseResults__parent, __pyx_t_1) < 0) __PYX_ERR(0, 759, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":760
 *         ret.__tokdict = self.__tokdict.copy()
 *         ret.__parent = self.__parent
 *         ret.__accumNames.update(self.__accumNames)             # <<<<<<<<<<<<<<
 *         ret.__name = self.__name
 *         return ret
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_ret, __pyx_n_s_ParseResults__accumNames); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_update); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__accumNames); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 760, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_5};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 760, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_5};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 760, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 760, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_t_5);
      __pyx_t_5 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 760, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":761
 *         ret.__parent = self.__parent
 *         ret.__accumNames.update(self.__accumNames)
 *         ret.__name = self.__name             # <<<<<<<<<<<<<<
 *         return ret
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_ret, __pyx_n_s_ParseResults__name, __pyx_t_1) < 0) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":762
 *         ret.__accumNames.update(self.__accumNames)
 *         ret.__name = self.__name
 *         return ret             # <<<<<<<<<<<<<<
 * 
 *     def asXML(self, doctag=None, namedItemsOnly=False, indent="", formatted=True):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ret);
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "cPyparsing.pyx":753
 *         return dict((k, toItem(v)) for k, v in item_fn())
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns a new copy of a C{ParseResults} object.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ParseResults.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":764
 *         return ret
 * 
 *     def asXML(self, doctag=None, namedItemsOnly=False, indent="", formatted=True):             # <<<<<<<<<<<<<<
 *         """
 *         (Deprecated) Returns the parse results as XML. Tags are created for tokens and lists that have defined results names.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_67asXML(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_12ParseResults_66asXML[] = "\n        (Deprecated) Returns the parse results as XML. Tags are created for tokens and lists that have defined results names.\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_67asXML = {"asXML", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_67asXML, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_66asXML};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_67asXML(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_doctag = 0;
  PyObject *__pyx_v_namedItemsOnly = 0;
  PyObject *__pyx_v_indent = 0;
  PyObject *__pyx_v_formatted = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("asXML (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_doctag,&__pyx_n_s_namedItemsOnly,&__pyx_n_s_indent,&__pyx_n_s_formatted,0};
    PyObject* values[5] = {0,0,0,0,0};
    values[1] = ((PyObject *)((PyObject *)Py_None));
    values[2] = ((PyObject *)((PyObject *)Py_False));
    values[3] = ((PyObject *)((PyObject*)__pyx_kp_u__9));
    values[4] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doctag);
          if (value) { values[1] = value; kw_args--; }
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_namedItemsOnly);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_indent);
          if (value) { values[3] = value; kw_args--; }
        }
        case  4:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_formatted);
          if (value) { values[4] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "asXML") < 0)) __PYX_ERR(0, 764, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_doctag = values[1];
    __pyx_v_namedItemsOnly = values[2];
    __pyx_v_indent = values[3];
    __pyx_v_formatted = values[4];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("asXML", 0, 1, 5, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 764, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.asXML", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_66asXML(__pyx_self, __pyx_v_self, __pyx_v_doctag, __pyx_v_namedItemsOnly, __pyx_v_indent, __pyx_v_formatted);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_12ParseResults_5asXML_2generator9(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":770
 *         nl = "\n"
 *         out = []
 *         namedItems = dict((v[1], k) for (k, vlist) in self.__tokdict.items()             # <<<<<<<<<<<<<<
 *                           for v in vlist)
 *         nextLevelIndent = indent + "  "
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_5asXML_genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_13_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_13_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 770, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_asXML *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_12ParseResults_5asXML_2generator9, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_ParseResults_asXML_locals_genexp, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 770, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.asXML.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_12ParseResults_5asXML_2generator9(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 770, __pyx_L1_error)
  __pyx_r = PyDict_New(); if (unlikely(!__pyx_r)) __PYX_ERR(0, 770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  __pyx_t_2 = 0;
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 770, __pyx_L1_error) }
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (unlikely(__pyx_t_5 == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "items");
    __PYX_ERR(0, 770, __pyx_L1_error)
  }
  __pyx_t_6 = __Pyx_dict_iterator(__pyx_t_5, 0, __pyx_n_s_items, (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_6;
  __pyx_t_6 = 0;
  while (1) {
    __pyx_t_7 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_6, &__pyx_t_5, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_7 == 0)) break;
    if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 770, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_k);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_k, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_vlist);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_vlist, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_t_5 = 0;

    /* "cPyparsing.pyx":771
 *         out = []
 *         namedItems = dict((v[1], k) for (k, vlist) in self.__tokdict.items()
 *                           for v in vlist)             # <<<<<<<<<<<<<<
 *         nextLevelIndent = indent + "  "
 * 
 */
    if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_v_vlist)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_v_vlist)) {
      __pyx_t_5 = __pyx_cur_scope->__pyx_v_vlist; __Pyx_INCREF(__pyx_t_5); __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
    } else {
      __pyx_t_8 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_cur_scope->__pyx_v_vlist); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 771, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_9 = Py_TYPE(__pyx_t_5)->tp_iternext; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 771, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_9)) {
        if (likely(PyList_CheckExact(__pyx_t_5))) {
          if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_5)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_8); __Pyx_INCREF(__pyx_t_6); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 771, __pyx_L1_error)
          #else
          __pyx_t_6 = PySequence_ITEM(__pyx_t_5, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 771, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
        } else {
          if (__pyx_t_8 >= PyTuple_GET_SIZE(__pyx_t_5)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_8); __Pyx_INCREF(__pyx_t_6); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 771, __pyx_L1_error)
          #else
          __pyx_t_6 = PySequence_ITEM(__pyx_t_5, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 771, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
        }
      } else {
        __pyx_t_6 = __pyx_t_9(__pyx_t_5);
        if (unlikely(!__pyx_t_6)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 771, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_v);
      __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_v, __pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_6);
      __pyx_t_6 = 0;

      /* "cPyparsing.pyx":770
 *         nl = "\n"
 *         out = []
 *         namedItems = dict((v[1], k) for (k, vlist) in self.__tokdict.items()             # <<<<<<<<<<<<<<
 *                           for v in vlist)
 *         nextLevelIndent = indent + "  "
 */
      __pyx_t_6 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_v, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 770, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (unlikely(PyDict_SetItem(__pyx_r, (PyObject*)__pyx_t_6, (PyObject*)__pyx_cur_scope->__pyx_v_k))) __PYX_ERR(0, 770, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "cPyparsing.pyx":771
 *         out = []
 *         namedItems = dict((v[1], k) for (k, vlist) in self.__tokdict.items()
 *                           for v in vlist)             # <<<<<<<<<<<<<<
 *         nextLevelIndent = indent + "  "
 * 
 */
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "cPyparsing.pyx":770
 *         nl = "\n"
 *         out = []
 *         namedItems = dict((v[1], k) for (k, vlist) in self.__tokdict.items()             # <<<<<<<<<<<<<<
 *                           for v in vlist)
 *         nextLevelIndent = indent + "  "
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":764
 *         return ret
 * 
 *     def asXML(self, doctag=None, namedItemsOnly=False, indent="", formatted=True):             # <<<<<<<<<<<<<<
 *         """
 *         (Deprecated) Returns the parse results as XML. Tags are created for tokens and lists that have defined results names.
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_66asXML(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_doctag, PyObject *__pyx_v_namedItemsOnly, PyObject *__pyx_v_indent, PyObject *__pyx_v_formatted) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_asXML *__pyx_cur_scope;
  PyObject *__pyx_v_nl = NULL;
  PyObject *__pyx_v_out = NULL;
  PyObject *__pyx_v_namedItems = NULL;
  PyObject *__pyx_v_nextLevelIndent = NULL;
  PyObject *__pyx_v_selfTag = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_v_resTag = NULL;
  PyObject *__pyx_v_xmlBodyText = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  __Pyx_RefNannySetupContext("asXML", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_asXML *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_12_asXML(__pyx_ptype_10cPyparsing___pyx_scope_struct_12_asXML, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_asXML *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 764, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_INCREF(__pyx_v_indent);

  /* "cPyparsing.pyx":768
 *         (Deprecated) Returns the parse results as XML. Tags are created for tokens and lists that have defined results names.
 *         """
 *         nl = "\n"             # <<<<<<<<<<<<<<
 *         out = []
 *         namedItems = dict((v[1], k) for (k, vlist) in self.__tokdict.items()
 */
  __Pyx_INCREF(__pyx_kp_u__21);
  __pyx_v_nl = __pyx_kp_u__21;

  /* "cPyparsing.pyx":769
 *         """
 *         nl = "\n"
 *         out = []             # <<<<<<<<<<<<<<
 *         namedItems = dict((v[1], k) for (k, vlist) in self.__tokdict.items()
 *                           for v in vlist)
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_out = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":770
 *         nl = "\n"
 *         out = []
 *         namedItems = dict((v[1], k) for (k, vlist) in self.__tokdict.items()             # <<<<<<<<<<<<<<
 *                           for v in vlist)
 *         nextLevelIndent = indent + "  "
 */
  __pyx_t_1 = __pyx_pf_10cPyparsing_12ParseResults_5asXML_genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_namedItems = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":772
 *         namedItems = dict((v[1], k) for (k, vlist) in self.__tokdict.items()
 *                           for v in vlist)
 *         nextLevelIndent = indent + "  "             # <<<<<<<<<<<<<<
 * 
 *         # collapse out indents if formatting is not desired
 */
  __pyx_t_2 = PyNumber_Add(__pyx_v_indent, __pyx_kp_u__22); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 772, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_nextLevelIndent = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":775
 * 
 *         # collapse out indents if formatting is not desired
 *         if not formatted:             # <<<<<<<<<<<<<<
 *             indent = ""
 *             nextLevelIndent = ""
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_formatted); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 775, __pyx_L1_error)
  __pyx_t_4 = ((!__pyx_t_3) != 0);
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":776
 *         # collapse out indents if formatting is not desired
 *         if not formatted:
 *             indent = ""             # <<<<<<<<<<<<<<
 *             nextLevelIndent = ""
 *             nl = ""
 */
    __Pyx_INCREF(__pyx_kp_u__9);
    __Pyx_DECREF_SET(__pyx_v_indent, __pyx_kp_u__9);

    /* "cPyparsing.pyx":777
 *         if not formatted:
 *             indent = ""
 *             nextLevelIndent = ""             # <<<<<<<<<<<<<<
 *             nl = ""
 * 
 */
    __Pyx_INCREF(__pyx_kp_u__9);
    __Pyx_DECREF_SET(__pyx_v_nextLevelIndent, __pyx_kp_u__9);

    /* "cPyparsing.pyx":778
 *             indent = ""
 *             nextLevelIndent = ""
 *             nl = ""             # <<<<<<<<<<<<<<
 * 
 *         selfTag = None
 */
    __Pyx_INCREF(__pyx_kp_u__9);
    __Pyx_DECREF_SET(__pyx_v_nl, __pyx_kp_u__9);

    /* "cPyparsing.pyx":775
 * 
 *         # collapse out indents if formatting is not desired
 *         if not formatted:             # <<<<<<<<<<<<<<
 *             indent = ""
 *             nextLevelIndent = ""
 */
  }

  /* "cPyparsing.pyx":780
 *             nl = ""
 * 
 *         selfTag = None             # <<<<<<<<<<<<<<
 *         if doctag is not None:
 *             selfTag = doctag
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_selfTag = Py_None;

  /* "cPyparsing.pyx":781
 * 
 *         selfTag = None
 *         if doctag is not None:             # <<<<<<<<<<<<<<
 *             selfTag = doctag
 *         else:
 */
  __pyx_t_4 = (__pyx_v_doctag != Py_None);
  __pyx_t_3 = (__pyx_t_4 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":782
 *         selfTag = None
 *         if doctag is not None:
 *             selfTag = doctag             # <<<<<<<<<<<<<<
 *         else:
 *             if self.__name:
 */
    __Pyx_INCREF(__pyx_v_doctag);
    __Pyx_DECREF_SET(__pyx_v_selfTag, __pyx_v_doctag);

    /* "cPyparsing.pyx":781
 * 
 *         selfTag = None
 *         if doctag is not None:             # <<<<<<<<<<<<<<
 *             selfTag = doctag
 *         else:
 */
    goto __pyx_L4;
  }

  /* "cPyparsing.pyx":784
 *             selfTag = doctag
 *         else:
 *             if self.__name:             # <<<<<<<<<<<<<<
 *                 selfTag = self.__name
 * 
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_ParseResults__name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 784, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 784, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_3) {

      /* "cPyparsing.pyx":785
 *         else:
 *             if self.__name:
 *                 selfTag = self.__name             # <<<<<<<<<<<<<<
 * 
 *         if not selfTag:
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_ParseResults__name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 785, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF_SET(__pyx_v_selfTag, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "cPyparsing.pyx":784
 *             selfTag = doctag
 *         else:
 *             if self.__name:             # <<<<<<<<<<<<<<
 *                 selfTag = self.__name
 * 
 */
    }
  }
  __pyx_L4:;

  /* "cPyparsing.pyx":787
 *                 selfTag = self.__name
 * 
 *         if not selfTag:             # <<<<<<<<<<<<<<
 *             if namedItemsOnly:
 *                 return ""
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_selfTag); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 787, __pyx_L1_error)
  __pyx_t_4 = ((!__pyx_t_3) != 0);
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":788
 * 
 *         if not selfTag:
 *             if namedItemsOnly:             # <<<<<<<<<<<<<<
 *                 return ""
 *             else:
 */
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_namedItemsOnly); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 788, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "cPyparsing.pyx":789
 *         if not selfTag:
 *             if namedItemsOnly:
 *                 return ""             # <<<<<<<<<<<<<<
 *             else:
 *                 selfTag = "ITEM"
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__9);
      __pyx_r = __pyx_kp_u__9;
      goto __pyx_L0;

      /* "cPyparsing.pyx":788
 * 
 *         if not selfTag:
 *             if namedItemsOnly:             # <<<<<<<<<<<<<<
 *                 return ""
 *             else:
 */
    }

    /* "cPyparsing.pyx":791
 *                 return ""
 *             else:
 *                 selfTag = "ITEM"             # <<<<<<<<<<<<<<
 * 
 *         out += [nl, indent, "<", selfTag, ">"]
 */
    /*else*/ {
      __Pyx_INCREF(__pyx_n_u_ITEM);
      __Pyx_DECREF_SET(__pyx_v_selfTag, __pyx_n_u_ITEM);
    }

    /* "cPyparsing.pyx":787
 *                 selfTag = self.__name
 * 
 *         if not selfTag:             # <<<<<<<<<<<<<<
 *             if namedItemsOnly:
 *                 return ""
 */
  }

  /* "cPyparsing.pyx":793
 *                 selfTag = "ITEM"
 * 
 *         out += [nl, indent, "<", selfTag, ">"]             # <<<<<<<<<<<<<<
 * 
 *         for i, res in enumerate(self.__toklist):
 */
  __pyx_t_2 = PyList_New(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_nl);
  __Pyx_GIVEREF(__pyx_v_nl);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_nl);
  __Pyx_INCREF(__pyx_v_indent);
  __Pyx_GIVEREF(__pyx_v_indent);
  PyList_SET_ITEM(__pyx_t_2, 1, __pyx_v_indent);
  __Pyx_INCREF(__pyx_kp_u__23);
  __Pyx_GIVEREF(__pyx_kp_u__23);
  PyList_SET_ITEM(__pyx_t_2, 2, __pyx_kp_u__23);
  __Pyx_INCREF(__pyx_v_selfTag);
  __Pyx_GIVEREF(__pyx_v_selfTag);
  PyList_SET_ITEM(__pyx_t_2, 3, __pyx_v_selfTag);
  __Pyx_INCREF(__pyx_kp_u__24);
  __Pyx_GIVEREF(__pyx_kp_u__24);
  PyList_SET_ITEM(__pyx_t_2, 4, __pyx_kp_u__24);
  __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_out, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_out, ((PyObject*)__pyx_t_1));
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":795
 *         out += [nl, indent, "<", selfTag, ">"]
 * 
 *         for i, res in enumerate(self.__toklist):             # <<<<<<<<<<<<<<
 *             if isinstance(res, ParseResults):
 *                 if i in namedItems:
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_t_1 = __pyx_int_0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_5 = __pyx_t_2; __Pyx_INCREF(__pyx_t_5); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 795, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = Py_TYPE(__pyx_t_5)->tp_iternext; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 795, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_5))) {
        if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_5)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_6); __Pyx_INCREF(__pyx_t_2); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 795, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_5, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 795, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      } else {
        if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_5)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_6); __Pyx_INCREF(__pyx_t_2); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 795, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_5, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 795, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      }
    } else {
      __pyx_t_2 = __pyx_t_7(__pyx_t_5);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 795, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_XDECREF_SET(__pyx_v_res, __pyx_t_2);
    __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_1);
    __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_t_1, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 795, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1);
    __pyx_t_1 = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":796
 * 
 *         for i, res in enumerate(self.__toklist):
 *             if isinstance(res, ParseResults):             # <<<<<<<<<<<<<<
 *                 if i in namedItems:
 *                     out += [res.asXML(namedItems[i],
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 796, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyObject_IsInstance(__pyx_v_res, __pyx_t_2); if (unlikely(__pyx_t_4 == -1)) __PYX_ERR(0, 796, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_3 = (__pyx_t_4 != 0);
    if (__pyx_t_3) {

      /* "cPyparsing.pyx":797
 *         for i, res in enumerate(self.__toklist):
 *             if isinstance(res, ParseResults):
 *                 if i in namedItems:             # <<<<<<<<<<<<<<
 *                     out += [res.asXML(namedItems[i],
 *                                       namedItemsOnly and doctag is None,
 */
      if (unlikely(__pyx_v_namedItems == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
        __PYX_ERR(0, 797, __pyx_L1_error)
      }
      __pyx_t_3 = (__Pyx_PyDict_ContainsTF(__pyx_v_i, __pyx_v_namedItems, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 797, __pyx_L1_error)
      __pyx_t_4 = (__pyx_t_3 != 0);
      if (__pyx_t_4) {

        /* "cPyparsing.pyx":798
 *             if isinstance(res, ParseResults):
 *                 if i in namedItems:
 *                     out += [res.asXML(namedItems[i],             # <<<<<<<<<<<<<<
 *                                       namedItemsOnly and doctag is None,
 *                                       nextLevelIndent,
 */
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_res, __pyx_n_s_asXML); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 798, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (unlikely(__pyx_v_namedItems == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 798, __pyx_L1_error)
        }
        __pyx_t_9 = __Pyx_PyDict_GetItem(__pyx_v_namedItems, __pyx_v_i); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 798, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);

        /* "cPyparsing.pyx":799
 *                 if i in namedItems:
 *                     out += [res.asXML(namedItems[i],
 *                                       namedItemsOnly and doctag is None,             # <<<<<<<<<<<<<<
 *                                       nextLevelIndent,
 *                                       formatted)]
 */
        __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_namedItemsOnly); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 799, __pyx_L1_error)
        if (__pyx_t_4) {
        } else {
          __Pyx_INCREF(__pyx_v_namedItemsOnly);
          __pyx_t_10 = __pyx_v_namedItemsOnly;
          goto __pyx_L12_bool_binop_done;
        }
        __pyx_t_4 = (__pyx_v_doctag == Py_None);
        __pyx_t_11 = __Pyx_PyBool_FromLong(__pyx_t_4); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 799, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_10 = __pyx_t_11;
        __pyx_t_11 = 0;
        __pyx_L12_bool_binop_done:;

        /* "cPyparsing.pyx":801
 *                                       namedItemsOnly and doctag is None,
 *                                       nextLevelIndent,
 *                                       formatted)]             # <<<<<<<<<<<<<<
 *                 else:
 *                     out += [res.asXML(None,
 */
        __pyx_t_11 = NULL;
        __pyx_t_12 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_11)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_11);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
            __pyx_t_12 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_8)) {
          PyObject *__pyx_temp[5] = {__pyx_t_11, __pyx_t_9, __pyx_t_10, __pyx_v_nextLevelIndent, __pyx_v_formatted};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_12, 4+__pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 798, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
          PyObject *__pyx_temp[5] = {__pyx_t_11, __pyx_t_9, __pyx_t_10, __pyx_v_nextLevelIndent, __pyx_v_formatted};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_12, 4+__pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 798, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        } else
        #endif
        {
          __pyx_t_13 = PyTuple_New(4+__pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 798, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          if (__pyx_t_11) {
            __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
          }
          __Pyx_GIVEREF(__pyx_t_9);
          PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_12, __pyx_t_9);
          __Pyx_GIVEREF(__pyx_t_10);
          PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_12, __pyx_t_10);
          __Pyx_INCREF(__pyx_v_nextLevelIndent);
          __Pyx_GIVEREF(__pyx_v_nextLevelIndent);
          PyTuple_SET_ITEM(__pyx_t_13, 2+__pyx_t_12, __pyx_v_nextLevelIndent);
          __Pyx_INCREF(__pyx_v_formatted);
          __Pyx_GIVEREF(__pyx_v_formatted);
          PyTuple_SET_ITEM(__pyx_t_13, 3+__pyx_t_12, __pyx_v_formatted);
          __pyx_t_9 = 0;
          __pyx_t_10 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_13, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 798, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "cPyparsing.pyx":798
 *             if isinstance(res, ParseResults):
 *                 if i in namedItems:
 *                     out += [res.asXML(namedItems[i],             # <<<<<<<<<<<<<<
 *                                       namedItemsOnly and doctag is None,
 *                                       nextLevelIndent,
 */
        __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 798, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_2);
        PyList_SET_ITEM(__pyx_t_8, 0, __pyx_t_2);
        __pyx_t_2 = 0;
        __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_out, __pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 798, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF_SET(__pyx_v_out, ((PyObject*)__pyx_t_2));
        __pyx_t_2 = 0;

        /* "cPyparsing.pyx":797
 *         for i, res in enumerate(self.__toklist):
 *             if isinstance(res, ParseResults):
 *                 if i in namedItems:             # <<<<<<<<<<<<<<
 *                     out += [res.asXML(namedItems[i],
 *                                       namedItemsOnly and doctag is None,
 */
        goto __pyx_L11;
      }

      /* "cPyparsing.pyx":803
 *                                       formatted)]
 *                 else:
 *                     out += [res.asXML(None,             # <<<<<<<<<<<<<<
 *                                       namedItemsOnly and doctag is None,
 *                                       nextLevelIndent,
 */
      /*else*/ {
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_res, __pyx_n_s_asXML); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 803, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);

        /* "cPyparsing.pyx":804
 *                 else:
 *                     out += [res.asXML(None,
 *                                       namedItemsOnly and doctag is None,             # <<<<<<<<<<<<<<
 *                                       nextLevelIndent,
 *                                       formatted)]
 */
        __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_namedItemsOnly); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 804, __pyx_L1_error)
        if (__pyx_t_4) {
        } else {
          __Pyx_INCREF(__pyx_v_namedItemsOnly);
          __pyx_t_13 = __pyx_v_namedItemsOnly;
          goto __pyx_L14_bool_binop_done;
        }
        __pyx_t_4 = (__pyx_v_doctag == Py_None);
        __pyx_t_10 = __Pyx_PyBool_FromLong(__pyx_t_4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 804, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_13 = __pyx_t_10;
        __pyx_t_10 = 0;
        __pyx_L14_bool_binop_done:;

        /* "cPyparsing.pyx":806
 *                                       namedItemsOnly and doctag is None,
 *                                       nextLevelIndent,
 *                                       formatted)]             # <<<<<<<<<<<<<<
 *             else:
 *                 # individual token, see if there is a name for it
 */
        __pyx_t_10 = NULL;
        __pyx_t_12 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
            __pyx_t_12 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_8)) {
          PyObject *__pyx_temp[5] = {__pyx_t_10, Py_None, __pyx_t_13, __pyx_v_nextLevelIndent, __pyx_v_formatted};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_12, 4+__pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 803, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
          PyObject *__pyx_temp[5] = {__pyx_t_10, Py_None, __pyx_t_13, __pyx_v_nextLevelIndent, __pyx_v_formatted};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_12, 4+__pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 803, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        } else
        #endif
        {
          __pyx_t_9 = PyTuple_New(4+__pyx_t_12); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 803, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          if (__pyx_t_10) {
            __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_10); __pyx_t_10 = NULL;
          }
          __Pyx_INCREF(Py_None);
          __Pyx_GIVEREF(Py_None);
          PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_12, Py_None);
          __Pyx_GIVEREF(__pyx_t_13);
          PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_12, __pyx_t_13);
          __Pyx_INCREF(__pyx_v_nextLevelIndent);
          __Pyx_GIVEREF(__pyx_v_nextLevelIndent);
          PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_12, __pyx_v_nextLevelIndent);
          __Pyx_INCREF(__pyx_v_formatted);
          __Pyx_GIVEREF(__pyx_v_formatted);
          PyTuple_SET_ITEM(__pyx_t_9, 3+__pyx_t_12, __pyx_v_formatted);
          __pyx_t_13 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_9, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 803, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "cPyparsing.pyx":803
 *                                       formatted)]
 *                 else:
 *                     out += [res.asXML(None,             # <<<<<<<<<<<<<<
 *                                       namedItemsOnly and doctag is None,
 *                                       nextLevelIndent,
 */
        __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 803, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_2);
        PyList_SET_ITEM(__pyx_t_8, 0, __pyx_t_2);
        __pyx_t_2 = 0;
        __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_out, __pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 803, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF_SET(__pyx_v_out, ((PyObject*)__pyx_t_2));
        __pyx_t_2 = 0;
      }
      __pyx_L11:;

      /* "cPyparsing.pyx":796
 * 
 *         for i, res in enumerate(self.__toklist):
 *             if isinstance(res, ParseResults):             # <<<<<<<<<<<<<<
 *                 if i in namedItems:
 *                     out += [res.asXML(namedItems[i],
 */
      goto __pyx_L10;
    }

    /* "cPyparsing.pyx":809
 *             else:
 *                 # individual token, see if there is a name for it
 *                 resTag = None             # <<<<<<<<<<<<<<
 *                 if i in namedItems:
 *                     resTag = namedItems[i]
 */
    /*else*/ {
      __Pyx_INCREF(Py_None);
      __Pyx_XDECREF_SET(__pyx_v_resTag, Py_None);

      /* "cPyparsing.pyx":810
 *                 # individual token, see if there is a name for it
 *                 resTag = None
 *                 if i in namedItems:             # <<<<<<<<<<<<<<
 *                     resTag = namedItems[i]
 *                 if not resTag:
 */
      if (unlikely(__pyx_v_namedItems == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
        __PYX_ERR(0, 810, __pyx_L1_error)
      }
      __pyx_t_4 = (__Pyx_PyDict_ContainsTF(__pyx_v_i, __pyx_v_namedItems, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 810, __pyx_L1_error)
      __pyx_t_3 = (__pyx_t_4 != 0);
      if (__pyx_t_3) {

        /* "cPyparsing.pyx":811
 *                 resTag = None
 *                 if i in namedItems:
 *                     resTag = namedItems[i]             # <<<<<<<<<<<<<<
 *                 if not resTag:
 *                     if namedItemsOnly:
 */
        if (unlikely(__pyx_v_namedItems == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 811, __pyx_L1_error)
        }
        __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_namedItems, __pyx_v_i); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 811, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF_SET(__pyx_v_resTag, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "cPyparsing.pyx":810
 *                 # individual token, see if there is a name for it
 *                 resTag = None
 *                 if i in namedItems:             # <<<<<<<<<<<<<<
 *                     resTag = namedItems[i]
 *                 if not resTag:
 */
      }

      /* "cPyparsing.pyx":812
 *                 if i in namedItems:
 *                     resTag = namedItems[i]
 *                 if not resTag:             # <<<<<<<<<<<<<<
 *                     if namedItemsOnly:
 *                         continue
 */
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_resTag); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 812, __pyx_L1_error)
      __pyx_t_4 = ((!__pyx_t_3) != 0);
      if (__pyx_t_4) {

        /* "cPyparsing.pyx":813
 *                     resTag = namedItems[i]
 *                 if not resTag:
 *                     if namedItemsOnly:             # <<<<<<<<<<<<<<
 *                         continue
 *                     else:
 */
        __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_namedItemsOnly); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 813, __pyx_L1_error)
        if (__pyx_t_4) {

          /* "cPyparsing.pyx":814
 *                 if not resTag:
 *                     if namedItemsOnly:
 *                         continue             # <<<<<<<<<<<<<<
 *                     else:
 *                         resTag = "ITEM"
 */
          goto __pyx_L8_continue;

          /* "cPyparsing.pyx":813
 *                     resTag = namedItems[i]
 *                 if not resTag:
 *                     if namedItemsOnly:             # <<<<<<<<<<<<<<
 *                         continue
 *                     else:
 */
        }

        /* "cPyparsing.pyx":816
 *                         continue
 *                     else:
 *                         resTag = "ITEM"             # <<<<<<<<<<<<<<
 *                 xmlBodyText = _xml_escape(_ustr(res))
 *                 out += [nl, nextLevelIndent, "<", resTag, ">",
 */
        /*else*/ {
          __Pyx_INCREF(__pyx_n_u_ITEM);
          __Pyx_DECREF_SET(__pyx_v_resTag, __pyx_n_u_ITEM);
        }

        /* "cPyparsing.pyx":812
 *                 if i in namedItems:
 *                     resTag = namedItems[i]
 *                 if not resTag:             # <<<<<<<<<<<<<<
 *                     if namedItemsOnly:
 *                         continue
 */
      }

      /* "cPyparsing.pyx":817
 *                     else:
 *                         resTag = "ITEM"
 *                 xmlBodyText = _xml_escape(_ustr(res))             # <<<<<<<<<<<<<<
 *                 out += [nl, nextLevelIndent, "<", resTag, ">",
 *                         xmlBodyText,
 */
      __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_xml_escape); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 817, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 817, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_10 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_13);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_13, function);
        }
      }
      if (!__pyx_t_10) {
        __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_v_res); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_13)) {
          PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_v_res};
          __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 817, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_t_9);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_13)) {
          PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_v_res};
          __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 817, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_t_9);
        } else
        #endif
        {
          __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 817, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_10); __pyx_t_10 = NULL;
          __Pyx_INCREF(__pyx_v_res);
          __Pyx_GIVEREF(__pyx_v_res);
          PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_v_res);
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_11, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 817, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_13 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_13)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_13);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      if (!__pyx_t_13) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 817, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_8)) {
          PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_9};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 817, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
          PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_9};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 817, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        } else
        #endif
        {
          __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 817, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_13); __pyx_t_13 = NULL;
          __Pyx_GIVEREF(__pyx_t_9);
          PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_t_9);
          __pyx_t_9 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 817, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF_SET(__pyx_v_xmlBodyText, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "cPyparsing.pyx":818
 *                         resTag = "ITEM"
 *                 xmlBodyText = _xml_escape(_ustr(res))
 *                 out += [nl, nextLevelIndent, "<", resTag, ">",             # <<<<<<<<<<<<<<
 *                         xmlBodyText,
 *                         "</", resTag, ">"]
 */
      __pyx_t_2 = PyList_New(9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 818, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_v_nl);
      __Pyx_GIVEREF(__pyx_v_nl);
      PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_nl);
      __Pyx_INCREF(__pyx_v_nextLevelIndent);
      __Pyx_GIVEREF(__pyx_v_nextLevelIndent);
      PyList_SET_ITEM(__pyx_t_2, 1, __pyx_v_nextLevelIndent);
      __Pyx_INCREF(__pyx_kp_u__23);
      __Pyx_GIVEREF(__pyx_kp_u__23);
      PyList_SET_ITEM(__pyx_t_2, 2, __pyx_kp_u__23);
      __Pyx_INCREF(__pyx_v_resTag);
      __Pyx_GIVEREF(__pyx_v_resTag);
      PyList_SET_ITEM(__pyx_t_2, 3, __pyx_v_resTag);
      __Pyx_INCREF(__pyx_kp_u__24);
      __Pyx_GIVEREF(__pyx_kp_u__24);
      PyList_SET_ITEM(__pyx_t_2, 4, __pyx_kp_u__24);
      __Pyx_INCREF(__pyx_v_xmlBodyText);
      __Pyx_GIVEREF(__pyx_v_xmlBodyText);
      PyList_SET_ITEM(__pyx_t_2, 5, __pyx_v_xmlBodyText);
      __Pyx_INCREF(__pyx_kp_u__25);
      __Pyx_GIVEREF(__pyx_kp_u__25);
      PyList_SET_ITEM(__pyx_t_2, 6, __pyx_kp_u__25);
      __Pyx_INCREF(__pyx_v_resTag);
      __Pyx_GIVEREF(__pyx_v_resTag);
      PyList_SET_ITEM(__pyx_t_2, 7, __pyx_v_resTag);
      __Pyx_INCREF(__pyx_kp_u__24);
      __Pyx_GIVEREF(__pyx_kp_u__24);
      PyList_SET_ITEM(__pyx_t_2, 8, __pyx_kp_u__24);
      __pyx_t_8 = PyNumber_InPlaceAdd(__pyx_v_out, __pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 818, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF_SET(__pyx_v_out, ((PyObject*)__pyx_t_8));
      __pyx_t_8 = 0;
    }
    __pyx_L10:;

    /* "cPyparsing.pyx":795
 *         out += [nl, indent, "<", selfTag, ">"]
 * 
 *         for i, res in enumerate(self.__toklist):             # <<<<<<<<<<<<<<
 *             if isinstance(res, ParseResults):
 *                 if i in namedItems:
 */
    __pyx_L8_continue:;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":822
 *                         "</", resTag, ">"]
 * 
 *         out += [nl, indent, "</", selfTag, ">"]             # <<<<<<<<<<<<<<
 *         return "".join(out)
 * 
 */
  __pyx_t_1 = PyList_New(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_nl);
  __Pyx_GIVEREF(__pyx_v_nl);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_nl);
  __Pyx_INCREF(__pyx_v_indent);
  __Pyx_GIVEREF(__pyx_v_indent);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_v_indent);
  __Pyx_INCREF(__pyx_kp_u__25);
  __Pyx_GIVEREF(__pyx_kp_u__25);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u__25);
  __Pyx_INCREF(__pyx_v_selfTag);
  __Pyx_GIVEREF(__pyx_v_selfTag);
  PyList_SET_ITEM(__pyx_t_1, 3, __pyx_v_selfTag);
  __Pyx_INCREF(__pyx_kp_u__24);
  __Pyx_GIVEREF(__pyx_kp_u__24);
  PyList_SET_ITEM(__pyx_t_1, 4, __pyx_kp_u__24);
  __pyx_t_5 = PyNumber_InPlaceAdd(__pyx_v_out, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_out, ((PyObject*)__pyx_t_5));
  __pyx_t_5 = 0;

  /* "cPyparsing.pyx":823
 * 
 *         out += [nl, indent, "</", selfTag, ">"]
 *         return "".join(out)             # <<<<<<<<<<<<<<
 * 
 *     def __lookup(self, sub):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyUnicode_Join(__pyx_kp_u__9, __pyx_v_out); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":764
 *         return ret
 * 
 *     def asXML(self, doctag=None, namedItemsOnly=False, indent="", formatted=True):             # <<<<<<<<<<<<<<
 *         """
 *         (Deprecated) Returns the parse results as XML. Tags are created for tokens and lists that have defined results names.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("cPyparsing.ParseResults.asXML", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_nl);
  __Pyx_XDECREF(__pyx_v_out);
  __Pyx_XDECREF(__pyx_v_namedItems);
  __Pyx_XDECREF(__pyx_v_nextLevelIndent);
  __Pyx_XDECREF(__pyx_v_selfTag);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XDECREF(__pyx_v_resTag);
  __Pyx_XDECREF(__pyx_v_xmlBodyText);
  __Pyx_XDECREF(__pyx_v_indent);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":825
 *         return "".join(out)
 * 
 *     def __lookup(self, sub):             # <<<<<<<<<<<<<<
 *         for k, vlist in self.__tokdict.items():
 *             for v, loc in vlist:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_69__lookup(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_69__lookup = {"__lookup", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_69__lookup, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_69__lookup(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_sub = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__lookup (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_sub,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_sub)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__lookup", 1, 2, 2, 1); __PYX_ERR(0, 825, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__lookup") < 0)) __PYX_ERR(0, 825, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_sub = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__lookup", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 825, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.__lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_68__lookup(__pyx_self, __pyx_v_self, __pyx_v_sub);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_68__lookup(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_sub) {
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_vlist = NULL;
  PyObject *__pyx_v_v = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_loc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *(*__pyx_t_13)(PyObject *);
  int __pyx_t_14;
  int __pyx_t_15;
  __Pyx_RefNannySetupContext("__lookup", 0);

  /* "cPyparsing.pyx":826
 * 
 *     def __lookup(self, sub):
 *         for k, vlist in self.__tokdict.items():             # <<<<<<<<<<<<<<
 *             for v, loc in vlist:
 *                 if sub is v:
 */
  __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (unlikely(__pyx_t_5 == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "items");
    __PYX_ERR(0, 826, __pyx_L1_error)
  }
  __pyx_t_6 = __Pyx_dict_iterator(__pyx_t_5, 0, __pyx_n_s_items, (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_6;
  __pyx_t_6 = 0;
  while (1) {
    __pyx_t_7 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_6, &__pyx_t_5, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_7 == 0)) break;
    if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_XDECREF_SET(__pyx_v_k, __pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_XDECREF_SET(__pyx_v_vlist, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "cPyparsing.pyx":827
 *     def __lookup(self, sub):
 *         for k, vlist in self.__tokdict.items():
 *             for v, loc in vlist:             # <<<<<<<<<<<<<<
 *                 if sub is v:
 *                     return k
 */
    if (likely(PyList_CheckExact(__pyx_v_vlist)) || PyTuple_CheckExact(__pyx_v_vlist)) {
      __pyx_t_5 = __pyx_v_vlist; __Pyx_INCREF(__pyx_t_5); __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
    } else {
      __pyx_t_8 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_v_vlist); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 827, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_9 = Py_TYPE(__pyx_t_5)->tp_iternext; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 827, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_9)) {
        if (likely(PyList_CheckExact(__pyx_t_5))) {
          if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_5)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_8); __Pyx_INCREF(__pyx_t_6); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 827, __pyx_L1_error)
          #else
          __pyx_t_6 = PySequence_ITEM(__pyx_t_5, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 827, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
        } else {
          if (__pyx_t_8 >= PyTuple_GET_SIZE(__pyx_t_5)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_8); __Pyx_INCREF(__pyx_t_6); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 827, __pyx_L1_error)
          #else
          __pyx_t_6 = PySequence_ITEM(__pyx_t_5, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 827, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
        }
      } else {
        __pyx_t_6 = __pyx_t_9(__pyx_t_5);
        if (unlikely(!__pyx_t_6)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 827, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_6);
      }
      if ((likely(PyTuple_CheckExact(__pyx_t_6))) || (PyList_CheckExact(__pyx_t_6))) {
        PyObject* sequence = __pyx_t_6;
        #if !CYTHON_COMPILING_IN_PYPY
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 827, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_10 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_11 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_10 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_11 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_11);
        #else
        __pyx_t_10 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 827, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_11 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 827, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        #endif
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_12 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 827, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_13 = Py_TYPE(__pyx_t_12)->tp_iternext;
        index = 0; __pyx_t_10 = __pyx_t_13(__pyx_t_12); if (unlikely(!__pyx_t_10)) goto __pyx_L7_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_10);
        index = 1; __pyx_t_11 = __pyx_t_13(__pyx_t_12); if (unlikely(!__pyx_t_11)) goto __pyx_L7_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_11);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_13(__pyx_t_12), 2) < 0) __PYX_ERR(0, 827, __pyx_L1_error)
        __pyx_t_13 = NULL;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        goto __pyx_L8_unpacking_done;
        __pyx_L7_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __pyx_t_13 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 827, __pyx_L1_error)
        __pyx_L8_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_10);
      __pyx_t_10 = 0;
      __Pyx_XDECREF_SET(__pyx_v_loc, __pyx_t_11);
      __pyx_t_11 = 0;

      /* "cPyparsing.pyx":828
 *         for k, vlist in self.__tokdict.items():
 *             for v, loc in vlist:
 *                 if sub is v:             # <<<<<<<<<<<<<<
 *                     return k
 *         return None
 */
      __pyx_t_14 = (__pyx_v_sub == __pyx_v_v);
      __pyx_t_15 = (__pyx_t_14 != 0);
      if (__pyx_t_15) {

        /* "cPyparsing.pyx":829
 *             for v, loc in vlist:
 *                 if sub is v:
 *                     return k             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_v_k);
        __pyx_r = __pyx_v_k;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        goto __pyx_L0;

        /* "cPyparsing.pyx":828
 *         for k, vlist in self.__tokdict.items():
 *             for v, loc in vlist:
 *                 if sub is v:             # <<<<<<<<<<<<<<
 *                     return k
 *         return None
 */
      }

      /* "cPyparsing.pyx":827
 *     def __lookup(self, sub):
 *         for k, vlist in self.__tokdict.items():
 *             for v, loc in vlist:             # <<<<<<<<<<<<<<
 *                 if sub is v:
 *                     return k
 */
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":830
 *                 if sub is v:
 *                     return k
 *         return None             # <<<<<<<<<<<<<<
 * 
 *     def getName(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_None);
  __pyx_r = Py_None;
  goto __pyx_L0;

  /* "cPyparsing.pyx":825
 *         return "".join(out)
 * 
 *     def __lookup(self, sub):             # <<<<<<<<<<<<<<
 *         for k, vlist in self.__tokdict.items():
 *             for v, loc in vlist:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_vlist);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":832
 *         return None
 * 
 *     def getName(self):             # <<<<<<<<<<<<<<
 *         r"""
 *         Returns the results name for this token expression. Useful when several
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_71getName(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_10cPyparsing_12ParseResults_70getName[] = "\n        Returns the results name for this token expression. Useful when several\n        different expressions might match at a particular location.\n\n        Example::\n            integer = Word(nums)\n            ssn_expr = Regex(r\"\\d\\d\\d-\\d\\d-\\d\\d\\d\\d\")\n            house_number_expr = Suppress('#') + Word(nums, alphanums)\n            user_data = (Group(house_number_expr)(\"house_number\")\n                        | Group(ssn_expr)(\"ssn\")\n                        | Group(integer)(\"age\"))\n            user_info = OneOrMore(user_data)\n\n            result = user_info.parseString(\"22 111-22-3333 #221B\")\n            for item in result:\n                print(item.getName(), ':', item[0])\n        prints::\n            age : 22\n            ssn : 111-22-3333\n            house_number : 221B\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_71getName = {"getName", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_71getName, METH_O, __pyx_doc_10cPyparsing_12ParseResults_70getName};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_71getName(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getName (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_70getName(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_70getName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_par = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  __Pyx_RefNannySetupContext("getName", 0);

  /* "cPyparsing.pyx":854
 *             house_number : 221B
 *         """
 *         if self.__name:             # <<<<<<<<<<<<<<
 *             return self.__name
 *         elif self.__parent:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 854, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":855
 *         """
 *         if self.__name:
 *             return self.__name             # <<<<<<<<<<<<<<
 *         elif self.__parent:
 *             par = self.__parent()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 855, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":854
 *             house_number : 221B
 *         """
 *         if self.__name:             # <<<<<<<<<<<<<<
 *             return self.__name
 *         elif self.__parent:
 */
  }

  /* "cPyparsing.pyx":856
 *         if self.__name:
 *             return self.__name
 *         elif self.__parent:             # <<<<<<<<<<<<<<
 *             par = self.__parent()
 *             if par:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__parent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 856, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 856, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":857
 *             return self.__name
 *         elif self.__parent:
 *             par = self.__parent()             # <<<<<<<<<<<<<<
 *             if par:
 *                 return par.__lookup(self)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__parent); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 857, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 857, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_par = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":858
 *         elif self.__parent:
 *             par = self.__parent()
 *             if par:             # <<<<<<<<<<<<<<
 *                 return par.__lookup(self)
 *             else:
 */
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_par); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 858, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":859
 *             par = self.__parent()
 *             if par:
 *                 return par.__lookup(self)             # <<<<<<<<<<<<<<
 *             else:
 *                 return None
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_par, __pyx_n_s_ParseResults__lookup); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 859, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_4) {
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 859, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_self};
          __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 859, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_1);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_self};
          __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 859, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_1);
        } else
        #endif
        {
          __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 859, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
          __Pyx_INCREF(__pyx_v_self);
          __Pyx_GIVEREF(__pyx_v_self);
          PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_self);
          __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 859, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "cPyparsing.pyx":858
 *         elif self.__parent:
 *             par = self.__parent()
 *             if par:             # <<<<<<<<<<<<<<
 *                 return par.__lookup(self)
 *             else:
 */
    }

    /* "cPyparsing.pyx":861
 *                 return par.__lookup(self)
 *             else:
 *                 return None             # <<<<<<<<<<<<<<
 *         elif (len(self) == 1 and
 *               len(self.__tokdict) == 1 and
 */
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_None);
      __pyx_r = Py_None;
      goto __pyx_L0;
    }

    /* "cPyparsing.pyx":856
 *         if self.__name:
 *             return self.__name
 *         elif self.__parent:             # <<<<<<<<<<<<<<
 *             par = self.__parent()
 *             if par:
 */
  }

  /* "cPyparsing.pyx":862
 *             else:
 *                 return None
 *         elif (len(self) == 1 and             # <<<<<<<<<<<<<<
 *               len(self.__tokdict) == 1 and
 *               next(iter(self.__tokdict.values()))[0][1] in (0, -1)):
 */
  __pyx_t_6 = PyObject_Length(__pyx_v_self); if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 862, __pyx_L1_error)
  __pyx_t_7 = ((__pyx_t_6 == 1) != 0);
  if (__pyx_t_7) {
  } else {
    __pyx_t_2 = __pyx_t_7;
    goto __pyx_L5_bool_binop_done;
  }

  /* "cPyparsing.pyx":863
 *                 return None
 *         elif (len(self) == 1 and
 *               len(self.__tokdict) == 1 and             # <<<<<<<<<<<<<<
 *               next(iter(self.__tokdict.values()))[0][1] in (0, -1)):
 *             return next(iter(self.__tokdict.keys()))
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 863, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = ((__pyx_t_6 == 1) != 0);
  if (__pyx_t_7) {
  } else {
    __pyx_t_2 = __pyx_t_7;
    goto __pyx_L5_bool_binop_done;
  }

  /* "cPyparsing.pyx":864
 *         elif (len(self) == 1 and
 *               len(self.__tokdict) == 1 and
 *               next(iter(self.__tokdict.values()))[0][1] in (0, -1)):             # <<<<<<<<<<<<<<
 *             return next(iter(self.__tokdict.keys()))
 *         else:
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_values); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 864, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 864, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyIter_Next(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_5, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyInt_EqObjC(__pyx_t_1, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 864, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (!__pyx_t_8) {
  } else {
    __pyx_t_7 = __pyx_t_8;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyInt_EqObjC(__pyx_t_1, __pyx_int_neg_1, -1L, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 864, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = __pyx_t_8;
  __pyx_L8_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_8 = (__pyx_t_7 != 0);
  __pyx_t_2 = __pyx_t_8;
  __pyx_L5_bool_binop_done:;

  /* "cPyparsing.pyx":862
 *             else:
 *                 return None
 *         elif (len(self) == 1 and             # <<<<<<<<<<<<<<
 *               len(self.__tokdict) == 1 and
 *               next(iter(self.__tokdict.values()))[0][1] in (0, -1)):
 */
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":865
 *               len(self.__tokdict) == 1 and
 *               next(iter(self.__tokdict.values()))[0][1] in (0, -1)):
 *             return next(iter(self.__tokdict.keys()))             # <<<<<<<<<<<<<<
 *         else:
 *             return None
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 865, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_keys); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 865, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (__pyx_t_5) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 865, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 865, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 865, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyIter_Next(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 865, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":862
 *             else:
 *                 return None
 *         elif (len(self) == 1 and             # <<<<<<<<<<<<<<
 *               len(self.__tokdict) == 1 and
 *               next(iter(self.__tokdict.values()))[0][1] in (0, -1)):
 */
  }

  /* "cPyparsing.pyx":867
 *             return next(iter(self.__tokdict.keys()))
 *         else:
 *             return None             # <<<<<<<<<<<<<<
 * 
 *     def dump(self, indent='', depth=0, full=True):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":832
 *         return None
 * 
 *     def getName(self):             # <<<<<<<<<<<<<<
 *         r"""
 *         Returns the results name for this token expression. Useful when several
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ParseResults.getName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_par);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":869
 *             return None
 * 
 *     def dump(self, indent='', depth=0, full=True):             # <<<<<<<<<<<<<<
 *         """
 *         Diagnostic method for listing out the contents of a C{ParseResults}.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_73dump(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_12ParseResults_72dump[] = "\n        Diagnostic method for listing out the contents of a C{ParseResults}.\n        Accepts an optional C{indent} argument so that this string can be embedded\n        in a nested display of other data.\n\n        Example::\n            integer = Word(nums)\n            date_str = integer(\"year\") + '/' + integer(\"month\") + '/' + integer(\"day\")\n\n            result = date_str.parseString('12/31/1999')\n            print(result.dump())\n        prints::\n            ['12', '/', '31', '/', '1999']\n            - day: 1999\n            - month: 31\n            - year: 12\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_73dump = {"dump", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_73dump, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_72dump};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_73dump(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_indent = 0;
  PyObject *__pyx_v_depth = 0;
  PyObject *__pyx_v_full = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dump (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_indent,&__pyx_n_s_depth,&__pyx_n_s_full,0};
    PyObject* values[4] = {0,0,0,0};
    values[1] = ((PyObject *)((PyObject*)__pyx_kp_u__9));
    values[2] = ((PyObject *)((PyObject *)__pyx_int_0));
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_indent);
          if (value) { values[1] = value; kw_args--; }
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_depth);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_full);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "dump") < 0)) __PYX_ERR(0, 869, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_indent = values[1];
    __pyx_v_depth = values[2];
    __pyx_v_full = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("dump", 0, 1, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 869, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_72dump(__pyx_self, __pyx_v_self, __pyx_v_indent, __pyx_v_depth, __pyx_v_full);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_12ParseResults_4dump_2generator10(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":892
 *         if full:
 *             if self.haskeys():
 *                 items = sorted((str(k), v) for k, v in self.items())             # <<<<<<<<<<<<<<
 *                 for k, v in items:
 *                     if out:
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_4dump_genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_15_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_15_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 892, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_dump *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_12ParseResults_4dump_2generator10, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_ParseResults_dump_locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 892, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.dump.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_12ParseResults_4dump_2generator10(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 892, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  __pyx_t_2 = 0;
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 892, __pyx_L1_error) }
  if (unlikely(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "items");
    __PYX_ERR(0, 892, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_dict_iterator(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, 0, __pyx_n_s_items, (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_7 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_5, &__pyx_t_6, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_7 == 0)) break;
    if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 892, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_k);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_k, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_v);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_v, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_str); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 892, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_8) {
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_cur_scope->__pyx_v_k); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 892, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_cur_scope->__pyx_v_k};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 892, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_cur_scope->__pyx_v_k};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 892, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 892, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_k);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_k);
        PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_cur_scope->__pyx_v_k);
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_9, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 892, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 892, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_v);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_v);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_cur_scope->__pyx_v_v);
    __pyx_t_6 = 0;
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_5))) __PYX_ERR(0, 892, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_12ParseResults_4dump_5generator11(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":904
 *                     else:
 *                         out.append(repr(v))
 *             elif any(isinstance(vv, ParseResults) for vv in self):             # <<<<<<<<<<<<<<
 *                 v = self
 *                 for i, vv in enumerate(v):
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_4dump_3genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_16_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_16_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_16_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_16_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_16_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 904, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_dump *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_12ParseResults_4dump_5generator11, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_ParseResults_dump_locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 904, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.dump.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_12ParseResults_4dump_5generator11(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_16_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_16_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 904, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 904, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_outer_scope->__pyx_v_self; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 904, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 904, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 904, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 904, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 904, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 904, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 904, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_vv);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_vv, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 904, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyObject_IsInstance(__pyx_cur_scope->__pyx_v_vv, __pyx_t_4); if (unlikely(__pyx_t_5 == -1)) __PYX_ERR(0, 904, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":869
 *             return None
 * 
 *     def dump(self, indent='', depth=0, full=True):             # <<<<<<<<<<<<<<
 *         """
 *         Diagnostic method for listing out the contents of a C{ParseResults}.
 */

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_72dump(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_indent, PyObject *__pyx_v_depth, PyObject *__pyx_v_full) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_dump *__pyx_cur_scope;
  PyObject *__pyx_v_out = NULL;
  PyObject *__pyx_v_NL = NULL;
  PyObject *__pyx_v_items = NULL;
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_v = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_vv = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_t_10;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *(*__pyx_t_13)(PyObject *);
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  __Pyx_RefNannySetupContext("dump", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_dump *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_14_dump(__pyx_ptype_10cPyparsing___pyx_scope_struct_14_dump, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_dump *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 869, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);

  /* "cPyparsing.pyx":887
 *             - year: 12
 *         """
 *         out = []             # <<<<<<<<<<<<<<
 *         NL = '\n'
 *         out.append(indent + _ustr(self.asList()))
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_out = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":888
 *         """
 *         out = []
 *         NL = '\n'             # <<<<<<<<<<<<<<
 *         out.append(indent + _ustr(self.asList()))
 *         if full:
 */
  __Pyx_INCREF(__pyx_kp_u__21);
  __pyx_v_NL = __pyx_kp_u__21;

  /* "cPyparsing.pyx":889
 *         out = []
 *         NL = '\n'
 *         out.append(indent + _ustr(self.asList()))             # <<<<<<<<<<<<<<
 *         if full:
 *             if self.haskeys():
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_asList); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 889, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 889, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 889, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 889, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 889, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 889, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 889, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_v_indent, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_2); if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 889, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":890
 *         NL = '\n'
 *         out.append(indent + _ustr(self.asList()))
 *         if full:             # <<<<<<<<<<<<<<
 *             if self.haskeys():
 *                 items = sorted((str(k), v) for k, v in self.items())
 */
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_v_full); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 890, __pyx_L1_error)
  if (__pyx_t_7) {

    /* "cPyparsing.pyx":891
 *         out.append(indent + _ustr(self.asList()))
 *         if full:
 *             if self.haskeys():             # <<<<<<<<<<<<<<
 *                 items = sorted((str(k), v) for k, v in self.items())
 *                 for k, v in items:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_haskeys); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 891, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (__pyx_t_5) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 891, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 891, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 891, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_7) {

      /* "cPyparsing.pyx":892
 *         if full:
 *             if self.haskeys():
 *                 items = sorted((str(k), v) for k, v in self.items())             # <<<<<<<<<<<<<<
 *                 for k, v in items:
 *                     if out:
 */
      __pyx_t_1 = __pyx_pf_10cPyparsing_12ParseResults_4dump_genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 892, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 892, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_2 = ((PyObject*)__pyx_t_5);
      __pyx_t_5 = 0;
      __pyx_t_6 = PyList_Sort(__pyx_t_2); if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 892, __pyx_L1_error)
      __pyx_v_items = ((PyObject*)__pyx_t_2);
      __pyx_t_2 = 0;

      /* "cPyparsing.pyx":893
 *             if self.haskeys():
 *                 items = sorted((str(k), v) for k, v in self.items())
 *                 for k, v in items:             # <<<<<<<<<<<<<<
 *                     if out:
 *                         out.append(NL)
 */
      if (unlikely(__pyx_v_items == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
        __PYX_ERR(0, 893, __pyx_L1_error)
      }
      __pyx_t_2 = __pyx_v_items; __Pyx_INCREF(__pyx_t_2); __pyx_t_8 = 0;
      for (;;) {
        if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_8); __Pyx_INCREF(__pyx_t_5); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 893, __pyx_L1_error)
        #else
        __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 893, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
        if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
          PyObject* sequence = __pyx_t_5;
          #if !CYTHON_COMPILING_IN_PYPY
          Py_ssize_t size = Py_SIZE(sequence);
          #else
          Py_ssize_t size = PySequence_Size(sequence);
          #endif
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 893, __pyx_L1_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
          } else {
            __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
          }
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_3);
          #else
          __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 893, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 893, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_4 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 893, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_9 = Py_TYPE(__pyx_t_4)->tp_iternext;
          index = 0; __pyx_t_1 = __pyx_t_9(__pyx_t_4); if (unlikely(!__pyx_t_1)) goto __pyx_L7_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_1);
          index = 1; __pyx_t_3 = __pyx_t_9(__pyx_t_4); if (unlikely(!__pyx_t_3)) goto __pyx_L7_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_3);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_4), 2) < 0) __PYX_ERR(0, 893, __pyx_L1_error)
          __pyx_t_9 = NULL;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          goto __pyx_L8_unpacking_done;
          __pyx_L7_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_9 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 893, __pyx_L1_error)
          __pyx_L8_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_k, __pyx_t_1);
        __pyx_t_1 = 0;
        __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "cPyparsing.pyx":894
 *                 items = sorted((str(k), v) for k, v in self.items())
 *                 for k, v in items:
 *                     if out:             # <<<<<<<<<<<<<<
 *                         out.append(NL)
 *                     out.append("%s%s- %s: " % (indent, ('  ' * depth), k))
 */
        __pyx_t_7 = (__pyx_v_out != Py_None) && (PyList_GET_SIZE(__pyx_v_out) != 0);
        if (__pyx_t_7) {

          /* "cPyparsing.pyx":895
 *                 for k, v in items:
 *                     if out:
 *                         out.append(NL)             # <<<<<<<<<<<<<<
 *                     out.append("%s%s- %s: " % (indent, ('  ' * depth), k))
 *                     if isinstance(v, ParseResults):
 */
          __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_out, __pyx_v_NL); if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 895, __pyx_L1_error)

          /* "cPyparsing.pyx":894
 *                 items = sorted((str(k), v) for k, v in self.items())
 *                 for k, v in items:
 *                     if out:             # <<<<<<<<<<<<<<
 *                         out.append(NL)
 *                     out.append("%s%s- %s: " % (indent, ('  ' * depth), k))
 */
        }

        /* "cPyparsing.pyx":896
 *                     if out:
 *                         out.append(NL)
 *                     out.append("%s%s- %s: " % (indent, ('  ' * depth), k))             # <<<<<<<<<<<<<<
 *                     if isinstance(v, ParseResults):
 *                         if v:
 */
        __pyx_t_5 = PyNumber_Multiply(__pyx_kp_u__22, __pyx_v_depth); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 896, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 896, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_v_indent);
        __Pyx_GIVEREF(__pyx_v_indent);
        PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_indent);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_5);
        __Pyx_INCREF(__pyx_v_k);
        __Pyx_GIVEREF(__pyx_v_k);
        PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_k);
        __pyx_t_5 = 0;
        __pyx_t_5 = PyUnicode_Format(__pyx_kp_u_s_s_s, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 896, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_5); if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 896, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "cPyparsing.pyx":897
 *                         out.append(NL)
 *                     out.append("%s%s- %s: " % (indent, ('  ' * depth), k))
 *                     if isinstance(v, ParseResults):             # <<<<<<<<<<<<<<
 *                         if v:
 *                             out.append(v.dump(indent, depth + 1))
 */
        __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 897, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_7 = PyObject_IsInstance(__pyx_v_v, __pyx_t_5); if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 897, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_10 = (__pyx_t_7 != 0);
        if (__pyx_t_10) {

          /* "cPyparsing.pyx":898
 *                     out.append("%s%s- %s: " % (indent, ('  ' * depth), k))
 *                     if isinstance(v, ParseResults):
 *                         if v:             # <<<<<<<<<<<<<<
 *                             out.append(v.dump(indent, depth + 1))
 *                         else:
 */
          __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_v_v); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(0, 898, __pyx_L1_error)
          if (__pyx_t_10) {

            /* "cPyparsing.pyx":899
 *                     if isinstance(v, ParseResults):
 *                         if v:
 *                             out.append(v.dump(indent, depth + 1))             # <<<<<<<<<<<<<<
 *                         else:
 *                             out.append(_ustr(v))
 */
            __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_v, __pyx_n_s_dump); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 899, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_v_depth, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 899, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_4 = NULL;
            __pyx_t_11 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
              __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
              if (likely(__pyx_t_4)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
                __Pyx_INCREF(__pyx_t_4);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_3, function);
                __pyx_t_11 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_3)) {
              PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_indent, __pyx_t_1};
              __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 899, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
              PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_indent, __pyx_t_1};
              __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 899, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            } else
            #endif
            {
              __pyx_t_12 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 899, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              if (__pyx_t_4) {
                __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_4); __pyx_t_4 = NULL;
              }
              __Pyx_INCREF(__pyx_v_indent);
              __Pyx_GIVEREF(__pyx_v_indent);
              PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_v_indent);
              __Pyx_GIVEREF(__pyx_t_1);
              PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_t_1);
              __pyx_t_1 = 0;
              __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_12, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 899, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            }
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_5); if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 899, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

            /* "cPyparsing.pyx":898
 *                     out.append("%s%s- %s: " % (indent, ('  ' * depth), k))
 *                     if isinstance(v, ParseResults):
 *                         if v:             # <<<<<<<<<<<<<<
 *                             out.append(v.dump(indent, depth + 1))
 *                         else:
 */
            goto __pyx_L11;
          }

          /* "cPyparsing.pyx":901
 *                             out.append(v.dump(indent, depth + 1))
 *                         else:
 *                             out.append(_ustr(v))             # <<<<<<<<<<<<<<
 *                     else:
 *                         out.append(repr(v))
 */
          /*else*/ {
            __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 901, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_t_12 = NULL;
            if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
              __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_3);
              if (likely(__pyx_t_12)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
                __Pyx_INCREF(__pyx_t_12);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_3, function);
              }
            }
            if (!__pyx_t_12) {
              __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_v); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 901, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_5);
            } else {
              #if CYTHON_FAST_PYCALL
              if (PyFunction_Check(__pyx_t_3)) {
                PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_v_v};
                __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 901, __pyx_L1_error)
                __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
                __Pyx_GOTREF(__pyx_t_5);
              } else
              #endif
              #if CYTHON_FAST_PYCCALL
              if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
                PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_v_v};
                __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 901, __pyx_L1_error)
                __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
                __Pyx_GOTREF(__pyx_t_5);
              } else
              #endif
              {
                __pyx_t_1 = PyTuple_New(1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 901, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_1);
                __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_12); __pyx_t_12 = NULL;
                __Pyx_INCREF(__pyx_v_v);
                __Pyx_GIVEREF(__pyx_v_v);
                PyTuple_SET_ITEM(__pyx_t_1, 0+1, __pyx_v_v);
                __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_1, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 901, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_5);
                __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              }
            }
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_5); if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 901, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          }
          __pyx_L11:;

          /* "cPyparsing.pyx":897
 *                         out.append(NL)
 *                     out.append("%s%s- %s: " % (indent, ('  ' * depth), k))
 *                     if isinstance(v, ParseResults):             # <<<<<<<<<<<<<<
 *                         if v:
 *                             out.append(v.dump(indent, depth + 1))
 */
          goto __pyx_L10;
        }

        /* "cPyparsing.pyx":903
 *                             out.append(_ustr(v))
 *                     else:
 *                         out.append(repr(v))             # <<<<<<<<<<<<<<
 *             elif any(isinstance(vv, ParseResults) for vv in self):
 *                 v = self
 */
        /*else*/ {
          __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_repr_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 903, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_1 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
            __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
            if (likely(__pyx_t_1)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
              __Pyx_INCREF(__pyx_t_1);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_3, function);
            }
          }
          if (!__pyx_t_1) {
            __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_v); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 903, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_3)) {
              PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_v_v};
              __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 903, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_GOTREF(__pyx_t_5);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
              PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_v_v};
              __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 903, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_GOTREF(__pyx_t_5);
            } else
            #endif
            {
              __pyx_t_12 = PyTuple_New(1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 903, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_1); __pyx_t_1 = NULL;
              __Pyx_INCREF(__pyx_v_v);
              __Pyx_GIVEREF(__pyx_v_v);
              PyTuple_SET_ITEM(__pyx_t_12, 0+1, __pyx_v_v);
              __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_12, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 903, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_5); if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 903, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __pyx_L10:;

        /* "cPyparsing.pyx":893
 *             if self.haskeys():
 *                 items = sorted((str(k), v) for k, v in self.items())
 *                 for k, v in items:             # <<<<<<<<<<<<<<
 *                     if out:
 *                         out.append(NL)
 */
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "cPyparsing.pyx":891
 *         out.append(indent + _ustr(self.asList()))
 *         if full:
 *             if self.haskeys():             # <<<<<<<<<<<<<<
 *                 items = sorted((str(k), v) for k, v in self.items())
 *                 for k, v in items:
 */
      goto __pyx_L4;
    }

    /* "cPyparsing.pyx":904
 *                     else:
 *                         out.append(repr(v))
 *             elif any(isinstance(vv, ParseResults) for vv in self):             # <<<<<<<<<<<<<<
 *                 v = self
 *                 for i, vv in enumerate(v):
 */
    __pyx_t_2 = __pyx_pf_10cPyparsing_12ParseResults_4dump_3genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 904, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_Generator_Next(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 904, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(0, 904, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_10) {

      /* "cPyparsing.pyx":905
 *                         out.append(repr(v))
 *             elif any(isinstance(vv, ParseResults) for vv in self):
 *                 v = self             # <<<<<<<<<<<<<<
 *                 for i, vv in enumerate(v):
 *                     if isinstance(vv, ParseResults):
 */
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
      __pyx_v_v = __pyx_cur_scope->__pyx_v_self;

      /* "cPyparsing.pyx":906
 *             elif any(isinstance(vv, ParseResults) for vv in self):
 *                 v = self
 *                 for i, vv in enumerate(v):             # <<<<<<<<<<<<<<
 *                     if isinstance(vv, ParseResults):
 *                         out.append("\n%s%s[%d]:\n%s%s%s" % (indent, ('  ' * (depth)), i, indent, ('  ' * (depth + 1)), vv.dump(indent, depth + 1)))
 */
      __Pyx_INCREF(__pyx_int_0);
      __pyx_t_5 = __pyx_int_0;
      if (likely(PyList_CheckExact(__pyx_v_v)) || PyTuple_CheckExact(__pyx_v_v)) {
        __pyx_t_2 = __pyx_v_v; __Pyx_INCREF(__pyx_t_2); __pyx_t_8 = 0;
        __pyx_t_13 = NULL;
      } else {
        __pyx_t_8 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_v); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 906, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_13 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 906, __pyx_L1_error)
      }
      for (;;) {
        if (likely(!__pyx_t_13)) {
          if (likely(PyList_CheckExact(__pyx_t_2))) {
            if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_2)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_8); __Pyx_INCREF(__pyx_t_3); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 906, __pyx_L1_error)
            #else
            __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 906, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            #endif
          } else {
            if (__pyx_t_8 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_8); __Pyx_INCREF(__pyx_t_3); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 906, __pyx_L1_error)
            #else
            __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 906, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            #endif
          }
        } else {
          __pyx_t_3 = __pyx_t_13(__pyx_t_2);
          if (unlikely(!__pyx_t_3)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 906, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_XDECREF_SET(__pyx_v_vv, __pyx_t_3);
        __pyx_t_3 = 0;
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_5);
        __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_t_5, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 906, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5);
        __pyx_t_5 = __pyx_t_3;
        __pyx_t_3 = 0;

        /* "cPyparsing.pyx":907
 *                 v = self
 *                 for i, vv in enumerate(v):
 *                     if isinstance(vv, ParseResults):             # <<<<<<<<<<<<<<
 *                         out.append("\n%s%s[%d]:\n%s%s%s" % (indent, ('  ' * (depth)), i, indent, ('  ' * (depth + 1)), vv.dump(indent, depth + 1)))
 *                     else:
 */
        __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 907, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_10 = PyObject_IsInstance(__pyx_v_vv, __pyx_t_3); if (unlikely(__pyx_t_10 == -1)) __PYX_ERR(0, 907, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_7 = (__pyx_t_10 != 0);
        if (__pyx_t_7) {

          /* "cPyparsing.pyx":908
 *                 for i, vv in enumerate(v):
 *                     if isinstance(vv, ParseResults):
 *                         out.append("\n%s%s[%d]:\n%s%s%s" % (indent, ('  ' * (depth)), i, indent, ('  ' * (depth + 1)), vv.dump(indent, depth + 1)))             # <<<<<<<<<<<<<<
 *                     else:
 *                         out.append("\n%s%s[%d]:\n%s%s%s" % (indent, ('  ' * (depth)), i, indent, ('  ' * (depth + 1)), _ustr(vv)))
 */
          __pyx_t_3 = PyNumber_Multiply(__pyx_kp_u__22, __pyx_v_depth); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 908, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_12 = __Pyx_PyInt_AddObjC(__pyx_v_depth, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 908, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_1 = PyNumber_Multiply(__pyx_kp_u__22, __pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 908, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_vv, __pyx_n_s_dump); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 908, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_14 = __Pyx_PyInt_AddObjC(__pyx_v_depth, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 908, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __pyx_t_15 = NULL;
          __pyx_t_11 = 0;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_15)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_15);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
              __pyx_t_11 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_4)) {
            PyObject *__pyx_temp[3] = {__pyx_t_15, __pyx_v_indent, __pyx_t_14};
            __pyx_t_12 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 908, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
            PyObject *__pyx_temp[3] = {__pyx_t_15, __pyx_v_indent, __pyx_t_14};
            __pyx_t_12 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 908, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          } else
          #endif
          {
            __pyx_t_16 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 908, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_16);
            if (__pyx_t_15) {
              __Pyx_GIVEREF(__pyx_t_15); PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_t_15); __pyx_t_15 = NULL;
            }
            __Pyx_INCREF(__pyx_v_indent);
            __Pyx_GIVEREF(__pyx_v_indent);
            PyTuple_SET_ITEM(__pyx_t_16, 0+__pyx_t_11, __pyx_v_indent);
            __Pyx_GIVEREF(__pyx_t_14);
            PyTuple_SET_ITEM(__pyx_t_16, 1+__pyx_t_11, __pyx_t_14);
            __pyx_t_14 = 0;
            __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_16, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 908, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          }
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = PyTuple_New(6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 908, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_INCREF(__pyx_v_indent);
          __Pyx_GIVEREF(__pyx_v_indent);
          PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_indent);
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3);
          __Pyx_INCREF(__pyx_v_i);
          __Pyx_GIVEREF(__pyx_v_i);
          PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_v_i);
          __Pyx_INCREF(__pyx_v_indent);
          __Pyx_GIVEREF(__pyx_v_indent);
          PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_v_indent);
          __Pyx_GIVEREF(__pyx_t_1);
          PyTuple_SET_ITEM(__pyx_t_4, 4, __pyx_t_1);
          __Pyx_GIVEREF(__pyx_t_12);
          PyTuple_SET_ITEM(__pyx_t_4, 5, __pyx_t_12);
          __pyx_t_3 = 0;
          __pyx_t_1 = 0;
          __pyx_t_12 = 0;
          __pyx_t_12 = PyUnicode_Format(__pyx_kp_u_s_s_d_s_s_s, __pyx_t_4); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 908, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_12); if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 908, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

          /* "cPyparsing.pyx":907
 *                 v = self
 *                 for i, vv in enumerate(v):
 *                     if isinstance(vv, ParseResults):             # <<<<<<<<<<<<<<
 *                         out.append("\n%s%s[%d]:\n%s%s%s" % (indent, ('  ' * (depth)), i, indent, ('  ' * (depth + 1)), vv.dump(indent, depth + 1)))
 *                     else:
 */
          goto __pyx_L14;
        }

        /* "cPyparsing.pyx":910
 *                         out.append("\n%s%s[%d]:\n%s%s%s" % (indent, ('  ' * (depth)), i, indent, ('  ' * (depth + 1)), vv.dump(indent, depth + 1)))
 *                     else:
 *                         out.append("\n%s%s[%d]:\n%s%s%s" % (indent, ('  ' * (depth)), i, indent, ('  ' * (depth + 1)), _ustr(vv)))             # <<<<<<<<<<<<<<
 * 
 *         return "".join(out)
 */
        /*else*/ {
          __pyx_t_12 = PyNumber_Multiply(__pyx_kp_u__22, __pyx_v_depth); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 910, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_v_depth, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 910, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_1 = PyNumber_Multiply(__pyx_kp_u__22, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 910, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 910, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_16 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
            __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_3);
            if (likely(__pyx_t_16)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
              __Pyx_INCREF(__pyx_t_16);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_3, function);
            }
          }
          if (!__pyx_t_16) {
            __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_vv); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 910, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_3)) {
              PyObject *__pyx_temp[2] = {__pyx_t_16, __pyx_v_vv};
              __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 910, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
              __Pyx_GOTREF(__pyx_t_4);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
              PyObject *__pyx_temp[2] = {__pyx_t_16, __pyx_v_vv};
              __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 910, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
              __Pyx_GOTREF(__pyx_t_4);
            } else
            #endif
            {
              __pyx_t_14 = PyTuple_New(1+1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 910, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_14);
              __Pyx_GIVEREF(__pyx_t_16); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_16); __pyx_t_16 = NULL;
              __Pyx_INCREF(__pyx_v_vv);
              __Pyx_GIVEREF(__pyx_v_vv);
              PyTuple_SET_ITEM(__pyx_t_14, 0+1, __pyx_v_vv);
              __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_14, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 910, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = PyTuple_New(6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 910, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_INCREF(__pyx_v_indent);
          __Pyx_GIVEREF(__pyx_v_indent);
          PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_indent);
          __Pyx_GIVEREF(__pyx_t_12);
          PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_12);
          __Pyx_INCREF(__pyx_v_i);
          __Pyx_GIVEREF(__pyx_v_i);
          PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_i);
          __Pyx_INCREF(__pyx_v_indent);
          __Pyx_GIVEREF(__pyx_v_indent);
          PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_v_indent);
          __Pyx_GIVEREF(__pyx_t_1);
          PyTuple_SET_ITEM(__pyx_t_3, 4, __pyx_t_1);
          __Pyx_GIVEREF(__pyx_t_4);
          PyTuple_SET_ITEM(__pyx_t_3, 5, __pyx_t_4);
          __pyx_t_12 = 0;
          __pyx_t_1 = 0;
          __pyx_t_4 = 0;
          __pyx_t_4 = PyUnicode_Format(__pyx_kp_u_s_s_d_s_s_s, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 910, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_4); if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 910, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_L14:;

        /* "cPyparsing.pyx":906
 *             elif any(isinstance(vv, ParseResults) for vv in self):
 *                 v = self
 *                 for i, vv in enumerate(v):             # <<<<<<<<<<<<<<
 *                     if isinstance(vv, ParseResults):
 *                         out.append("\n%s%s[%d]:\n%s%s%s" % (indent, ('  ' * (depth)), i, indent, ('  ' * (depth + 1)), vv.dump(indent, depth + 1)))
 */
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "cPyparsing.pyx":904
 *                     else:
 *                         out.append(repr(v))
 *             elif any(isinstance(vv, ParseResults) for vv in self):             # <<<<<<<<<<<<<<
 *                 v = self
 *                 for i, vv in enumerate(v):
 */
    }
    __pyx_L4:;

    /* "cPyparsing.pyx":890
 *         NL = '\n'
 *         out.append(indent + _ustr(self.asList()))
 *         if full:             # <<<<<<<<<<<<<<
 *             if self.haskeys():
 *                 items = sorted((str(k), v) for k, v in self.items())
 */
  }

  /* "cPyparsing.pyx":912
 *                         out.append("\n%s%s[%d]:\n%s%s%s" % (indent, ('  ' * (depth)), i, indent, ('  ' * (depth + 1)), _ustr(vv)))
 * 
 *         return "".join(out)             # <<<<<<<<<<<<<<
 * 
 *     def pprint(self, *args, **kwargs):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyUnicode_Join(__pyx_kp_u__9, __pyx_v_out); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":869
 *             return None
 * 
 *     def dump(self, indent='', depth=0, full=True):             # <<<<<<<<<<<<<<
 *         """
 *         Diagnostic method for listing out the contents of a C{ParseResults}.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("cPyparsing.ParseResults.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_out);
  __Pyx_XDECREF(__pyx_v_NL);
  __Pyx_XDECREF(__pyx_v_items);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_vv);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":914
 *         return "".join(out)
 * 
 *     def pprint(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Pretty-printer for parsed results as a list, using the C{pprint} module.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_75pprint(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_12ParseResults_74pprint[] = "\n        Pretty-printer for parsed results as a list, using the C{pprint} module.\n        Accepts additional positional or keyword args as defined for the\n        C{pprint.pprint} method. (U{http://docs.python.org/3/library/pprint.html#pprint.pprint})\n\n        Example::\n            ident = Word(alphas, alphanums)\n            num = Word(nums)\n            func = Forward()\n            term = ident | num | Group('(' + func + ')')\n            func <<= ident + Group(Optional(delimitedList(term)))\n            result = func.parseString(\"fna a,b,(fnb c,d,200),100\")\n            result.pprint(width=40)\n        prints::\n            ['fna',\n             ['a',\n              'b',\n              ['(', 'fnb', ['c', 'd', '200'], ')'],\n              '100']]\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_75pprint = {"pprint", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_75pprint, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_12ParseResults_74pprint};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_75pprint(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pprint (wrapper)", 0);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  if (PyTuple_GET_SIZE(__pyx_args) > 1) {
    __pyx_v_args = PyTuple_GetSlice(__pyx_args, 1, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v_args)) {
      __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
      __Pyx_RefNannyFinishContext();
      return NULL;
    }
    __Pyx_GOTREF(__pyx_v_args);
  } else {
    __pyx_v_args = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 1) ? pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, __pyx_v_kwargs, values, used_pos_args, "pprint") < 0)) __PYX_ERR(0, 914, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pprint", 0, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 914, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("cPyparsing.ParseResults.pprint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_74pprint(__pyx_self, __pyx_v_self, __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_74pprint(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("pprint", 0);

  /* "cPyparsing.pyx":935
 *               '100']]
 *         """
 *         pprint.pprint(self.asList(), *args, **kwargs)             # <<<<<<<<<<<<<<
 * 
 *     # add support for pickle protocol
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_pprint); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_pprint); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_asList); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 935, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 935, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_3, __pyx_v_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_v_kwargs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":914
 *         return "".join(out)
 * 
 *     def pprint(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Pretty-printer for parsed results as a list, using the C{pprint} module.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParseResults.pprint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":938
 * 
 *     # add support for pickle protocol
 *     def __getstate__(self):             # <<<<<<<<<<<<<<
 *         return (self.__toklist,
 *                 (self.__tokdict.copy(),
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_77__getstate__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_77__getstate__ = {"__getstate__", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_77__getstate__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_77__getstate__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getstate__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_76__getstate__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_76__getstate__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("__getstate__", 0);

  /* "cPyparsing.pyx":939
 *     # add support for pickle protocol
 *     def __getstate__(self):
 *         return (self.__toklist,             # <<<<<<<<<<<<<<
 *                 (self.__tokdict.copy(),
 *                  self.__parent is not None and self.__parent() or None,
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "cPyparsing.pyx":940
 *     def __getstate__(self):
 *         return (self.__toklist,
 *                 (self.__tokdict.copy(),             # <<<<<<<<<<<<<<
 *                  self.__parent is not None and self.__parent() or None,
 *                  self.__accumNames,
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 940, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_copy); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 940, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 940, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 940, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":941
 *         return (self.__toklist,
 *                 (self.__tokdict.copy(),
 *                  self.__parent is not None and self.__parent() or None,             # <<<<<<<<<<<<<<
 *                  self.__accumNames,
 *                  self.__name))
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__parent); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = (__pyx_t_3 != Py_None);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (!__pyx_t_5) {
    goto __pyx_L4_next_or;
  } else {
  }
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__parent); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  if (__pyx_t_7) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 941, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  } else {
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 941, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 941, __pyx_L1_error)
  if (!__pyx_t_5) {
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = __pyx_t_3;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_L4_next_or:;
  __Pyx_INCREF(Py_None);
  __pyx_t_4 = Py_None;
  __pyx_L3_bool_binop_done:;

  /* "cPyparsing.pyx":942
 *                 (self.__tokdict.copy(),
 *                  self.__parent is not None and self.__parent() or None,
 *                  self.__accumNames,             # <<<<<<<<<<<<<<
 *                  self.__name))
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__accumNames); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 942, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "cPyparsing.pyx":943
 *                  self.__parent is not None and self.__parent() or None,
 *                  self.__accumNames,
 *                  self.__name))             # <<<<<<<<<<<<<<
 * 
 *     def __setstate__(self, state):
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__name); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);

  /* "cPyparsing.pyx":940
 *     def __getstate__(self):
 *         return (self.__toklist,
 *                 (self.__tokdict.copy(),             # <<<<<<<<<<<<<<
 *                  self.__parent is not None and self.__parent() or None,
 *                  self.__accumNames,
 */
  __pyx_t_7 = PyTuple_New(4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 940, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_7, 3, __pyx_t_6);
  __pyx_t_2 = 0;
  __pyx_t_4 = 0;
  __pyx_t_3 = 0;
  __pyx_t_6 = 0;

  /* "cPyparsing.pyx":939
 *     # add support for pickle protocol
 *     def __getstate__(self):
 *         return (self.__toklist,             # <<<<<<<<<<<<<<
 *                 (self.__tokdict.copy(),
 *                  self.__parent is not None and self.__parent() or None,
 */
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_7);
  __pyx_t_1 = 0;
  __pyx_t_7 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":938
 * 
 *     # add support for pickle protocol
 *     def __getstate__(self):             # <<<<<<<<<<<<<<
 *         return (self.__toklist,
 *                 (self.__tokdict.copy(),
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__getstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":945
 *                  self.__name))
 * 
 *     def __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.__toklist = state[0]
 *         (self.__tokdict,
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_79__setstate__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_79__setstate__ = {"__setstate__", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_79__setstate__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_79__setstate__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_state,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__setstate__", 1, 2, 2, 1); __PYX_ERR(0, 945, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__setstate__") < 0)) __PYX_ERR(0, 945, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_state = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 945, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseResults.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_78__setstate__(__pyx_self, __pyx_v_self, __pyx_v_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_78__setstate__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_state) {
  PyObject *__pyx_v_par = NULL;
  PyObject *__pyx_v_inAccumNames = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_t_8;
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("__setstate__", 0);

  /* "cPyparsing.pyx":946
 * 
 *     def __setstate__(self, state):
 *         self.__toklist = state[0]             # <<<<<<<<<<<<<<
 *         (self.__tokdict,
 *          par,
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist, __pyx_t_1) < 0) __PYX_ERR(0, 946, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":950
 *          par,
 *          inAccumNames,
 *          self.__name) = state[1]             # <<<<<<<<<<<<<<
 *         self.__accumNames = {}
 *         self.__accumNames.update(inAccumNames)
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    #if !CYTHON_COMPILING_IN_PYPY
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 4)) {
      if (size > 4) __Pyx_RaiseTooManyValuesError(4);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 947, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 2); 
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 3); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 2); 
      __pyx_t_5 = PyList_GET_ITEM(sequence, 3); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_5);
    #else
    {
      Py_ssize_t i;
      PyObject** temps[4] = {&__pyx_t_2,&__pyx_t_3,&__pyx_t_4,&__pyx_t_5};
      for (i=0; i < 4; i++) {
        PyObject* item = PySequence_ITEM(sequence, i); if (unlikely(!item)) __PYX_ERR(0, 947, __pyx_L1_error)
        __Pyx_GOTREF(item);
        *(temps[i]) = item;
      }
    }
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    PyObject** temps[4] = {&__pyx_t_2,&__pyx_t_3,&__pyx_t_4,&__pyx_t_5};
    __pyx_t_6 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 947, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = Py_TYPE(__pyx_t_6)->tp_iternext;
    for (index=0; index < 4; index++) {
      PyObject* item = __pyx_t_7(__pyx_t_6); if (unlikely(!item)) goto __pyx_L3_unpacking_failed;
      __Pyx_GOTREF(item);
      *(temps[index]) = item;
    }
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 4) < 0) __PYX_ERR(0, 947, __pyx_L1_error)
    __pyx_t_7 = NULL;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 947, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }

  /* "cPyparsing.pyx":947
 *     def __setstate__(self, state):
 *         self.__toklist = state[0]
 *         (self.__tokdict,             # <<<<<<<<<<<<<<
 *          par,
 *          inAccumNames,
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__tokdict, __pyx_t_2) < 0) __PYX_ERR(0, 947, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_par = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_inAccumNames = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":950
 *          par,
 *          inAccumNames,
 *          self.__name) = state[1]             # <<<<<<<<<<<<<<
 *         self.__accumNames = {}
 *         self.__accumNames.update(inAccumNames)
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__name, __pyx_t_5) < 0) __PYX_ERR(0, 950, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cPyparsing.pyx":951
 *          inAccumNames,
 *          self.__name) = state[1]
 *         self.__accumNames = {}             # <<<<<<<<<<<<<<
 *         self.__accumNames.update(inAccumNames)
 *         if par is not None:
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__accumNames, __pyx_t_1) < 0) __PYX_ERR(0, 951, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":952
 *          self.__name) = state[1]
 *         self.__accumNames = {}
 *         self.__accumNames.update(inAccumNames)             # <<<<<<<<<<<<<<
 *         if par is not None:
 *             self.__parent = wkref(par)
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__accumNames); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_update); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (!__pyx_t_5) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_inAccumNames); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 952, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_inAccumNames};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 952, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_inAccumNames};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 952, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_3 = PyTuple_New(1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 952, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5); __pyx_t_5 = NULL;
      __Pyx_INCREF(__pyx_v_inAccumNames);
      __Pyx_GIVEREF(__pyx_v_inAccumNames);
      PyTuple_SET_ITEM(__pyx_t_3, 0+1, __pyx_v_inAccumNames);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 952, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":953
 *         self.__accumNames = {}
 *         self.__accumNames.update(inAccumNames)
 *         if par is not None:             # <<<<<<<<<<<<<<
 *             self.__parent = wkref(par)
 *         else:
 */
  __pyx_t_8 = (__pyx_v_par != Py_None);
  __pyx_t_9 = (__pyx_t_8 != 0);
  if (__pyx_t_9) {

    /* "cPyparsing.pyx":954
 *         self.__accumNames.update(inAccumNames)
 *         if par is not None:
 *             self.__parent = wkref(par)             # <<<<<<<<<<<<<<
 *         else:
 *             self.__parent = None
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_wkref); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 954, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_3) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_par); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 954, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_par};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 954, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_par};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 954, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 954, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_v_par);
        __Pyx_GIVEREF(__pyx_v_par);
        PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_par);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 954, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__parent, __pyx_t_1) < 0) __PYX_ERR(0, 954, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":953
 *         self.__accumNames = {}
 *         self.__accumNames.update(inAccumNames)
 *         if par is not None:             # <<<<<<<<<<<<<<
 *             self.__parent = wkref(par)
 *         else:
 */
    goto __pyx_L5;
  }

  /* "cPyparsing.pyx":956
 *             self.__parent = wkref(par)
 *         else:
 *             self.__parent = None             # <<<<<<<<<<<<<<
 * 
 *     def __getnewargs__(self):
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__parent, Py_None) < 0) __PYX_ERR(0, 956, __pyx_L1_error)
  }
  __pyx_L5:;

  /* "cPyparsing.pyx":945
 *                  self.__name))
 * 
 *     def __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.__toklist = state[0]
 *         (self.__tokdict,
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_par);
  __Pyx_XDECREF(__pyx_v_inAccumNames);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":958
 *             self.__parent = None
 * 
 *     def __getnewargs__(self):             # <<<<<<<<<<<<<<
 *         return self.__toklist, self.__name, self.__asList, self.__modal
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_81__getnewargs__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_81__getnewargs__ = {"__getnewargs__", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_81__getnewargs__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_81__getnewargs__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getnewargs__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_80__getnewargs__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_80__getnewargs__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("__getnewargs__", 0);

  /* "cPyparsing.pyx":959
 * 
 *     def __getnewargs__(self):
 *         return self.__toklist, self.__name, self.__asList, self.__modal             # <<<<<<<<<<<<<<
 * 
 *     def __dir__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__toklist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 959, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 959, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__asList); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 959, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ParseResults__modal); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 959, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 959, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_t_4);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":958
 *             self.__parent = None
 * 
 *     def __getnewargs__(self):             # <<<<<<<<<<<<<<
 *         return self.__toklist, self.__name, self.__asList, self.__modal
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__getnewargs__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":961
 *         return self.__toklist, self.__name, self.__asList, self.__modal
 * 
 *     def __dir__(self):             # <<<<<<<<<<<<<<
 *         return (dir(type(self)) + list(self.keys()))
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_83__dir__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12ParseResults_83__dir__ = {"__dir__", (PyCFunction)__pyx_pw_10cPyparsing_12ParseResults_83__dir__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_12ParseResults_83__dir__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dir__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_12ParseResults_82__dir__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12ParseResults_82__dir__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("__dir__", 0);

  /* "cPyparsing.pyx":962
 * 
 *     def __dir__(self):
 *         return (dir(type(self)) + list(self.keys()))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyObject_Dir(((PyObject *)Py_TYPE(__pyx_v_self))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_keys); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 962, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 962, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PySequence_List(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":961
 *         return self.__toklist, self.__name, self.__asList, self.__modal
 * 
 *     def __dir__(self):             # <<<<<<<<<<<<<<
 *         return (dir(type(self)) + list(self.keys()))
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParseResults.__dir__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":968
 * 
 * 
 * def col(int loc, strg):             # <<<<<<<<<<<<<<
 *     """Returns current column within a string, counting newlines as line separators.
 *     The first column is number 1.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7col(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_6col[] = "Returns current column within a string, counting newlines as line separators.\n    The first column is number 1.\n\n    Note: the default parsing behavior is to expand tabs in the input string\n    before starting the parsing process.  See L{I{ParserElement.parseString}<ParserElement.parseString>} for more information\n    on parsing strings containing C{<TAB>}s, and suggested methods to maintain a\n    consistent view of the parsed string, the parse location, and line and column\n    positions within the parsed string.\n    ";
static PyMethodDef __pyx_mdef_10cPyparsing_7col = {"col", (PyCFunction)__pyx_pw_10cPyparsing_7col, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_6col};
static PyObject *__pyx_pw_10cPyparsing_7col(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_v_loc;
  PyObject *__pyx_v_strg = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("col (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_loc,&__pyx_n_s_strg,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_strg)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("col", 1, 2, 2, 1); __PYX_ERR(0, 968, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "col") < 0)) __PYX_ERR(0, 968, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_loc = __Pyx_PyInt_As_int(values[0]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 968, __pyx_L3_error)
    __pyx_v_strg = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("col", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 968, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.col", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_6col(__pyx_self, __pyx_v_loc, __pyx_v_strg);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_6col(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_loc, PyObject *__pyx_v_strg) {
  PyObject *__pyx_v_s = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  long __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  __Pyx_RefNannySetupContext("col", 0);

  /* "cPyparsing.pyx":978
 *     positions within the parsed string.
 *     """
 *     s = strg             # <<<<<<<<<<<<<<
 *     return 1 if 0 < loc < len(s) and s[loc - 1] == '\n' else loc - s.rfind("\n", 0, loc)
 * 
 */
  __Pyx_INCREF(__pyx_v_strg);
  __pyx_v_s = __pyx_v_strg;

  /* "cPyparsing.pyx":979
 *     """
 *     s = strg
 *     return 1 if 0 < loc < len(s) and s[loc - 1] == '\n' else loc - s.rfind("\n", 0, loc)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = (0 < __pyx_v_loc);
  if (__pyx_t_3) {
    __pyx_t_4 = PyObject_Length(__pyx_v_s); if (unlikely(__pyx_t_4 == -1)) __PYX_ERR(0, 979, __pyx_L1_error)
    __pyx_t_3 = (__pyx_v_loc < __pyx_t_4);
  }
  __pyx_t_5 = (__pyx_t_3 != 0);
  if (__pyx_t_5) {
  } else {
    __pyx_t_2 = __pyx_t_5;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_6 = 0;
  __pyx_t_7 = __Pyx_sub_const_long_checking_overflow(__pyx_v_loc, 1, &__pyx_t_6);
  if (unlikely(__pyx_t_6)) {
    PyErr_SetString(PyExc_OverflowError, "value too large");
    __PYX_ERR(0, 979, __pyx_L1_error)
  }
  __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_s, __pyx_t_7, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_8, __pyx_kp_u__21, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 979, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_2 = __pyx_t_5;
  __pyx_L3_bool_binop_done:;
  if (__pyx_t_2) {
    __Pyx_INCREF(__pyx_int_1);
    __pyx_t_1 = __pyx_int_1;
  } else {
    __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 979, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_s, __pyx_n_s_rfind); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 979, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_11 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 979, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_12 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_12)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
        __pyx_t_6 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_10)) {
      PyObject *__pyx_temp[4] = {__pyx_t_12, __pyx_kp_u__21, __pyx_int_0, __pyx_t_11};
      __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 979, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
      PyObject *__pyx_temp[4] = {__pyx_t_12, __pyx_kp_u__21, __pyx_int_0, __pyx_t_11};
      __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 979, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    } else
    #endif
    {
      __pyx_t_13 = PyTuple_New(3+__pyx_t_6); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 979, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      if (__pyx_t_12) {
        __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_12); __pyx_t_12 = NULL;
      }
      __Pyx_INCREF(__pyx_kp_u__21);
      __Pyx_GIVEREF(__pyx_kp_u__21);
      PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_6, __pyx_kp_u__21);
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_GIVEREF(__pyx_int_0);
      PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_6, __pyx_int_0);
      __Pyx_GIVEREF(__pyx_t_11);
      PyTuple_SET_ITEM(__pyx_t_13, 2+__pyx_t_6, __pyx_t_11);
      __pyx_t_11 = 0;
      __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 979, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    }
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = PyNumber_Subtract(__pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 979, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_1 = __pyx_t_10;
    __pyx_t_10 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":968
 * 
 * 
 * def col(int loc, strg):             # <<<<<<<<<<<<<<
 *     """Returns current column within a string, counting newlines as line separators.
 *     The first column is number 1.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("cPyparsing.col", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_s);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":982
 * 
 * 
 * def lineno(int loc, strg):             # <<<<<<<<<<<<<<
 *     """Returns current line number within a string, counting newlines as line separators.
 *     The first line is number 1.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_9lineno(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_8lineno[] = "Returns current line number within a string, counting newlines as line separators.\n    The first line is number 1.\n\n    Note: the default parsing behavior is to expand tabs in the input string\n    before starting the parsing process.  See L{I{ParserElement.parseString}<ParserElement.parseString>} for more information\n    on parsing strings containing C{<TAB>}s, and suggested methods to maintain a\n    consistent view of the parsed string, the parse location, and line and column\n    positions within the parsed string.\n    ";
static PyMethodDef __pyx_mdef_10cPyparsing_9lineno = {"lineno", (PyCFunction)__pyx_pw_10cPyparsing_9lineno, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_8lineno};
static PyObject *__pyx_pw_10cPyparsing_9lineno(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_v_loc;
  PyObject *__pyx_v_strg = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lineno (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_loc,&__pyx_n_s_strg,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_strg)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("lineno", 1, 2, 2, 1); __PYX_ERR(0, 982, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "lineno") < 0)) __PYX_ERR(0, 982, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_loc = __Pyx_PyInt_As_int(values[0]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 982, __pyx_L3_error)
    __pyx_v_strg = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lineno", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 982, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.lineno", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_8lineno(__pyx_self, __pyx_v_loc, __pyx_v_strg);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_8lineno(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_loc, PyObject *__pyx_v_strg) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("lineno", 0);

  /* "cPyparsing.pyx":992
 *     positions within the parsed string.
 *     """
 *     return strg.count("\n", 0, loc) + 1             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_strg, __pyx_n_s_count); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[4] = {__pyx_t_4, __pyx_kp_u__21, __pyx_int_0, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 3+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 992, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[4] = {__pyx_t_4, __pyx_kp_u__21, __pyx_int_0, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 3+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 992, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  {
    __pyx_t_6 = PyTuple_New(3+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 992, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_INCREF(__pyx_kp_u__21);
    __Pyx_GIVEREF(__pyx_kp_u__21);
    PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_kp_u__21);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_int_0);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_6, 2+__pyx_t_5, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 992, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_t_1, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":982
 * 
 * 
 * def lineno(int loc, strg):             # <<<<<<<<<<<<<<
 *     """Returns current line number within a string, counting newlines as line separators.
 *     The first line is number 1.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.lineno", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":995
 * 
 * 
 * def line(int loc, strg):             # <<<<<<<<<<<<<<
 *     """Returns the line of text containing loc within a string, counting newlines as line separators.
 *     """
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_11line(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_10line[] = "Returns the line of text containing loc within a string, counting newlines as line separators.\n    ";
static PyMethodDef __pyx_mdef_10cPyparsing_11line = {"line", (PyCFunction)__pyx_pw_10cPyparsing_11line, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_10line};
static PyObject *__pyx_pw_10cPyparsing_11line(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_v_loc;
  PyObject *__pyx_v_strg = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("line (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_loc,&__pyx_n_s_strg,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_strg)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("line", 1, 2, 2, 1); __PYX_ERR(0, 995, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "line") < 0)) __PYX_ERR(0, 995, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_loc = __Pyx_PyInt_As_int(values[0]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 995, __pyx_L3_error)
    __pyx_v_strg = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("line", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 995, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.line", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10line(__pyx_self, __pyx_v_loc, __pyx_v_strg);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10line(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_loc, PyObject *__pyx_v_strg) {
  PyObject *__pyx_v_lastCR = NULL;
  PyObject *__pyx_v_nextCR = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("line", 0);

  /* "cPyparsing.pyx":998
 *     """Returns the line of text containing loc within a string, counting newlines as line separators.
 *     """
 *     lastCR = strg.rfind("\n", 0, loc)             # <<<<<<<<<<<<<<
 *     nextCR = strg.find("\n", loc)
 *     if nextCR >= 0:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_strg, __pyx_n_s_rfind); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[4] = {__pyx_t_4, __pyx_kp_u__21, __pyx_int_0, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 3+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 998, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[4] = {__pyx_t_4, __pyx_kp_u__21, __pyx_int_0, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 3+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 998, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  {
    __pyx_t_6 = PyTuple_New(3+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 998, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_INCREF(__pyx_kp_u__21);
    __Pyx_GIVEREF(__pyx_kp_u__21);
    PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_kp_u__21);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_int_0);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_6, 2+__pyx_t_5, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 998, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_lastCR = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":999
 *     """
 *     lastCR = strg.rfind("\n", 0, loc)
 *     nextCR = strg.find("\n", loc)             # <<<<<<<<<<<<<<
 *     if nextCR >= 0:
 *         return strg[lastCR + 1:nextCR]
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_strg, __pyx_n_s_find); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_kp_u__21, __pyx_t_6};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 999, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_kp_u__21, __pyx_t_6};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 999, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else
  #endif
  {
    __pyx_t_4 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 999, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_kp_u__21);
    __Pyx_GIVEREF(__pyx_kp_u__21);
    PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_5, __pyx_kp_u__21);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_5, __pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 999, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_nextCR = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1000
 *     lastCR = strg.rfind("\n", 0, loc)
 *     nextCR = strg.find("\n", loc)
 *     if nextCR >= 0:             # <<<<<<<<<<<<<<
 *         return strg[lastCR + 1:nextCR]
 *     else:
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_nextCR, __pyx_int_0, Py_GE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1000, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 1000, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_7) {

    /* "cPyparsing.pyx":1001
 *     nextCR = strg.find("\n", loc)
 *     if nextCR >= 0:
 *         return strg[lastCR + 1:nextCR]             # <<<<<<<<<<<<<<
 *     else:
 *         return strg[lastCR + 1:]
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_v_lastCR, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1001, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_strg, 0, 0, &__pyx_t_1, &__pyx_v_nextCR, NULL, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1001, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":1000
 *     lastCR = strg.rfind("\n", 0, loc)
 *     nextCR = strg.find("\n", loc)
 *     if nextCR >= 0:             # <<<<<<<<<<<<<<
 *         return strg[lastCR + 1:nextCR]
 *     else:
 */
  }

  /* "cPyparsing.pyx":1003
 *         return strg[lastCR + 1:nextCR]
 *     else:
 *         return strg[lastCR + 1:]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_lastCR, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1003, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_strg, 0, 0, &__pyx_t_2, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1003, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":995
 * 
 * 
 * def line(int loc, strg):             # <<<<<<<<<<<<<<
 *     """Returns the line of text containing loc within a string, counting newlines as line separators.
 *     """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.line", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_lastCR);
  __Pyx_XDECREF(__pyx_v_nextCR);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1006
 * 
 * 
 * def _defaultStartDebugAction(instring, loc, expr):             # <<<<<<<<<<<<<<
 *     print(("Match " + _ustr(expr) + " at loc " + _ustr(loc) + "(%d,%d)" % (lineno(loc, instring), col(loc, instring))))
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13_defaultStartDebugAction(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13_defaultStartDebugAction = {"_defaultStartDebugAction", (PyCFunction)__pyx_pw_10cPyparsing_13_defaultStartDebugAction, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13_defaultStartDebugAction(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_defaultStartDebugAction (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_expr,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_defaultStartDebugAction", 1, 3, 3, 1); __PYX_ERR(0, 1006, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_expr)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_defaultStartDebugAction", 1, 3, 3, 2); __PYX_ERR(0, 1006, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "_defaultStartDebugAction") < 0)) __PYX_ERR(0, 1006, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_instring = values[0];
    __pyx_v_loc = values[1];
    __pyx_v_expr = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_defaultStartDebugAction", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1006, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing._defaultStartDebugAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12_defaultStartDebugAction(__pyx_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_expr);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12_defaultStartDebugAction(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_expr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("_defaultStartDebugAction", 0);

  /* "cPyparsing.pyx":1007
 * 
 * def _defaultStartDebugAction(instring, loc, expr):
 *     print(("Match " + _ustr(expr) + " at loc " + _ustr(loc) + "(%d,%d)" % (lineno(loc, instring), col(loc, instring))))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1007, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_expr};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1007, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_expr};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1007, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1007, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_v_expr);
      __Pyx_GIVEREF(__pyx_v_expr);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_expr);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1007, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_kp_u_Match, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_kp_u_at_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1007, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_loc};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1007, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_loc};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1007, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1007, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_v_loc);
      __Pyx_GIVEREF(__pyx_v_loc);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_loc);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1007, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_lineno); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_1)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_loc, __pyx_v_instring};
    __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1007, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_2);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_loc, __pyx_v_instring};
    __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1007, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_2);
  } else
  #endif
  {
    __pyx_t_3 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1007, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__pyx_t_5) {
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5); __pyx_t_5 = NULL;
    }
    __Pyx_INCREF(__pyx_v_loc);
    __Pyx_GIVEREF(__pyx_v_loc);
    PyTuple_SET_ITEM(__pyx_t_3, 0+__pyx_t_6, __pyx_v_loc);
    __Pyx_INCREF(__pyx_v_instring);
    __Pyx_GIVEREF(__pyx_v_instring);
    PyTuple_SET_ITEM(__pyx_t_3, 1+__pyx_t_6, __pyx_v_instring);
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1007, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_col); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_loc, __pyx_v_instring};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1007, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_loc, __pyx_v_instring};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1007, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1007, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__pyx_t_5) {
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
    }
    __Pyx_INCREF(__pyx_v_loc);
    __Pyx_GIVEREF(__pyx_v_loc);
    PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_loc);
    __Pyx_INCREF(__pyx_v_instring);
    __Pyx_GIVEREF(__pyx_v_instring);
    PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_v_instring);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1007, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1);
  __pyx_t_2 = 0;
  __pyx_t_1 = 0;
  __pyx_t_1 = PyUnicode_Format(__pyx_kp_u_d_d, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Add(__pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_t_1, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":1006
 * 
 * 
 * def _defaultStartDebugAction(instring, loc, expr):             # <<<<<<<<<<<<<<
 *     print(("Match " + _ustr(expr) + " at loc " + _ustr(loc) + "(%d,%d)" % (lineno(loc, instring), col(loc, instring))))
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing._defaultStartDebugAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1010
 * 
 * 
 * def _defaultSuccessDebugAction(instring, startloc, endloc, expr, toks):             # <<<<<<<<<<<<<<
 *     print("Matched " + _ustr(expr) + " -> " + str(toks.asList()))
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15_defaultSuccessDebugAction(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15_defaultSuccessDebugAction = {"_defaultSuccessDebugAction", (PyCFunction)__pyx_pw_10cPyparsing_15_defaultSuccessDebugAction, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_15_defaultSuccessDebugAction(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_instring = 0;
  CYTHON_UNUSED PyObject *__pyx_v_startloc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_endloc = 0;
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_toks = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_defaultSuccessDebugAction (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_instring,&__pyx_n_s_startloc,&__pyx_n_s_endloc,&__pyx_n_s_expr,&__pyx_n_s_toks,0};
    PyObject* values[5] = {0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_startloc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_defaultSuccessDebugAction", 1, 5, 5, 1); __PYX_ERR(0, 1010, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_endloc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_defaultSuccessDebugAction", 1, 5, 5, 2); __PYX_ERR(0, 1010, __pyx_L3_error)
        }
        case  3:
        if (likely((values[3] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_expr)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_defaultSuccessDebugAction", 1, 5, 5, 3); __PYX_ERR(0, 1010, __pyx_L3_error)
        }
        case  4:
        if (likely((values[4] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_toks)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_defaultSuccessDebugAction", 1, 5, 5, 4); __PYX_ERR(0, 1010, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "_defaultSuccessDebugAction") < 0)) __PYX_ERR(0, 1010, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 5) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
    }
    __pyx_v_instring = values[0];
    __pyx_v_startloc = values[1];
    __pyx_v_endloc = values[2];
    __pyx_v_expr = values[3];
    __pyx_v_toks = values[4];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_defaultSuccessDebugAction", 1, 5, 5, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1010, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing._defaultSuccessDebugAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_14_defaultSuccessDebugAction(__pyx_self, __pyx_v_instring, __pyx_v_startloc, __pyx_v_endloc, __pyx_v_expr, __pyx_v_toks);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_14_defaultSuccessDebugAction(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_startloc, CYTHON_UNUSED PyObject *__pyx_v_endloc, PyObject *__pyx_v_expr, PyObject *__pyx_v_toks) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("_defaultSuccessDebugAction", 0);

  /* "cPyparsing.pyx":1011
 * 
 * def _defaultSuccessDebugAction(instring, startloc, endloc, expr, toks):
 *     print("Matched " + _ustr(expr) + " -> " + str(toks.asList()))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1011, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1011, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_expr};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1011, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_expr};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1011, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1011, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_v_expr);
      __Pyx_GIVEREF(__pyx_v_expr);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_expr);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1011, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_kp_u_Matched, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1011, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_kp_u__26); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1011, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_str); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1011, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_toks, __pyx_n_s_asList); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1011, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (__pyx_t_6) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1011, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else {
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1011, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (!__pyx_t_5) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1011, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_3};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1011, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_3};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1011, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1011, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1011, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1011, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1011, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_4);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1011, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":1010
 * 
 * 
 * def _defaultSuccessDebugAction(instring, startloc, endloc, expr, toks):             # <<<<<<<<<<<<<<
 *     print("Matched " + _ustr(expr) + " -> " + str(toks.asList()))
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing._defaultSuccessDebugAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1014
 * 
 * 
 * def _defaultExceptionDebugAction(instring, loc, expr, exc):             # <<<<<<<<<<<<<<
 *     print("Exception raised:" + _ustr(exc))
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_17_defaultExceptionDebugAction(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_17_defaultExceptionDebugAction = {"_defaultExceptionDebugAction", (PyCFunction)__pyx_pw_10cPyparsing_17_defaultExceptionDebugAction, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_17_defaultExceptionDebugAction(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_instring = 0;
  CYTHON_UNUSED PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_exc = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_defaultExceptionDebugAction (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_expr,&__pyx_n_s_exc,0};
    PyObject* values[4] = {0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_defaultExceptionDebugAction", 1, 4, 4, 1); __PYX_ERR(0, 1014, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_expr)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_defaultExceptionDebugAction", 1, 4, 4, 2); __PYX_ERR(0, 1014, __pyx_L3_error)
        }
        case  3:
        if (likely((values[3] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_exc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_defaultExceptionDebugAction", 1, 4, 4, 3); __PYX_ERR(0, 1014, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "_defaultExceptionDebugAction") < 0)) __PYX_ERR(0, 1014, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 4) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
    }
    __pyx_v_instring = values[0];
    __pyx_v_loc = values[1];
    __pyx_v_expr = values[2];
    __pyx_v_exc = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_defaultExceptionDebugAction", 1, 4, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1014, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing._defaultExceptionDebugAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_16_defaultExceptionDebugAction(__pyx_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_expr, __pyx_v_exc);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_16_defaultExceptionDebugAction(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_expr, PyObject *__pyx_v_exc) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("_defaultExceptionDebugAction", 0);

  /* "cPyparsing.pyx":1015
 * 
 * def _defaultExceptionDebugAction(instring, loc, expr, exc):
 *     print("Exception raised:" + _ustr(exc))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_exc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_exc};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1015, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_exc};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1015, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1015, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_v_exc);
      __Pyx_GIVEREF(__pyx_v_exc);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_exc);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1015, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_kp_u_Exception_raised, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1014
 * 
 * 
 * def _defaultExceptionDebugAction(instring, loc, expr, exc):             # <<<<<<<<<<<<<<
 *     print("Exception raised:" + _ustr(exc))
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing._defaultExceptionDebugAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1018
 * 
 * 
 * def nullDebugAction(*args):             # <<<<<<<<<<<<<<
 *     """'Do-nothing' debug action, to suppress debugging output during parsing."""
 *     pass
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_19nullDebugAction(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_18nullDebugAction[] = "'Do-nothing' debug action, to suppress debugging output during parsing.";
static PyMethodDef __pyx_mdef_10cPyparsing_19nullDebugAction = {"nullDebugAction", (PyCFunction)__pyx_pw_10cPyparsing_19nullDebugAction, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_18nullDebugAction};
static PyObject *__pyx_pw_10cPyparsing_19nullDebugAction(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_args = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nullDebugAction (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nullDebugAction", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_10cPyparsing_18nullDebugAction(__pyx_self, __pyx_v_args);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_18nullDebugAction(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nullDebugAction", 0);

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1023
 * 
 * 
 * def _trim_arity(func, maxargs=2):             # <<<<<<<<<<<<<<
 *     """decorator to trim function calls to match the arity of the target"""
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_21_trim_arity(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_20_trim_arity[] = "decorator to trim function calls to match the arity of the target";
static PyMethodDef __pyx_mdef_10cPyparsing_21_trim_arity = {"_trim_arity", (PyCFunction)__pyx_pw_10cPyparsing_21_trim_arity, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_20_trim_arity};
static PyObject *__pyx_pw_10cPyparsing_21_trim_arity(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_func = 0;
  PyObject *__pyx_v_maxargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_trim_arity (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_func,&__pyx_n_s_maxargs,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)__pyx_int_2);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_func)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_maxargs);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "_trim_arity") < 0)) __PYX_ERR(0, 1023, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_func = values[0];
    __pyx_v_maxargs = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_trim_arity", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1023, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing._trim_arity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_20_trim_arity(__pyx_self, __pyx_v_func, __pyx_v_maxargs);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1039
 *         #     return [(frame_summary.filename, frame_summary.lineno)]
 * 
 *         def extract_tb(tb, limit=None):             # <<<<<<<<<<<<<<
 *             frames = traceback.extract_tb(tb, limit=limit)
 *             frame_summary = frames[-1]
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_11_trim_arity_1extract_tb(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_11_trim_arity_1extract_tb = {"extract_tb", (PyCFunction)__pyx_pw_10cPyparsing_11_trim_arity_1extract_tb, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_11_trim_arity_1extract_tb(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_tb = 0;
  PyObject *__pyx_v_limit = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("extract_tb (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_tb,&__pyx_n_s_limit,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_tb)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_limit);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "extract_tb") < 0)) __PYX_ERR(0, 1039, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_tb = values[0];
    __pyx_v_limit = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("extract_tb", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1039, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing._trim_arity.extract_tb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_11_trim_arity_extract_tb(__pyx_self, __pyx_v_tb, __pyx_v_limit);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_11_trim_arity_extract_tb(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tb, PyObject *__pyx_v_limit) {
  PyObject *__pyx_v_frames = NULL;
  PyObject *__pyx_v_frame_summary = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("extract_tb", 0);

  /* "cPyparsing.pyx":1040
 * 
 *         def extract_tb(tb, limit=None):
 *             frames = traceback.extract_tb(tb, limit=limit)             # <<<<<<<<<<<<<<
 *             frame_summary = frames[-1]
 *             return [(frame_summary.filename, frame_summary.lineno)]
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_traceback); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1040, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_extract_tb); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1040, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1040, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_tb);
  __Pyx_GIVEREF(__pyx_v_tb);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_tb);
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1040, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_limit, __pyx_v_limit) < 0) __PYX_ERR(0, 1040, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1040, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_frames = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":1041
 *         def extract_tb(tb, limit=None):
 *             frames = traceback.extract_tb(tb, limit=limit)
 *             frame_summary = frames[-1]             # <<<<<<<<<<<<<<
 *             return [(frame_summary.filename, frame_summary.lineno)]
 *     else:
 */
  __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_frames, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_frame_summary = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":1042
 *             frames = traceback.extract_tb(tb, limit=limit)
 *             frame_summary = frames[-1]
 *             return [(frame_summary.filename, frame_summary.lineno)]             # <<<<<<<<<<<<<<
 *     else:
 *         # extract_stack = traceback.extract_stack
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame_summary, __pyx_n_s_filename); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame_summary, __pyx_n_s_lineno); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3);
  __pyx_t_4 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  PyList_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1039
 *         #     return [(frame_summary.filename, frame_summary.lineno)]
 * 
 *         def extract_tb(tb, limit=None):             # <<<<<<<<<<<<<<
 *             frames = traceback.extract_tb(tb, limit=limit)
 *             frame_summary = frames[-1]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing._trim_arity.extract_tb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_frames);
  __Pyx_XDECREF(__pyx_v_frame_summary);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1051
 *     tb_info_synth = (_FILE_NAME, _WRAP_CALL_LINE_NUM)
 * 
 *     def wrapper(*args):             # <<<<<<<<<<<<<<
 *         nonlocal foundArity, limit
 *         while True:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_11_trim_arity_3wrapper(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_11_trim_arity_3wrapper = {"wrapper", (PyCFunction)__pyx_pw_10cPyparsing_11_trim_arity_3wrapper, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_11_trim_arity_3wrapper(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("wrapper (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "wrapper", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_10cPyparsing_11_trim_arity_2wrapper(__pyx_self, __pyx_v_args);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_11_trim_arity_2wrapper(PyObject *__pyx_self, PyObject *__pyx_v_args) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_17__trim_arity *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_17__trim_arity *__pyx_outer_scope;
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_v_tb = NULL;
  PyObject *__pyx_v_tb_info = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  char const *__pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  __Pyx_RefNannySetupContext("wrapper", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_17__trim_arity *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":1053
 *     def wrapper(*args):
 *         nonlocal foundArity, limit
 *         while True:             # <<<<<<<<<<<<<<
 *             try:
 *                 # any changes to the following line must be reflected in wrap_call_line
 */
  while (1) {

    /* "cPyparsing.pyx":1054
 *         nonlocal foundArity, limit
 *         while True:
 *             try:             # <<<<<<<<<<<<<<
 *                 # any changes to the following line must be reflected in wrap_call_line
 *                 ret = func(*args[limit:])
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_3);
      /*try:*/ {

        /* "cPyparsing.pyx":1056
 *             try:
 *                 # any changes to the following line must be reflected in wrap_call_line
 *                 ret = func(*args[limit:])             # <<<<<<<<<<<<<<
 *                 foundArity = True
 *                 return ret
 */
        if (unlikely(!__pyx_cur_scope->__pyx_v_func)) { __Pyx_RaiseClosureNameError("func"); __PYX_ERR(0, 1056, __pyx_L5_error) }
        if (unlikely(!__pyx_cur_scope->__pyx_v_limit)) { __Pyx_RaiseClosureNameError("limit"); __PYX_ERR(0, 1056, __pyx_L5_error) }
        __pyx_t_4 = __Pyx_PyIndex_AsSsize_t(__pyx_cur_scope->__pyx_v_limit); if (unlikely((__pyx_t_4 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1056, __pyx_L5_error)
        __pyx_t_5 = __Pyx_PyTuple_GetSlice(__pyx_v_args, __pyx_t_4, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1056, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_cur_scope->__pyx_v_func, __pyx_t_5, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1056, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF_SET(__pyx_v_ret, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "cPyparsing.pyx":1057
 *                 # any changes to the following line must be reflected in wrap_call_line
 *                 ret = func(*args[limit:])
 *                 foundArity = True             # <<<<<<<<<<<<<<
 *                 return ret
 *             except TypeError:
 */
        __pyx_cur_scope->__pyx_v_foundArity = 1;

        /* "cPyparsing.pyx":1058
 *                 ret = func(*args[limit:])
 *                 foundArity = True
 *                 return ret             # <<<<<<<<<<<<<<
 *             except TypeError:
 *                 # re-raise TypeErrors if they did not come from our arity testing
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_v_ret);
        __pyx_r = __pyx_v_ret;
        goto __pyx_L9_try_return;

        /* "cPyparsing.pyx":1054
 *         nonlocal foundArity, limit
 *         while True:
 *             try:             # <<<<<<<<<<<<<<
 *                 # any changes to the following line must be reflected in wrap_call_line
 *                 ret = func(*args[limit:])
 */
      }
      __pyx_L5_error:;
      __Pyx_PyThreadState_assign
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "cPyparsing.pyx":1059
 *                 foundArity = True
 *                 return ret
 *             except TypeError:             # <<<<<<<<<<<<<<
 *                 # re-raise TypeErrors if they did not come from our arity testing
 *                 if foundArity:
 */
      __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_TypeError);
      if (__pyx_t_7) {
        __Pyx_AddTraceback("cPyparsing._trim_arity.wrapper", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_5, &__pyx_t_8) < 0) __PYX_ERR(0, 1059, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_GOTREF(__pyx_t_8);

        /* "cPyparsing.pyx":1061
 *             except TypeError:
 *                 # re-raise TypeErrors if they did not come from our arity testing
 *                 if foundArity:             # <<<<<<<<<<<<<<
 *                     raise
 *                 else:
 */
        __pyx_t_9 = (__pyx_cur_scope->__pyx_v_foundArity != 0);
        if (__pyx_t_9) {

          /* "cPyparsing.pyx":1062
 *                 # re-raise TypeErrors if they did not come from our arity testing
 *                 if foundArity:
 *                     raise             # <<<<<<<<<<<<<<
 *                 else:
 *                     try:
 */
          __Pyx_GIVEREF(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_5);
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_ErrRestoreWithState(__pyx_t_6, __pyx_t_5, __pyx_t_8);
          __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_8 = 0; 
          __PYX_ERR(0, 1062, __pyx_L7_except_error)

          /* "cPyparsing.pyx":1061
 *             except TypeError:
 *                 # re-raise TypeErrors if they did not come from our arity testing
 *                 if foundArity:             # <<<<<<<<<<<<<<
 *                     raise
 *                 else:
 */
        }

        /* "cPyparsing.pyx":1064
 *                     raise
 *                 else:
 *                     try:             # <<<<<<<<<<<<<<
 *                         tb = sys.exc_info()[-1]
 *                         tb_info = extract_tb(tb, limit=2)[-1][:2]
 */
        /*else*/ {
          /*try:*/ {

            /* "cPyparsing.pyx":1065
 *                 else:
 *                     try:
 *                         tb = sys.exc_info()[-1]             # <<<<<<<<<<<<<<
 *                         tb_info = extract_tb(tb, limit=2)[-1][:2]
 *                         if tb_info != tb_info_synth:
 */
            __pyx_t_11 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1065, __pyx_L19_error)
            __Pyx_GOTREF(__pyx_t_11);
            __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_exc_info); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1065, __pyx_L19_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            __pyx_t_11 = NULL;
            if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
              __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_12);
              if (likely(__pyx_t_11)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
                __Pyx_INCREF(__pyx_t_11);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_12, function);
              }
            }
            if (__pyx_t_11) {
              __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_11); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1065, __pyx_L19_error)
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            } else {
              __pyx_t_10 = __Pyx_PyObject_CallNoArg(__pyx_t_12); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1065, __pyx_L19_error)
            }
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_t_12 = __Pyx_GetItemInt(__pyx_t_10, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1065, __pyx_L19_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __pyx_v_tb = __pyx_t_12;
            __pyx_t_12 = 0;

            /* "cPyparsing.pyx":1066
 *                     try:
 *                         tb = sys.exc_info()[-1]
 *                         tb_info = extract_tb(tb, limit=2)[-1][:2]             # <<<<<<<<<<<<<<
 *                         if tb_info != tb_info_synth:
 *                             raise
 */
            if (unlikely(!__pyx_cur_scope->__pyx_v_extract_tb)) { __Pyx_RaiseClosureNameError("extract_tb"); __PYX_ERR(0, 1066, __pyx_L19_error) }
            __pyx_t_12 = PyTuple_New(1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1066, __pyx_L19_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_INCREF(__pyx_v_tb);
            __Pyx_GIVEREF(__pyx_v_tb);
            PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_v_tb);
            __pyx_t_10 = PyDict_New(); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1066, __pyx_L19_error)
            __Pyx_GOTREF(__pyx_t_10);
            if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_limit, __pyx_int_2) < 0) __PYX_ERR(0, 1066, __pyx_L19_error)
            __pyx_t_11 = __Pyx_PyObject_Call(__pyx_cur_scope->__pyx_v_extract_tb, __pyx_t_12, __pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1066, __pyx_L19_error)
            __Pyx_GOTREF(__pyx_t_11);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __pyx_t_10 = __Pyx_GetItemInt(__pyx_t_11, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1066, __pyx_L19_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            __pyx_t_11 = __Pyx_PyObject_GetSlice(__pyx_t_10, 0, 2, NULL, NULL, &__pyx_slice__27, 0, 1, 1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1066, __pyx_L19_error)
            __Pyx_GOTREF(__pyx_t_11);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_XDECREF_SET(__pyx_v_tb_info, __pyx_t_11);
            __pyx_t_11 = 0;

            /* "cPyparsing.pyx":1067
 *                         tb = sys.exc_info()[-1]
 *                         tb_info = extract_tb(tb, limit=2)[-1][:2]
 *                         if tb_info != tb_info_synth:             # <<<<<<<<<<<<<<
 *                             raise
 *                     finally:
 */
            if (unlikely(!__pyx_cur_scope->__pyx_v_tb_info_synth)) { __Pyx_RaiseClosureNameError("tb_info_synth"); __PYX_ERR(0, 1067, __pyx_L19_error) }
            __pyx_t_11 = PyObject_RichCompare(__pyx_v_tb_info, __pyx_cur_scope->__pyx_v_tb_info_synth, Py_NE); __Pyx_XGOTREF(__pyx_t_11); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1067, __pyx_L19_error)
            __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1067, __pyx_L19_error)
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            if (__pyx_t_9) {

              /* "cPyparsing.pyx":1068
 *                         tb_info = extract_tb(tb, limit=2)[-1][:2]
 *                         if tb_info != tb_info_synth:
 *                             raise             # <<<<<<<<<<<<<<
 *                     finally:
 *                         del tb
 */
              __Pyx_GIVEREF(__pyx_t_6);
              __Pyx_GIVEREF(__pyx_t_5);
              __Pyx_XGIVEREF(__pyx_t_8);
              __Pyx_ErrRestoreWithState(__pyx_t_6, __pyx_t_5, __pyx_t_8);
              __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_8 = 0; 
              __PYX_ERR(0, 1068, __pyx_L19_error)

              /* "cPyparsing.pyx":1067
 *                         tb = sys.exc_info()[-1]
 *                         tb_info = extract_tb(tb, limit=2)[-1][:2]
 *                         if tb_info != tb_info_synth:             # <<<<<<<<<<<<<<
 *                             raise
 *                     finally:
 */
            }
          }

          /* "cPyparsing.pyx":1070
 *                             raise
 *                     finally:
 *                         del tb             # <<<<<<<<<<<<<<
 * 
 *                 if limit <= maxargs:
 */
          /*finally:*/ {
            /*normal exit:*/{
              __Pyx_DECREF(__pyx_v_tb);
              __pyx_v_tb = NULL;
              goto __pyx_L20;
            }
            /*exception exit:*/{
              __Pyx_PyThreadState_declare
              __pyx_L19_error:;
              __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
              __Pyx_PyThreadState_assign
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
              if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17) < 0)) __Pyx_ErrFetch(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
              __Pyx_XGOTREF(__pyx_t_15);
              __Pyx_XGOTREF(__pyx_t_16);
              __Pyx_XGOTREF(__pyx_t_17);
              __Pyx_XGOTREF(__pyx_t_18);
              __Pyx_XGOTREF(__pyx_t_19);
              __Pyx_XGOTREF(__pyx_t_20);
              __pyx_t_7 = __pyx_lineno; __pyx_t_13 = __pyx_clineno; __pyx_t_14 = __pyx_filename;
              {
                if (unlikely(!__pyx_v_tb)) { __Pyx_RaiseUnboundLocalError("tb"); __PYX_ERR(0, 1070, __pyx_L25_error) }
                __Pyx_DECREF(__pyx_v_tb);
                __pyx_v_tb = NULL;
              }
              __Pyx_PyThreadState_assign
              if (PY_MAJOR_VERSION >= 3) {
                __Pyx_XGIVEREF(__pyx_t_18);
                __Pyx_XGIVEREF(__pyx_t_19);
                __Pyx_XGIVEREF(__pyx_t_20);
                __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_19, __pyx_t_20);
              }
              __Pyx_XGIVEREF(__pyx_t_15);
              __Pyx_XGIVEREF(__pyx_t_16);
              __Pyx_XGIVEREF(__pyx_t_17);
              __Pyx_ErrRestore(__pyx_t_15, __pyx_t_16, __pyx_t_17);
              __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
              __pyx_lineno = __pyx_t_7; __pyx_clineno = __pyx_t_13; __pyx_filename = __pyx_t_14;
              goto __pyx_L7_except_error;
              __pyx_L25_error:;
              __Pyx_PyThreadState_assign
              if (PY_MAJOR_VERSION >= 3) {
                __Pyx_XGIVEREF(__pyx_t_18);
                __Pyx_XGIVEREF(__pyx_t_19);
                __Pyx_XGIVEREF(__pyx_t_20);
                __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_19, __pyx_t_20);
              }
              __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
              __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
              __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
              __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
              goto __pyx_L7_except_error;
            }
            __pyx_L20:;
          }
        }

        /* "cPyparsing.pyx":1072
 *                         del tb
 * 
 *                 if limit <= maxargs:             # <<<<<<<<<<<<<<
 *                     limit += 1
 *                     continue
 */
        if (unlikely(!__pyx_cur_scope->__pyx_v_limit)) { __Pyx_RaiseClosureNameError("limit"); __PYX_ERR(0, 1072, __pyx_L7_except_error) }
        if (unlikely(!__pyx_cur_scope->__pyx_v_maxargs)) { __Pyx_RaiseClosureNameError("maxargs"); __PYX_ERR(0, 1072, __pyx_L7_except_error) }
        __pyx_t_11 = PyObject_RichCompare(__pyx_cur_scope->__pyx_v_limit, __pyx_cur_scope->__pyx_v_maxargs, Py_LE); __Pyx_XGOTREF(__pyx_t_11); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1072, __pyx_L7_except_error)
        __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1072, __pyx_L7_except_error)
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (__pyx_t_9) {

          /* "cPyparsing.pyx":1073
 * 
 *                 if limit <= maxargs:
 *                     limit += 1             # <<<<<<<<<<<<<<
 *                     continue
 *                 raise
 */
          if (unlikely(!__pyx_cur_scope->__pyx_v_limit)) { __Pyx_RaiseClosureNameError("limit"); __PYX_ERR(0, 1073, __pyx_L7_except_error) }
          __pyx_t_11 = __Pyx_PyInt_AddObjC(__pyx_cur_scope->__pyx_v_limit, __pyx_int_1, 1, 1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1073, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_limit);
          __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_limit, __pyx_t_11);
          __Pyx_GIVEREF(__pyx_t_11);
          __pyx_t_11 = 0;

          /* "cPyparsing.pyx":1074
 *                 if limit <= maxargs:
 *                     limit += 1
 *                     continue             # <<<<<<<<<<<<<<
 *                 raise
 * 
 */
          goto __pyx_L14_except_continue;

          /* "cPyparsing.pyx":1072
 *                         del tb
 * 
 *                 if limit <= maxargs:             # <<<<<<<<<<<<<<
 *                     limit += 1
 *                     continue
 */
        }

        /* "cPyparsing.pyx":1075
 *                     limit += 1
 *                     continue
 *                 raise             # <<<<<<<<<<<<<<
 * 
 *     # copy func name to wrapper for sensible debug output
 */
        __Pyx_GIVEREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ErrRestoreWithState(__pyx_t_6, __pyx_t_5, __pyx_t_8);
        __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_8 = 0; 
        __PYX_ERR(0, 1075, __pyx_L7_except_error)
        __pyx_L14_except_continue:;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L11_try_continue;
      }
      goto __pyx_L7_except_error;
      __pyx_L7_except_error:;

      /* "cPyparsing.pyx":1054
 *         nonlocal foundArity, limit
 *         while True:
 *             try:             # <<<<<<<<<<<<<<
 *                 # any changes to the following line must be reflected in wrap_call_line
 *                 ret = func(*args[limit:])
 */
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_1);
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
      goto __pyx_L1_error;
      __pyx_L11_try_continue:;
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_1);
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
      goto __pyx_L3_continue;
      __pyx_L9_try_return:;
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_1);
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
      goto __pyx_L0;
    }
    __pyx_L3_continue:;
  }

  /* "cPyparsing.pyx":1051
 *     tb_info_synth = (_FILE_NAME, _WRAP_CALL_LINE_NUM)
 * 
 *     def wrapper(*args):             # <<<<<<<<<<<<<<
 *         nonlocal foundArity, limit
 *         while True:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("cPyparsing._trim_arity.wrapper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_tb);
  __Pyx_XDECREF(__pyx_v_tb_info);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1027
 * 
 *     if func in singleArgBuiltins:
 *         return lambda s, l, t: func(t)             # <<<<<<<<<<<<<<
 *     limit = 0
 *     foundArity = False
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_11_trim_arity_4lambda10(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_11_trim_arity_4lambda10 = {"lambda10", (PyCFunction)__pyx_pw_10cPyparsing_11_trim_arity_4lambda10, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_11_trim_arity_4lambda10(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda10 (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("lambda10", 1, 3, 3, 1); __PYX_ERR(0, 1027, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("lambda10", 1, 3, 3, 2); __PYX_ERR(0, 1027, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "lambda10") < 0)) __PYX_ERR(0, 1027, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda10", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1027, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing._trim_arity.lambda10", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda10(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda10(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_17__trim_arity *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_17__trim_arity *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("lambda10", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_17__trim_arity *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_v_func)) { __Pyx_RaiseClosureNameError("func"); __PYX_ERR(0, 1027, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_func);
  __pyx_t_2 = __pyx_cur_scope->__pyx_v_func; __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_t); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1027, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_t};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1027, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_t};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1027, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1027, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_v_t);
      __Pyx_GIVEREF(__pyx_v_t);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_t);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1027, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing._trim_arity.lambda10", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1023
 * 
 * 
 * def _trim_arity(func, maxargs=2):             # <<<<<<<<<<<<<<
 *     """decorator to trim function calls to match the arity of the target"""
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_20_trim_arity(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_func, PyObject *__pyx_v_maxargs) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_17__trim_arity *__pyx_cur_scope;
  PyObject *__pyx_v_wrapper = 0;
  PyObject *__pyx_v_func_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  __Pyx_RefNannySetupContext("_trim_arity", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_17__trim_arity *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_17__trim_arity(__pyx_ptype_10cPyparsing___pyx_scope_struct_17__trim_arity, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_17__trim_arity *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1023, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_func = __pyx_v_func;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_func);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_func);
  __pyx_cur_scope->__pyx_v_maxargs = __pyx_v_maxargs;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_maxargs);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_maxargs);

  /* "cPyparsing.pyx":1026
 *     """decorator to trim function calls to match the arity of the target"""
 * 
 *     if func in singleArgBuiltins:             # <<<<<<<<<<<<<<
 *         return lambda s, l, t: func(t)
 *     limit = 0
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_singleArgBuiltins); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_cur_scope->__pyx_v_func, __pyx_t_1, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1026, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":1027
 * 
 *     if func in singleArgBuiltins:
 *         return lambda s, l, t: func(t)             # <<<<<<<<<<<<<<
 *     limit = 0
 *     foundArity = False
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_11_trim_arity_4lambda10, 0, __pyx_n_s_trim_arity_locals_lambda, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1027, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":1026
 *     """decorator to trim function calls to match the arity of the target"""
 * 
 *     if func in singleArgBuiltins:             # <<<<<<<<<<<<<<
 *         return lambda s, l, t: func(t)
 *     limit = 0
 */
  }

  /* "cPyparsing.pyx":1028
 *     if func in singleArgBuiltins:
 *         return lambda s, l, t: func(t)
 *     limit = 0             # <<<<<<<<<<<<<<
 *     foundArity = False
 * 
 */
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __pyx_cur_scope->__pyx_v_limit = __pyx_int_0;

  /* "cPyparsing.pyx":1029
 *         return lambda s, l, t: func(t)
 *     limit = 0
 *     foundArity = False             # <<<<<<<<<<<<<<
 * 
 *     # traceback return data structure changed in Py3.5 - normalize back to plain tuples
 */
  __pyx_cur_scope->__pyx_v_foundArity = 0;

  /* "cPyparsing.pyx":1032
 * 
 *     # traceback return data structure changed in Py3.5 - normalize back to plain tuples
 *     if system_version[:2] >= (3, 5):             # <<<<<<<<<<<<<<
 *         # def extract_stack(limit=None):
 *         #     # special handling for Python 3.5.0 - extra deep call stack by 1
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_system_version); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1032, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_t_1, 0, 2, NULL, NULL, &__pyx_slice__28, 0, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1032, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_t_4, __pyx_tuple__29, Py_GE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1032, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1032, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":1039
 *         #     return [(frame_summary.filename, frame_summary.lineno)]
 * 
 *         def extract_tb(tb, limit=None):             # <<<<<<<<<<<<<<
 *             frames = traceback.extract_tb(tb, limit=limit)
 *             frame_summary = frames[-1]
 */
    __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_11_trim_arity_1extract_tb, 0, __pyx_n_s_trim_arity_locals_extract_tb, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__31)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1039, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__32);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_v_extract_tb = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1032
 * 
 *     # traceback return data structure changed in Py3.5 - normalize back to plain tuples
 *     if system_version[:2] >= (3, 5):             # <<<<<<<<<<<<<<
 *         # def extract_stack(limit=None):
 *         #     # special handling for Python 3.5.0 - extra deep call stack by 1
 */
    goto __pyx_L4;
  }

  /* "cPyparsing.pyx":1045
 *     else:
 *         # extract_stack = traceback.extract_stack
 *         extract_tb = traceback.extract_tb             # <<<<<<<<<<<<<<
 * 
 *     # synthesize what would be returned by traceback.extract_tb at the call to
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_traceback); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_extract_tb); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_cur_scope->__pyx_v_extract_tb = __pyx_t_4;
    __pyx_t_4 = 0;
  }
  __pyx_L4:;

  /* "cPyparsing.pyx":1049
 *     # synthesize what would be returned by traceback.extract_tb at the call to
 *     # user's parse action 'func', so that we don't incur call penalty at parse time
 *     tb_info_synth = (_FILE_NAME, _WRAP_CALL_LINE_NUM)             # <<<<<<<<<<<<<<
 * 
 *     def wrapper(*args):
 */
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_FILE_NAME); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_WRAP_CALL_LINE_NUM); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1);
  __pyx_t_4 = 0;
  __pyx_t_1 = 0;
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_cur_scope->__pyx_v_tb_info_synth = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "cPyparsing.pyx":1051
 *     tb_info_synth = (_FILE_NAME, _WRAP_CALL_LINE_NUM)
 * 
 *     def wrapper(*args):             # <<<<<<<<<<<<<<
 *         nonlocal foundArity, limit
 *         while True:
 */
  __pyx_t_5 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_11_trim_arity_3wrapper, 0, __pyx_n_s_trim_arity_locals_wrapper, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__34)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_wrapper = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "cPyparsing.pyx":1078
 * 
 *     # copy func name to wrapper for sensible debug output
 *     func_name = "<parse action>"             # <<<<<<<<<<<<<<
 *     try:
 *         func_name = getattr(func, '__name__',
 */
  __Pyx_INCREF(__pyx_kp_u_parse_action);
  __pyx_v_func_name = __pyx_kp_u_parse_action;

  /* "cPyparsing.pyx":1079
 *     # copy func name to wrapper for sensible debug output
 *     func_name = "<parse action>"
 *     try:             # <<<<<<<<<<<<<<
 *         func_name = getattr(func, '__name__',
 *                             getattr(func, '__class__').__name__)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    /*try:*/ {

      /* "cPyparsing.pyx":1080
 *     func_name = "<parse action>"
 *     try:
 *         func_name = getattr(func, '__name__',             # <<<<<<<<<<<<<<
 *                             getattr(func, '__class__').__name__)
 *     except Exception:
 */
      __pyx_t_5 = __pyx_cur_scope->__pyx_v_func;
      __Pyx_INCREF(__pyx_t_5);

      /* "cPyparsing.pyx":1081
 *     try:
 *         func_name = getattr(func, '__name__',
 *                             getattr(func, '__class__').__name__)             # <<<<<<<<<<<<<<
 *     except Exception:
 *         func_name = str(func)
 */
      __pyx_t_1 = __pyx_cur_scope->__pyx_v_func;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_GetAttr(__pyx_t_1, __pyx_n_u_class); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1081, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1081, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "cPyparsing.pyx":1080
 *     func_name = "<parse action>"
 *     try:
 *         func_name = getattr(func, '__name__',             # <<<<<<<<<<<<<<
 *                             getattr(func, '__class__').__name__)
 *     except Exception:
 */
      __pyx_t_4 = __Pyx_GetAttr3(__pyx_t_5, __pyx_n_u_name_2, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1080, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF_SET(__pyx_v_func_name, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "cPyparsing.pyx":1079
 *     # copy func name to wrapper for sensible debug output
 *     func_name = "<parse action>"
 *     try:             # <<<<<<<<<<<<<<
 *         func_name = getattr(func, '__name__',
 *                             getattr(func, '__class__').__name__)
 */
    }
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    goto __pyx_L12_try_end;
    __pyx_L5_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":1082
 *         func_name = getattr(func, '__name__',
 *                             getattr(func, '__class__').__name__)
 *     except Exception:             # <<<<<<<<<<<<<<
 *         func_name = str(func)
 *     wrapper.__name__ = py_str(func_name)
 */
    __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_9) {
      __Pyx_AddTraceback("cPyparsing._trim_arity", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_1, &__pyx_t_5) < 0) __PYX_ERR(0, 1082, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_5);

      /* "cPyparsing.pyx":1083
 *                             getattr(func, '__class__').__name__)
 *     except Exception:
 *         func_name = str(func)             # <<<<<<<<<<<<<<
 *     wrapper.__name__ = py_str(func_name)
 * 
 */
      __pyx_t_11 = __Pyx_GetModuleGlobalName(__pyx_n_s_str); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1083, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_12 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_11))) {
        __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
        if (likely(__pyx_t_12)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
          __Pyx_INCREF(__pyx_t_12);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_11, function);
        }
      }
      if (!__pyx_t_12) {
        __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_cur_scope->__pyx_v_func); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1083, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_10);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_11)) {
          PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_cur_scope->__pyx_v_func};
          __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1083, __pyx_L7_except_error)
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_GOTREF(__pyx_t_10);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_11)) {
          PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_cur_scope->__pyx_v_func};
          __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1083, __pyx_L7_except_error)
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_GOTREF(__pyx_t_10);
        } else
        #endif
        {
          __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1083, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_12); __pyx_t_12 = NULL;
          __Pyx_INCREF(__pyx_cur_scope->__pyx_v_func);
          __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_func);
          PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_cur_scope->__pyx_v_func);
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_13, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1083, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF_SET(__pyx_v_func_name, __pyx_t_10);
      __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L6_exception_handled;
    }
    goto __pyx_L7_except_error;
    __pyx_L7_except_error:;

    /* "cPyparsing.pyx":1079
 *     # copy func name to wrapper for sensible debug output
 *     func_name = "<parse action>"
 *     try:             # <<<<<<<<<<<<<<
 *         func_name = getattr(func, '__name__',
 *                             getattr(func, '__class__').__name__)
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    goto __pyx_L1_error;
    __pyx_L6_exception_handled:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    __pyx_L12_try_end:;
  }

  /* "cPyparsing.pyx":1084
 *     except Exception:
 *         func_name = str(func)
 *     wrapper.__name__ = py_str(func_name)             # <<<<<<<<<<<<<<
 * 
 *     return wrapper
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_py_str); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_func_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1084, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_func_name};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1084, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_5);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_func_name};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1084, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_5);
    } else
    #endif
    {
      __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1084, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_INCREF(__pyx_v_func_name);
      __Pyx_GIVEREF(__pyx_v_func_name);
      PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_v_func_name);
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_10, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1084, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_wrapper, __pyx_n_s_name_2, __pyx_t_5) < 0) __PYX_ERR(0, 1084, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cPyparsing.pyx":1086
 *     wrapper.__name__ = py_str(func_name)
 * 
 *     return wrapper             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_wrapper);
  __pyx_r = __pyx_v_wrapper;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1023
 * 
 * 
 * def _trim_arity(func, maxargs=2):             # <<<<<<<<<<<<<<
 *     """decorator to trim function calls to match the arity of the target"""
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("cPyparsing._trim_arity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_wrapper);
  __Pyx_XDECREF(__pyx_v_func_name);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1095
 * 
 *     @staticmethod
 *     def setDefaultWhitespaceChars(chars):             # <<<<<<<<<<<<<<
 *         r"""
 *         Overrides the default whitespace chars
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_1setDefaultWhitespaceChars(PyObject *__pyx_self, PyObject *__pyx_v_chars); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_setDefaultWhitespaceChars[] = "\n        Overrides the default whitespace chars\n\n        Example::\n            # default whitespace chars are space, <TAB> and newline\n            OneOrMore(Word(alphas)).parseString(\"abc def\\nghi jkl\")  # -> ['abc', 'def', 'ghi', 'jkl']\n\n            # change to just treat newline as significant\n            ParserElement.setDefaultWhitespaceChars(\" \\t\")\n            OneOrMore(Word(alphas)).parseString(\"abc def\\nghi jkl\")  # -> ['abc', 'def']\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_1setDefaultWhitespaceChars = {"setDefaultWhitespaceChars", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_1setDefaultWhitespaceChars, METH_O, __pyx_doc_10cPyparsing_13ParserElement_setDefaultWhitespaceChars};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_1setDefaultWhitespaceChars(PyObject *__pyx_self, PyObject *__pyx_v_chars) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setDefaultWhitespaceChars (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_setDefaultWhitespaceChars(__pyx_self, ((PyObject *)__pyx_v_chars));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_setDefaultWhitespaceChars(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_chars) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("setDefaultWhitespaceChars", 0);

  /* "cPyparsing.pyx":1107
 *             OneOrMore(Word(alphas)).parseString("abc def\nghi jkl")  # -> ['abc', 'def']
 *         """
 *         ParserElement.DEFAULT_WHITE_CHARS = chars             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_n_s_DEFAULT_WHITE_CHARS, __pyx_v_chars) < 0) __PYX_ERR(0, 1107, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1095
 * 
 *     @staticmethod
 *     def setDefaultWhitespaceChars(chars):             # <<<<<<<<<<<<<<
 *         r"""
 *         Overrides the default whitespace chars
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParserElement.setDefaultWhitespaceChars", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1110
 * 
 *     @staticmethod
 *     def inlineLiteralsUsing(cls):             # <<<<<<<<<<<<<<
 *         """
 *         Set class to be used for inclusion of string literals into a parser.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_3inlineLiteralsUsing(PyObject *__pyx_self, PyObject *__pyx_v_cls); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_2inlineLiteralsUsing[] = "\n        Set class to be used for inclusion of string literals into a parser.\n\n        Example::\n            # default literal class used is Literal\n            integer = Word(nums)\n            date_str = integer(\"year\") + '/' + integer(\"month\") + '/' + integer(\"day\")\n\n            date_str.parseString(\"1999/12/31\")  # -> ['1999', '/', '12', '/', '31']\n\n\n            # change to Suppress\n            ParserElement.inlineLiteralsUsing(Suppress)\n            date_str = integer(\"year\") + '/' + integer(\"month\") + '/' + integer(\"day\")\n\n            date_str.parseString(\"1999/12/31\")  # -> ['1999', '12', '31']\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_3inlineLiteralsUsing = {"inlineLiteralsUsing", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_3inlineLiteralsUsing, METH_O, __pyx_doc_10cPyparsing_13ParserElement_2inlineLiteralsUsing};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_3inlineLiteralsUsing(PyObject *__pyx_self, PyObject *__pyx_v_cls) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("inlineLiteralsUsing (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_2inlineLiteralsUsing(__pyx_self, ((PyObject *)__pyx_v_cls));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_2inlineLiteralsUsing(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("inlineLiteralsUsing", 0);

  /* "cPyparsing.pyx":1128
 *             date_str.parseString("1999/12/31")  # -> ['1999', '12', '31']
 *         """
 *         ParserElement._literalStringClass = cls             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, savelist=False):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_n_s_literalStringClass, __pyx_v_cls) < 0) __PYX_ERR(0, 1128, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1110
 * 
 *     @staticmethod
 *     def inlineLiteralsUsing(cls):             # <<<<<<<<<<<<<<
 *         """
 *         Set class to be used for inclusion of string literals into a parser.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParserElement.inlineLiteralsUsing", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1130
 *         ParserElement._literalStringClass = cls
 * 
 *     def __init__(self, savelist=False):             # <<<<<<<<<<<<<<
 *         self.parseAction = list()
 *         self.failAction = None
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_5__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_5__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_5__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_5__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_savelist = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_savelist,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)((PyObject *)Py_False));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_savelist);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 1130, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_savelist = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1130, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_4__init__(__pyx_self, __pyx_v_self, __pyx_v_savelist);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_4__init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_savelist) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":1131
 * 
 *     def __init__(self, savelist=False):
 *         self.parseAction = list()             # <<<<<<<<<<<<<<
 *         self.failAction = None
 *         #~ self.name = "<unknown>"  # don't define self.name, let subclasses try/except upcall
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_parseAction, __pyx_t_1) < 0) __PYX_ERR(0, 1131, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1132
 *     def __init__(self, savelist=False):
 *         self.parseAction = list()
 *         self.failAction = None             # <<<<<<<<<<<<<<
 *         #~ self.name = "<unknown>"  # don't define self.name, let subclasses try/except upcall
 *         self.strRepr = None
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_failAction, Py_None) < 0) __PYX_ERR(0, 1132, __pyx_L1_error)

  /* "cPyparsing.pyx":1134
 *         self.failAction = None
 *         #~ self.name = "<unknown>"  # don't define self.name, let subclasses try/except upcall
 *         self.strRepr = None             # <<<<<<<<<<<<<<
 *         self.resultsName = None
 *         self.saveAsList = savelist
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, Py_None) < 0) __PYX_ERR(0, 1134, __pyx_L1_error)

  /* "cPyparsing.pyx":1135
 *         #~ self.name = "<unknown>"  # don't define self.name, let subclasses try/except upcall
 *         self.strRepr = None
 *         self.resultsName = None             # <<<<<<<<<<<<<<
 *         self.saveAsList = savelist
 *         self.skipWhitespace = True
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_resultsName, Py_None) < 0) __PYX_ERR(0, 1135, __pyx_L1_error)

  /* "cPyparsing.pyx":1136
 *         self.strRepr = None
 *         self.resultsName = None
 *         self.saveAsList = savelist             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = True
 *         self.whiteChars = ParserElement.DEFAULT_WHITE_CHARS
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList, __pyx_v_savelist) < 0) __PYX_ERR(0, 1136, __pyx_L1_error)

  /* "cPyparsing.pyx":1137
 *         self.resultsName = None
 *         self.saveAsList = savelist
 *         self.skipWhitespace = True             # <<<<<<<<<<<<<<
 *         self.whiteChars = ParserElement.DEFAULT_WHITE_CHARS
 *         self.copyDefaultWhiteChars = True
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, Py_True) < 0) __PYX_ERR(0, 1137, __pyx_L1_error)

  /* "cPyparsing.pyx":1138
 *         self.saveAsList = savelist
 *         self.skipWhitespace = True
 *         self.whiteChars = ParserElement.DEFAULT_WHITE_CHARS             # <<<<<<<<<<<<<<
 *         self.copyDefaultWhiteChars = True
 *         self.mayReturnEmpty = False  # used when checking for left-recursion
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DEFAULT_WHITE_CHARS); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_whiteChars, __pyx_t_2) < 0) __PYX_ERR(0, 1138, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1139
 *         self.skipWhitespace = True
 *         self.whiteChars = ParserElement.DEFAULT_WHITE_CHARS
 *         self.copyDefaultWhiteChars = True             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = False  # used when checking for left-recursion
 *         self.keepTabs = False
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_copyDefaultWhiteChars, Py_True) < 0) __PYX_ERR(0, 1139, __pyx_L1_error)

  /* "cPyparsing.pyx":1140
 *         self.whiteChars = ParserElement.DEFAULT_WHITE_CHARS
 *         self.copyDefaultWhiteChars = True
 *         self.mayReturnEmpty = False  # used when checking for left-recursion             # <<<<<<<<<<<<<<
 *         self.keepTabs = False
 *         self.ignoreExprs = list()
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_False) < 0) __PYX_ERR(0, 1140, __pyx_L1_error)

  /* "cPyparsing.pyx":1141
 *         self.copyDefaultWhiteChars = True
 *         self.mayReturnEmpty = False  # used when checking for left-recursion
 *         self.keepTabs = False             # <<<<<<<<<<<<<<
 *         self.ignoreExprs = list()
 *         self.debug = False
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_keepTabs, Py_False) < 0) __PYX_ERR(0, 1141, __pyx_L1_error)

  /* "cPyparsing.pyx":1142
 *         self.mayReturnEmpty = False  # used when checking for left-recursion
 *         self.keepTabs = False
 *         self.ignoreExprs = list()             # <<<<<<<<<<<<<<
 *         self.debug = False
 *         self.streamlined = False
 */
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs, __pyx_t_2) < 0) __PYX_ERR(0, 1142, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1143
 *         self.keepTabs = False
 *         self.ignoreExprs = list()
 *         self.debug = False             # <<<<<<<<<<<<<<
 *         self.streamlined = False
 *         self.mayIndexError = True  # used to optimize exception handling for subclasses that don't advance parse index
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_debug, Py_False) < 0) __PYX_ERR(0, 1143, __pyx_L1_error)

  /* "cPyparsing.pyx":1144
 *         self.ignoreExprs = list()
 *         self.debug = False
 *         self.streamlined = False             # <<<<<<<<<<<<<<
 *         self.mayIndexError = True  # used to optimize exception handling for subclasses that don't advance parse index
 *         self.errmsg = ""
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_streamlined, Py_False) < 0) __PYX_ERR(0, 1144, __pyx_L1_error)

  /* "cPyparsing.pyx":1145
 *         self.debug = False
 *         self.streamlined = False
 *         self.mayIndexError = True  # used to optimize exception handling for subclasses that don't advance parse index             # <<<<<<<<<<<<<<
 *         self.errmsg = ""
 *         self.modalResults = True  # used to mark results names as modal (report only last) or cumulative (list all)
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, Py_True) < 0) __PYX_ERR(0, 1145, __pyx_L1_error)

  /* "cPyparsing.pyx":1146
 *         self.streamlined = False
 *         self.mayIndexError = True  # used to optimize exception handling for subclasses that don't advance parse index
 *         self.errmsg = ""             # <<<<<<<<<<<<<<
 *         self.modalResults = True  # used to mark results names as modal (report only last) or cumulative (list all)
 *         self.debugActions = (None, None, None)  # custom debug actions
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_kp_u__9) < 0) __PYX_ERR(0, 1146, __pyx_L1_error)

  /* "cPyparsing.pyx":1147
 *         self.mayIndexError = True  # used to optimize exception handling for subclasses that don't advance parse index
 *         self.errmsg = ""
 *         self.modalResults = True  # used to mark results names as modal (report only last) or cumulative (list all)             # <<<<<<<<<<<<<<
 *         self.debugActions = (None, None, None)  # custom debug actions
 *         self.re = None
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_modalResults, Py_True) < 0) __PYX_ERR(0, 1147, __pyx_L1_error)

  /* "cPyparsing.pyx":1148
 *         self.errmsg = ""
 *         self.modalResults = True  # used to mark results names as modal (report only last) or cumulative (list all)
 *         self.debugActions = (None, None, None)  # custom debug actions             # <<<<<<<<<<<<<<
 *         self.re = None
 *         self.callPreparse = True  # used to avoid redundant calls to preParse
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_debugActions, __pyx_tuple__35) < 0) __PYX_ERR(0, 1148, __pyx_L1_error)

  /* "cPyparsing.pyx":1149
 *         self.modalResults = True  # used to mark results names as modal (report only last) or cumulative (list all)
 *         self.debugActions = (None, None, None)  # custom debug actions
 *         self.re = None             # <<<<<<<<<<<<<<
 *         self.callPreparse = True  # used to avoid redundant calls to preParse
 *         self.callDuringTry = False
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_re, Py_None) < 0) __PYX_ERR(0, 1149, __pyx_L1_error)

  /* "cPyparsing.pyx":1150
 *         self.debugActions = (None, None, None)  # custom debug actions
 *         self.re = None
 *         self.callPreparse = True  # used to avoid redundant calls to preParse             # <<<<<<<<<<<<<<
 *         self.callDuringTry = False
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_callPreparse, Py_True) < 0) __PYX_ERR(0, 1150, __pyx_L1_error)

  /* "cPyparsing.pyx":1151
 *         self.re = None
 *         self.callPreparse = True  # used to avoid redundant calls to preParse
 *         self.callDuringTry = False             # <<<<<<<<<<<<<<
 * 
 *     def copy(self):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_callDuringTry, Py_False) < 0) __PYX_ERR(0, 1151, __pyx_L1_error)

  /* "cPyparsing.pyx":1130
 *         ParserElement._literalStringClass = cls
 * 
 *     def __init__(self, savelist=False):             # <<<<<<<<<<<<<<
 *         self.parseAction = list()
 *         self.failAction = None
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1153
 *         self.callDuringTry = False
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         """
 *         Make a copy of this C{ParserElement}.  Useful for defining different parse actions
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_7copy(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_6copy[] = "\n        Make a copy of this C{ParserElement}.  Useful for defining different parse actions\n        for the same parsing pattern, using copies of the original parse element.\n\n        Example::\n            integer = Word(nums).setParseAction(lambda toks: int(toks[0]))\n            integerK = integer.copy().addParseAction(lambda toks: toks[0]*1024) + Suppress(\"K\")\n            integerM = integer.copy().addParseAction(lambda toks: toks[0]*1024*1024) + Suppress(\"M\")\n\n            print(OneOrMore(integerK | integerM | integer).parseString(\"5K 100 640K 256M\"))\n        prints::\n            [5120, 100, 655360, 268435456]\n        Equivalent form of C{expr.copy()} is just C{expr()}::\n            integerM = integer().addParseAction(lambda toks: toks[0]*1024*1024) + Suppress(\"M\")\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_7copy = {"copy", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_7copy, METH_O, __pyx_doc_10cPyparsing_13ParserElement_6copy};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_7copy(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_6copy(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_6copy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_cpy = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  __Pyx_RefNannySetupContext("copy", 0);

  /* "cPyparsing.pyx":1169
 *             integerM = integer().addParseAction(lambda toks: toks[0]*1024*1024) + Suppress("M")
 *         """
 *         cpy = copy.copy(self)             # <<<<<<<<<<<<<<
 *         cpy.parseAction = self.parseAction[:]
 *         cpy.ignoreExprs = self.ignoreExprs[:]
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_copy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_copy); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1169, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1169, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1169, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1169, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_self);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1169, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_cpy = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1170
 *         """
 *         cpy = copy.copy(self)
 *         cpy.parseAction = self.parseAction[:]             # <<<<<<<<<<<<<<
 *         cpy.ignoreExprs = self.ignoreExprs[:]
 *         if self.copyDefaultWhiteChars:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_1, 0, 0, NULL, NULL, &__pyx_slice__36, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_cpy, __pyx_n_s_parseAction, __pyx_t_3) < 0) __PYX_ERR(0, 1170, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":1171
 *         cpy = copy.copy(self)
 *         cpy.parseAction = self.parseAction[:]
 *         cpy.ignoreExprs = self.ignoreExprs[:]             # <<<<<<<<<<<<<<
 *         if self.copyDefaultWhiteChars:
 *             cpy.whiteChars = ParserElement.DEFAULT_WHITE_CHARS
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_t_3, 0, 0, NULL, NULL, &__pyx_slice__37, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_cpy, __pyx_n_s_ignoreExprs, __pyx_t_1) < 0) __PYX_ERR(0, 1171, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1172
 *         cpy.parseAction = self.parseAction[:]
 *         cpy.ignoreExprs = self.ignoreExprs[:]
 *         if self.copyDefaultWhiteChars:             # <<<<<<<<<<<<<<
 *             cpy.whiteChars = ParserElement.DEFAULT_WHITE_CHARS
 *         return cpy
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_copyDefaultWhiteChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1172, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":1173
 *         cpy.ignoreExprs = self.ignoreExprs[:]
 *         if self.copyDefaultWhiteChars:
 *             cpy.whiteChars = ParserElement.DEFAULT_WHITE_CHARS             # <<<<<<<<<<<<<<
 *         return cpy
 * 
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1173, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DEFAULT_WHITE_CHARS); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1173, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_cpy, __pyx_n_s_whiteChars, __pyx_t_3) < 0) __PYX_ERR(0, 1173, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":1172
 *         cpy.parseAction = self.parseAction[:]
 *         cpy.ignoreExprs = self.ignoreExprs[:]
 *         if self.copyDefaultWhiteChars:             # <<<<<<<<<<<<<<
 *             cpy.whiteChars = ParserElement.DEFAULT_WHITE_CHARS
 *         return cpy
 */
  }

  /* "cPyparsing.pyx":1174
 *         if self.copyDefaultWhiteChars:
 *             cpy.whiteChars = ParserElement.DEFAULT_WHITE_CHARS
 *         return cpy             # <<<<<<<<<<<<<<
 * 
 *     def setName(self, name):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cpy);
  __pyx_r = __pyx_v_cpy;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1153
 *         self.callDuringTry = False
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         """
 *         Make a copy of this C{ParserElement}.  Useful for defining different parse actions
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParserElement.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cpy);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1176
 *         return cpy
 * 
 *     def setName(self, name):             # <<<<<<<<<<<<<<
 *         """
 *         Define name for this expression, makes debugging and exception messages clearer.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_9setName(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_8setName[] = "\n        Define name for this expression, makes debugging and exception messages clearer.\n\n        Example::\n            Word(nums).parseString(\"ABC\")  # -> Exception: Expected W:(0123...) (at char 0), (line:1, col:1)\n            Word(nums).setName(\"integer\").parseString(\"ABC\")  # -> Exception: Expected integer (at char 0), (line:1, col:1)\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_9setName = {"setName", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_9setName, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_8setName};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_9setName(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setName (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_name,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("setName", 1, 2, 2, 1); __PYX_ERR(0, 1176, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "setName") < 0)) __PYX_ERR(0, 1176, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_name = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setName", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1176, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.setName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_8setName(__pyx_self, __pyx_v_self, __pyx_v_name);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_8setName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  __Pyx_RefNannySetupContext("setName", 0);

  /* "cPyparsing.pyx":1184
 *             Word(nums).setName("integer").parseString("ABC")  # -> Exception: Expected integer (at char 0), (line:1, col:1)
 *         """
 *         self.name = name             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected " + self.name
 *         if hasattr(self, "exception"):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name, __pyx_v_name) < 0) __PYX_ERR(0, 1184, __pyx_L1_error)

  /* "cPyparsing.pyx":1185
 *         """
 *         self.name = name
 *         self.errmsg = "Expected " + self.name             # <<<<<<<<<<<<<<
 *         if hasattr(self, "exception"):
 *             self.exception.msg = self.errmsg
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Add(__pyx_kp_u_Expected, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_2) < 0) __PYX_ERR(0, 1185, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1186
 *         self.name = name
 *         self.errmsg = "Expected " + self.name
 *         if hasattr(self, "exception"):             # <<<<<<<<<<<<<<
 *             self.exception.msg = self.errmsg
 *         return self
 */
  __pyx_t_3 = PyObject_HasAttr(__pyx_v_self, __pyx_n_u_exception); if (unlikely(__pyx_t_3 == -1)) __PYX_ERR(0, 1186, __pyx_L1_error)
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":1187
 *         self.errmsg = "Expected " + self.name
 *         if hasattr(self, "exception"):
 *             self.exception.msg = self.errmsg             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1187, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exception); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1187, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_n_s_msg, __pyx_t_2) < 0) __PYX_ERR(0, 1187, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1186
 *         self.name = name
 *         self.errmsg = "Expected " + self.name
 *         if hasattr(self, "exception"):             # <<<<<<<<<<<<<<
 *             self.exception.msg = self.errmsg
 *         return self
 */
  }

  /* "cPyparsing.pyx":1188
 *         if hasattr(self, "exception"):
 *             self.exception.msg = self.errmsg
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def setResultsName(self, name, listAllMatches=False):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1176
 *         return cpy
 * 
 *     def setName(self, name):             # <<<<<<<<<<<<<<
 *         """
 *         Define name for this expression, makes debugging and exception messages clearer.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.ParserElement.setName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1190
 *         return self
 * 
 *     def setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         """
 *         Define name for referencing matching tokens as a nested attribute
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_11setResultsName(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_10setResultsName[] = "\n        Define name for referencing matching tokens as a nested attribute\n        of the returned parse results.\n        NOTE: this returns a *copy* of the original C{ParserElement} object;\n        this is so that the client can define a basic element, such as an\n        integer, and reference it in multiple places with different names.\n\n        You can also set results names using the abbreviated syntax,\n        C{expr(\"name\")} in place of C{expr.setResultsName(\"name\")} -\n        see L{I{__call__}<__call__>}.\n\n        Example::\n            date_str = (integer.setResultsName(\"year\") + '/'\n                        + integer.setResultsName(\"month\") + '/'\n                        + integer.setResultsName(\"day\"))\n\n            # equivalent form:\n            date_str = integer(\"year\") + '/' + integer(\"month\") + '/' + integer(\"day\")\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_11setResultsName = {"setResultsName", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_11setResultsName, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_10setResultsName};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_11setResultsName(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_listAllMatches = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setResultsName (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_name,&__pyx_n_s_listAllMatches,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_False));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("setResultsName", 0, 2, 3, 1); __PYX_ERR(0, 1190, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_listAllMatches);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "setResultsName") < 0)) __PYX_ERR(0, 1190, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_name = values[1];
    __pyx_v_listAllMatches = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setResultsName", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1190, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.setResultsName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_10setResultsName(__pyx_self, __pyx_v_self, __pyx_v_name, __pyx_v_listAllMatches);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_10setResultsName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_listAllMatches) {
  PyObject *__pyx_v_newself = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  __Pyx_RefNannySetupContext("setResultsName", 0);
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_INCREF(__pyx_v_listAllMatches);

  /* "cPyparsing.pyx":1210
 *             date_str = integer("year") + '/' + integer("month") + '/' + integer("day")
 *         """
 *         newself = self.copy()             # <<<<<<<<<<<<<<
 *         if name.endswith("*"):
 *             name = name[:-1]
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_copy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1210, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1210, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_newself = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1211
 *         """
 *         newself = self.copy()
 *         if name.endswith("*"):             # <<<<<<<<<<<<<<
 *             name = name[:-1]
 *             listAllMatches = True
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_name, __pyx_n_s_endswith); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__39, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 1211, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":1212
 *         newself = self.copy()
 *         if name.endswith("*"):
 *             name = name[:-1]             # <<<<<<<<<<<<<<
 *             listAllMatches = True
 *         newself.resultsName = name
 */
    __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_name, 0, -1L, NULL, NULL, &__pyx_slice__40, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_name, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":1213
 *         if name.endswith("*"):
 *             name = name[:-1]
 *             listAllMatches = True             # <<<<<<<<<<<<<<
 *         newself.resultsName = name
 *         newself.modalResults = not listAllMatches
 */
    __Pyx_INCREF(Py_True);
    __Pyx_DECREF_SET(__pyx_v_listAllMatches, Py_True);

    /* "cPyparsing.pyx":1211
 *         """
 *         newself = self.copy()
 *         if name.endswith("*"):             # <<<<<<<<<<<<<<
 *             name = name[:-1]
 *             listAllMatches = True
 */
  }

  /* "cPyparsing.pyx":1214
 *             name = name[:-1]
 *             listAllMatches = True
 *         newself.resultsName = name             # <<<<<<<<<<<<<<
 *         newself.modalResults = not listAllMatches
 *         return newself
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_newself, __pyx_n_s_resultsName, __pyx_v_name) < 0) __PYX_ERR(0, 1214, __pyx_L1_error)

  /* "cPyparsing.pyx":1215
 *             listAllMatches = True
 *         newself.resultsName = name
 *         newself.modalResults = not listAllMatches             # <<<<<<<<<<<<<<
 *         return newself
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_listAllMatches); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 1215, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong((!__pyx_t_4)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_newself, __pyx_n_s_modalResults, __pyx_t_2) < 0) __PYX_ERR(0, 1215, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1216
 *         newself.resultsName = name
 *         newself.modalResults = not listAllMatches
 *         return newself             # <<<<<<<<<<<<<<
 * 
 *     def setBreak(self, breakFlag=True):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_newself);
  __pyx_r = __pyx_v_newself;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1190
 *         return self
 * 
 *     def setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         """
 *         Define name for referencing matching tokens as a nested attribute
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParserElement.setResultsName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_newself);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_listAllMatches);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1218
 *         return newself
 * 
 *     def setBreak(self, breakFlag=True):             # <<<<<<<<<<<<<<
 *         """Method to invoke the Python pdb debugger when this element is
 *            about to be parsed. Set C{breakFlag} to True to enable, False to
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_13setBreak(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_12setBreak[] = "Method to invoke the Python pdb debugger when this element is\n           about to be parsed. Set C{breakFlag} to True to enable, False to\n           disable.\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_13setBreak = {"setBreak", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_13setBreak, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_12setBreak};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_13setBreak(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_breakFlag = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setBreak (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_breakFlag,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_breakFlag);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "setBreak") < 0)) __PYX_ERR(0, 1218, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_breakFlag = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setBreak", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1218, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.setBreak", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_12setBreak(__pyx_self, __pyx_v_self, __pyx_v_breakFlag);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1226
 *             _parseMethod = self._parse
 * 
 *             def breaker(instring, loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *                 import pdb
 *                 pdb.set_trace()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_8setBreak_1breaker(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_8setBreak_1breaker = {"breaker", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_8setBreak_1breaker, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_8setBreak_1breaker(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_v_callPreParse = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("breaker (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,&__pyx_n_s_callPreParse,0};
    PyObject* values[4] = {0,0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_True));
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("breaker", 0, 2, 4, 1); __PYX_ERR(0, 1226, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_callPreParse);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "breaker") < 0)) __PYX_ERR(0, 1226, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_instring = values[0];
    __pyx_v_loc = values[1];
    __pyx_v_doActions = values[2];
    __pyx_v_callPreParse = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("breaker", 0, 2, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1226, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.setBreak.breaker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_8setBreak_breaker(__pyx_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions, __pyx_v_callPreParse);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_8setBreak_breaker(PyObject *__pyx_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc, PyObject *__pyx_v_doActions, PyObject *__pyx_v_callPreParse) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_setBreak *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_setBreak *__pyx_outer_scope;
  PyObject *__pyx_v_pdb = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("breaker", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_setBreak *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":1227
 * 
 *             def breaker(instring, loc, doActions=True, callPreParse=True):
 *                 import pdb             # <<<<<<<<<<<<<<
 *                 pdb.set_trace()
 *                 return _parseMethod(instring, loc, doActions, callPreParse)
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_pdb, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pdb = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1228
 *             def breaker(instring, loc, doActions=True, callPreParse=True):
 *                 import pdb
 *                 pdb.set_trace()             # <<<<<<<<<<<<<<
 *                 return _parseMethod(instring, loc, doActions, callPreParse)
 *             breaker._originalParseMethod = _parseMethod
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_pdb, __pyx_n_s_set_trace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1228, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1228, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1229
 *                 import pdb
 *                 pdb.set_trace()
 *                 return _parseMethod(instring, loc, doActions, callPreParse)             # <<<<<<<<<<<<<<
 *             breaker._originalParseMethod = _parseMethod
 *             self._parse = breaker
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_v__parseMethod)) { __Pyx_RaiseClosureNameError("_parseMethod"); __PYX_ERR(0, 1229, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v__parseMethod);
  __pyx_t_2 = __pyx_cur_scope->__pyx_v__parseMethod; __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[5] = {__pyx_t_3, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions, __pyx_v_callPreParse};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 4+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1229, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[5] = {__pyx_t_3, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions, __pyx_v_callPreParse};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 4+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1229, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(4+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1229, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_instring);
    __Pyx_GIVEREF(__pyx_v_instring);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_instring);
    __Pyx_INCREF(__pyx_v_loc);
    __Pyx_GIVEREF(__pyx_v_loc);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_loc);
    __Pyx_INCREF(__pyx_v_doActions);
    __Pyx_GIVEREF(__pyx_v_doActions);
    PyTuple_SET_ITEM(__pyx_t_5, 2+__pyx_t_4, __pyx_v_doActions);
    __Pyx_INCREF(__pyx_v_callPreParse);
    __Pyx_GIVEREF(__pyx_v_callPreParse);
    PyTuple_SET_ITEM(__pyx_t_5, 3+__pyx_t_4, __pyx_v_callPreParse);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1229, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1226
 *             _parseMethod = self._parse
 * 
 *             def breaker(instring, loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *                 import pdb
 *                 pdb.set_trace()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ParserElement.setBreak.breaker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pdb);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1218
 *         return newself
 * 
 *     def setBreak(self, breakFlag=True):             # <<<<<<<<<<<<<<
 *         """Method to invoke the Python pdb debugger when this element is
 *            about to be parsed. Set C{breakFlag} to True to enable, False to
 */

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_12setBreak(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_breakFlag) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_setBreak *__pyx_cur_scope;
  PyObject *__pyx_v_breaker = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("setBreak", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_setBreak *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_18_setBreak(__pyx_ptype_10cPyparsing___pyx_scope_struct_18_setBreak, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_setBreak *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1218, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }

  /* "cPyparsing.pyx":1223
 *            disable.
 *         """
 *         if breakFlag:             # <<<<<<<<<<<<<<
 *             _parseMethod = self._parse
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_breakFlag); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 1223, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":1224
 *         """
 *         if breakFlag:
 *             _parseMethod = self._parse             # <<<<<<<<<<<<<<
 * 
 *             def breaker(instring, loc, doActions=True, callPreParse=True):
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1224, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_cur_scope->__pyx_v__parseMethod = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":1226
 *             _parseMethod = self._parse
 * 
 *             def breaker(instring, loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *                 import pdb
 *                 pdb.set_trace()
 */
    __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_8setBreak_1breaker, 0, __pyx_n_s_ParserElement_setBreak_locals_br, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__42)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1226, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__43);
    __pyx_v_breaker = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":1230
 *                 pdb.set_trace()
 *                 return _parseMethod(instring, loc, doActions, callPreParse)
 *             breaker._originalParseMethod = _parseMethod             # <<<<<<<<<<<<<<
 *             self._parse = breaker
 *         else:
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_breaker, __pyx_n_s_originalParseMethod, __pyx_cur_scope->__pyx_v__parseMethod) < 0) __PYX_ERR(0, 1230, __pyx_L1_error)

    /* "cPyparsing.pyx":1231
 *                 return _parseMethod(instring, loc, doActions, callPreParse)
 *             breaker._originalParseMethod = _parseMethod
 *             self._parse = breaker             # <<<<<<<<<<<<<<
 *         else:
 *             if hasattr(self._parse, "_originalParseMethod"):
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_parse, __pyx_v_breaker) < 0) __PYX_ERR(0, 1231, __pyx_L1_error)

    /* "cPyparsing.pyx":1223
 *            disable.
 *         """
 *         if breakFlag:             # <<<<<<<<<<<<<<
 *             _parseMethod = self._parse
 * 
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":1233
 *             self._parse = breaker
 *         else:
 *             if hasattr(self._parse, "_originalParseMethod"):             # <<<<<<<<<<<<<<
 *                 self._parse = self._parse._originalParseMethod
 *         return self
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1233, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyObject_HasAttr(__pyx_t_2, __pyx_n_u_originalParseMethod); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 1233, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_3 = (__pyx_t_1 != 0);
    if (__pyx_t_3) {

      /* "cPyparsing.pyx":1234
 *         else:
 *             if hasattr(self._parse, "_originalParseMethod"):
 *                 self._parse = self._parse._originalParseMethod             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1234, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_originalParseMethod); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1234, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_parse, __pyx_t_4) < 0) __PYX_ERR(0, 1234, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "cPyparsing.pyx":1233
 *             self._parse = breaker
 *         else:
 *             if hasattr(self._parse, "_originalParseMethod"):             # <<<<<<<<<<<<<<
 *                 self._parse = self._parse._originalParseMethod
 *         return self
 */
    }
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":1235
 *             if hasattr(self._parse, "_originalParseMethod"):
 *                 self._parse = self._parse._originalParseMethod
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def setParseAction(self, *fns, **kwargs):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1218
 *         return newself
 * 
 *     def setBreak(self, breakFlag=True):             # <<<<<<<<<<<<<<
 *         """Method to invoke the Python pdb debugger when this element is
 *            about to be parsed. Set C{breakFlag} to True to enable, False to
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParserElement.setBreak", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_breaker);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1237
 *         return self
 * 
 *     def setParseAction(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Define one or more actions to perform when successfully matching parse element definition.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_15setParseAction(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_14setParseAction[] = "\n        Define one or more actions to perform when successfully matching parse element definition.\n        Parse action fn is a callable method with 0-3 arguments, called as C{fn(s,loc,toks)},\n        C{fn(loc,toks)}, C{fn(toks)}, or just C{fn()}, where:\n         - s   = the original string being parsed (see note below)\n         - loc = the location of the matching substring\n         - toks = a list of the matched tokens, packaged as a C{L{ParseResults}} object\n        If the functions in fns modify the tokens, they can return them as the return\n        value from fn, and the modified list of tokens will replace the original.\n        Otherwise, fn does not need to return any value.\n\n        Optional keyword arguments:\n         - callDuringTry = (default=C{False}) indicate if parse action should be run during lookaheads and alternate testing\n\n        Note: the default parsing behavior is to expand tabs in the input string\n        before starting the parsing process.  See L{I{parseString}<parseString>} for more information\n        on parsing strings containing C{<TAB>}s, and suggested methods to maintain a\n        consistent view of the parsed string, the parse location, and line and column\n        positions within the parsed string.\n\n        Example::\n            integer = Word(nums)\n            date_str = integer + '/' + integer + '/' + integer\n\n            date_str.parseString(\"1999/12/31\")  # -> ['1999', '/', '12', '/', '31']\n\n            # use parse action to convert to ints at parse time\n            integer = Word(nums).setParseAction(lambda toks: int(toks[0]))\n            date_str = integer + '/' + integer + '/' + integer\n\n            # note that integer fields are now ints, not strings\n            date_str.parseString(\"1999/12/31\")  # -> [1999, '/', 12, '/', 31]\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_15setParseAction = {"setParseAction", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_15setParseAction, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_14setParseAction};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_15setParseAction(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_fns = 0;
  PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setParseAction (wrapper)", 0);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  if (PyTuple_GET_SIZE(__pyx_args) > 1) {
    __pyx_v_fns = PyTuple_GetSlice(__pyx_args, 1, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v_fns)) {
      __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
      __Pyx_RefNannyFinishContext();
      return NULL;
    }
    __Pyx_GOTREF(__pyx_v_fns);
  } else {
    __pyx_v_fns = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 1) ? pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, __pyx_v_kwargs, values, used_pos_args, "setParseAction") < 0)) __PYX_ERR(0, 1237, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setParseAction", 0, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1237, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_fns); __pyx_v_fns = 0;
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("cPyparsing.ParserElement.setParseAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_14setParseAction(__pyx_self, __pyx_v_self, __pyx_v_fns, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_fns);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_14setParseAction(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_fns, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("setParseAction", 0);

  /* "cPyparsing.pyx":1271
 *             date_str.parseString("1999/12/31")  # -> [1999, '/', 12, '/', 31]
 *         """
 *         self.parseAction = list(map(_trim_arity, list(fns)))             # <<<<<<<<<<<<<<
 *         self.callDuringTry = kwargs.get("callDuringTry", False)
 *         return self
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_trim_arity); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PySequence_List(__pyx_v_fns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_map, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PySequence_List(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_parseAction, __pyx_t_3) < 0) __PYX_ERR(0, 1271, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":1272
 *         """
 *         self.parseAction = list(map(_trim_arity, list(fns)))
 *         self.callDuringTry = kwargs.get("callDuringTry", False)             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  __pyx_t_3 = __Pyx_PyDict_GetItemDefault(__pyx_v_kwargs, __pyx_n_u_callDuringTry, Py_False); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_callDuringTry, __pyx_t_3) < 0) __PYX_ERR(0, 1272, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":1273
 *         self.parseAction = list(map(_trim_arity, list(fns)))
 *         self.callDuringTry = kwargs.get("callDuringTry", False)
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def addParseAction(self, *fns, **kwargs):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1237
 *         return self
 * 
 *     def setParseAction(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Define one or more actions to perform when successfully matching parse element definition.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParserElement.setParseAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1275
 *         return self
 * 
 *     def addParseAction(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Add one or more parse actions to expression's list of parse actions. See L{I{setParseAction}<setParseAction>}.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_17addParseAction(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_16addParseAction[] = "\n        Add one or more parse actions to expression's list of parse actions. See L{I{setParseAction}<setParseAction>}.\n\n        See examples in L{I{copy}<copy>}.\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_17addParseAction = {"addParseAction", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_17addParseAction, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_16addParseAction};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_17addParseAction(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_fns = 0;
  PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("addParseAction (wrapper)", 0);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  if (PyTuple_GET_SIZE(__pyx_args) > 1) {
    __pyx_v_fns = PyTuple_GetSlice(__pyx_args, 1, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v_fns)) {
      __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
      __Pyx_RefNannyFinishContext();
      return NULL;
    }
    __Pyx_GOTREF(__pyx_v_fns);
  } else {
    __pyx_v_fns = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 1) ? pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, __pyx_v_kwargs, values, used_pos_args, "addParseAction") < 0)) __PYX_ERR(0, 1275, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("addParseAction", 0, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1275, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_fns); __pyx_v_fns = 0;
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("cPyparsing.ParserElement.addParseAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_16addParseAction(__pyx_self, __pyx_v_self, __pyx_v_fns, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_fns);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_16addParseAction(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_fns, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  __Pyx_RefNannySetupContext("addParseAction", 0);

  /* "cPyparsing.pyx":1281
 *         See examples in L{I{copy}<copy>}.
 *         """
 *         self.parseAction += list(map(_trim_arity, list(fns)))             # <<<<<<<<<<<<<<
 *         self.callDuringTry = self.callDuringTry or kwargs.get("callDuringTry", False)
 *         return self
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_trim_arity); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PySequence_List(__pyx_v_fns); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3);
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_map, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PySequence_List(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_parseAction, __pyx_t_3) < 0) __PYX_ERR(0, 1281, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":1282
 *         """
 *         self.parseAction += list(map(_trim_arity, list(fns)))
 *         self.callDuringTry = self.callDuringTry or kwargs.get("callDuringTry", False)             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_callDuringTry); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1282, __pyx_L1_error)
  if (!__pyx_t_5) {
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_3 = __pyx_t_4;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyDict_GetItemDefault(__pyx_v_kwargs, __pyx_n_u_callDuringTry, Py_False); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_3 = __pyx_t_4;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_L3_bool_binop_done:;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_callDuringTry, __pyx_t_3) < 0) __PYX_ERR(0, 1282, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":1283
 *         self.parseAction += list(map(_trim_arity, list(fns)))
 *         self.callDuringTry = self.callDuringTry or kwargs.get("callDuringTry", False)
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def addCondition(self, *fns, **kwargs):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1275
 *         return self
 * 
 *     def addParseAction(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Add one or more parse actions to expression's list of parse actions. See L{I{setParseAction}<setParseAction>}.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParserElement.addParseAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1285
 *         return self
 * 
 *     def addCondition(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """Add a boolean predicate function to expression's list of parse actions. See
 *         L{I{setParseAction}<setParseAction>} for function call signatures. Unlike C{setParseAction},
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_19addCondition(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_18addCondition[] = "Add a boolean predicate function to expression's list of parse actions. See\n        L{I{setParseAction}<setParseAction>} for function call signatures. Unlike C{setParseAction},\n        functions passed to C{addCondition} need to return boolean success/fail of the condition.\n\n        Optional keyword arguments:\n         - message = define a custom message to be used in the raised exception\n         - fatal   = if True, will raise ParseFatalException to stop parsing immediately; otherwise will raise ParseException\n\n        Example::\n            integer = Word(nums).setParseAction(lambda toks: int(toks[0]))\n            year_int = integer.copy()\n            year_int.addCondition(lambda toks: toks[0] >= 2000, message=\"Only support years 2000 and later\")\n            date_str = year_int + '/' + integer + '/' + integer\n\n            result = date_str.parseString(\"1999/12/31\")  # -> Exception: Only support years 2000 and later (at char 0), (line:1, col:1)\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_19addCondition = {"addCondition", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_19addCondition, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_18addCondition};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_19addCondition(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_fns = 0;
  PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("addCondition (wrapper)", 0);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  if (PyTuple_GET_SIZE(__pyx_args) > 1) {
    __pyx_v_fns = PyTuple_GetSlice(__pyx_args, 1, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v_fns)) {
      __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
      __Pyx_RefNannyFinishContext();
      return NULL;
    }
    __Pyx_GOTREF(__pyx_v_fns);
  } else {
    __pyx_v_fns = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 1) ? pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, __pyx_v_kwargs, values, used_pos_args, "addCondition") < 0)) __PYX_ERR(0, 1285, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("addCondition", 0, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1285, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_fns); __pyx_v_fns = 0;
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("cPyparsing.ParserElement.addCondition", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_18addCondition(__pyx_self, __pyx_v_self, __pyx_v_fns, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_fns);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1305
 *         exc_type = ParseFatalException if kwargs.get("fatal", False) else ParseException
 *         for fn in fns:
 *             def pa(s, l, t):             # <<<<<<<<<<<<<<
 *                 if not bool(_trim_arity(fn)(s, l, t)):
 *                     raise exc_type(s, l, msg)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_12addCondition_1pa(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_12addCondition_1pa = {"pa", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_12addCondition_1pa, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_12addCondition_1pa(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_s = 0;
  PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pa (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pa", 1, 3, 3, 1); __PYX_ERR(0, 1305, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pa", 1, 3, 3, 2); __PYX_ERR(0, 1305, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "pa") < 0)) __PYX_ERR(0, 1305, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pa", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1305, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.addCondition.pa", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_12addCondition_pa(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_12addCondition_pa(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_addCondition *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_addCondition *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  __Pyx_RefNannySetupContext("pa", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_addCondition *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":1306
 *         for fn in fns:
 *             def pa(s, l, t):
 *                 if not bool(_trim_arity(fn)(s, l, t)):             # <<<<<<<<<<<<<<
 *                     raise exc_type(s, l, msg)
 *             self.parseAction.append(pa)
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_trim_arity); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (unlikely(!__pyx_cur_scope->__pyx_v_fn)) { __Pyx_RaiseClosureNameError("fn"); __PYX_ERR(0, 1306, __pyx_L1_error) }
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_cur_scope->__pyx_v_fn); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1306, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_cur_scope->__pyx_v_fn};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1306, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_cur_scope->__pyx_v_fn};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1306, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1306, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_fn);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_fn);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_cur_scope->__pyx_v_fn);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1306, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[4] = {__pyx_t_3, __pyx_v_s, __pyx_v_l, __pyx_v_t};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1306, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[4] = {__pyx_t_3, __pyx_v_s, __pyx_v_l, __pyx_v_t};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1306, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(3+__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1306, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_s);
    __Pyx_GIVEREF(__pyx_v_s);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_6, __pyx_v_s);
    __Pyx_INCREF(__pyx_v_l);
    __Pyx_GIVEREF(__pyx_v_l);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_6, __pyx_v_l);
    __Pyx_INCREF(__pyx_v_t);
    __Pyx_GIVEREF(__pyx_v_t);
    PyTuple_SET_ITEM(__pyx_t_5, 2+__pyx_t_6, __pyx_v_t);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1306, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 1306, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_8 = ((!((!(!__pyx_t_7)) != 0)) != 0);
  if (__pyx_t_8) {

    /* "cPyparsing.pyx":1307
 *             def pa(s, l, t):
 *                 if not bool(_trim_arity(fn)(s, l, t)):
 *                     raise exc_type(s, l, msg)             # <<<<<<<<<<<<<<
 *             self.parseAction.append(pa)
 *         self.callDuringTry = self.callDuringTry or kwargs.get("callDuringTry", False)
 */
    if (unlikely(!__pyx_cur_scope->__pyx_v_exc_type)) { __Pyx_RaiseClosureNameError("exc_type"); __PYX_ERR(0, 1307, __pyx_L1_error) }
    if (unlikely(!__pyx_cur_scope->__pyx_v_msg)) { __Pyx_RaiseClosureNameError("msg"); __PYX_ERR(0, 1307, __pyx_L1_error) }
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_exc_type);
    __pyx_t_2 = __pyx_cur_scope->__pyx_v_exc_type; __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_6 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_v_s, __pyx_v_l, __pyx_cur_scope->__pyx_v_msg};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1307, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_v_s, __pyx_v_l, __pyx_cur_scope->__pyx_v_msg};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1307, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_3 = PyTuple_New(3+__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1307, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (__pyx_t_5) {
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5); __pyx_t_5 = NULL;
      }
      __Pyx_INCREF(__pyx_v_s);
      __Pyx_GIVEREF(__pyx_v_s);
      PyTuple_SET_ITEM(__pyx_t_3, 0+__pyx_t_6, __pyx_v_s);
      __Pyx_INCREF(__pyx_v_l);
      __Pyx_GIVEREF(__pyx_v_l);
      PyTuple_SET_ITEM(__pyx_t_3, 1+__pyx_t_6, __pyx_v_l);
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_msg);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_msg);
      PyTuple_SET_ITEM(__pyx_t_3, 2+__pyx_t_6, __pyx_cur_scope->__pyx_v_msg);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1307, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1307, __pyx_L1_error)

    /* "cPyparsing.pyx":1306
 *         for fn in fns:
 *             def pa(s, l, t):
 *                 if not bool(_trim_arity(fn)(s, l, t)):             # <<<<<<<<<<<<<<
 *                     raise exc_type(s, l, msg)
 *             self.parseAction.append(pa)
 */
  }

  /* "cPyparsing.pyx":1305
 *         exc_type = ParseFatalException if kwargs.get("fatal", False) else ParseException
 *         for fn in fns:
 *             def pa(s, l, t):             # <<<<<<<<<<<<<<
 *                 if not bool(_trim_arity(fn)(s, l, t)):
 *                     raise exc_type(s, l, msg)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ParserElement.addCondition.pa", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1285
 *         return self
 * 
 *     def addCondition(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """Add a boolean predicate function to expression's list of parse actions. See
 *         L{I{setParseAction}<setParseAction>} for function call signatures. Unlike C{setParseAction},
 */

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_18addCondition(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_fns, PyObject *__pyx_v_kwargs) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_addCondition *__pyx_cur_scope;
  PyObject *__pyx_v_pa = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  __Pyx_RefNannySetupContext("addCondition", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_addCondition *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_19_addCondition(__pyx_ptype_10cPyparsing___pyx_scope_struct_19_addCondition, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_addCondition *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1285, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }

  /* "cPyparsing.pyx":1302
 *             result = date_str.parseString("1999/12/31")  # -> Exception: Only support years 2000 and later (at char 0), (line:1, col:1)
 *         """
 *         msg = kwargs.get("message", "failed user-defined condition")             # <<<<<<<<<<<<<<
 *         exc_type = ParseFatalException if kwargs.get("fatal", False) else ParseException
 *         for fn in fns:
 */
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_kwargs, __pyx_n_u_message, __pyx_kp_u_failed_user_defined_condition); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_msg = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1303
 *         """
 *         msg = kwargs.get("message", "failed user-defined condition")
 *         exc_type = ParseFatalException if kwargs.get("fatal", False) else ParseException             # <<<<<<<<<<<<<<
 *         for fn in fns:
 *             def pa(s, l, t):
 */
  __pyx_t_2 = __Pyx_PyDict_GetItemDefault(__pyx_v_kwargs, __pyx_n_u_fatal, Py_False); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1303, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseFatalException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1303, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __pyx_t_2;
    __pyx_t_2 = 0;
  } else {
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1303, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_exc_type = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1304
 *         msg = kwargs.get("message", "failed user-defined condition")
 *         exc_type = ParseFatalException if kwargs.get("fatal", False) else ParseException
 *         for fn in fns:             # <<<<<<<<<<<<<<
 *             def pa(s, l, t):
 *                 if not bool(_trim_arity(fn)(s, l, t)):
 */
  __pyx_t_1 = __pyx_v_fns; __Pyx_INCREF(__pyx_t_1); __pyx_t_4 = 0;
  for (;;) {
    if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 1304, __pyx_L1_error)
    #else
    __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1304, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_fn);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_fn, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":1305
 *         exc_type = ParseFatalException if kwargs.get("fatal", False) else ParseException
 *         for fn in fns:
 *             def pa(s, l, t):             # <<<<<<<<<<<<<<
 *                 if not bool(_trim_arity(fn)(s, l, t)):
 *                     raise exc_type(s, l, msg)
 */
    __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_12addCondition_1pa, 0, __pyx_n_s_ParserElement_addCondition_local, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__45)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1305, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_pa, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":1308
 *                 if not bool(_trim_arity(fn)(s, l, t)):
 *                     raise exc_type(s, l, msg)
 *             self.parseAction.append(pa)             # <<<<<<<<<<<<<<
 *         self.callDuringTry = self.callDuringTry or kwargs.get("callDuringTry", False)
 *         return self
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1308, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_Append(__pyx_t_2, __pyx_v_pa); if (unlikely(__pyx_t_5 == -1)) __PYX_ERR(0, 1308, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":1304
 *         msg = kwargs.get("message", "failed user-defined condition")
 *         exc_type = ParseFatalException if kwargs.get("fatal", False) else ParseException
 *         for fn in fns:             # <<<<<<<<<<<<<<
 *             def pa(s, l, t):
 *                 if not bool(_trim_arity(fn)(s, l, t)):
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1309
 *                     raise exc_type(s, l, msg)
 *             self.parseAction.append(pa)
 *         self.callDuringTry = self.callDuringTry or kwargs.get("callDuringTry", False)             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_callDuringTry); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1309, __pyx_L1_error)
  if (!__pyx_t_3) {
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_1 = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyDict_GetItemDefault(__pyx_v_kwargs, __pyx_n_u_callDuringTry, Py_False); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_1 = __pyx_t_2;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_L5_bool_binop_done:;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_callDuringTry, __pyx_t_1) < 0) __PYX_ERR(0, 1309, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1310
 *             self.parseAction.append(pa)
 *         self.callDuringTry = self.callDuringTry or kwargs.get("callDuringTry", False)
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def setFailAction(self, fn):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1285
 *         return self
 * 
 *     def addCondition(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """Add a boolean predicate function to expression's list of parse actions. See
 *         L{I{setParseAction}<setParseAction>} for function call signatures. Unlike C{setParseAction},
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.ParserElement.addCondition", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pa);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1312
 *         return self
 * 
 *     def setFailAction(self, fn):             # <<<<<<<<<<<<<<
 *         """Define action to perform if parsing fails at this expression.
 *            Fail acton fn is a callable function that takes the arguments
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_21setFailAction(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_20setFailAction[] = "Define action to perform if parsing fails at this expression.\n           Fail acton fn is a callable function that takes the arguments\n           C{fn(s,loc,expr,err)} where:\n            - s = string being parsed\n            - loc = location where expression match was attempted and failed\n            - expr = the parse expression that failed\n            - err = the exception thrown\n           The function returns no value.  It may throw C{L{ParseFatalException}}\n           if it is desired to stop parsing immediately.";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_21setFailAction = {"setFailAction", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_21setFailAction, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_20setFailAction};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_21setFailAction(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_fn = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setFailAction (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_fn,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_fn)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("setFailAction", 1, 2, 2, 1); __PYX_ERR(0, 1312, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "setFailAction") < 0)) __PYX_ERR(0, 1312, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_fn = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setFailAction", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1312, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.setFailAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_20setFailAction(__pyx_self, __pyx_v_self, __pyx_v_fn);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_20setFailAction(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_fn) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setFailAction", 0);

  /* "cPyparsing.pyx":1322
 *            The function returns no value.  It may throw C{L{ParseFatalException}}
 *            if it is desired to stop parsing immediately."""
 *         self.failAction = fn             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_failAction, __pyx_v_fn) < 0) __PYX_ERR(0, 1322, __pyx_L1_error)

  /* "cPyparsing.pyx":1323
 *            if it is desired to stop parsing immediately."""
 *         self.failAction = fn
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def _skipIgnorables(self, instring, loc):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1312
 *         return self
 * 
 *     def setFailAction(self, fn):             # <<<<<<<<<<<<<<
 *         """Define action to perform if parsing fails at this expression.
 *            Fail acton fn is a callable function that takes the arguments
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.setFailAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1325
 *         return self
 * 
 *     def _skipIgnorables(self, instring, loc):             # <<<<<<<<<<<<<<
 *         exprsFound = True
 *         while exprsFound:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_23_skipIgnorables(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_23_skipIgnorables = {"_skipIgnorables", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_23_skipIgnorables, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_23_skipIgnorables(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_skipIgnorables (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_skipIgnorables", 1, 3, 3, 1); __PYX_ERR(0, 1325, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_skipIgnorables", 1, 3, 3, 2); __PYX_ERR(0, 1325, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "_skipIgnorables") < 0)) __PYX_ERR(0, 1325, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_skipIgnorables", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1325, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement._skipIgnorables", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_22_skipIgnorables(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_22_skipIgnorables(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_loc) {
  int __pyx_v_exprsFound;
  PyObject *__pyx_v_e = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_dummy = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *(*__pyx_t_13)(PyObject *);
  __Pyx_RefNannySetupContext("_skipIgnorables", 0);
  __Pyx_INCREF(__pyx_v_loc);

  /* "cPyparsing.pyx":1326
 * 
 *     def _skipIgnorables(self, instring, loc):
 *         exprsFound = True             # <<<<<<<<<<<<<<
 *         while exprsFound:
 *             exprsFound = False
 */
  __pyx_v_exprsFound = 1;

  /* "cPyparsing.pyx":1327
 *     def _skipIgnorables(self, instring, loc):
 *         exprsFound = True
 *         while exprsFound:             # <<<<<<<<<<<<<<
 *             exprsFound = False
 *             for e in self.ignoreExprs:
 */
  while (1) {
    __pyx_t_1 = (__pyx_v_exprsFound != 0);
    if (!__pyx_t_1) break;

    /* "cPyparsing.pyx":1328
 *         exprsFound = True
 *         while exprsFound:
 *             exprsFound = False             # <<<<<<<<<<<<<<
 *             for e in self.ignoreExprs:
 *                 try:
 */
    __pyx_v_exprsFound = 0;

    /* "cPyparsing.pyx":1329
 *         while exprsFound:
 *             exprsFound = False
 *             for e in self.ignoreExprs:             # <<<<<<<<<<<<<<
 *                 try:
 *                     while True:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
      __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
      __pyx_t_5 = NULL;
    } else {
      __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1329, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1329, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (likely(!__pyx_t_5)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_3)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 1329, __pyx_L1_error)
          #else
          __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1329, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 1329, __pyx_L1_error)
          #else
          __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1329, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        }
      } else {
        __pyx_t_2 = __pyx_t_5(__pyx_t_3);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 1329, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "cPyparsing.pyx":1330
 *             exprsFound = False
 *             for e in self.ignoreExprs:
 *                 try:             # <<<<<<<<<<<<<<
 *                     while True:
 *                         loc, dummy = e._parse(instring, loc)
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_8);
        /*try:*/ {

          /* "cPyparsing.pyx":1331
 *             for e in self.ignoreExprs:
 *                 try:
 *                     while True:             # <<<<<<<<<<<<<<
 *                         loc, dummy = e._parse(instring, loc)
 *                         exprsFound = True
 */
          while (1) {

            /* "cPyparsing.pyx":1332
 *                 try:
 *                     while True:
 *                         loc, dummy = e._parse(instring, loc)             # <<<<<<<<<<<<<<
 *                         exprsFound = True
 *                 except ParseException:
 */
            __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_parse); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1332, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_9);
            __pyx_t_10 = NULL;
            __pyx_t_11 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
              __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
              if (likely(__pyx_t_10)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
                __Pyx_INCREF(__pyx_t_10);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_9, function);
                __pyx_t_11 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_v_instring, __pyx_v_loc};
              __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1332, __pyx_L7_error)
              __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_GOTREF(__pyx_t_2);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_v_instring, __pyx_v_loc};
              __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1332, __pyx_L7_error)
              __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_GOTREF(__pyx_t_2);
            } else
            #endif
            {
              __pyx_t_12 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1332, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_12);
              if (__pyx_t_10) {
                __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_10); __pyx_t_10 = NULL;
              }
              __Pyx_INCREF(__pyx_v_instring);
              __Pyx_GIVEREF(__pyx_v_instring);
              PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_v_instring);
              __Pyx_INCREF(__pyx_v_loc);
              __Pyx_GIVEREF(__pyx_v_loc);
              PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_v_loc);
              __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_12, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1332, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_2);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            }
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
              PyObject* sequence = __pyx_t_2;
              #if !CYTHON_COMPILING_IN_PYPY
              Py_ssize_t size = Py_SIZE(sequence);
              #else
              Py_ssize_t size = PySequence_Size(sequence);
              #endif
              if (unlikely(size != 2)) {
                if (size > 2) __Pyx_RaiseTooManyValuesError(2);
                else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                __PYX_ERR(0, 1332, __pyx_L7_error)
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              if (likely(PyTuple_CheckExact(sequence))) {
                __pyx_t_9 = PyTuple_GET_ITEM(sequence, 0); 
                __pyx_t_12 = PyTuple_GET_ITEM(sequence, 1); 
              } else {
                __pyx_t_9 = PyList_GET_ITEM(sequence, 0); 
                __pyx_t_12 = PyList_GET_ITEM(sequence, 1); 
              }
              __Pyx_INCREF(__pyx_t_9);
              __Pyx_INCREF(__pyx_t_12);
              #else
              __pyx_t_9 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1332, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_9);
              __pyx_t_12 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1332, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_12);
              #endif
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            } else {
              Py_ssize_t index = -1;
              __pyx_t_10 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1332, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
              __pyx_t_13 = Py_TYPE(__pyx_t_10)->tp_iternext;
              index = 0; __pyx_t_9 = __pyx_t_13(__pyx_t_10); if (unlikely(!__pyx_t_9)) goto __pyx_L17_unpacking_failed;
              __Pyx_GOTREF(__pyx_t_9);
              index = 1; __pyx_t_12 = __pyx_t_13(__pyx_t_10); if (unlikely(!__pyx_t_12)) goto __pyx_L17_unpacking_failed;
              __Pyx_GOTREF(__pyx_t_12);
              if (__Pyx_IternextUnpackEndCheck(__pyx_t_13(__pyx_t_10), 2) < 0) __PYX_ERR(0, 1332, __pyx_L7_error)
              __pyx_t_13 = NULL;
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
              goto __pyx_L18_unpacking_done;
              __pyx_L17_unpacking_failed:;
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
              __pyx_t_13 = NULL;
              if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
              __PYX_ERR(0, 1332, __pyx_L7_error)
              __pyx_L18_unpacking_done:;
            }
            __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_9);
            __pyx_t_9 = 0;
            __Pyx_XDECREF_SET(__pyx_v_dummy, __pyx_t_12);
            __pyx_t_12 = 0;

            /* "cPyparsing.pyx":1333
 *                     while True:
 *                         loc, dummy = e._parse(instring, loc)
 *                         exprsFound = True             # <<<<<<<<<<<<<<
 *                 except ParseException:
 *                     pass
 */
            __pyx_v_exprsFound = 1;
          }

          /* "cPyparsing.pyx":1330
 *             exprsFound = False
 *             for e in self.ignoreExprs:
 *                 try:             # <<<<<<<<<<<<<<
 *                     while True:
 *                         loc, dummy = e._parse(instring, loc)
 */
        }
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L14_try_end;
        __pyx_L7_error:;
        __Pyx_PyThreadState_assign
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "cPyparsing.pyx":1334
 *                         loc, dummy = e._parse(instring, loc)
 *                         exprsFound = True
 *                 except ParseException:             # <<<<<<<<<<<<<<
 *                     pass
 *         return loc
 */
        __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1334, __pyx_L9_except_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_11 = __Pyx_PyErr_ExceptionMatches(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (__pyx_t_11) {
          __Pyx_ErrRestore(0,0,0);
          goto __pyx_L8_exception_handled;
        }
        goto __pyx_L9_except_error;
        __pyx_L9_except_error:;

        /* "cPyparsing.pyx":1330
 *             exprsFound = False
 *             for e in self.ignoreExprs:
 *                 try:             # <<<<<<<<<<<<<<
 *                     while True:
 *                         loc, dummy = e._parse(instring, loc)
 */
        __Pyx_PyThreadState_assign
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
        goto __pyx_L1_error;
        __pyx_L8_exception_handled:;
        __Pyx_PyThreadState_assign
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
        __pyx_L14_try_end:;
      }

      /* "cPyparsing.pyx":1329
 *         while exprsFound:
 *             exprsFound = False
 *             for e in self.ignoreExprs:             # <<<<<<<<<<<<<<
 *                 try:
 *                     while True:
 */
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }

  /* "cPyparsing.pyx":1336
 *                 except ParseException:
 *                     pass
 *         return loc             # <<<<<<<<<<<<<<
 * 
 *     def preParse(self, instring, int loc):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_loc);
  __pyx_r = __pyx_v_loc;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1325
 *         return self
 * 
 *     def _skipIgnorables(self, instring, loc):             # <<<<<<<<<<<<<<
 *         exprsFound = True
 *         while exprsFound:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("cPyparsing.ParserElement._skipIgnorables", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_dummy);
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1338
 *         return loc
 * 
 *     def preParse(self, instring, int loc):             # <<<<<<<<<<<<<<
 *         if self.ignoreExprs:
 *             loc = self._skipIgnorables(instring, loc)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_25preParse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_25preParse = {"preParse", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_25preParse, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_25preParse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("preParse (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("preParse", 1, 3, 3, 1); __PYX_ERR(0, 1338, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("preParse", 1, 3, 3, 2); __PYX_ERR(0, 1338, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "preParse") < 0)) __PYX_ERR(0, 1338, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1338, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("preParse", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1338, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.preParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_24preParse(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_24preParse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc) {
  PyObject *__pyx_v_wt = NULL;
  Py_ssize_t __pyx_v_instrlen;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  long __pyx_t_11;
  __Pyx_RefNannySetupContext("preParse", 0);

  /* "cPyparsing.pyx":1339
 * 
 *     def preParse(self, instring, int loc):
 *         if self.ignoreExprs:             # <<<<<<<<<<<<<<
 *             loc = self._skipIgnorables(instring, loc)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1339, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1339, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1340
 *     def preParse(self, instring, int loc):
 *         if self.ignoreExprs:
 *             loc = self._skipIgnorables(instring, loc)             # <<<<<<<<<<<<<<
 * 
 *         if self.skipWhitespace:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_skipIgnorables); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_instring, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1340, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_instring, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1340, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1340, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__pyx_t_5) {
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
      }
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_instring);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1340, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1340, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_loc = __pyx_t_6;

    /* "cPyparsing.pyx":1339
 * 
 *     def preParse(self, instring, int loc):
 *         if self.ignoreExprs:             # <<<<<<<<<<<<<<
 *             loc = self._skipIgnorables(instring, loc)
 * 
 */
  }

  /* "cPyparsing.pyx":1342
 *             loc = self._skipIgnorables(instring, loc)
 * 
 *         if self.skipWhitespace:             # <<<<<<<<<<<<<<
 *             wt = self.whiteChars
 *             instrlen = len(instring)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1342, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1343
 * 
 *         if self.skipWhitespace:
 *             wt = self.whiteChars             # <<<<<<<<<<<<<<
 *             instrlen = len(instring)
 *             while loc < instrlen and instring[loc] in wt:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_whiteChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1343, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_wt = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1344
 *         if self.skipWhitespace:
 *             wt = self.whiteChars
 *             instrlen = len(instring)             # <<<<<<<<<<<<<<
 *             while loc < instrlen and instring[loc] in wt:
 *                 loc += 1
 */
    __pyx_t_8 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_8 == -1)) __PYX_ERR(0, 1344, __pyx_L1_error)
    __pyx_v_instrlen = __pyx_t_8;

    /* "cPyparsing.pyx":1345
 *             wt = self.whiteChars
 *             instrlen = len(instring)
 *             while loc < instrlen and instring[loc] in wt:             # <<<<<<<<<<<<<<
 *                 loc += 1
 * 
 */
    while (1) {
      __pyx_t_9 = ((__pyx_v_loc < __pyx_v_instrlen) != 0);
      if (__pyx_t_9) {
      } else {
        __pyx_t_2 = __pyx_t_9;
        goto __pyx_L7_bool_binop_done;
      }
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_instring, __pyx_v_loc, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1345, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_v_wt, Py_EQ)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 1345, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_10 = (__pyx_t_9 != 0);
      __pyx_t_2 = __pyx_t_10;
      __pyx_L7_bool_binop_done:;
      if (!__pyx_t_2) break;

      /* "cPyparsing.pyx":1346
 *             instrlen = len(instring)
 *             while loc < instrlen and instring[loc] in wt:
 *                 loc += 1             # <<<<<<<<<<<<<<
 * 
 *         return loc
 */
      __pyx_t_6 = 0;
      __pyx_t_11 = __Pyx_add_const_long_checking_overflow(__pyx_v_loc, 1, &__pyx_t_6);
      if (unlikely(__pyx_t_6)) {
        PyErr_SetString(PyExc_OverflowError, "value too large");
        __PYX_ERR(0, 1346, __pyx_L1_error)
      }
      __pyx_v_loc = __pyx_t_11;
    }

    /* "cPyparsing.pyx":1342
 *             loc = self._skipIgnorables(instring, loc)
 * 
 *         if self.skipWhitespace:             # <<<<<<<<<<<<<<
 *             wt = self.whiteChars
 *             instrlen = len(instring)
 */
  }

  /* "cPyparsing.pyx":1348
 *                 loc += 1
 * 
 *         return loc             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1338
 *         return loc
 * 
 *     def preParse(self, instring, int loc):             # <<<<<<<<<<<<<<
 *         if self.ignoreExprs:
 *             loc = self._skipIgnorables(instring, loc)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParserElement.preParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_wt);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1350
 *         return loc
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         return loc, []
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_27parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_27parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_27parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_27parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  CYTHON_UNUSED PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 1350, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 1350, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 1350, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1350, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1350, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_26parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_26parseImpl(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":1351
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         return loc, []             # <<<<<<<<<<<<<<
 * 
 *     def postParse(self, instring, int loc, tokenlist):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1350
 *         return loc
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         return loc, []
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParserElement.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1353
 *         return loc, []
 * 
 *     def postParse(self, instring, int loc, tokenlist):             # <<<<<<<<<<<<<<
 *         return tokenlist
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_29postParse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_29postParse = {"postParse", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_29postParse, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_29postParse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  CYTHON_UNUSED PyObject *__pyx_v_instring = 0;
  CYTHON_UNUSED int __pyx_v_loc;
  PyObject *__pyx_v_tokenlist = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("postParse (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_tokenlist,0};
    PyObject* values[4] = {0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 1); __PYX_ERR(0, 1353, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 2); __PYX_ERR(0, 1353, __pyx_L3_error)
        }
        case  3:
        if (likely((values[3] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_tokenlist)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 3); __PYX_ERR(0, 1353, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "postParse") < 0)) __PYX_ERR(0, 1353, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 4) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1353, __pyx_L3_error)
    __pyx_v_tokenlist = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1353, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.postParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_28postParse(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_tokenlist);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_28postParse(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED int __pyx_v_loc, PyObject *__pyx_v_tokenlist) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("postParse", 0);

  /* "cPyparsing.pyx":1354
 * 
 *     def postParse(self, instring, int loc, tokenlist):
 *         return tokenlist             # <<<<<<<<<<<<<<
 * 
 *     #~ @profile
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_tokenlist);
  __pyx_r = __pyx_v_tokenlist;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1353
 *         return loc, []
 * 
 *     def postParse(self, instring, int loc, tokenlist):             # <<<<<<<<<<<<<<
 *         return tokenlist
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1357
 * 
 *     #~ @profile
 *     def _parseNoCache(self, instring, int loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *         debugging = (self.debug)  # and doActions )
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_31_parseNoCache(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_31_parseNoCache = {"_parseNoCache", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_31_parseNoCache, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_31_parseNoCache(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_v_callPreParse = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_parseNoCache (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,&__pyx_n_s_callPreParse,0};
    PyObject* values[5] = {0,0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    values[4] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_parseNoCache", 0, 3, 5, 1); __PYX_ERR(0, 1357, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_parseNoCache", 0, 3, 5, 2); __PYX_ERR(0, 1357, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
        case  4:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_callPreParse);
          if (value) { values[4] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "_parseNoCache") < 0)) __PYX_ERR(0, 1357, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1357, __pyx_L3_error)
    __pyx_v_doActions = values[3];
    __pyx_v_callPreParse = values[4];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_parseNoCache", 0, 3, 5, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1357, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement._parseNoCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_30_parseNoCache(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions, __pyx_v_callPreParse);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_30_parseNoCache(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, PyObject *__pyx_v_doActions, PyObject *__pyx_v_callPreParse) {
  PyObject *__pyx_v_debugging = NULL;
  PyObject *__pyx_v_preloc = NULL;
  PyObject *__pyx_v_tokensStart = NULL;
  PyObject *__pyx_v_tokens = NULL;
  PyObject *__pyx_v_err = NULL;
  PyObject *__pyx_v_retTokens = NULL;
  PyObject *__pyx_v_fn = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *(*__pyx_t_15)(PyObject *);
  Py_ssize_t __pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  int __pyx_t_21;
  char const *__pyx_t_22;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  PyObject *(*__pyx_t_26)(PyObject *);
  int __pyx_t_27;
  char const *__pyx_t_28;
  __Pyx_RefNannySetupContext("_parseNoCache", 0);

  /* "cPyparsing.pyx":1358
 *     #~ @profile
 *     def _parseNoCache(self, instring, int loc, doActions=True, callPreParse=True):
 *         debugging = (self.debug)  # and doActions )             # <<<<<<<<<<<<<<
 * 
 *         if debugging or self.failAction:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debug); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1358, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_debugging = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1360
 *         debugging = (self.debug)  # and doActions )
 * 
 *         if debugging or self.failAction:             # <<<<<<<<<<<<<<
 *             #~ print ("Match",self,"at loc",loc,"(%d,%d)" % ( lineno(loc,instring), col(loc,instring) ))
 *             if (self.debugActions[0]):
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_debugging); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1360, __pyx_L1_error)
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_failAction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1360, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1362
 *         if debugging or self.failAction:
 *             #~ print ("Match",self,"at loc",loc,"(%d,%d)" % ( lineno(loc,instring), col(loc,instring) ))
 *             if (self.debugActions[0]):             # <<<<<<<<<<<<<<
 *                 self.debugActions[0](instring, loc, self)
 *             if callPreParse and self.callPreparse:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1362, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1362, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1362, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":1363
 *             #~ print ("Match",self,"at loc",loc,"(%d,%d)" % ( lineno(loc,instring), col(loc,instring) ))
 *             if (self.debugActions[0]):
 *                 self.debugActions[0](instring, loc, self)             # <<<<<<<<<<<<<<
 *             if callPreParse and self.callPreparse:
 *                 preloc = self.preParse(instring, loc)
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1363, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1363, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1363, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = NULL;
      __pyx_t_7 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_7 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_v_instring, __pyx_t_1, __pyx_v_self};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1363, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_v_instring, __pyx_t_1, __pyx_v_self};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1363, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(3+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1363, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_6) {
          __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6); __pyx_t_6 = NULL;
        }
        __Pyx_INCREF(__pyx_v_instring);
        __Pyx_GIVEREF(__pyx_v_instring);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_v_instring);
        __Pyx_GIVEREF(__pyx_t_1);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_t_1);
        __Pyx_INCREF(__pyx_v_self);
        __Pyx_GIVEREF(__pyx_v_self);
        PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_7, __pyx_v_self);
        __pyx_t_1 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_8, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1363, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "cPyparsing.pyx":1362
 *         if debugging or self.failAction:
 *             #~ print ("Match",self,"at loc",loc,"(%d,%d)" % ( lineno(loc,instring), col(loc,instring) ))
 *             if (self.debugActions[0]):             # <<<<<<<<<<<<<<
 *                 self.debugActions[0](instring, loc, self)
 *             if callPreParse and self.callPreparse:
 */
    }

    /* "cPyparsing.pyx":1364
 *             if (self.debugActions[0]):
 *                 self.debugActions[0](instring, loc, self)
 *             if callPreParse and self.callPreparse:             # <<<<<<<<<<<<<<
 *                 preloc = self.preParse(instring, loc)
 *             else:
 */
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_callPreParse); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1364, __pyx_L1_error)
    if (__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_callPreparse); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1364, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1364, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_2 = __pyx_t_3;
    __pyx_L8_bool_binop_done:;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":1365
 *                 self.debugActions[0](instring, loc, self)
 *             if callPreParse and self.callPreparse:
 *                 preloc = self.preParse(instring, loc)             # <<<<<<<<<<<<<<
 *             else:
 *                 preloc = loc
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_preParse); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1365, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1365, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = NULL;
      __pyx_t_7 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_7 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_v_instring, __pyx_t_8};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1365, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_v_instring, __pyx_t_8};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1365, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1365, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        if (__pyx_t_1) {
          __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1); __pyx_t_1 = NULL;
        }
        __Pyx_INCREF(__pyx_v_instring);
        __Pyx_GIVEREF(__pyx_v_instring);
        PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_7, __pyx_v_instring);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_7, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1365, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_preloc = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "cPyparsing.pyx":1364
 *             if (self.debugActions[0]):
 *                 self.debugActions[0](instring, loc, self)
 *             if callPreParse and self.callPreparse:             # <<<<<<<<<<<<<<
 *                 preloc = self.preParse(instring, loc)
 *             else:
 */
      goto __pyx_L7;
    }

    /* "cPyparsing.pyx":1367
 *                 preloc = self.preParse(instring, loc)
 *             else:
 *                 preloc = loc             # <<<<<<<<<<<<<<
 *             tokensStart = preloc
 *             try:
 */
    /*else*/ {
      __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1367, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_preloc = __pyx_t_4;
      __pyx_t_4 = 0;
    }
    __pyx_L7:;

    /* "cPyparsing.pyx":1368
 *             else:
 *                 preloc = loc
 *             tokensStart = preloc             # <<<<<<<<<<<<<<
 *             try:
 *                 try:
 */
    __Pyx_INCREF(__pyx_v_preloc);
    __pyx_v_tokensStart = __pyx_v_preloc;

    /* "cPyparsing.pyx":1369
 *                 preloc = loc
 *             tokensStart = preloc
 *             try:             # <<<<<<<<<<<<<<
 *                 try:
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      /*try:*/ {

        /* "cPyparsing.pyx":1370
 *             tokensStart = preloc
 *             try:
 *                 try:             # <<<<<<<<<<<<<<
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                 except IndexError:
 */
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_14);
          /*try:*/ {

            /* "cPyparsing.pyx":1371
 *             try:
 *                 try:
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)             # <<<<<<<<<<<<<<
 *                 except IndexError:
 *                     raise ParseException(instring, len(instring), self.errmsg, self)
 */
            __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseImpl); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1371, __pyx_L18_error)
            __Pyx_GOTREF(__pyx_t_5);
            __pyx_t_6 = NULL;
            __pyx_t_7 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
              __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
              if (likely(__pyx_t_6)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
                __Pyx_INCREF(__pyx_t_6);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_5, function);
                __pyx_t_7 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_5)) {
              PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_v_instring, __pyx_v_preloc, __pyx_v_doActions};
              __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1371, __pyx_L18_error)
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_GOTREF(__pyx_t_4);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
              PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_v_instring, __pyx_v_preloc, __pyx_v_doActions};
              __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1371, __pyx_L18_error)
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_GOTREF(__pyx_t_4);
            } else
            #endif
            {
              __pyx_t_8 = PyTuple_New(3+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1371, __pyx_L18_error)
              __Pyx_GOTREF(__pyx_t_8);
              if (__pyx_t_6) {
                __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6); __pyx_t_6 = NULL;
              }
              __Pyx_INCREF(__pyx_v_instring);
              __Pyx_GIVEREF(__pyx_v_instring);
              PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_v_instring);
              __Pyx_INCREF(__pyx_v_preloc);
              __Pyx_GIVEREF(__pyx_v_preloc);
              PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_v_preloc);
              __Pyx_INCREF(__pyx_v_doActions);
              __Pyx_GIVEREF(__pyx_v_doActions);
              PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_7, __pyx_v_doActions);
              __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_8, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1371, __pyx_L18_error)
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            }
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
              PyObject* sequence = __pyx_t_4;
              #if !CYTHON_COMPILING_IN_PYPY
              Py_ssize_t size = Py_SIZE(sequence);
              #else
              Py_ssize_t size = PySequence_Size(sequence);
              #endif
              if (unlikely(size != 2)) {
                if (size > 2) __Pyx_RaiseTooManyValuesError(2);
                else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                __PYX_ERR(0, 1371, __pyx_L18_error)
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              if (likely(PyTuple_CheckExact(sequence))) {
                __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
                __pyx_t_8 = PyTuple_GET_ITEM(sequence, 1); 
              } else {
                __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
                __pyx_t_8 = PyList_GET_ITEM(sequence, 1); 
              }
              __Pyx_INCREF(__pyx_t_5);
              __Pyx_INCREF(__pyx_t_8);
              #else
              __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1371, __pyx_L18_error)
              __Pyx_GOTREF(__pyx_t_5);
              __pyx_t_8 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1371, __pyx_L18_error)
              __Pyx_GOTREF(__pyx_t_8);
              #endif
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            } else {
              Py_ssize_t index = -1;
              __pyx_t_6 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1371, __pyx_L18_error)
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              __pyx_t_15 = Py_TYPE(__pyx_t_6)->tp_iternext;
              index = 0; __pyx_t_5 = __pyx_t_15(__pyx_t_6); if (unlikely(!__pyx_t_5)) goto __pyx_L26_unpacking_failed;
              __Pyx_GOTREF(__pyx_t_5);
              index = 1; __pyx_t_8 = __pyx_t_15(__pyx_t_6); if (unlikely(!__pyx_t_8)) goto __pyx_L26_unpacking_failed;
              __Pyx_GOTREF(__pyx_t_8);
              if (__Pyx_IternextUnpackEndCheck(__pyx_t_15(__pyx_t_6), 2) < 0) __PYX_ERR(0, 1371, __pyx_L18_error)
              __pyx_t_15 = NULL;
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
              goto __pyx_L27_unpacking_done;
              __pyx_L26_unpacking_failed:;
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
              __pyx_t_15 = NULL;
              if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
              __PYX_ERR(0, 1371, __pyx_L18_error)
              __pyx_L27_unpacking_done:;
            }
            __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_5); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1371, __pyx_L18_error)
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __pyx_v_loc = __pyx_t_7;
            __pyx_v_tokens = __pyx_t_8;
            __pyx_t_8 = 0;

            /* "cPyparsing.pyx":1370
 *             tokensStart = preloc
 *             try:
 *                 try:             # <<<<<<<<<<<<<<
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                 except IndexError:
 */
          }
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          goto __pyx_L25_try_end;
          __pyx_L18_error:;
          __Pyx_PyThreadState_assign
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

          /* "cPyparsing.pyx":1372
 *                 try:
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                 except IndexError:             # <<<<<<<<<<<<<<
 *                     raise ParseException(instring, len(instring), self.errmsg, self)
 *             except ParseBaseException as err:
 */
          __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
          if (__pyx_t_7) {
            __Pyx_AddTraceback("cPyparsing.ParserElement._parseNoCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1372, __pyx_L20_except_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_GOTREF(__pyx_t_5);

            /* "cPyparsing.pyx":1373
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                 except IndexError:
 *                     raise ParseException(instring, len(instring), self.errmsg, self)             # <<<<<<<<<<<<<<
 *             except ParseBaseException as err:
 *                 #~ print ("Exception raised:", err)
 */
            __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1373, __pyx_L20_except_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_16 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_16 == -1)) __PYX_ERR(0, 1373, __pyx_L20_except_error)
            __pyx_t_17 = PyInt_FromSsize_t(__pyx_t_16); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1373, __pyx_L20_except_error)
            __Pyx_GOTREF(__pyx_t_17);
            __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1373, __pyx_L20_except_error)
            __Pyx_GOTREF(__pyx_t_18);
            __pyx_t_19 = NULL;
            __pyx_t_7 = 0;
            if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
              __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_1);
              if (likely(__pyx_t_19)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                __Pyx_INCREF(__pyx_t_19);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_1, function);
                __pyx_t_7 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[5] = {__pyx_t_19, __pyx_v_instring, __pyx_t_17, __pyx_t_18, __pyx_v_self};
              __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_7, 4+__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1373, __pyx_L20_except_error)
              __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
              __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[5] = {__pyx_t_19, __pyx_v_instring, __pyx_t_17, __pyx_t_18, __pyx_v_self};
              __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_7, 4+__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1373, __pyx_L20_except_error)
              __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
              __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
            } else
            #endif
            {
              __pyx_t_20 = PyTuple_New(4+__pyx_t_7); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 1373, __pyx_L20_except_error)
              __Pyx_GOTREF(__pyx_t_20);
              if (__pyx_t_19) {
                __Pyx_GIVEREF(__pyx_t_19); PyTuple_SET_ITEM(__pyx_t_20, 0, __pyx_t_19); __pyx_t_19 = NULL;
              }
              __Pyx_INCREF(__pyx_v_instring);
              __Pyx_GIVEREF(__pyx_v_instring);
              PyTuple_SET_ITEM(__pyx_t_20, 0+__pyx_t_7, __pyx_v_instring);
              __Pyx_GIVEREF(__pyx_t_17);
              PyTuple_SET_ITEM(__pyx_t_20, 1+__pyx_t_7, __pyx_t_17);
              __Pyx_GIVEREF(__pyx_t_18);
              PyTuple_SET_ITEM(__pyx_t_20, 2+__pyx_t_7, __pyx_t_18);
              __Pyx_INCREF(__pyx_v_self);
              __Pyx_GIVEREF(__pyx_v_self);
              PyTuple_SET_ITEM(__pyx_t_20, 3+__pyx_t_7, __pyx_v_self);
              __pyx_t_17 = 0;
              __pyx_t_18 = 0;
              __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_20, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1373, __pyx_L20_except_error)
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
            }
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_Raise(__pyx_t_6, 0, 0, 0);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            __PYX_ERR(0, 1373, __pyx_L20_except_error)
          }
          goto __pyx_L20_except_error;
          __pyx_L20_except_error:;

          /* "cPyparsing.pyx":1370
 *             tokensStart = preloc
 *             try:
 *                 try:             # <<<<<<<<<<<<<<
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                 except IndexError:
 */
          __Pyx_PyThreadState_assign
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
          goto __pyx_L10_error;
          __pyx_L25_try_end:;
        }

        /* "cPyparsing.pyx":1369
 *                 preloc = loc
 *             tokensStart = preloc
 *             try:             # <<<<<<<<<<<<<<
 *                 try:
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 */
      }
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      goto __pyx_L17_try_end;
      __pyx_L10_error:;
      __Pyx_PyThreadState_assign
      __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
      __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
      __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
      __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "cPyparsing.pyx":1374
 *                 except IndexError:
 *                     raise ParseException(instring, len(instring), self.errmsg, self)
 *             except ParseBaseException as err:             # <<<<<<<<<<<<<<
 *                 #~ print ("Exception raised:", err)
 *                 if self.debugActions[2]:
 */
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1374, __pyx_L12_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_7) {
        __Pyx_AddTraceback("cPyparsing.ParserElement._parseNoCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_8, &__pyx_t_4) < 0) __PYX_ERR(0, 1374, __pyx_L12_except_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_8);
        __pyx_v_err = __pyx_t_8;
        /*try:*/ {

          /* "cPyparsing.pyx":1376
 *             except ParseBaseException as err:
 *                 #~ print ("Exception raised:", err)
 *                 if self.debugActions[2]:             # <<<<<<<<<<<<<<
 *                     self.debugActions[2](instring, tokensStart, self, err)
 *                 if self.failAction:
 */
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1376, __pyx_L35_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_6, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1376, __pyx_L35_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1376, __pyx_L35_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (__pyx_t_2) {

            /* "cPyparsing.pyx":1377
 *                 #~ print ("Exception raised:", err)
 *                 if self.debugActions[2]:
 *                     self.debugActions[2](instring, tokensStart, self, err)             # <<<<<<<<<<<<<<
 *                 if self.failAction:
 *                     self.failAction(instring, tokensStart, self, err)
 */
            __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1377, __pyx_L35_error)
            __Pyx_GOTREF(__pyx_t_6);
            __pyx_t_20 = __Pyx_GetItemInt(__pyx_t_6, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 1377, __pyx_L35_error)
            __Pyx_GOTREF(__pyx_t_20);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            __pyx_t_6 = NULL;
            __pyx_t_7 = 0;
            if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_20))) {
              __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_20);
              if (likely(__pyx_t_6)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_20);
                __Pyx_INCREF(__pyx_t_6);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_20, function);
                __pyx_t_7 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_20)) {
              PyObject *__pyx_temp[5] = {__pyx_t_6, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_self, __pyx_v_err};
              __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_20, __pyx_temp+1-__pyx_t_7, 4+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1377, __pyx_L35_error)
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_GOTREF(__pyx_t_1);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_20)) {
              PyObject *__pyx_temp[5] = {__pyx_t_6, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_self, __pyx_v_err};
              __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_20, __pyx_temp+1-__pyx_t_7, 4+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1377, __pyx_L35_error)
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_GOTREF(__pyx_t_1);
            } else
            #endif
            {
              __pyx_t_18 = PyTuple_New(4+__pyx_t_7); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1377, __pyx_L35_error)
              __Pyx_GOTREF(__pyx_t_18);
              if (__pyx_t_6) {
                __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_18, 0, __pyx_t_6); __pyx_t_6 = NULL;
              }
              __Pyx_INCREF(__pyx_v_instring);
              __Pyx_GIVEREF(__pyx_v_instring);
              PyTuple_SET_ITEM(__pyx_t_18, 0+__pyx_t_7, __pyx_v_instring);
              __Pyx_INCREF(__pyx_v_tokensStart);
              __Pyx_GIVEREF(__pyx_v_tokensStart);
              PyTuple_SET_ITEM(__pyx_t_18, 1+__pyx_t_7, __pyx_v_tokensStart);
              __Pyx_INCREF(__pyx_v_self);
              __Pyx_GIVEREF(__pyx_v_self);
              PyTuple_SET_ITEM(__pyx_t_18, 2+__pyx_t_7, __pyx_v_self);
              __Pyx_INCREF(__pyx_v_err);
              __Pyx_GIVEREF(__pyx_v_err);
              PyTuple_SET_ITEM(__pyx_t_18, 3+__pyx_t_7, __pyx_v_err);
              __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_20, __pyx_t_18, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1377, __pyx_L35_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
            }
            __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

            /* "cPyparsing.pyx":1376
 *             except ParseBaseException as err:
 *                 #~ print ("Exception raised:", err)
 *                 if self.debugActions[2]:             # <<<<<<<<<<<<<<
 *                     self.debugActions[2](instring, tokensStart, self, err)
 *                 if self.failAction:
 */
          }

          /* "cPyparsing.pyx":1378
 *                 if self.debugActions[2]:
 *                     self.debugActions[2](instring, tokensStart, self, err)
 *                 if self.failAction:             # <<<<<<<<<<<<<<
 *                     self.failAction(instring, tokensStart, self, err)
 *                 raise
 */
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_failAction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1378, __pyx_L35_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1378, __pyx_L35_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (__pyx_t_2) {

            /* "cPyparsing.pyx":1379
 *                     self.debugActions[2](instring, tokensStart, self, err)
 *                 if self.failAction:
 *                     self.failAction(instring, tokensStart, self, err)             # <<<<<<<<<<<<<<
 *                 raise
 *         else:
 */
            __pyx_t_20 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_failAction); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 1379, __pyx_L35_error)
            __Pyx_GOTREF(__pyx_t_20);
            __pyx_t_18 = NULL;
            __pyx_t_7 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_20))) {
              __pyx_t_18 = PyMethod_GET_SELF(__pyx_t_20);
              if (likely(__pyx_t_18)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_20);
                __Pyx_INCREF(__pyx_t_18);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_20, function);
                __pyx_t_7 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_20)) {
              PyObject *__pyx_temp[5] = {__pyx_t_18, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_self, __pyx_v_err};
              __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_20, __pyx_temp+1-__pyx_t_7, 4+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1379, __pyx_L35_error)
              __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
              __Pyx_GOTREF(__pyx_t_1);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_20)) {
              PyObject *__pyx_temp[5] = {__pyx_t_18, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_self, __pyx_v_err};
              __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_20, __pyx_temp+1-__pyx_t_7, 4+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1379, __pyx_L35_error)
              __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
              __Pyx_GOTREF(__pyx_t_1);
            } else
            #endif
            {
              __pyx_t_6 = PyTuple_New(4+__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1379, __pyx_L35_error)
              __Pyx_GOTREF(__pyx_t_6);
              if (__pyx_t_18) {
                __Pyx_GIVEREF(__pyx_t_18); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_18); __pyx_t_18 = NULL;
              }
              __Pyx_INCREF(__pyx_v_instring);
              __Pyx_GIVEREF(__pyx_v_instring);
              PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_7, __pyx_v_instring);
              __Pyx_INCREF(__pyx_v_tokensStart);
              __Pyx_GIVEREF(__pyx_v_tokensStart);
              PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_7, __pyx_v_tokensStart);
              __Pyx_INCREF(__pyx_v_self);
              __Pyx_GIVEREF(__pyx_v_self);
              PyTuple_SET_ITEM(__pyx_t_6, 2+__pyx_t_7, __pyx_v_self);
              __Pyx_INCREF(__pyx_v_err);
              __Pyx_GIVEREF(__pyx_v_err);
              PyTuple_SET_ITEM(__pyx_t_6, 3+__pyx_t_7, __pyx_v_err);
              __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_20, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1379, __pyx_L35_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            }
            __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

            /* "cPyparsing.pyx":1378
 *                 if self.debugActions[2]:
 *                     self.debugActions[2](instring, tokensStart, self, err)
 *                 if self.failAction:             # <<<<<<<<<<<<<<
 *                     self.failAction(instring, tokensStart, self, err)
 *                 raise
 */
          }

          /* "cPyparsing.pyx":1380
 *                 if self.failAction:
 *                     self.failAction(instring, tokensStart, self, err)
 *                 raise             # <<<<<<<<<<<<<<
 *         else:
 *             if callPreParse and self.callPreparse:
 */
          __Pyx_GIVEREF(__pyx_t_5);
          __Pyx_GIVEREF(__pyx_t_8);
          __Pyx_XGIVEREF(__pyx_t_4);
          __Pyx_ErrRestoreWithState(__pyx_t_5, __pyx_t_8, __pyx_t_4);
          __pyx_t_5 = 0; __pyx_t_8 = 0; __pyx_t_4 = 0; 
          __PYX_ERR(0, 1380, __pyx_L35_error)
        }

        /* "cPyparsing.pyx":1374
 *                 except IndexError:
 *                     raise ParseException(instring, len(instring), self.errmsg, self)
 *             except ParseBaseException as err:             # <<<<<<<<<<<<<<
 *                 #~ print ("Exception raised:", err)
 *                 if self.debugActions[2]:
 */
        /*finally:*/ {
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __pyx_L35_error:;
            __pyx_t_14 = 0; __pyx_t_13 = 0; __pyx_t_12 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0;
            __Pyx_PyThreadState_assign
            __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
            __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
            __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_23, &__pyx_t_24, &__pyx_t_25);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_14, &__pyx_t_13, &__pyx_t_12) < 0)) __Pyx_ErrFetch(&__pyx_t_14, &__pyx_t_13, &__pyx_t_12);
            __Pyx_XGOTREF(__pyx_t_14);
            __Pyx_XGOTREF(__pyx_t_13);
            __Pyx_XGOTREF(__pyx_t_12);
            __Pyx_XGOTREF(__pyx_t_23);
            __Pyx_XGOTREF(__pyx_t_24);
            __Pyx_XGOTREF(__pyx_t_25);
            __pyx_t_7 = __pyx_lineno; __pyx_t_21 = __pyx_clineno; __pyx_t_22 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_err);
              __pyx_v_err = NULL;
            }
            __Pyx_PyThreadState_assign
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_23);
              __Pyx_XGIVEREF(__pyx_t_24);
              __Pyx_XGIVEREF(__pyx_t_25);
              __Pyx_ExceptionReset(__pyx_t_23, __pyx_t_24, __pyx_t_25);
            }
            __Pyx_XGIVEREF(__pyx_t_14);
            __Pyx_XGIVEREF(__pyx_t_13);
            __Pyx_XGIVEREF(__pyx_t_12);
            __Pyx_ErrRestore(__pyx_t_14, __pyx_t_13, __pyx_t_12);
            __pyx_t_14 = 0; __pyx_t_13 = 0; __pyx_t_12 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0;
            __pyx_lineno = __pyx_t_7; __pyx_clineno = __pyx_t_21; __pyx_filename = __pyx_t_22;
            goto __pyx_L12_except_error;
          }
        }
      }
      goto __pyx_L12_except_error;
      __pyx_L12_except_error:;

      /* "cPyparsing.pyx":1369
 *                 preloc = loc
 *             tokensStart = preloc
 *             try:             # <<<<<<<<<<<<<<
 *                 try:
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 */
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
      goto __pyx_L1_error;
      __pyx_L17_try_end:;
    }

    /* "cPyparsing.pyx":1360
 *         debugging = (self.debug)  # and doActions )
 * 
 *         if debugging or self.failAction:             # <<<<<<<<<<<<<<
 *             #~ print ("Match",self,"at loc",loc,"(%d,%d)" % ( lineno(loc,instring), col(loc,instring) ))
 *             if (self.debugActions[0]):
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":1382
 *                 raise
 *         else:
 *             if callPreParse and self.callPreparse:             # <<<<<<<<<<<<<<
 *                 preloc = self.preParse(instring, loc)
 *             else:
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_callPreParse); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1382, __pyx_L1_error)
    if (__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L44_bool_binop_done;
    }
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_callPreparse); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1382, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1382, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_2 = __pyx_t_3;
    __pyx_L44_bool_binop_done:;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":1383
 *         else:
 *             if callPreParse and self.callPreparse:
 *                 preloc = self.preParse(instring, loc)             # <<<<<<<<<<<<<<
 *             else:
 *                 preloc = loc
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_preParse); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1383, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1383, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_1 = NULL;
      __pyx_t_21 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_21 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_v_instring, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_21, 2+__pyx_t_21); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1383, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_v_instring, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_21, 2+__pyx_t_21); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1383, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_20 = PyTuple_New(2+__pyx_t_21); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 1383, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_20);
        if (__pyx_t_1) {
          __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_20, 0, __pyx_t_1); __pyx_t_1 = NULL;
        }
        __Pyx_INCREF(__pyx_v_instring);
        __Pyx_GIVEREF(__pyx_v_instring);
        PyTuple_SET_ITEM(__pyx_t_20, 0+__pyx_t_21, __pyx_v_instring);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_20, 1+__pyx_t_21, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_20, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1383, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_preloc = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "cPyparsing.pyx":1382
 *                 raise
 *         else:
 *             if callPreParse and self.callPreparse:             # <<<<<<<<<<<<<<
 *                 preloc = self.preParse(instring, loc)
 *             else:
 */
      goto __pyx_L43;
    }

    /* "cPyparsing.pyx":1385
 *                 preloc = self.preParse(instring, loc)
 *             else:
 *                 preloc = loc             # <<<<<<<<<<<<<<
 *             tokensStart = preloc
 *             if self.mayIndexError or loc >= len(instring):
 */
    /*else*/ {
      __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1385, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_preloc = __pyx_t_4;
      __pyx_t_4 = 0;
    }
    __pyx_L43:;

    /* "cPyparsing.pyx":1386
 *             else:
 *                 preloc = loc
 *             tokensStart = preloc             # <<<<<<<<<<<<<<
 *             if self.mayIndexError or loc >= len(instring):
 *                 try:
 */
    __Pyx_INCREF(__pyx_v_preloc);
    __pyx_v_tokensStart = __pyx_v_preloc;

    /* "cPyparsing.pyx":1387
 *                 preloc = loc
 *             tokensStart = preloc
 *             if self.mayIndexError or loc >= len(instring):             # <<<<<<<<<<<<<<
 *                 try:
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1387, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1387, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L47_bool_binop_done;
    }
    __pyx_t_16 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_16 == -1)) __PYX_ERR(0, 1387, __pyx_L1_error)
    __pyx_t_3 = ((__pyx_v_loc >= __pyx_t_16) != 0);
    __pyx_t_2 = __pyx_t_3;
    __pyx_L47_bool_binop_done:;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":1388
 *             tokensStart = preloc
 *             if self.mayIndexError or loc >= len(instring):
 *                 try:             # <<<<<<<<<<<<<<
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                 except IndexError:
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_10, &__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_11);
        __Pyx_XGOTREF(__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_9);
        /*try:*/ {

          /* "cPyparsing.pyx":1389
 *             if self.mayIndexError or loc >= len(instring):
 *                 try:
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)             # <<<<<<<<<<<<<<
 *                 except IndexError:
 *                     raise ParseException(instring, len(instring), self.errmsg, self)
 */
          __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseImpl); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1389, __pyx_L49_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_20 = NULL;
          __pyx_t_21 = 0;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
            __pyx_t_20 = PyMethod_GET_SELF(__pyx_t_8);
            if (likely(__pyx_t_20)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
              __Pyx_INCREF(__pyx_t_20);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_8, function);
              __pyx_t_21 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_8)) {
            PyObject *__pyx_temp[4] = {__pyx_t_20, __pyx_v_instring, __pyx_v_preloc, __pyx_v_doActions};
            __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_21, 3+__pyx_t_21); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1389, __pyx_L49_error)
            __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
            __Pyx_GOTREF(__pyx_t_4);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
            PyObject *__pyx_temp[4] = {__pyx_t_20, __pyx_v_instring, __pyx_v_preloc, __pyx_v_doActions};
            __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_21, 3+__pyx_t_21); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1389, __pyx_L49_error)
            __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
            __Pyx_GOTREF(__pyx_t_4);
          } else
          #endif
          {
            __pyx_t_5 = PyTuple_New(3+__pyx_t_21); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1389, __pyx_L49_error)
            __Pyx_GOTREF(__pyx_t_5);
            if (__pyx_t_20) {
              __Pyx_GIVEREF(__pyx_t_20); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_20); __pyx_t_20 = NULL;
            }
            __Pyx_INCREF(__pyx_v_instring);
            __Pyx_GIVEREF(__pyx_v_instring);
            PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_21, __pyx_v_instring);
            __Pyx_INCREF(__pyx_v_preloc);
            __Pyx_GIVEREF(__pyx_v_preloc);
            PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_21, __pyx_v_preloc);
            __Pyx_INCREF(__pyx_v_doActions);
            __Pyx_GIVEREF(__pyx_v_doActions);
            PyTuple_SET_ITEM(__pyx_t_5, 2+__pyx_t_21, __pyx_v_doActions);
            __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_5, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1389, __pyx_L49_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          }
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
            PyObject* sequence = __pyx_t_4;
            #if !CYTHON_COMPILING_IN_PYPY
            Py_ssize_t size = Py_SIZE(sequence);
            #else
            Py_ssize_t size = PySequence_Size(sequence);
            #endif
            if (unlikely(size != 2)) {
              if (size > 2) __Pyx_RaiseTooManyValuesError(2);
              else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
              __PYX_ERR(0, 1389, __pyx_L49_error)
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            if (likely(PyTuple_CheckExact(sequence))) {
              __pyx_t_8 = PyTuple_GET_ITEM(sequence, 0); 
              __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
            } else {
              __pyx_t_8 = PyList_GET_ITEM(sequence, 0); 
              __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
            }
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_5);
            #else
            __pyx_t_8 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1389, __pyx_L49_error)
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1389, __pyx_L49_error)
            __Pyx_GOTREF(__pyx_t_5);
            #endif
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          } else {
            Py_ssize_t index = -1;
            __pyx_t_20 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 1389, __pyx_L49_error)
            __Pyx_GOTREF(__pyx_t_20);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __pyx_t_15 = Py_TYPE(__pyx_t_20)->tp_iternext;
            index = 0; __pyx_t_8 = __pyx_t_15(__pyx_t_20); if (unlikely(!__pyx_t_8)) goto __pyx_L57_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_8);
            index = 1; __pyx_t_5 = __pyx_t_15(__pyx_t_20); if (unlikely(!__pyx_t_5)) goto __pyx_L57_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_5);
            if (__Pyx_IternextUnpackEndCheck(__pyx_t_15(__pyx_t_20), 2) < 0) __PYX_ERR(0, 1389, __pyx_L49_error)
            __pyx_t_15 = NULL;
            __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
            goto __pyx_L58_unpacking_done;
            __pyx_L57_unpacking_failed:;
            __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
            __pyx_t_15 = NULL;
            if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
            __PYX_ERR(0, 1389, __pyx_L49_error)
            __pyx_L58_unpacking_done:;
          }
          __pyx_t_21 = __Pyx_PyInt_As_int(__pyx_t_8); if (unlikely((__pyx_t_21 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1389, __pyx_L49_error)
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_v_loc = __pyx_t_21;
          __pyx_v_tokens = __pyx_t_5;
          __pyx_t_5 = 0;

          /* "cPyparsing.pyx":1388
 *             tokensStart = preloc
 *             if self.mayIndexError or loc >= len(instring):
 *                 try:             # <<<<<<<<<<<<<<
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                 except IndexError:
 */
        }
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L56_try_end;
        __pyx_L49_error:;
        __Pyx_PyThreadState_assign
        __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
        __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
        __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "cPyparsing.pyx":1390
 *                 try:
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                 except IndexError:             # <<<<<<<<<<<<<<
 *                     raise ParseException(instring, len(instring), self.errmsg, self)
 *             else:
 */
        __pyx_t_21 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
        if (__pyx_t_21) {
          __Pyx_AddTraceback("cPyparsing.ParserElement._parseNoCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_8) < 0) __PYX_ERR(0, 1390, __pyx_L51_except_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_GOTREF(__pyx_t_8);

          /* "cPyparsing.pyx":1391
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                 except IndexError:
 *                     raise ParseException(instring, len(instring), self.errmsg, self)             # <<<<<<<<<<<<<<
 *             else:
 *                 loc, tokens = self.parseImpl(instring, preloc, doActions)
 */
          __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1391, __pyx_L51_except_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_16 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_16 == -1)) __PYX_ERR(0, 1391, __pyx_L51_except_error)
          __pyx_t_6 = PyInt_FromSsize_t(__pyx_t_16); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1391, __pyx_L51_except_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1391, __pyx_L51_except_error)
          __Pyx_GOTREF(__pyx_t_18);
          __pyx_t_17 = NULL;
          __pyx_t_21 = 0;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_17)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_17);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
              __pyx_t_21 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_1)) {
            PyObject *__pyx_temp[5] = {__pyx_t_17, __pyx_v_instring, __pyx_t_6, __pyx_t_18, __pyx_v_self};
            __pyx_t_20 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_21, 4+__pyx_t_21); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 1391, __pyx_L51_except_error)
            __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
            __Pyx_GOTREF(__pyx_t_20);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
            PyObject *__pyx_temp[5] = {__pyx_t_17, __pyx_v_instring, __pyx_t_6, __pyx_t_18, __pyx_v_self};
            __pyx_t_20 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_21, 4+__pyx_t_21); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 1391, __pyx_L51_except_error)
            __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
            __Pyx_GOTREF(__pyx_t_20);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          } else
          #endif
          {
            __pyx_t_19 = PyTuple_New(4+__pyx_t_21); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 1391, __pyx_L51_except_error)
            __Pyx_GOTREF(__pyx_t_19);
            if (__pyx_t_17) {
              __Pyx_GIVEREF(__pyx_t_17); PyTuple_SET_ITEM(__pyx_t_19, 0, __pyx_t_17); __pyx_t_17 = NULL;
            }
            __Pyx_INCREF(__pyx_v_instring);
            __Pyx_GIVEREF(__pyx_v_instring);
            PyTuple_SET_ITEM(__pyx_t_19, 0+__pyx_t_21, __pyx_v_instring);
            __Pyx_GIVEREF(__pyx_t_6);
            PyTuple_SET_ITEM(__pyx_t_19, 1+__pyx_t_21, __pyx_t_6);
            __Pyx_GIVEREF(__pyx_t_18);
            PyTuple_SET_ITEM(__pyx_t_19, 2+__pyx_t_21, __pyx_t_18);
            __Pyx_INCREF(__pyx_v_self);
            __Pyx_GIVEREF(__pyx_v_self);
            PyTuple_SET_ITEM(__pyx_t_19, 3+__pyx_t_21, __pyx_v_self);
            __pyx_t_6 = 0;
            __pyx_t_18 = 0;
            __pyx_t_20 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_19, NULL); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 1391, __pyx_L51_except_error)
            __Pyx_GOTREF(__pyx_t_20);
            __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_Raise(__pyx_t_20, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
          __PYX_ERR(0, 1391, __pyx_L51_except_error)
        }
        goto __pyx_L51_except_error;
        __pyx_L51_except_error:;

        /* "cPyparsing.pyx":1388
 *             tokensStart = preloc
 *             if self.mayIndexError or loc >= len(instring):
 *                 try:             # <<<<<<<<<<<<<<
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 *                 except IndexError:
 */
        __Pyx_PyThreadState_assign
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_10, __pyx_t_9);
        goto __pyx_L1_error;
        __pyx_L56_try_end:;
      }

      /* "cPyparsing.pyx":1387
 *                 preloc = loc
 *             tokensStart = preloc
 *             if self.mayIndexError or loc >= len(instring):             # <<<<<<<<<<<<<<
 *                 try:
 *                     loc, tokens = self.parseImpl(instring, preloc, doActions)
 */
      goto __pyx_L46;
    }

    /* "cPyparsing.pyx":1393
 *                     raise ParseException(instring, len(instring), self.errmsg, self)
 *             else:
 *                 loc, tokens = self.parseImpl(instring, preloc, doActions)             # <<<<<<<<<<<<<<
 * 
 *         tokens = self.postParse(instring, loc, tokens)
 */
    /*else*/ {
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseImpl); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1393, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = NULL;
      __pyx_t_21 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_21 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[4] = {__pyx_t_4, __pyx_v_instring, __pyx_v_preloc, __pyx_v_doActions};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_21, 3+__pyx_t_21); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1393, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_8);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[4] = {__pyx_t_4, __pyx_v_instring, __pyx_v_preloc, __pyx_v_doActions};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_21, 3+__pyx_t_21); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1393, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_8);
      } else
      #endif
      {
        __pyx_t_20 = PyTuple_New(3+__pyx_t_21); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 1393, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_20);
        if (__pyx_t_4) {
          __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_20, 0, __pyx_t_4); __pyx_t_4 = NULL;
        }
        __Pyx_INCREF(__pyx_v_instring);
        __Pyx_GIVEREF(__pyx_v_instring);
        PyTuple_SET_ITEM(__pyx_t_20, 0+__pyx_t_21, __pyx_v_instring);
        __Pyx_INCREF(__pyx_v_preloc);
        __Pyx_GIVEREF(__pyx_v_preloc);
        PyTuple_SET_ITEM(__pyx_t_20, 1+__pyx_t_21, __pyx_v_preloc);
        __Pyx_INCREF(__pyx_v_doActions);
        __Pyx_GIVEREF(__pyx_v_doActions);
        PyTuple_SET_ITEM(__pyx_t_20, 2+__pyx_t_21, __pyx_v_doActions);
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_20, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1393, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if ((likely(PyTuple_CheckExact(__pyx_t_8))) || (PyList_CheckExact(__pyx_t_8))) {
        PyObject* sequence = __pyx_t_8;
        #if !CYTHON_COMPILING_IN_PYPY
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 1393, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_20 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_20 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_20);
        #else
        __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1393, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_20 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 1393, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_20);
        #endif
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_4 = PyObject_GetIter(__pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1393, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_15 = Py_TYPE(__pyx_t_4)->tp_iternext;
        index = 0; __pyx_t_5 = __pyx_t_15(__pyx_t_4); if (unlikely(!__pyx_t_5)) goto __pyx_L61_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_5);
        index = 1; __pyx_t_20 = __pyx_t_15(__pyx_t_4); if (unlikely(!__pyx_t_20)) goto __pyx_L61_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_20);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_15(__pyx_t_4), 2) < 0) __PYX_ERR(0, 1393, __pyx_L1_error)
        __pyx_t_15 = NULL;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        goto __pyx_L62_unpacking_done;
        __pyx_L61_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_15 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 1393, __pyx_L1_error)
        __pyx_L62_unpacking_done:;
      }
      __pyx_t_21 = __Pyx_PyInt_As_int(__pyx_t_5); if (unlikely((__pyx_t_21 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1393, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_loc = __pyx_t_21;
      __pyx_v_tokens = __pyx_t_20;
      __pyx_t_20 = 0;
    }
    __pyx_L46:;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":1395
 *                 loc, tokens = self.parseImpl(instring, preloc, doActions)
 * 
 *         tokens = self.postParse(instring, loc, tokens)             # <<<<<<<<<<<<<<
 * 
 *         retTokens = ParseResults(tokens, self.resultsName, asList=self.saveAsList, modal=self.modalResults)
 */
  __pyx_t_20 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_postParse); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 1395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_20);
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = NULL;
  __pyx_t_21 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_20))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_20);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_20);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_20, function);
      __pyx_t_21 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_20)) {
    PyObject *__pyx_temp[4] = {__pyx_t_4, __pyx_v_instring, __pyx_t_5, __pyx_v_tokens};
    __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_20, __pyx_temp+1-__pyx_t_21, 3+__pyx_t_21); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1395, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_20)) {
    PyObject *__pyx_temp[4] = {__pyx_t_4, __pyx_v_instring, __pyx_t_5, __pyx_v_tokens};
    __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_20, __pyx_temp+1-__pyx_t_21, 3+__pyx_t_21); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1395, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else
  #endif
  {
    __pyx_t_1 = PyTuple_New(3+__pyx_t_21); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1395, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_INCREF(__pyx_v_instring);
    __Pyx_GIVEREF(__pyx_v_instring);
    PyTuple_SET_ITEM(__pyx_t_1, 0+__pyx_t_21, __pyx_v_instring);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_1, 1+__pyx_t_21, __pyx_t_5);
    __Pyx_INCREF(__pyx_v_tokens);
    __Pyx_GIVEREF(__pyx_v_tokens);
    PyTuple_SET_ITEM(__pyx_t_1, 2+__pyx_t_21, __pyx_v_tokens);
    __pyx_t_5 = 0;
    __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_20, __pyx_t_1, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1395, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
  __Pyx_DECREF_SET(__pyx_v_tokens, __pyx_t_8);
  __pyx_t_8 = 0;

  /* "cPyparsing.pyx":1397
 *         tokens = self.postParse(instring, loc, tokens)
 * 
 *         retTokens = ParseResults(tokens, self.resultsName, asList=self.saveAsList, modal=self.modalResults)             # <<<<<<<<<<<<<<
 *         if self.parseAction and (doActions or self.callDuringTry):
 *             if debugging:
 */
  __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_20 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 1397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_20);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_tokens);
  __Pyx_GIVEREF(__pyx_v_tokens);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_tokens);
  __Pyx_GIVEREF(__pyx_t_20);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_20);
  __pyx_t_20 = 0;
  __pyx_t_20 = PyDict_New(); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 1397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_20);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_asList, __pyx_t_5) < 0) __PYX_ERR(0, 1397, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_modalResults); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_modal, __pyx_t_5) < 0) __PYX_ERR(0, 1397, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_1, __pyx_t_20); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
  __pyx_v_retTokens = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "cPyparsing.pyx":1398
 * 
 *         retTokens = ParseResults(tokens, self.resultsName, asList=self.saveAsList, modal=self.modalResults)
 *         if self.parseAction and (doActions or self.callDuringTry):             # <<<<<<<<<<<<<<
 *             if debugging:
 *                 try:
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1398, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L64_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_doActions); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1398, __pyx_L1_error)
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L64_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_callDuringTry); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1398, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_2 = __pyx_t_3;
  __pyx_L64_bool_binop_done:;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1399
 *         retTokens = ParseResults(tokens, self.resultsName, asList=self.saveAsList, modal=self.modalResults)
 *         if self.parseAction and (doActions or self.callDuringTry):
 *             if debugging:             # <<<<<<<<<<<<<<
 *                 try:
 *                     for fn in self.parseAction:
 */
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_debugging); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1399, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":1400
 *         if self.parseAction and (doActions or self.callDuringTry):
 *             if debugging:
 *                 try:             # <<<<<<<<<<<<<<
 *                     for fn in self.parseAction:
 *                         tokens = fn(instring, tokensStart, retTokens)
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
        __Pyx_XGOTREF(__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_11);
        /*try:*/ {

          /* "cPyparsing.pyx":1401
 *             if debugging:
 *                 try:
 *                     for fn in self.parseAction:             # <<<<<<<<<<<<<<
 *                         tokens = fn(instring, tokensStart, retTokens)
 *                         if tokens is not None:
 */
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1401, __pyx_L68_error)
          __Pyx_GOTREF(__pyx_t_5);
          if (likely(PyList_CheckExact(__pyx_t_5)) || PyTuple_CheckExact(__pyx_t_5)) {
            __pyx_t_20 = __pyx_t_5; __Pyx_INCREF(__pyx_t_20); __pyx_t_16 = 0;
            __pyx_t_26 = NULL;
          } else {
            __pyx_t_16 = -1; __pyx_t_20 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 1401, __pyx_L68_error)
            __Pyx_GOTREF(__pyx_t_20);
            __pyx_t_26 = Py_TYPE(__pyx_t_20)->tp_iternext; if (unlikely(!__pyx_t_26)) __PYX_ERR(0, 1401, __pyx_L68_error)
          }
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          for (;;) {
            if (likely(!__pyx_t_26)) {
              if (likely(PyList_CheckExact(__pyx_t_20))) {
                if (__pyx_t_16 >= PyList_GET_SIZE(__pyx_t_20)) break;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_5 = PyList_GET_ITEM(__pyx_t_20, __pyx_t_16); __Pyx_INCREF(__pyx_t_5); __pyx_t_16++; if (unlikely(0 < 0)) __PYX_ERR(0, 1401, __pyx_L68_error)
                #else
                __pyx_t_5 = PySequence_ITEM(__pyx_t_20, __pyx_t_16); __pyx_t_16++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1401, __pyx_L68_error)
                __Pyx_GOTREF(__pyx_t_5);
                #endif
              } else {
                if (__pyx_t_16 >= PyTuple_GET_SIZE(__pyx_t_20)) break;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_20, __pyx_t_16); __Pyx_INCREF(__pyx_t_5); __pyx_t_16++; if (unlikely(0 < 0)) __PYX_ERR(0, 1401, __pyx_L68_error)
                #else
                __pyx_t_5 = PySequence_ITEM(__pyx_t_20, __pyx_t_16); __pyx_t_16++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1401, __pyx_L68_error)
                __Pyx_GOTREF(__pyx_t_5);
                #endif
              }
            } else {
              __pyx_t_5 = __pyx_t_26(__pyx_t_20);
              if (unlikely(!__pyx_t_5)) {
                PyObject* exc_type = PyErr_Occurred();
                if (exc_type) {
                  if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                  else __PYX_ERR(0, 1401, __pyx_L68_error)
                }
                break;
              }
              __Pyx_GOTREF(__pyx_t_5);
            }
            __Pyx_XDECREF_SET(__pyx_v_fn, __pyx_t_5);
            __pyx_t_5 = 0;

            /* "cPyparsing.pyx":1402
 *                 try:
 *                     for fn in self.parseAction:
 *                         tokens = fn(instring, tokensStart, retTokens)             # <<<<<<<<<<<<<<
 *                         if tokens is not None:
 *                             retTokens = ParseResults(tokens,
 */
            __Pyx_INCREF(__pyx_v_fn);
            __pyx_t_1 = __pyx_v_fn; __pyx_t_8 = NULL;
            __pyx_t_21 = 0;
            if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
              __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
              if (likely(__pyx_t_8)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                __Pyx_INCREF(__pyx_t_8);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_1, function);
                __pyx_t_21 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[4] = {__pyx_t_8, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_retTokens};
              __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_21, 3+__pyx_t_21); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1402, __pyx_L68_error)
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_GOTREF(__pyx_t_5);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[4] = {__pyx_t_8, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_retTokens};
              __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_21, 3+__pyx_t_21); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1402, __pyx_L68_error)
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_GOTREF(__pyx_t_5);
            } else
            #endif
            {
              __pyx_t_4 = PyTuple_New(3+__pyx_t_21); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1402, __pyx_L68_error)
              __Pyx_GOTREF(__pyx_t_4);
              if (__pyx_t_8) {
                __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_8); __pyx_t_8 = NULL;
              }
              __Pyx_INCREF(__pyx_v_instring);
              __Pyx_GIVEREF(__pyx_v_instring);
              PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_21, __pyx_v_instring);
              __Pyx_INCREF(__pyx_v_tokensStart);
              __Pyx_GIVEREF(__pyx_v_tokensStart);
              PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_21, __pyx_v_tokensStart);
              __Pyx_INCREF(__pyx_v_retTokens);
              __Pyx_GIVEREF(__pyx_v_retTokens);
              PyTuple_SET_ITEM(__pyx_t_4, 2+__pyx_t_21, __pyx_v_retTokens);
              __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_4, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1402, __pyx_L68_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            }
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF_SET(__pyx_v_tokens, __pyx_t_5);
            __pyx_t_5 = 0;

            /* "cPyparsing.pyx":1403
 *                     for fn in self.parseAction:
 *                         tokens = fn(instring, tokensStart, retTokens)
 *                         if tokens is not None:             # <<<<<<<<<<<<<<
 *                             retTokens = ParseResults(tokens,
 *                                                      self.resultsName,
 */
            __pyx_t_2 = (__pyx_v_tokens != Py_None);
            __pyx_t_3 = (__pyx_t_2 != 0);
            if (__pyx_t_3) {

              /* "cPyparsing.pyx":1404
 *                         tokens = fn(instring, tokensStart, retTokens)
 *                         if tokens is not None:
 *                             retTokens = ParseResults(tokens,             # <<<<<<<<<<<<<<
 *                                                      self.resultsName,
 *                                                      asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 */
              __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1404, __pyx_L68_error)
              __Pyx_GOTREF(__pyx_t_5);

              /* "cPyparsing.pyx":1405
 *                         if tokens is not None:
 *                             retTokens = ParseResults(tokens,
 *                                                      self.resultsName,             # <<<<<<<<<<<<<<
 *                                                      asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                      modal=self.modalResults)
 */
              __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1405, __pyx_L68_error)
              __Pyx_GOTREF(__pyx_t_1);

              /* "cPyparsing.pyx":1404
 *                         tokens = fn(instring, tokensStart, retTokens)
 *                         if tokens is not None:
 *                             retTokens = ParseResults(tokens,             # <<<<<<<<<<<<<<
 *                                                      self.resultsName,
 *                                                      asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 */
              __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1404, __pyx_L68_error)
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_INCREF(__pyx_v_tokens);
              __Pyx_GIVEREF(__pyx_v_tokens);
              PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_tokens);
              __Pyx_GIVEREF(__pyx_t_1);
              PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
              __pyx_t_1 = 0;

              /* "cPyparsing.pyx":1406
 *                             retTokens = ParseResults(tokens,
 *                                                      self.resultsName,
 *                                                      asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),             # <<<<<<<<<<<<<<
 *                                                      modal=self.modalResults)
 *                 except ParseBaseException as err:
 */
              __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1406, __pyx_L68_error)
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 1406, __pyx_L68_error)
              __Pyx_GOTREF(__pyx_t_19);
              __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_19); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1406, __pyx_L68_error)
              if (__pyx_t_3) {
                __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
              } else {
                __Pyx_INCREF(__pyx_t_19);
                __pyx_t_8 = __pyx_t_19;
                __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
                goto __pyx_L79_bool_binop_done;
              }
              __pyx_t_19 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 1406, __pyx_L68_error)
              __Pyx_GOTREF(__pyx_t_19);
              __pyx_t_2 = PyObject_IsInstance(__pyx_v_tokens, __pyx_t_19); 
              __pyx_t_27 = (__pyx_t_2 != 0);
              if (!__pyx_t_27) {
              } else {
                __pyx_t_3 = __pyx_t_27;
                goto __pyx_L81_bool_binop_done;
              }
              __pyx_t_27 = PyList_Check(__pyx_v_tokens); 
              __pyx_t_2 = (__pyx_t_27 != 0);
              __pyx_t_3 = __pyx_t_2;
              __pyx_L81_bool_binop_done:;
              __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
              __pyx_t_19 = __Pyx_PyBool_FromLong(__pyx_t_3); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 1406, __pyx_L68_error)
              __Pyx_GOTREF(__pyx_t_19);
              __pyx_t_8 = __pyx_t_19;
              __pyx_t_19 = 0;
              __pyx_L79_bool_binop_done:;
              if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_asList, __pyx_t_8) < 0) __PYX_ERR(0, 1406, __pyx_L68_error)
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

              /* "cPyparsing.pyx":1407
 *                                                      self.resultsName,
 *                                                      asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                      modal=self.modalResults)             # <<<<<<<<<<<<<<
 *                 except ParseBaseException as err:
 *                     #~ print "Exception raised in user parse action:", err
 */
              __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_modalResults); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1407, __pyx_L68_error)
              __Pyx_GOTREF(__pyx_t_8);
              if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_modal, __pyx_t_8) < 0) __PYX_ERR(0, 1406, __pyx_L68_error)
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

              /* "cPyparsing.pyx":1404
 *                         tokens = fn(instring, tokensStart, retTokens)
 *                         if tokens is not None:
 *                             retTokens = ParseResults(tokens,             # <<<<<<<<<<<<<<
 *                                                      self.resultsName,
 *                                                      asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 */
              __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1404, __pyx_L68_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_DECREF_SET(__pyx_v_retTokens, __pyx_t_8);
              __pyx_t_8 = 0;

              /* "cPyparsing.pyx":1403
 *                     for fn in self.parseAction:
 *                         tokens = fn(instring, tokensStart, retTokens)
 *                         if tokens is not None:             # <<<<<<<<<<<<<<
 *                             retTokens = ParseResults(tokens,
 *                                                      self.resultsName,
 */
            }

            /* "cPyparsing.pyx":1401
 *             if debugging:
 *                 try:
 *                     for fn in self.parseAction:             # <<<<<<<<<<<<<<
 *                         tokens = fn(instring, tokensStart, retTokens)
 *                         if tokens is not None:
 */
          }
          __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;

          /* "cPyparsing.pyx":1400
 *         if self.parseAction and (doActions or self.callDuringTry):
 *             if debugging:
 *                 try:             # <<<<<<<<<<<<<<
 *                     for fn in self.parseAction:
 *                         tokens = fn(instring, tokensStart, retTokens)
 */
        }
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        goto __pyx_L75_try_end;
        __pyx_L68_error:;
        __Pyx_PyThreadState_assign
        __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
        __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;

        /* "cPyparsing.pyx":1408
 *                                                      asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                      modal=self.modalResults)
 *                 except ParseBaseException as err:             # <<<<<<<<<<<<<<
 *                     #~ print "Exception raised in user parse action:", err
 *                     if (self.debugActions[2]):
 */
        __pyx_t_20 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 1408, __pyx_L70_except_error)
        __Pyx_GOTREF(__pyx_t_20);
        __pyx_t_21 = __Pyx_PyErr_ExceptionMatches(__pyx_t_20);
        __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
        if (__pyx_t_21) {
          __Pyx_AddTraceback("cPyparsing.ParserElement._parseNoCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_20, &__pyx_t_8, &__pyx_t_1) < 0) __PYX_ERR(0, 1408, __pyx_L70_except_error)
          __Pyx_GOTREF(__pyx_t_20);
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_8);
          __pyx_v_err = __pyx_t_8;
          /*try:*/ {

            /* "cPyparsing.pyx":1410
 *                 except ParseBaseException as err:
 *                     #~ print "Exception raised in user parse action:", err
 *                     if (self.debugActions[2]):             # <<<<<<<<<<<<<<
 *                         self.debugActions[2](instring, tokensStart, self, err)
 *                     raise
 */
            __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1410, __pyx_L88_error)
            __Pyx_GOTREF(__pyx_t_4);
            __pyx_t_5 = __Pyx_GetItemInt(__pyx_t_4, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1410, __pyx_L88_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1410, __pyx_L88_error)
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (__pyx_t_3) {

              /* "cPyparsing.pyx":1411
 *                     #~ print "Exception raised in user parse action:", err
 *                     if (self.debugActions[2]):
 *                         self.debugActions[2](instring, tokensStart, self, err)             # <<<<<<<<<<<<<<
 *                     raise
 *             else:
 */
              __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1411, __pyx_L88_error)
              __Pyx_GOTREF(__pyx_t_4);
              __pyx_t_19 = __Pyx_GetItemInt(__pyx_t_4, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 1411, __pyx_L88_error)
              __Pyx_GOTREF(__pyx_t_19);
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              __pyx_t_4 = NULL;
              __pyx_t_21 = 0;
              if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_19))) {
                __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_19);
                if (likely(__pyx_t_4)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
                  __Pyx_INCREF(__pyx_t_4);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_19, function);
                  __pyx_t_21 = 1;
                }
              }
              #if CYTHON_FAST_PYCALL
              if (PyFunction_Check(__pyx_t_19)) {
                PyObject *__pyx_temp[5] = {__pyx_t_4, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_self, __pyx_v_err};
                __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_19, __pyx_temp+1-__pyx_t_21, 4+__pyx_t_21); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1411, __pyx_L88_error)
                __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                __Pyx_GOTREF(__pyx_t_5);
              } else
              #endif
              #if CYTHON_FAST_PYCCALL
              if (__Pyx_PyFastCFunction_Check(__pyx_t_19)) {
                PyObject *__pyx_temp[5] = {__pyx_t_4, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_self, __pyx_v_err};
                __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_19, __pyx_temp+1-__pyx_t_21, 4+__pyx_t_21); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1411, __pyx_L88_error)
                __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                __Pyx_GOTREF(__pyx_t_5);
              } else
              #endif
              {
                __pyx_t_18 = PyTuple_New(4+__pyx_t_21); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1411, __pyx_L88_error)
                __Pyx_GOTREF(__pyx_t_18);
                if (__pyx_t_4) {
                  __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_18, 0, __pyx_t_4); __pyx_t_4 = NULL;
                }
                __Pyx_INCREF(__pyx_v_instring);
                __Pyx_GIVEREF(__pyx_v_instring);
                PyTuple_SET_ITEM(__pyx_t_18, 0+__pyx_t_21, __pyx_v_instring);
                __Pyx_INCREF(__pyx_v_tokensStart);
                __Pyx_GIVEREF(__pyx_v_tokensStart);
                PyTuple_SET_ITEM(__pyx_t_18, 1+__pyx_t_21, __pyx_v_tokensStart);
                __Pyx_INCREF(__pyx_v_self);
                __Pyx_GIVEREF(__pyx_v_self);
                PyTuple_SET_ITEM(__pyx_t_18, 2+__pyx_t_21, __pyx_v_self);
                __Pyx_INCREF(__pyx_v_err);
                __Pyx_GIVEREF(__pyx_v_err);
                PyTuple_SET_ITEM(__pyx_t_18, 3+__pyx_t_21, __pyx_v_err);
                __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_19, __pyx_t_18, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1411, __pyx_L88_error)
                __Pyx_GOTREF(__pyx_t_5);
                __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
              }
              __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

              /* "cPyparsing.pyx":1410
 *                 except ParseBaseException as err:
 *                     #~ print "Exception raised in user parse action:", err
 *                     if (self.debugActions[2]):             # <<<<<<<<<<<<<<
 *                         self.debugActions[2](instring, tokensStart, self, err)
 *                     raise
 */
            }

            /* "cPyparsing.pyx":1412
 *                     if (self.debugActions[2]):
 *                         self.debugActions[2](instring, tokensStart, self, err)
 *                     raise             # <<<<<<<<<<<<<<
 *             else:
 *                 for fn in self.parseAction:
 */
            __Pyx_GIVEREF(__pyx_t_20);
            __Pyx_GIVEREF(__pyx_t_8);
            __Pyx_XGIVEREF(__pyx_t_1);
            __Pyx_ErrRestoreWithState(__pyx_t_20, __pyx_t_8, __pyx_t_1);
            __pyx_t_20 = 0; __pyx_t_8 = 0; __pyx_t_1 = 0; 
            __PYX_ERR(0, 1412, __pyx_L88_error)
          }

          /* "cPyparsing.pyx":1408
 *                                                      asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                      modal=self.modalResults)
 *                 except ParseBaseException as err:             # <<<<<<<<<<<<<<
 *                     #~ print "Exception raised in user parse action:", err
 *                     if (self.debugActions[2]):
 */
          /*finally:*/ {
            /*exception exit:*/{
              __Pyx_PyThreadState_declare
              __pyx_L88_error:;
              __pyx_t_25 = 0; __pyx_t_24 = 0; __pyx_t_23 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
              __Pyx_PyThreadState_assign
              __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
              __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
              if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_25, &__pyx_t_24, &__pyx_t_23) < 0)) __Pyx_ErrFetch(&__pyx_t_25, &__pyx_t_24, &__pyx_t_23);
              __Pyx_XGOTREF(__pyx_t_25);
              __Pyx_XGOTREF(__pyx_t_24);
              __Pyx_XGOTREF(__pyx_t_23);
              __Pyx_XGOTREF(__pyx_t_12);
              __Pyx_XGOTREF(__pyx_t_13);
              __Pyx_XGOTREF(__pyx_t_14);
              __pyx_t_21 = __pyx_lineno; __pyx_t_7 = __pyx_clineno; __pyx_t_28 = __pyx_filename;
              {
                __Pyx_DECREF(__pyx_v_err);
                __pyx_v_err = NULL;
              }
              __Pyx_PyThreadState_assign
              if (PY_MAJOR_VERSION >= 3) {
                __Pyx_XGIVEREF(__pyx_t_12);
                __Pyx_XGIVEREF(__pyx_t_13);
                __Pyx_XGIVEREF(__pyx_t_14);
                __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
              }
              __Pyx_XGIVEREF(__pyx_t_25);
              __Pyx_XGIVEREF(__pyx_t_24);
              __Pyx_XGIVEREF(__pyx_t_23);
              __Pyx_ErrRestore(__pyx_t_25, __pyx_t_24, __pyx_t_23);
              __pyx_t_25 = 0; __pyx_t_24 = 0; __pyx_t_23 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
              __pyx_lineno = __pyx_t_21; __pyx_clineno = __pyx_t_7; __pyx_filename = __pyx_t_28;
              goto __pyx_L70_except_error;
            }
          }
        }
        goto __pyx_L70_except_error;
        __pyx_L70_except_error:;

        /* "cPyparsing.pyx":1400
 *         if self.parseAction and (doActions or self.callDuringTry):
 *             if debugging:
 *                 try:             # <<<<<<<<<<<<<<
 *                     for fn in self.parseAction:
 *                         tokens = fn(instring, tokensStart, retTokens)
 */
        __Pyx_PyThreadState_assign
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
        goto __pyx_L1_error;
        __pyx_L75_try_end:;
      }

      /* "cPyparsing.pyx":1399
 *         retTokens = ParseResults(tokens, self.resultsName, asList=self.saveAsList, modal=self.modalResults)
 *         if self.parseAction and (doActions or self.callDuringTry):
 *             if debugging:             # <<<<<<<<<<<<<<
 *                 try:
 *                     for fn in self.parseAction:
 */
      goto __pyx_L67;
    }

    /* "cPyparsing.pyx":1414
 *                     raise
 *             else:
 *                 for fn in self.parseAction:             # <<<<<<<<<<<<<<
 *                     tokens = fn(instring, tokensStart, retTokens)
 *                     if tokens is not None:
 */
    /*else*/ {
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1414, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
        __pyx_t_8 = __pyx_t_1; __Pyx_INCREF(__pyx_t_8); __pyx_t_16 = 0;
        __pyx_t_26 = NULL;
      } else {
        __pyx_t_16 = -1; __pyx_t_8 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1414, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_26 = Py_TYPE(__pyx_t_8)->tp_iternext; if (unlikely(!__pyx_t_26)) __PYX_ERR(0, 1414, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      for (;;) {
        if (likely(!__pyx_t_26)) {
          if (likely(PyList_CheckExact(__pyx_t_8))) {
            if (__pyx_t_16 >= PyList_GET_SIZE(__pyx_t_8)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyList_GET_ITEM(__pyx_t_8, __pyx_t_16); __Pyx_INCREF(__pyx_t_1); __pyx_t_16++; if (unlikely(0 < 0)) __PYX_ERR(0, 1414, __pyx_L1_error)
            #else
            __pyx_t_1 = PySequence_ITEM(__pyx_t_8, __pyx_t_16); __pyx_t_16++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1414, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          } else {
            if (__pyx_t_16 >= PyTuple_GET_SIZE(__pyx_t_8)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_8, __pyx_t_16); __Pyx_INCREF(__pyx_t_1); __pyx_t_16++; if (unlikely(0 < 0)) __PYX_ERR(0, 1414, __pyx_L1_error)
            #else
            __pyx_t_1 = PySequence_ITEM(__pyx_t_8, __pyx_t_16); __pyx_t_16++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1414, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          }
        } else {
          __pyx_t_1 = __pyx_t_26(__pyx_t_8);
          if (unlikely(!__pyx_t_1)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1414, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_XDECREF_SET(__pyx_v_fn, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "cPyparsing.pyx":1415
 *             else:
 *                 for fn in self.parseAction:
 *                     tokens = fn(instring, tokensStart, retTokens)             # <<<<<<<<<<<<<<
 *                     if tokens is not None:
 *                         retTokens = ParseResults(tokens,
 */
        __Pyx_INCREF(__pyx_v_fn);
        __pyx_t_20 = __pyx_v_fn; __pyx_t_5 = NULL;
        __pyx_t_7 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_20))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_20);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_20);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_20, function);
            __pyx_t_7 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_20)) {
          PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_retTokens};
          __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_20, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1415, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_1);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_20)) {
          PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_v_instring, __pyx_v_tokensStart, __pyx_v_retTokens};
          __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_20, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1415, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_1);
        } else
        #endif
        {
          __pyx_t_19 = PyTuple_New(3+__pyx_t_7); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 1415, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          if (__pyx_t_5) {
            __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_19, 0, __pyx_t_5); __pyx_t_5 = NULL;
          }
          __Pyx_INCREF(__pyx_v_instring);
          __Pyx_GIVEREF(__pyx_v_instring);
          PyTuple_SET_ITEM(__pyx_t_19, 0+__pyx_t_7, __pyx_v_instring);
          __Pyx_INCREF(__pyx_v_tokensStart);
          __Pyx_GIVEREF(__pyx_v_tokensStart);
          PyTuple_SET_ITEM(__pyx_t_19, 1+__pyx_t_7, __pyx_v_tokensStart);
          __Pyx_INCREF(__pyx_v_retTokens);
          __Pyx_GIVEREF(__pyx_v_retTokens);
          PyTuple_SET_ITEM(__pyx_t_19, 2+__pyx_t_7, __pyx_v_retTokens);
          __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_20, __pyx_t_19, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1415, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
        }
        __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
        __Pyx_DECREF_SET(__pyx_v_tokens, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "cPyparsing.pyx":1416
 *                 for fn in self.parseAction:
 *                     tokens = fn(instring, tokensStart, retTokens)
 *                     if tokens is not None:             # <<<<<<<<<<<<<<
 *                         retTokens = ParseResults(tokens,
 *                                                  self.resultsName,
 */
        __pyx_t_3 = (__pyx_v_tokens != Py_None);
        __pyx_t_2 = (__pyx_t_3 != 0);
        if (__pyx_t_2) {

          /* "cPyparsing.pyx":1417
 *                     tokens = fn(instring, tokensStart, retTokens)
 *                     if tokens is not None:
 *                         retTokens = ParseResults(tokens,             # <<<<<<<<<<<<<<
 *                                                  self.resultsName,
 *                                                  asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 */
          __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1417, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);

          /* "cPyparsing.pyx":1418
 *                     if tokens is not None:
 *                         retTokens = ParseResults(tokens,
 *                                                  self.resultsName,             # <<<<<<<<<<<<<<
 *                                                  asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                  modal=self.modalResults)
 */
          __pyx_t_20 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 1418, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_20);

          /* "cPyparsing.pyx":1417
 *                     tokens = fn(instring, tokensStart, retTokens)
 *                     if tokens is not None:
 *                         retTokens = ParseResults(tokens,             # <<<<<<<<<<<<<<
 *                                                  self.resultsName,
 *                                                  asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 */
          __pyx_t_19 = PyTuple_New(2); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 1417, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_19);
          __Pyx_INCREF(__pyx_v_tokens);
          __Pyx_GIVEREF(__pyx_v_tokens);
          PyTuple_SET_ITEM(__pyx_t_19, 0, __pyx_v_tokens);
          __Pyx_GIVEREF(__pyx_t_20);
          PyTuple_SET_ITEM(__pyx_t_19, 1, __pyx_t_20);
          __pyx_t_20 = 0;

          /* "cPyparsing.pyx":1419
 *                         retTokens = ParseResults(tokens,
 *                                                  self.resultsName,
 *                                                  asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),             # <<<<<<<<<<<<<<
 *                                                  modal=self.modalResults)
 * 
 */
          __pyx_t_20 = PyDict_New(); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 1419, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_20);
          __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1419, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_18);
          __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_18); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1419, __pyx_L1_error)
          if (__pyx_t_2) {
            __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          } else {
            __Pyx_INCREF(__pyx_t_18);
            __pyx_t_5 = __pyx_t_18;
            __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
            goto __pyx_L98_bool_binop_done;
          }
          __pyx_t_18 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1419, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_18);
          __pyx_t_3 = PyObject_IsInstance(__pyx_v_tokens, __pyx_t_18); 
          __pyx_t_27 = (__pyx_t_3 != 0);
          if (!__pyx_t_27) {
          } else {
            __pyx_t_2 = __pyx_t_27;
            goto __pyx_L100_bool_binop_done;
          }
          __pyx_t_27 = PyList_Check(__pyx_v_tokens); 
          __pyx_t_3 = (__pyx_t_27 != 0);
          __pyx_t_2 = __pyx_t_3;
          __pyx_L100_bool_binop_done:;
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          __pyx_t_18 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1419, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_18);
          __pyx_t_5 = __pyx_t_18;
          __pyx_t_18 = 0;
          __pyx_L98_bool_binop_done:;
          if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_asList, __pyx_t_5) < 0) __PYX_ERR(0, 1419, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "cPyparsing.pyx":1420
 *                                                  self.resultsName,
 *                                                  asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 *                                                  modal=self.modalResults)             # <<<<<<<<<<<<<<
 * 
 *         if debugging:
 */
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_modalResults); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1420, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          if (PyDict_SetItem(__pyx_t_20, __pyx_n_s_modal, __pyx_t_5) < 0) __PYX_ERR(0, 1419, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "cPyparsing.pyx":1417
 *                     tokens = fn(instring, tokensStart, retTokens)
 *                     if tokens is not None:
 *                         retTokens = ParseResults(tokens,             # <<<<<<<<<<<<<<
 *                                                  self.resultsName,
 *                                                  asList=self.saveAsList and isinstance(tokens, (ParseResults, list)),
 */
          __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_19, __pyx_t_20); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1417, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
          __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
          __Pyx_DECREF_SET(__pyx_v_retTokens, __pyx_t_5);
          __pyx_t_5 = 0;

          /* "cPyparsing.pyx":1416
 *                 for fn in self.parseAction:
 *                     tokens = fn(instring, tokensStart, retTokens)
 *                     if tokens is not None:             # <<<<<<<<<<<<<<
 *                         retTokens = ParseResults(tokens,
 *                                                  self.resultsName,
 */
        }

        /* "cPyparsing.pyx":1414
 *                     raise
 *             else:
 *                 for fn in self.parseAction:             # <<<<<<<<<<<<<<
 *                     tokens = fn(instring, tokensStart, retTokens)
 *                     if tokens is not None:
 */
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __pyx_L67:;

    /* "cPyparsing.pyx":1398
 * 
 *         retTokens = ParseResults(tokens, self.resultsName, asList=self.saveAsList, modal=self.modalResults)
 *         if self.parseAction and (doActions or self.callDuringTry):             # <<<<<<<<<<<<<<
 *             if debugging:
 *                 try:
 */
  }

  /* "cPyparsing.pyx":1422
 *                                                  modal=self.modalResults)
 * 
 *         if debugging:             # <<<<<<<<<<<<<<
 *             #~ print ("Matched",self,"->",retTokens.asList())
 *             if (self.debugActions[1]):
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_debugging); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1422, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1424
 *         if debugging:
 *             #~ print ("Matched",self,"->",retTokens.asList())
 *             if (self.debugActions[1]):             # <<<<<<<<<<<<<<
 *                 self.debugActions[1](instring, tokensStart, loc, self, retTokens)
 * 
 */
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1424, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_t_8, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1424, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1424, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":1425
 *             #~ print ("Matched",self,"->",retTokens.asList())
 *             if (self.debugActions[1]):
 *                 self.debugActions[1](instring, tokensStart, loc, self, retTokens)             # <<<<<<<<<<<<<<
 * 
 *         return loc, retTokens
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debugActions); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1425, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_20 = __Pyx_GetItemInt(__pyx_t_8, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 1425, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_20);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1425, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_19 = NULL;
      __pyx_t_7 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_20))) {
        __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_20);
        if (likely(__pyx_t_19)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_20);
          __Pyx_INCREF(__pyx_t_19);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_20, function);
          __pyx_t_7 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_20)) {
        PyObject *__pyx_temp[6] = {__pyx_t_19, __pyx_v_instring, __pyx_v_tokensStart, __pyx_t_8, __pyx_v_self, __pyx_v_retTokens};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_20, __pyx_temp+1-__pyx_t_7, 5+__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1425, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_20)) {
        PyObject *__pyx_temp[6] = {__pyx_t_19, __pyx_v_instring, __pyx_v_tokensStart, __pyx_t_8, __pyx_v_self, __pyx_v_retTokens};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_20, __pyx_temp+1-__pyx_t_7, 5+__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1425, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_1 = PyTuple_New(5+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1425, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        if (__pyx_t_19) {
          __Pyx_GIVEREF(__pyx_t_19); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_19); __pyx_t_19 = NULL;
        }
        __Pyx_INCREF(__pyx_v_instring);
        __Pyx_GIVEREF(__pyx_v_instring);
        PyTuple_SET_ITEM(__pyx_t_1, 0+__pyx_t_7, __pyx_v_instring);
        __Pyx_INCREF(__pyx_v_tokensStart);
        __Pyx_GIVEREF(__pyx_v_tokensStart);
        PyTuple_SET_ITEM(__pyx_t_1, 1+__pyx_t_7, __pyx_v_tokensStart);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_1, 2+__pyx_t_7, __pyx_t_8);
        __Pyx_INCREF(__pyx_v_self);
        __Pyx_GIVEREF(__pyx_v_self);
        PyTuple_SET_ITEM(__pyx_t_1, 3+__pyx_t_7, __pyx_v_self);
        __Pyx_INCREF(__pyx_v_retTokens);
        __Pyx_GIVEREF(__pyx_v_retTokens);
        PyTuple_SET_ITEM(__pyx_t_1, 4+__pyx_t_7, __pyx_v_retTokens);
        __pyx_t_8 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_20, __pyx_t_1, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1425, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "cPyparsing.pyx":1424
 *         if debugging:
 *             #~ print ("Matched",self,"->",retTokens.asList())
 *             if (self.debugActions[1]):             # <<<<<<<<<<<<<<
 *                 self.debugActions[1](instring, tokensStart, loc, self, retTokens)
 * 
 */
    }

    /* "cPyparsing.pyx":1422
 *                                                  modal=self.modalResults)
 * 
 *         if debugging:             # <<<<<<<<<<<<<<
 *             #~ print ("Matched",self,"->",retTokens.asList())
 *             if (self.debugActions[1]):
 */
  }

  /* "cPyparsing.pyx":1427
 *                 self.debugActions[1](instring, tokensStart, loc, self, retTokens)
 * 
 *         return loc, retTokens             # <<<<<<<<<<<<<<
 * 
 *     def tryParse(self, instring, int loc):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_20 = PyTuple_New(2); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 1427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_20);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_20, 0, __pyx_t_5);
  __Pyx_INCREF(__pyx_v_retTokens);
  __Pyx_GIVEREF(__pyx_v_retTokens);
  PyTuple_SET_ITEM(__pyx_t_20, 1, __pyx_v_retTokens);
  __pyx_t_5 = 0;
  __pyx_r = __pyx_t_20;
  __pyx_t_20 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1357
 * 
 *     #~ @profile
 *     def _parseNoCache(self, instring, int loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *         debugging = (self.debug)  # and doActions )
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_XDECREF(__pyx_t_20);
  __Pyx_AddTraceback("cPyparsing.ParserElement._parseNoCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_debugging);
  __Pyx_XDECREF(__pyx_v_preloc);
  __Pyx_XDECREF(__pyx_v_tokensStart);
  __Pyx_XDECREF(__pyx_v_tokens);
  __Pyx_XDECREF(__pyx_v_err);
  __Pyx_XDECREF(__pyx_v_retTokens);
  __Pyx_XDECREF(__pyx_v_fn);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1429
 *         return loc, retTokens
 * 
 *     def tryParse(self, instring, int loc):             # <<<<<<<<<<<<<<
 *         try:
 *             return self._parse(instring, loc, doActions=False)[0]
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_33tryParse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_33tryParse = {"tryParse", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_33tryParse, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_33tryParse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tryParse (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("tryParse", 1, 3, 3, 1); __PYX_ERR(0, 1429, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("tryParse", 1, 3, 3, 2); __PYX_ERR(0, 1429, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "tryParse") < 0)) __PYX_ERR(0, 1429, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1429, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("tryParse", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1429, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.tryParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_32tryParse(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_32tryParse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  __Pyx_RefNannySetupContext("tryParse", 0);

  /* "cPyparsing.pyx":1430
 * 
 *     def tryParse(self, instring, int loc):
 *         try:             # <<<<<<<<<<<<<<
 *             return self._parse(instring, loc, doActions=False)[0]
 *         except ParseFatalException:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":1431
 *     def tryParse(self, instring, int loc):
 *         try:
 *             return self._parse(instring, loc, doActions=False)[0]             # <<<<<<<<<<<<<<
 *         except ParseFatalException:
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parse); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1431, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1431, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1431, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_instring);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_5);
      __pyx_t_5 = 0;
      __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1431, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_doActions, Py_False) < 0) __PYX_ERR(0, 1431, __pyx_L3_error)
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1431, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_t_7, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1431, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":1430
 * 
 *     def tryParse(self, instring, int loc):
 *         try:             # <<<<<<<<<<<<<<
 *             return self._parse(instring, loc, doActions=False)[0]
 *         except ParseFatalException:
 */
    }
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "cPyparsing.pyx":1432
 *         try:
 *             return self._parse(instring, loc, doActions=False)[0]
 *         except ParseFatalException:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseFatalException); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1432, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_8) {
      __Pyx_AddTraceback("cPyparsing.ParserElement.tryParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_7, &__pyx_t_6) < 0) __PYX_ERR(0, 1432, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_6);

      /* "cPyparsing.pyx":1433
 *             return self._parse(instring, loc, doActions=False)[0]
 *         except ParseFatalException:
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *     def canParseNext(self, instring, int loc):
 */
      __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1433, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1433, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1433, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_12 = NULL;
      __pyx_t_8 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_12)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_12);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_8 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[5] = {__pyx_t_12, __pyx_v_instring, __pyx_t_10, __pyx_t_11, __pyx_v_self};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_8, 4+__pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1433, __pyx_L5_except_error)
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[5] = {__pyx_t_12, __pyx_v_instring, __pyx_t_10, __pyx_t_11, __pyx_v_self};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_8, 4+__pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1433, __pyx_L5_except_error)
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(4+__pyx_t_8); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1433, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_12) {
          __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_12); __pyx_t_12 = NULL;
        }
        __Pyx_INCREF(__pyx_v_instring);
        __Pyx_GIVEREF(__pyx_v_instring);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_8, __pyx_v_instring);
        __Pyx_GIVEREF(__pyx_t_10);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_8, __pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_11);
        PyTuple_SET_ITEM(__pyx_t_13, 2+__pyx_t_8, __pyx_t_11);
        __Pyx_INCREF(__pyx_v_self);
        __Pyx_GIVEREF(__pyx_v_self);
        PyTuple_SET_ITEM(__pyx_t_13, 3+__pyx_t_8, __pyx_v_self);
        __pyx_t_10 = 0;
        __pyx_t_11 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_13, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1433, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(0, 1433, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cPyparsing.pyx":1430
 * 
 *     def tryParse(self, instring, int loc):
 *         try:             # <<<<<<<<<<<<<<
 *             return self._parse(instring, loc, doActions=False)[0]
 *         except ParseFatalException:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":1429
 *         return loc, retTokens
 * 
 *     def tryParse(self, instring, int loc):             # <<<<<<<<<<<<<<
 *         try:
 *             return self._parse(instring, loc, doActions=False)[0]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("cPyparsing.ParserElement.tryParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1435
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *     def canParseNext(self, instring, int loc):             # <<<<<<<<<<<<<<
 *         try:
 *             self.tryParse(instring, loc)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_35canParseNext(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_35canParseNext = {"canParseNext", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_35canParseNext, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_35canParseNext(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("canParseNext (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("canParseNext", 1, 3, 3, 1); __PYX_ERR(0, 1435, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("canParseNext", 1, 3, 3, 2); __PYX_ERR(0, 1435, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "canParseNext") < 0)) __PYX_ERR(0, 1435, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1435, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("canParseNext", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1435, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.canParseNext", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_34canParseNext(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_34canParseNext(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("canParseNext", 0);

  /* "cPyparsing.pyx":1436
 * 
 *     def canParseNext(self, instring, int loc):
 *         try:             # <<<<<<<<<<<<<<
 *             self.tryParse(instring, loc)
 *         except (ParseException, IndexError):
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":1437
 *     def canParseNext(self, instring, int loc):
 *         try:
 *             self.tryParse(instring, loc)             # <<<<<<<<<<<<<<
 *         except (ParseException, IndexError):
 *             return False
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_tryParse); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1437, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1437, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = NULL;
      __pyx_t_8 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_8 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_v_instring, __pyx_t_6};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1437, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_v_instring, __pyx_t_6};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1437, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(2+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1437, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_9);
        if (__pyx_t_7) {
          __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
        }
        __Pyx_INCREF(__pyx_v_instring);
        __Pyx_GIVEREF(__pyx_v_instring);
        PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_v_instring);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_9, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1437, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "cPyparsing.pyx":1436
 * 
 *     def canParseNext(self, instring, int loc):
 *         try:             # <<<<<<<<<<<<<<
 *             self.tryParse(instring, loc)
 *         except (ParseException, IndexError):
 */
    }

    /* "cPyparsing.pyx":1441
 *             return False
 *         else:
 *             return True             # <<<<<<<<<<<<<<
 * 
 *     class _UnboundedCache(object):
 */
    /*else:*/ {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      goto __pyx_L6_except_return;
    }
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":1438
 *         try:
 *             self.tryParse(instring, loc)
 *         except (ParseException, IndexError):             # <<<<<<<<<<<<<<
 *             return False
 *         else:
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1438, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_t_4) || __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_8) {
      __Pyx_AddTraceback("cPyparsing.ParserElement.canParseNext", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_9) < 0) __PYX_ERR(0, 1438, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_9);

      /* "cPyparsing.pyx":1439
 *             self.tryParse(instring, loc)
 *         except (ParseException, IndexError):
 *             return False             # <<<<<<<<<<<<<<
 *         else:
 *             return True
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cPyparsing.pyx":1436
 * 
 *     def canParseNext(self, instring, int loc):
 *         try:             # <<<<<<<<<<<<<<
 *             self.tryParse(instring, loc)
 *         except (ParseException, IndexError):
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":1435
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *     def canParseNext(self, instring, int loc):             # <<<<<<<<<<<<<<
 *         try:
 *             self.tryParse(instring, loc)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.ParserElement.canParseNext", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1444
 * 
 *     class _UnboundedCache(object):
 *         def __init__(self):             # <<<<<<<<<<<<<<
 *             cache = {}
 *             self.not_in_cache = not_in_cache = object()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15_UnboundedCache_1__init__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15_UnboundedCache_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_15_UnboundedCache_1__init__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_15_UnboundedCache_1__init__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_15_UnboundedCache___init__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1448
 *             self.not_in_cache = not_in_cache = object()
 * 
 *             def get(self, key):             # <<<<<<<<<<<<<<
 *                 return cache.get(key, not_in_cache)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15_UnboundedCache_8__init___1get(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15_UnboundedCache_8__init___1get = {"get", (PyCFunction)__pyx_pw_10cPyparsing_15_UnboundedCache_8__init___1get, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_15_UnboundedCache_8__init___1get(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_key = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_key,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_key)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get", 1, 2, 2, 1); __PYX_ERR(0, 1448, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get") < 0)) __PYX_ERR(0, 1448, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_key = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1448, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing._UnboundedCache.__init__.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15_UnboundedCache_8__init___get(__pyx_self, __pyx_v_self, __pyx_v_key);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15_UnboundedCache_8__init___get(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_key) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__ *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__ *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("get", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__ *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":1449
 * 
 *             def get(self, key):
 *                 return cache.get(key, not_in_cache)             # <<<<<<<<<<<<<<
 * 
 *             def set(self, key, value):
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_v_cache)) { __Pyx_RaiseClosureNameError("cache"); __PYX_ERR(0, 1449, __pyx_L1_error) }
  if (unlikely(__pyx_cur_scope->__pyx_v_cache == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    __PYX_ERR(0, 1449, __pyx_L1_error)
  }
  if (unlikely(!__pyx_cur_scope->__pyx_v_not_in_cache)) { __Pyx_RaiseClosureNameError("not_in_cache"); __PYX_ERR(0, 1449, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_cur_scope->__pyx_v_cache, __pyx_v_key, __pyx_cur_scope->__pyx_v_not_in_cache); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1448
 *             self.not_in_cache = not_in_cache = object()
 * 
 *             def get(self, key):             # <<<<<<<<<<<<<<
 *                 return cache.get(key, not_in_cache)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing._UnboundedCache.__init__.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1451
 *                 return cache.get(key, not_in_cache)
 * 
 *             def set(self, key, value):             # <<<<<<<<<<<<<<
 *                 cache[key] = value
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15_UnboundedCache_8__init___3set(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15_UnboundedCache_8__init___3set = {"set", (PyCFunction)__pyx_pw_10cPyparsing_15_UnboundedCache_8__init___3set, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_15_UnboundedCache_8__init___3set(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_key = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_key,&__pyx_n_s_value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_key)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set", 1, 3, 3, 1); __PYX_ERR(0, 1451, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set", 1, 3, 3, 2); __PYX_ERR(0, 1451, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set") < 0)) __PYX_ERR(0, 1451, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_key = values[1];
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1451, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing._UnboundedCache.__init__.set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15_UnboundedCache_8__init___2set(__pyx_self, __pyx_v_self, __pyx_v_key, __pyx_v_value);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15_UnboundedCache_8__init___2set(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__ *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__ *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__ *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":1452
 * 
 *             def set(self, key, value):
 *                 cache[key] = value             # <<<<<<<<<<<<<<
 * 
 *             def clear(self):
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_cache)) { __Pyx_RaiseClosureNameError("cache"); __PYX_ERR(0, 1452, __pyx_L1_error) }
  if (unlikely(__pyx_cur_scope->__pyx_v_cache == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 1452, __pyx_L1_error)
  }
  if (unlikely(PyDict_SetItem(__pyx_cur_scope->__pyx_v_cache, __pyx_v_key, __pyx_v_value) < 0)) __PYX_ERR(0, 1452, __pyx_L1_error)

  /* "cPyparsing.pyx":1451
 *                 return cache.get(key, not_in_cache)
 * 
 *             def set(self, key, value):             # <<<<<<<<<<<<<<
 *                 cache[key] = value
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing._UnboundedCache.__init__.set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1454
 *                 cache[key] = value
 * 
 *             def clear(self):             # <<<<<<<<<<<<<<
 *                 cache.clear()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15_UnboundedCache_8__init___5clear(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15_UnboundedCache_8__init___5clear = {"clear", (PyCFunction)__pyx_pw_10cPyparsing_15_UnboundedCache_8__init___5clear, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_15_UnboundedCache_8__init___5clear(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("clear (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_15_UnboundedCache_8__init___4clear(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15_UnboundedCache_8__init___4clear(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__ *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__ *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("clear", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__ *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":1455
 * 
 *             def clear(self):
 *                 cache.clear()             # <<<<<<<<<<<<<<
 * 
 *             def cache_len(self):
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_cache)) { __Pyx_RaiseClosureNameError("cache"); __PYX_ERR(0, 1455, __pyx_L1_error) }
  if (unlikely(__pyx_cur_scope->__pyx_v_cache == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "clear");
    __PYX_ERR(0, 1455, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyDict_Clear(__pyx_cur_scope->__pyx_v_cache); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 1455, __pyx_L1_error)

  /* "cPyparsing.pyx":1454
 *                 cache[key] = value
 * 
 *             def clear(self):             # <<<<<<<<<<<<<<
 *                 cache.clear()
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing._UnboundedCache.__init__.clear", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1457
 *                 cache.clear()
 * 
 *             def cache_len(self):             # <<<<<<<<<<<<<<
 *                 return len(cache)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15_UnboundedCache_8__init___7cache_len(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15_UnboundedCache_8__init___7cache_len = {"cache_len", (PyCFunction)__pyx_pw_10cPyparsing_15_UnboundedCache_8__init___7cache_len, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_15_UnboundedCache_8__init___7cache_len(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cache_len (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_15_UnboundedCache_8__init___6cache_len(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15_UnboundedCache_8__init___6cache_len(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__ *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__ *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  __Pyx_RefNannySetupContext("cache_len", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__ *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":1458
 * 
 *             def cache_len(self):
 *                 return len(cache)             # <<<<<<<<<<<<<<
 * 
 *             self.get = types.MethodType(get, self)
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_v_cache)) { __Pyx_RaiseClosureNameError("cache"); __PYX_ERR(0, 1458, __pyx_L1_error) }
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_cache;
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 1458, __pyx_L1_error)
  }
  __pyx_t_2 = PyDict_Size(__pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 1458, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1457
 *                 cache.clear()
 * 
 *             def cache_len(self):             # <<<<<<<<<<<<<<
 *                 return len(cache)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing._UnboundedCache.__init__.cache_len", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1444
 * 
 *     class _UnboundedCache(object):
 *         def __init__(self):             # <<<<<<<<<<<<<<
 *             cache = {}
 *             self.not_in_cache = not_in_cache = object()
 */

static PyObject *__pyx_pf_10cPyparsing_15_UnboundedCache___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__ *__pyx_cur_scope;
  PyObject *__pyx_v_get = 0;
  PyObject *__pyx_v_set = 0;
  PyObject *__pyx_v_clear = 0;
  PyObject *__pyx_v_cache_len = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_20___init__(__pyx_ptype_10cPyparsing___pyx_scope_struct_20___init__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1444, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }

  /* "cPyparsing.pyx":1445
 *     class _UnboundedCache(object):
 *         def __init__(self):
 *             cache = {}             # <<<<<<<<<<<<<<
 *             self.not_in_cache = not_in_cache = object()
 * 
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_cache = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1446
 *         def __init__(self):
 *             cache = {}
 *             self.not_in_cache = not_in_cache = object()             # <<<<<<<<<<<<<<
 * 
 *             def get(self, key):
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_builtin_object); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_not_in_cache, __pyx_t_1) < 0) __PYX_ERR(0, 1446, __pyx_L1_error)
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_not_in_cache = __pyx_t_1;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1448
 *             self.not_in_cache = not_in_cache = object()
 * 
 *             def get(self, key):             # <<<<<<<<<<<<<<
 *                 return cache.get(key, not_in_cache)
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_15_UnboundedCache_8__init___1get, 0, __pyx_n_s_ParserElement__UnboundedCache, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__47)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_get = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1451
 *                 return cache.get(key, not_in_cache)
 * 
 *             def set(self, key, value):             # <<<<<<<<<<<<<<
 *                 cache[key] = value
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_15_UnboundedCache_8__init___3set, 0, __pyx_n_s_ParserElement__UnboundedCache_2, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__49)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_set = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1454
 *                 cache[key] = value
 * 
 *             def clear(self):             # <<<<<<<<<<<<<<
 *                 cache.clear()
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_15_UnboundedCache_8__init___5clear, 0, __pyx_n_s_ParserElement__UnboundedCache_3, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__51)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_clear = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1457
 *                 cache.clear()
 * 
 *             def cache_len(self):             # <<<<<<<<<<<<<<
 *                 return len(cache)
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_15_UnboundedCache_8__init___7cache_len, 0, __pyx_n_s_ParserElement__UnboundedCache_4, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__53)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cache_len = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1460
 *                 return len(cache)
 * 
 *             self.get = types.MethodType(get, self)             # <<<<<<<<<<<<<<
 *             self.set = types.MethodType(set, self)
 *             self.clear = types.MethodType(clear, self)
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_MethodType); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_get, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1460, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_get, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1460, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1460, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_2) {
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2); __pyx_t_2 = NULL;
    }
    __Pyx_INCREF(__pyx_v_get);
    __Pyx_GIVEREF(__pyx_v_get);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_get);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_self);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1460, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_get, __pyx_t_1) < 0) __PYX_ERR(0, 1460, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1461
 * 
 *             self.get = types.MethodType(get, self)
 *             self.set = types.MethodType(set, self)             # <<<<<<<<<<<<<<
 *             self.clear = types.MethodType(clear, self)
 *             self.__len__ = types.MethodType(cache_len, self)
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_MethodType); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_5)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_set, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1461, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_set, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1461, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_2 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_set);
    __Pyx_GIVEREF(__pyx_v_set);
    PyTuple_SET_ITEM(__pyx_t_2, 0+__pyx_t_4, __pyx_v_set);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_2, 1+__pyx_t_4, __pyx_v_self);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_set, __pyx_t_1) < 0) __PYX_ERR(0, 1461, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1462
 *             self.get = types.MethodType(get, self)
 *             self.set = types.MethodType(set, self)
 *             self.clear = types.MethodType(clear, self)             # <<<<<<<<<<<<<<
 *             self.__len__ = types.MethodType(cache_len, self)
 * 
 */
  __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_MethodType); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_clear, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1462, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_clear, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1462, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_3 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1462, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__pyx_t_5) {
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5); __pyx_t_5 = NULL;
    }
    __Pyx_INCREF(__pyx_v_clear);
    __Pyx_GIVEREF(__pyx_v_clear);
    PyTuple_SET_ITEM(__pyx_t_3, 0+__pyx_t_4, __pyx_v_clear);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_3, 1+__pyx_t_4, __pyx_v_self);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1462, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_clear, __pyx_t_1) < 0) __PYX_ERR(0, 1462, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1463
 *             self.set = types.MethodType(set, self)
 *             self.clear = types.MethodType(clear, self)
 *             self.__len__ = types.MethodType(cache_len, self)             # <<<<<<<<<<<<<<
 * 
 *     if _OrderedDict is not None:
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_MethodType); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_cache_len, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1463, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_cache_len, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1463, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1463, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_2) {
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2); __pyx_t_2 = NULL;
    }
    __Pyx_INCREF(__pyx_v_cache_len);
    __Pyx_GIVEREF(__pyx_v_cache_len);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_cache_len);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_self);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1463, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_len, __pyx_t_1) < 0) __PYX_ERR(0, 1463, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1444
 * 
 *     class _UnboundedCache(object):
 *         def __init__(self):             # <<<<<<<<<<<<<<
 *             cache = {}
 *             self.not_in_cache = not_in_cache = object()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing._UnboundedCache.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_get);
  __Pyx_XDECREF(__pyx_v_set);
  __Pyx_XDECREF(__pyx_v_clear);
  __Pyx_XDECREF(__pyx_v_cache_len);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1467
 *     if _OrderedDict is not None:
 *         class _FifoCache(object):
 *             def __init__(self, size):             # <<<<<<<<<<<<<<
 *                 self.not_in_cache = not_in_cache = object()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10_FifoCache_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_10_FifoCache_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_size = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_size,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_size)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 1467, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 1467, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_size = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1467, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing._FifoCache.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10_FifoCache___init__(__pyx_self, __pyx_v_self, __pyx_v_size);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1472
 *                 cache = _OrderedDict()
 * 
 *                 def get(self, key):             # <<<<<<<<<<<<<<
 *                     return cache.get(key, not_in_cache)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_8__init___1get(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10_FifoCache_8__init___1get = {"get", (PyCFunction)__pyx_pw_10cPyparsing_10_FifoCache_8__init___1get, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_8__init___1get(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_key = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_key,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_key)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get", 1, 2, 2, 1); __PYX_ERR(0, 1472, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get") < 0)) __PYX_ERR(0, 1472, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_key = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1472, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing._FifoCache.__init__.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10_FifoCache_8__init___get(__pyx_self, __pyx_v_self, __pyx_v_key);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_8__init___get(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_key) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__ *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__ *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("get", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__ *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":1473
 * 
 *                 def get(self, key):
 *                     return cache.get(key, not_in_cache)             # <<<<<<<<<<<<<<
 * 
 *                 def set(self, key, value):
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_v_cache)) { __Pyx_RaiseClosureNameError("cache"); __PYX_ERR(0, 1473, __pyx_L1_error) }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_cache, __pyx_n_s_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely(!__pyx_cur_scope->__pyx_v_not_in_cache)) { __Pyx_RaiseClosureNameError("not_in_cache"); __PYX_ERR(0, 1473, __pyx_L1_error) }
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_key, __pyx_cur_scope->__pyx_v_not_in_cache};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1473, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_key, __pyx_cur_scope->__pyx_v_not_in_cache};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1473, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1473, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_key);
    __Pyx_GIVEREF(__pyx_v_key);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_key);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_not_in_cache);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_not_in_cache);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_cur_scope->__pyx_v_not_in_cache);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1473, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1472
 *                 cache = _OrderedDict()
 * 
 *                 def get(self, key):             # <<<<<<<<<<<<<<
 *                     return cache.get(key, not_in_cache)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing._FifoCache.__init__.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1475
 *                     return cache.get(key, not_in_cache)
 * 
 *                 def set(self, key, value):             # <<<<<<<<<<<<<<
 *                     cache[key] = value
 *                     while len(cache) > size:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_8__init___3set(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10_FifoCache_8__init___3set = {"set", (PyCFunction)__pyx_pw_10cPyparsing_10_FifoCache_8__init___3set, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_8__init___3set(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_key = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_key,&__pyx_n_s_value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_key)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set", 1, 3, 3, 1); __PYX_ERR(0, 1475, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set", 1, 3, 3, 2); __PYX_ERR(0, 1475, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set") < 0)) __PYX_ERR(0, 1475, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_key = values[1];
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1475, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing._FifoCache.__init__.set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10_FifoCache_8__init___2set(__pyx_self, __pyx_v_self, __pyx_v_key, __pyx_v_value);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_8__init___2set(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__ *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__ *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  __Pyx_RefNannySetupContext("set", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__ *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":1476
 * 
 *                 def set(self, key, value):
 *                     cache[key] = value             # <<<<<<<<<<<<<<
 *                     while len(cache) > size:
 *                         try:
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_cache)) { __Pyx_RaiseClosureNameError("cache"); __PYX_ERR(0, 1476, __pyx_L1_error) }
  if (unlikely(PyObject_SetItem(__pyx_cur_scope->__pyx_v_cache, __pyx_v_key, __pyx_v_value) < 0)) __PYX_ERR(0, 1476, __pyx_L1_error)

  /* "cPyparsing.pyx":1477
 *                 def set(self, key, value):
 *                     cache[key] = value
 *                     while len(cache) > size:             # <<<<<<<<<<<<<<
 *                         try:
 *                             cache.popitem(False)
 */
  while (1) {
    if (unlikely(!__pyx_cur_scope->__pyx_v_cache)) { __Pyx_RaiseClosureNameError("cache"); __PYX_ERR(0, 1477, __pyx_L1_error) }
    __pyx_t_1 = __pyx_cur_scope->__pyx_v_cache;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 1477, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1477, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely(!__pyx_cur_scope->__pyx_v_size)) { __Pyx_RaiseClosureNameError("size"); __PYX_ERR(0, 1477, __pyx_L1_error) }
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_cur_scope->__pyx_v_size, Py_GT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1477, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 1477, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (!__pyx_t_4) break;

    /* "cPyparsing.pyx":1478
 *                     cache[key] = value
 *                     while len(cache) > size:
 *                         try:             # <<<<<<<<<<<<<<
 *                             cache.popitem(False)
 *                         except KeyError:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      /*try:*/ {

        /* "cPyparsing.pyx":1479
 *                     while len(cache) > size:
 *                         try:
 *                             cache.popitem(False)             # <<<<<<<<<<<<<<
 *                         except KeyError:
 *                             pass
 */
        if (unlikely(!__pyx_cur_scope->__pyx_v_cache)) { __Pyx_RaiseClosureNameError("cache"); __PYX_ERR(0, 1479, __pyx_L5_error) }
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_cache, __pyx_n_s_popitem); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1479, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__54, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1479, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "cPyparsing.pyx":1478
 *                     cache[key] = value
 *                     while len(cache) > size:
 *                         try:             # <<<<<<<<<<<<<<
 *                             cache.popitem(False)
 *                         except KeyError:
 */
      }
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L12_try_end;
      __pyx_L5_error:;
      __Pyx_PyThreadState_assign
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":1480
 *                         try:
 *                             cache.popitem(False)
 *                         except KeyError:             # <<<<<<<<<<<<<<
 *                             pass
 * 
 */
      __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
      if (__pyx_t_8) {
        __Pyx_ErrRestore(0,0,0);
        goto __pyx_L6_exception_handled;
      }
      goto __pyx_L7_except_error;
      __pyx_L7_except_error:;

      /* "cPyparsing.pyx":1478
 *                     cache[key] = value
 *                     while len(cache) > size:
 *                         try:             # <<<<<<<<<<<<<<
 *                             cache.popitem(False)
 *                         except KeyError:
 */
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
      goto __pyx_L1_error;
      __pyx_L6_exception_handled:;
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
      __pyx_L12_try_end:;
    }
  }

  /* "cPyparsing.pyx":1475
 *                     return cache.get(key, not_in_cache)
 * 
 *                 def set(self, key, value):             # <<<<<<<<<<<<<<
 *                     cache[key] = value
 *                     while len(cache) > size:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing._FifoCache.__init__.set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1483
 *                             pass
 * 
 *                 def clear(self):             # <<<<<<<<<<<<<<
 *                     cache.clear()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_8__init___5clear(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10_FifoCache_8__init___5clear = {"clear", (PyCFunction)__pyx_pw_10cPyparsing_10_FifoCache_8__init___5clear, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_8__init___5clear(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("clear (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_10_FifoCache_8__init___4clear(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_8__init___4clear(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__ *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__ *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("clear", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__ *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":1484
 * 
 *                 def clear(self):
 *                     cache.clear()             # <<<<<<<<<<<<<<
 * 
 *                 def cache_len(self):
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_cache)) { __Pyx_RaiseClosureNameError("cache"); __PYX_ERR(0, 1484, __pyx_L1_error) }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_cache, __pyx_n_s_clear); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1484, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1484, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1483
 *                             pass
 * 
 *                 def clear(self):             # <<<<<<<<<<<<<<
 *                     cache.clear()
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing._FifoCache.__init__.clear", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1486
 *                     cache.clear()
 * 
 *                 def cache_len(self):             # <<<<<<<<<<<<<<
 *                     return len(cache)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_8__init___7cache_len(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10_FifoCache_8__init___7cache_len = {"cache_len", (PyCFunction)__pyx_pw_10cPyparsing_10_FifoCache_8__init___7cache_len, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_8__init___7cache_len(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cache_len (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_10_FifoCache_8__init___6cache_len(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_8__init___6cache_len(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__ *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__ *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  __Pyx_RefNannySetupContext("cache_len", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__ *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":1487
 * 
 *                 def cache_len(self):
 *                     return len(cache)             # <<<<<<<<<<<<<<
 * 
 *                 self.get = types.MethodType(get, self)
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_v_cache)) { __Pyx_RaiseClosureNameError("cache"); __PYX_ERR(0, 1487, __pyx_L1_error) }
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_cache;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 1487, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1486
 *                     cache.clear()
 * 
 *                 def cache_len(self):             # <<<<<<<<<<<<<<
 *                     return len(cache)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing._FifoCache.__init__.cache_len", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1467
 *     if _OrderedDict is not None:
 *         class _FifoCache(object):
 *             def __init__(self, size):             # <<<<<<<<<<<<<<
 *                 self.not_in_cache = not_in_cache = object()
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_10_FifoCache___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_size) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__ *__pyx_cur_scope;
  PyObject *__pyx_v_get = 0;
  PyObject *__pyx_v_set = 0;
  PyObject *__pyx_v_clear = 0;
  PyObject *__pyx_v_cache_len = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_21___init__(__pyx_ptype_10cPyparsing___pyx_scope_struct_21___init__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1467, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_size = __pyx_v_size;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_size);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_size);

  /* "cPyparsing.pyx":1468
 *         class _FifoCache(object):
 *             def __init__(self, size):
 *                 self.not_in_cache = not_in_cache = object()             # <<<<<<<<<<<<<<
 * 
 *                 cache = _OrderedDict()
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_builtin_object); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_not_in_cache, __pyx_t_1) < 0) __PYX_ERR(0, 1468, __pyx_L1_error)
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_not_in_cache = __pyx_t_1;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1470
 *                 self.not_in_cache = not_in_cache = object()
 * 
 *                 cache = _OrderedDict()             # <<<<<<<<<<<<<<
 * 
 *                 def get(self, key):
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_OrderedDict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1470, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1470, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_cache = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1472
 *                 cache = _OrderedDict()
 * 
 *                 def get(self, key):             # <<<<<<<<<<<<<<
 *                     return cache.get(key, not_in_cache)
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10_FifoCache_8__init___1get, 0, __pyx_n_s_ParserElement__FifoCache___init, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__56)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_get = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1475
 *                     return cache.get(key, not_in_cache)
 * 
 *                 def set(self, key, value):             # <<<<<<<<<<<<<<
 *                     cache[key] = value
 *                     while len(cache) > size:
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10_FifoCache_8__init___3set, 0, __pyx_n_s_ParserElement__FifoCache___init_2, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__58)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_set = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1483
 *                             pass
 * 
 *                 def clear(self):             # <<<<<<<<<<<<<<
 *                     cache.clear()
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10_FifoCache_8__init___5clear, 0, __pyx_n_s_ParserElement__FifoCache___init_3, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__60)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_clear = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1486
 *                     cache.clear()
 * 
 *                 def cache_len(self):             # <<<<<<<<<<<<<<
 *                     return len(cache)
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10_FifoCache_8__init___7cache_len, 0, __pyx_n_s_ParserElement__FifoCache___init_4, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__62)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cache_len = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1489
 *                     return len(cache)
 * 
 *                 self.get = types.MethodType(get, self)             # <<<<<<<<<<<<<<
 *                 self.set = types.MethodType(set, self)
 *                 self.clear = types.MethodType(clear, self)
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_MethodType); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_get, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1489, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_get, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1489, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1489, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_2) {
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2); __pyx_t_2 = NULL;
    }
    __Pyx_INCREF(__pyx_v_get);
    __Pyx_GIVEREF(__pyx_v_get);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_get);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_self);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1489, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_get, __pyx_t_1) < 0) __PYX_ERR(0, 1489, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1490
 * 
 *                 self.get = types.MethodType(get, self)
 *                 self.set = types.MethodType(set, self)             # <<<<<<<<<<<<<<
 *                 self.clear = types.MethodType(clear, self)
 *                 self.__len__ = types.MethodType(cache_len, self)
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_MethodType); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_5)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_set, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1490, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_set, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1490, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_2 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1490, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_set);
    __Pyx_GIVEREF(__pyx_v_set);
    PyTuple_SET_ITEM(__pyx_t_2, 0+__pyx_t_4, __pyx_v_set);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_2, 1+__pyx_t_4, __pyx_v_self);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1490, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_set, __pyx_t_1) < 0) __PYX_ERR(0, 1490, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1491
 *                 self.get = types.MethodType(get, self)
 *                 self.set = types.MethodType(set, self)
 *                 self.clear = types.MethodType(clear, self)             # <<<<<<<<<<<<<<
 *                 self.__len__ = types.MethodType(cache_len, self)
 * 
 */
  __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_MethodType); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_clear, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1491, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_clear, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1491, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_3 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1491, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__pyx_t_5) {
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5); __pyx_t_5 = NULL;
    }
    __Pyx_INCREF(__pyx_v_clear);
    __Pyx_GIVEREF(__pyx_v_clear);
    PyTuple_SET_ITEM(__pyx_t_3, 0+__pyx_t_4, __pyx_v_clear);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_3, 1+__pyx_t_4, __pyx_v_self);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1491, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_clear, __pyx_t_1) < 0) __PYX_ERR(0, 1491, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1492
 *                 self.set = types.MethodType(set, self)
 *                 self.clear = types.MethodType(clear, self)
 *                 self.__len__ = types.MethodType(cache_len, self)             # <<<<<<<<<<<<<<
 * 
 *     else:
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_MethodType); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_cache_len, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1492, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_cache_len, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1492, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1492, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_2) {
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2); __pyx_t_2 = NULL;
    }
    __Pyx_INCREF(__pyx_v_cache_len);
    __Pyx_GIVEREF(__pyx_v_cache_len);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_cache_len);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_self);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1492, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_len, __pyx_t_1) < 0) __PYX_ERR(0, 1492, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1467
 *     if _OrderedDict is not None:
 *         class _FifoCache(object):
 *             def __init__(self, size):             # <<<<<<<<<<<<<<
 *                 self.not_in_cache = not_in_cache = object()
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing._FifoCache.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_get);
  __Pyx_XDECREF(__pyx_v_set);
  __Pyx_XDECREF(__pyx_v_clear);
  __Pyx_XDECREF(__pyx_v_cache_len);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1496
 *     else:
 *         class _FifoCache(object):
 *             def __init__(self, size):             # <<<<<<<<<<<<<<
 *                 self.not_in_cache = not_in_cache = object()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_3__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10_FifoCache_3__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_10_FifoCache_3__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_3__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_size = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_size,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_size)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 1496, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 1496, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_size = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1496, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing._FifoCache.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10_FifoCache_2__init__(__pyx_self, __pyx_v_self, __pyx_v_size);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1502
 *                 key_fifo = collections.deque([], size)
 * 
 *                 def get(self, key):             # <<<<<<<<<<<<<<
 *                     return cache.get(key, not_in_cache)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_8__init___9get(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10_FifoCache_8__init___9get = {"get", (PyCFunction)__pyx_pw_10cPyparsing_10_FifoCache_8__init___9get, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_8__init___9get(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_key = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_key,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_key)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get", 1, 2, 2, 1); __PYX_ERR(0, 1502, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get") < 0)) __PYX_ERR(0, 1502, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_key = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1502, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing._FifoCache.__init__.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10_FifoCache_8__init___8get(__pyx_self, __pyx_v_self, __pyx_v_key);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_8__init___8get(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_key) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__ *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__ *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("get", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__ *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":1503
 * 
 *                 def get(self, key):
 *                     return cache.get(key, not_in_cache)             # <<<<<<<<<<<<<<
 * 
 *                 def set(self, key, value):
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_v_cache)) { __Pyx_RaiseClosureNameError("cache"); __PYX_ERR(0, 1503, __pyx_L1_error) }
  if (unlikely(__pyx_cur_scope->__pyx_v_cache == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "get");
    __PYX_ERR(0, 1503, __pyx_L1_error)
  }
  if (unlikely(!__pyx_cur_scope->__pyx_v_not_in_cache)) { __Pyx_RaiseClosureNameError("not_in_cache"); __PYX_ERR(0, 1503, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_cur_scope->__pyx_v_cache, __pyx_v_key, __pyx_cur_scope->__pyx_v_not_in_cache); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1502
 *                 key_fifo = collections.deque([], size)
 * 
 *                 def get(self, key):             # <<<<<<<<<<<<<<
 *                     return cache.get(key, not_in_cache)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing._FifoCache.__init__.get", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1505
 *                     return cache.get(key, not_in_cache)
 * 
 *                 def set(self, key, value):             # <<<<<<<<<<<<<<
 *                     cache[key] = value
 *                     while len(key_fifo) > size:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_8__init___11set(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10_FifoCache_8__init___11set = {"set", (PyCFunction)__pyx_pw_10cPyparsing_10_FifoCache_8__init___11set, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_8__init___11set(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_key = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_key,&__pyx_n_s_value,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_key)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set", 1, 3, 3, 1); __PYX_ERR(0, 1505, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set", 1, 3, 3, 2); __PYX_ERR(0, 1505, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set") < 0)) __PYX_ERR(0, 1505, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_key = values[1];
    __pyx_v_value = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1505, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing._FifoCache.__init__.set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10_FifoCache_8__init___10set(__pyx_self, __pyx_v_self, __pyx_v_key, __pyx_v_value);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_8__init___10set(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__ *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__ *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("set", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__ *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":1506
 * 
 *                 def set(self, key, value):
 *                     cache[key] = value             # <<<<<<<<<<<<<<
 *                     while len(key_fifo) > size:
 *                         cache.pop(key_fifo.popleft(), None)
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_cache)) { __Pyx_RaiseClosureNameError("cache"); __PYX_ERR(0, 1506, __pyx_L1_error) }
  if (unlikely(__pyx_cur_scope->__pyx_v_cache == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 1506, __pyx_L1_error)
  }
  if (unlikely(PyDict_SetItem(__pyx_cur_scope->__pyx_v_cache, __pyx_v_key, __pyx_v_value) < 0)) __PYX_ERR(0, 1506, __pyx_L1_error)

  /* "cPyparsing.pyx":1507
 *                 def set(self, key, value):
 *                     cache[key] = value
 *                     while len(key_fifo) > size:             # <<<<<<<<<<<<<<
 *                         cache.pop(key_fifo.popleft(), None)
 *                     key_fifo.append(key)
 */
  while (1) {
    if (unlikely(!__pyx_cur_scope->__pyx_v_key_fifo)) { __Pyx_RaiseClosureNameError("key_fifo"); __PYX_ERR(0, 1507, __pyx_L1_error) }
    __pyx_t_1 = __pyx_cur_scope->__pyx_v_key_fifo;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 1507, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1507, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely(!__pyx_cur_scope->__pyx_v_size)) { __Pyx_RaiseClosureNameError("size"); __PYX_ERR(0, 1507, __pyx_L1_error) }
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_cur_scope->__pyx_v_size, Py_GT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1507, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 1507, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (!__pyx_t_4) break;

    /* "cPyparsing.pyx":1508
 *                     cache[key] = value
 *                     while len(key_fifo) > size:
 *                         cache.pop(key_fifo.popleft(), None)             # <<<<<<<<<<<<<<
 *                     key_fifo.append(key)
 * 
 */
    if (unlikely(!__pyx_cur_scope->__pyx_v_cache)) { __Pyx_RaiseClosureNameError("cache"); __PYX_ERR(0, 1508, __pyx_L1_error) }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_cache, __pyx_n_s_pop); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1508, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely(!__pyx_cur_scope->__pyx_v_key_fifo)) { __Pyx_RaiseClosureNameError("key_fifo"); __PYX_ERR(0, 1508, __pyx_L1_error) }
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_key_fifo, __pyx_n_s_popleft); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1508, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    if (__pyx_t_7) {
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1508, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else {
      __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1508, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    __pyx_t_8 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_8 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_t_5, Py_None};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1508, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_t_5, Py_None};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1508, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(2+__pyx_t_8); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1508, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__pyx_t_6) {
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_8, __pyx_t_5);
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_8, Py_None);
      __pyx_t_5 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1508, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }

  /* "cPyparsing.pyx":1509
 *                     while len(key_fifo) > size:
 *                         cache.pop(key_fifo.popleft(), None)
 *                     key_fifo.append(key)             # <<<<<<<<<<<<<<
 * 
 *                 def clear(self):
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_key_fifo)) { __Pyx_RaiseClosureNameError("key_fifo"); __PYX_ERR(0, 1509, __pyx_L1_error) }
  __pyx_t_9 = __Pyx_PyObject_Append(__pyx_cur_scope->__pyx_v_key_fifo, __pyx_v_key); if (unlikely(__pyx_t_9 == -1)) __PYX_ERR(0, 1509, __pyx_L1_error)

  /* "cPyparsing.pyx":1505
 *                     return cache.get(key, not_in_cache)
 * 
 *                 def set(self, key, value):             # <<<<<<<<<<<<<<
 *                     cache[key] = value
 *                     while len(key_fifo) > size:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing._FifoCache.__init__.set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1511
 *                     key_fifo.append(key)
 * 
 *                 def clear(self):             # <<<<<<<<<<<<<<
 *                     cache.clear()
 *                     key_fifo.clear()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_8__init___13clear(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10_FifoCache_8__init___13clear = {"clear", (PyCFunction)__pyx_pw_10cPyparsing_10_FifoCache_8__init___13clear, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_8__init___13clear(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("clear (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_10_FifoCache_8__init___12clear(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_8__init___12clear(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__ *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__ *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("clear", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__ *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":1512
 * 
 *                 def clear(self):
 *                     cache.clear()             # <<<<<<<<<<<<<<
 *                     key_fifo.clear()
 * 
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_cache)) { __Pyx_RaiseClosureNameError("cache"); __PYX_ERR(0, 1512, __pyx_L1_error) }
  if (unlikely(__pyx_cur_scope->__pyx_v_cache == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "clear");
    __PYX_ERR(0, 1512, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyDict_Clear(__pyx_cur_scope->__pyx_v_cache); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 1512, __pyx_L1_error)

  /* "cPyparsing.pyx":1513
 *                 def clear(self):
 *                     cache.clear()
 *                     key_fifo.clear()             # <<<<<<<<<<<<<<
 * 
 *                 def cache_len(self):
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_key_fifo)) { __Pyx_RaiseClosureNameError("key_fifo"); __PYX_ERR(0, 1513, __pyx_L1_error) }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_key_fifo, __pyx_n_s_clear); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1513, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1513, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1511
 *                     key_fifo.append(key)
 * 
 *                 def clear(self):             # <<<<<<<<<<<<<<
 *                     cache.clear()
 *                     key_fifo.clear()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing._FifoCache.__init__.clear", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1515
 *                     key_fifo.clear()
 * 
 *                 def cache_len(self):             # <<<<<<<<<<<<<<
 *                     return len(cache)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_8__init___15cache_len(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10_FifoCache_8__init___15cache_len = {"cache_len", (PyCFunction)__pyx_pw_10cPyparsing_10_FifoCache_8__init___15cache_len, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_10_FifoCache_8__init___15cache_len(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cache_len (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_10_FifoCache_8__init___14cache_len(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_8__init___14cache_len(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__ *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__ *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  __Pyx_RefNannySetupContext("cache_len", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__ *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":1516
 * 
 *                 def cache_len(self):
 *                     return len(cache)             # <<<<<<<<<<<<<<
 * 
 *                 self.get = types.MethodType(get, self)
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_v_cache)) { __Pyx_RaiseClosureNameError("cache"); __PYX_ERR(0, 1516, __pyx_L1_error) }
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_cache;
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 1516, __pyx_L1_error)
  }
  __pyx_t_2 = PyDict_Size(__pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 1516, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1515
 *                     key_fifo.clear()
 * 
 *                 def cache_len(self):             # <<<<<<<<<<<<<<
 *                     return len(cache)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing._FifoCache.__init__.cache_len", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1496
 *     else:
 *         class _FifoCache(object):
 *             def __init__(self, size):             # <<<<<<<<<<<<<<
 *                 self.not_in_cache = not_in_cache = object()
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_10_FifoCache_2__init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_size) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__ *__pyx_cur_scope;
  PyObject *__pyx_v_get = 0;
  PyObject *__pyx_v_set = 0;
  PyObject *__pyx_v_clear = 0;
  PyObject *__pyx_v_cache_len = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_22___init__(__pyx_ptype_10cPyparsing___pyx_scope_struct_22___init__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1496, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_size = __pyx_v_size;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_size);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_size);

  /* "cPyparsing.pyx":1497
 *         class _FifoCache(object):
 *             def __init__(self, size):
 *                 self.not_in_cache = not_in_cache = object()             # <<<<<<<<<<<<<<
 * 
 *                 cache = {}
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_builtin_object); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_not_in_cache, __pyx_t_1) < 0) __PYX_ERR(0, 1497, __pyx_L1_error)
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_not_in_cache = __pyx_t_1;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1499
 *                 self.not_in_cache = not_in_cache = object()
 * 
 *                 cache = {}             # <<<<<<<<<<<<<<
 *                 key_fifo = collections.deque([], size)
 * 
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_cache = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1500
 * 
 *                 cache = {}
 *                 key_fifo = collections.deque([], size)             # <<<<<<<<<<<<<<
 * 
 *                 def get(self, key):
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_collections); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_deque); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_t_2, __pyx_cur_scope->__pyx_v_size};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1500, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_t_2, __pyx_cur_scope->__pyx_v_size};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1500, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  {
    __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1500, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_t_2);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_size);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_size);
    PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_cur_scope->__pyx_v_size);
    __pyx_t_2 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1500, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_key_fifo = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1502
 *                 key_fifo = collections.deque([], size)
 * 
 *                 def get(self, key):             # <<<<<<<<<<<<<<
 *                     return cache.get(key, not_in_cache)
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10_FifoCache_8__init___9get, 0, __pyx_n_s_ParserElement__FifoCache___init, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__64)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_get = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1505
 *                     return cache.get(key, not_in_cache)
 * 
 *                 def set(self, key, value):             # <<<<<<<<<<<<<<
 *                     cache[key] = value
 *                     while len(key_fifo) > size:
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10_FifoCache_8__init___11set, 0, __pyx_n_s_ParserElement__FifoCache___init_2, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__66)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_set = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1511
 *                     key_fifo.append(key)
 * 
 *                 def clear(self):             # <<<<<<<<<<<<<<
 *                     cache.clear()
 *                     key_fifo.clear()
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10_FifoCache_8__init___13clear, 0, __pyx_n_s_ParserElement__FifoCache___init_3, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__68)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_clear = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1515
 *                     key_fifo.clear()
 * 
 *                 def cache_len(self):             # <<<<<<<<<<<<<<
 *                     return len(cache)
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10_FifoCache_8__init___15cache_len, 0, __pyx_n_s_ParserElement__FifoCache___init_4, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__70)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cache_len = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1518
 *                     return len(cache)
 * 
 *                 self.get = types.MethodType(get, self)             # <<<<<<<<<<<<<<
 *                 self.set = types.MethodType(set, self)
 *                 self.clear = types.MethodType(clear, self)
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_MethodType); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_6)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_get, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1518, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_get, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1518, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_2 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1518, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_get);
    __Pyx_GIVEREF(__pyx_v_get);
    PyTuple_SET_ITEM(__pyx_t_2, 0+__pyx_t_5, __pyx_v_get);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_2, 1+__pyx_t_5, __pyx_v_self);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1518, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_get, __pyx_t_1) < 0) __PYX_ERR(0, 1518, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1519
 * 
 *                 self.get = types.MethodType(get, self)
 *                 self.set = types.MethodType(set, self)             # <<<<<<<<<<<<<<
 *                 self.clear = types.MethodType(clear, self)
 *                 self.__len__ = types.MethodType(cache_len, self)
 */
  __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_MethodType); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_v_set, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1519, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_v_set, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1519, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_3 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1519, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__pyx_t_6) {
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_6); __pyx_t_6 = NULL;
    }
    __Pyx_INCREF(__pyx_v_set);
    __Pyx_GIVEREF(__pyx_v_set);
    PyTuple_SET_ITEM(__pyx_t_3, 0+__pyx_t_5, __pyx_v_set);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_3, 1+__pyx_t_5, __pyx_v_self);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1519, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_set, __pyx_t_1) < 0) __PYX_ERR(0, 1519, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1520
 *                 self.get = types.MethodType(get, self)
 *                 self.set = types.MethodType(set, self)
 *                 self.clear = types.MethodType(clear, self)             # <<<<<<<<<<<<<<
 *                 self.__len__ = types.MethodType(cache_len, self)
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_MethodType); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_clear, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1520, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_clear, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1520, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1520, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__pyx_t_2) {
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2); __pyx_t_2 = NULL;
    }
    __Pyx_INCREF(__pyx_v_clear);
    __Pyx_GIVEREF(__pyx_v_clear);
    PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_v_clear);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_v_self);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1520, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_clear, __pyx_t_1) < 0) __PYX_ERR(0, 1520, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1521
 *                 self.set = types.MethodType(set, self)
 *                 self.clear = types.MethodType(clear, self)
 *                 self.__len__ = types.MethodType(cache_len, self)             # <<<<<<<<<<<<<<
 * 
 *     # argument cache for optimizing repeated calls when backtracking through recursive expressions
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_types); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_MethodType); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_6)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_cache_len, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1521, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_cache_len, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1521, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_2 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1521, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_cache_len);
    __Pyx_GIVEREF(__pyx_v_cache_len);
    PyTuple_SET_ITEM(__pyx_t_2, 0+__pyx_t_5, __pyx_v_cache_len);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_2, 1+__pyx_t_5, __pyx_v_self);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1521, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_len, __pyx_t_1) < 0) __PYX_ERR(0, 1521, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1496
 *     else:
 *         class _FifoCache(object):
 *             def __init__(self, size):             # <<<<<<<<<<<<<<
 *                 self.not_in_cache = not_in_cache = object()
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing._FifoCache.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_get);
  __Pyx_XDECREF(__pyx_v_set);
  __Pyx_XDECREF(__pyx_v_clear);
  __Pyx_XDECREF(__pyx_v_cache_len);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1530
 *     # this method gets repeatedly called during backtracking with the same arguments -
 *     # we can cache these arguments and save ourselves the trouble of re-parsing the contained expression
 *     def _parseCache(self, instring, int loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *         HIT, MISS = 0, 1
 *         lookup = (self, instring, loc, callPreParse, doActions)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_37_parseCache(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_37_parseCache = {"_parseCache", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_37_parseCache, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_37_parseCache(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_v_callPreParse = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_parseCache (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,&__pyx_n_s_callPreParse,0};
    PyObject* values[5] = {0,0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    values[4] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_parseCache", 0, 3, 5, 1); __PYX_ERR(0, 1530, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_parseCache", 0, 3, 5, 2); __PYX_ERR(0, 1530, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
        case  4:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_callPreParse);
          if (value) { values[4] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "_parseCache") < 0)) __PYX_ERR(0, 1530, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1530, __pyx_L3_error)
    __pyx_v_doActions = values[3];
    __pyx_v_callPreParse = values[4];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_parseCache", 0, 3, 5, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1530, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement._parseCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_36_parseCache(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions, __pyx_v_callPreParse);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_36_parseCache(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, PyObject *__pyx_v_doActions, PyObject *__pyx_v_callPreParse) {
  long __pyx_v_HIT;
  long __pyx_v_MISS;
  PyObject *__pyx_v_lookup = NULL;
  PyObject *__pyx_v_cache = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_pe = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  long __pyx_t_1;
  long __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  int __pyx_t_21;
  char const *__pyx_t_22;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  PyObject *__pyx_t_27 = NULL;
  PyObject *__pyx_t_28 = NULL;
  __Pyx_RefNannySetupContext("_parseCache", 0);

  /* "cPyparsing.pyx":1531
 *     # we can cache these arguments and save ourselves the trouble of re-parsing the contained expression
 *     def _parseCache(self, instring, int loc, doActions=True, callPreParse=True):
 *         HIT, MISS = 0, 1             # <<<<<<<<<<<<<<
 *         lookup = (self, instring, loc, callPreParse, doActions)
 *         with ParserElement.packrat_cache_lock:
 */
  __pyx_t_1 = 0;
  __pyx_t_2 = 1;
  __pyx_v_HIT = __pyx_t_1;
  __pyx_v_MISS = __pyx_t_2;

  /* "cPyparsing.pyx":1532
 *     def _parseCache(self, instring, int loc, doActions=True, callPreParse=True):
 *         HIT, MISS = 0, 1
 *         lookup = (self, instring, loc, callPreParse, doActions)             # <<<<<<<<<<<<<<
 *         with ParserElement.packrat_cache_lock:
 *             cache = ParserElement.packrat_cache
 */
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_self);
  __Pyx_INCREF(__pyx_v_instring);
  __Pyx_GIVEREF(__pyx_v_instring);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_instring);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_3);
  __Pyx_INCREF(__pyx_v_callPreParse);
  __Pyx_GIVEREF(__pyx_v_callPreParse);
  PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_v_callPreParse);
  __Pyx_INCREF(__pyx_v_doActions);
  __Pyx_GIVEREF(__pyx_v_doActions);
  PyTuple_SET_ITEM(__pyx_t_4, 4, __pyx_v_doActions);
  __pyx_t_3 = 0;
  __pyx_v_lookup = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":1533
 *         HIT, MISS = 0, 1
 *         lookup = (self, instring, loc, callPreParse, doActions)
 *         with ParserElement.packrat_cache_lock:             # <<<<<<<<<<<<<<
 *             cache = ParserElement.packrat_cache
 *             value = cache.get(lookup)
 */
  /*with:*/ {
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1533, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_packrat_cache_lock); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1533, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_PyObject_LookupSpecial(__pyx_t_3, __pyx_n_s_exit); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1533, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_LookupSpecial(__pyx_t_3, __pyx_n_s_enter); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1533, __pyx_L3_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    if (__pyx_t_7) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1533, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else {
      __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1533, __pyx_L3_error)
    }
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    /*try:*/ {
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_10);
        /*try:*/ {

          /* "cPyparsing.pyx":1534
 *         lookup = (self, instring, loc, callPreParse, doActions)
 *         with ParserElement.packrat_cache_lock:
 *             cache = ParserElement.packrat_cache             # <<<<<<<<<<<<<<
 *             value = cache.get(lookup)
 *             if value is cache.not_in_cache:
 */
          __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1534, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_packrat_cache); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1534, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_v_cache = __pyx_t_4;
          __pyx_t_4 = 0;

          /* "cPyparsing.pyx":1535
 *         with ParserElement.packrat_cache_lock:
 *             cache = ParserElement.packrat_cache
 *             value = cache.get(lookup)             # <<<<<<<<<<<<<<
 *             if value is cache.not_in_cache:
 *                 ParserElement.packrat_cache_stats[MISS] += 1
 */
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_cache, __pyx_n_s_get); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1535, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_6 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_3, function);
            }
          }
          if (!__pyx_t_6) {
            __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_lookup); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1535, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_4);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_3)) {
              PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_lookup};
              __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1535, __pyx_L7_error)
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_GOTREF(__pyx_t_4);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
              PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_lookup};
              __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1535, __pyx_L7_error)
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_GOTREF(__pyx_t_4);
            } else
            #endif
            {
              __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1535, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
              __Pyx_INCREF(__pyx_v_lookup);
              __Pyx_GIVEREF(__pyx_v_lookup);
              PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_lookup);
              __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1535, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_v_value = __pyx_t_4;
          __pyx_t_4 = 0;

          /* "cPyparsing.pyx":1536
 *             cache = ParserElement.packrat_cache
 *             value = cache.get(lookup)
 *             if value is cache.not_in_cache:             # <<<<<<<<<<<<<<
 *                 ParserElement.packrat_cache_stats[MISS] += 1
 *                 try:
 */
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_cache, __pyx_n_s_not_in_cache); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1536, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_11 = (__pyx_v_value == __pyx_t_4);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_12 = (__pyx_t_11 != 0);
          if (__pyx_t_12) {

            /* "cPyparsing.pyx":1537
 *             value = cache.get(lookup)
 *             if value is cache.not_in_cache:
 *                 ParserElement.packrat_cache_stats[MISS] += 1             # <<<<<<<<<<<<<<
 *                 try:
 *                     value = self._parseNoCache(instring, loc, doActions, callPreParse)
 */
            __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1537, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_4);
            __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_packrat_cache_stats); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1537, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __pyx_t_2 = __pyx_v_MISS;
            __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_3, __pyx_t_2, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1537, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_4);
            __pyx_t_7 = __Pyx_PyInt_AddObjC(__pyx_t_4, __pyx_int_1, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1537, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(__Pyx_SetItemInt(__pyx_t_3, __pyx_t_2, __pyx_t_7, long, 1, __Pyx_PyInt_From_long, 0, 1, 1) < 0)) __PYX_ERR(0, 1537, __pyx_L7_error)
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

            /* "cPyparsing.pyx":1538
 *             if value is cache.not_in_cache:
 *                 ParserElement.packrat_cache_stats[MISS] += 1
 *                 try:             # <<<<<<<<<<<<<<
 *                     value = self._parseNoCache(instring, loc, doActions, callPreParse)
 *                 except ParseBaseException as pe:
 */
            {
              __Pyx_PyThreadState_declare
              __Pyx_PyThreadState_assign
              __Pyx_ExceptionSave(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
              __Pyx_XGOTREF(__pyx_t_13);
              __Pyx_XGOTREF(__pyx_t_14);
              __Pyx_XGOTREF(__pyx_t_15);
              /*try:*/ {

                /* "cPyparsing.pyx":1539
 *                 ParserElement.packrat_cache_stats[MISS] += 1
 *                 try:
 *                     value = self._parseNoCache(instring, loc, doActions, callPreParse)             # <<<<<<<<<<<<<<
 *                 except ParseBaseException as pe:
 *                     # cache a copy of the exception, without the traceback
 */
                __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseNoCache); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1539, __pyx_L16_error)
                __Pyx_GOTREF(__pyx_t_7);
                __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1539, __pyx_L16_error)
                __Pyx_GOTREF(__pyx_t_4);
                __pyx_t_6 = NULL;
                __pyx_t_16 = 0;
                if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
                  __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
                  if (likely(__pyx_t_6)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
                    __Pyx_INCREF(__pyx_t_6);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_7, function);
                    __pyx_t_16 = 1;
                  }
                }
                #if CYTHON_FAST_PYCALL
                if (PyFunction_Check(__pyx_t_7)) {
                  PyObject *__pyx_temp[5] = {__pyx_t_6, __pyx_v_instring, __pyx_t_4, __pyx_v_doActions, __pyx_v_callPreParse};
                  __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_16, 4+__pyx_t_16); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1539, __pyx_L16_error)
                  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
                  __Pyx_GOTREF(__pyx_t_3);
                  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                } else
                #endif
                #if CYTHON_FAST_PYCCALL
                if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
                  PyObject *__pyx_temp[5] = {__pyx_t_6, __pyx_v_instring, __pyx_t_4, __pyx_v_doActions, __pyx_v_callPreParse};
                  __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_16, 4+__pyx_t_16); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1539, __pyx_L16_error)
                  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
                  __Pyx_GOTREF(__pyx_t_3);
                  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                } else
                #endif
                {
                  __pyx_t_17 = PyTuple_New(4+__pyx_t_16); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1539, __pyx_L16_error)
                  __Pyx_GOTREF(__pyx_t_17);
                  if (__pyx_t_6) {
                    __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_t_6); __pyx_t_6 = NULL;
                  }
                  __Pyx_INCREF(__pyx_v_instring);
                  __Pyx_GIVEREF(__pyx_v_instring);
                  PyTuple_SET_ITEM(__pyx_t_17, 0+__pyx_t_16, __pyx_v_instring);
                  __Pyx_GIVEREF(__pyx_t_4);
                  PyTuple_SET_ITEM(__pyx_t_17, 1+__pyx_t_16, __pyx_t_4);
                  __Pyx_INCREF(__pyx_v_doActions);
                  __Pyx_GIVEREF(__pyx_v_doActions);
                  PyTuple_SET_ITEM(__pyx_t_17, 2+__pyx_t_16, __pyx_v_doActions);
                  __Pyx_INCREF(__pyx_v_callPreParse);
                  __Pyx_GIVEREF(__pyx_v_callPreParse);
                  PyTuple_SET_ITEM(__pyx_t_17, 3+__pyx_t_16, __pyx_v_callPreParse);
                  __pyx_t_4 = 0;
                  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_17, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1539, __pyx_L16_error)
                  __Pyx_GOTREF(__pyx_t_3);
                  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
                }
                __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
                __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_3);
                __pyx_t_3 = 0;

                /* "cPyparsing.pyx":1538
 *             if value is cache.not_in_cache:
 *                 ParserElement.packrat_cache_stats[MISS] += 1
 *                 try:             # <<<<<<<<<<<<<<
 *                     value = self._parseNoCache(instring, loc, doActions, callPreParse)
 *                 except ParseBaseException as pe:
 */
              }

              /* "cPyparsing.pyx":1545
 *                     raise
 *                 else:
 *                     cache.set(lookup, (value[0], value[1].copy()))             # <<<<<<<<<<<<<<
 *                     return value
 *             else:
 */
              /*else:*/ {
                __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_cache, __pyx_n_s_set); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1545, __pyx_L18_except_error)
                __Pyx_GOTREF(__pyx_t_7);
                __pyx_t_17 = __Pyx_GetItemInt(__pyx_v_value, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1545, __pyx_L18_except_error)
                __Pyx_GOTREF(__pyx_t_17);
                __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_value, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1545, __pyx_L18_except_error)
                __Pyx_GOTREF(__pyx_t_6);
                __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_copy); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1545, __pyx_L18_except_error)
                __Pyx_GOTREF(__pyx_t_18);
                __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                __pyx_t_6 = NULL;
                if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_18))) {
                  __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_18);
                  if (likely(__pyx_t_6)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_18);
                    __Pyx_INCREF(__pyx_t_6);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_18, function);
                  }
                }
                if (__pyx_t_6) {
                  __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_18, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1545, __pyx_L18_except_error)
                  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                } else {
                  __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_18); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1545, __pyx_L18_except_error)
                }
                __Pyx_GOTREF(__pyx_t_4);
                __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
                __pyx_t_18 = PyTuple_New(2); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1545, __pyx_L18_except_error)
                __Pyx_GOTREF(__pyx_t_18);
                __Pyx_GIVEREF(__pyx_t_17);
                PyTuple_SET_ITEM(__pyx_t_18, 0, __pyx_t_17);
                __Pyx_GIVEREF(__pyx_t_4);
                PyTuple_SET_ITEM(__pyx_t_18, 1, __pyx_t_4);
                __pyx_t_17 = 0;
                __pyx_t_4 = 0;
                __pyx_t_4 = NULL;
                __pyx_t_16 = 0;
                if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
                  __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
                  if (likely(__pyx_t_4)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
                    __Pyx_INCREF(__pyx_t_4);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_7, function);
                    __pyx_t_16 = 1;
                  }
                }
                #if CYTHON_FAST_PYCALL
                if (PyFunction_Check(__pyx_t_7)) {
                  PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_lookup, __pyx_t_18};
                  __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_16, 2+__pyx_t_16); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1545, __pyx_L18_except_error)
                  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                  __Pyx_GOTREF(__pyx_t_3);
                  __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
                } else
                #endif
                #if CYTHON_FAST_PYCCALL
                if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
                  PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_lookup, __pyx_t_18};
                  __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_16, 2+__pyx_t_16); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1545, __pyx_L18_except_error)
                  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                  __Pyx_GOTREF(__pyx_t_3);
                  __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
                } else
                #endif
                {
                  __pyx_t_17 = PyTuple_New(2+__pyx_t_16); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1545, __pyx_L18_except_error)
                  __Pyx_GOTREF(__pyx_t_17);
                  if (__pyx_t_4) {
                    __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_t_4); __pyx_t_4 = NULL;
                  }
                  __Pyx_INCREF(__pyx_v_lookup);
                  __Pyx_GIVEREF(__pyx_v_lookup);
                  PyTuple_SET_ITEM(__pyx_t_17, 0+__pyx_t_16, __pyx_v_lookup);
                  __Pyx_GIVEREF(__pyx_t_18);
                  PyTuple_SET_ITEM(__pyx_t_17, 1+__pyx_t_16, __pyx_t_18);
                  __pyx_t_18 = 0;
                  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_17, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1545, __pyx_L18_except_error)
                  __Pyx_GOTREF(__pyx_t_3);
                  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
                }
                __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
                __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

                /* "cPyparsing.pyx":1546
 *                 else:
 *                     cache.set(lookup, (value[0], value[1].copy()))
 *                     return value             # <<<<<<<<<<<<<<
 *             else:
 *                 ParserElement.packrat_cache_stats[HIT] += 1
 */
                __Pyx_XDECREF(__pyx_r);
                __Pyx_INCREF(__pyx_v_value);
                __pyx_r = __pyx_v_value;
                goto __pyx_L19_except_return;
              }
              __pyx_L16_error:;
              __Pyx_PyThreadState_assign
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

              /* "cPyparsing.pyx":1540
 *                 try:
 *                     value = self._parseNoCache(instring, loc, doActions, callPreParse)
 *                 except ParseBaseException as pe:             # <<<<<<<<<<<<<<
 *                     # cache a copy of the exception, without the traceback
 *                     cache.set(lookup, pe.__class__(*pe.args))
 */
              __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1540, __pyx_L18_except_error)
              __Pyx_GOTREF(__pyx_t_3);
              __pyx_t_16 = __Pyx_PyErr_ExceptionMatches(__pyx_t_3);
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
              if (__pyx_t_16) {
                __Pyx_AddTraceback("cPyparsing.ParserElement._parseCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
                if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_7, &__pyx_t_17) < 0) __PYX_ERR(0, 1540, __pyx_L18_except_error)
                __Pyx_GOTREF(__pyx_t_3);
                __Pyx_GOTREF(__pyx_t_7);
                __Pyx_GOTREF(__pyx_t_17);
                __Pyx_INCREF(__pyx_t_7);
                __pyx_v_pe = __pyx_t_7;
                /*try:*/ {

                  /* "cPyparsing.pyx":1542
 *                 except ParseBaseException as pe:
 *                     # cache a copy of the exception, without the traceback
 *                     cache.set(lookup, pe.__class__(*pe.args))             # <<<<<<<<<<<<<<
 *                     raise
 *                 else:
 */
                  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_cache, __pyx_n_s_set); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1542, __pyx_L29_error)
                  __Pyx_GOTREF(__pyx_t_4);
                  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_pe, __pyx_n_s_class); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1542, __pyx_L29_error)
                  __Pyx_GOTREF(__pyx_t_6);
                  __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_v_pe, __pyx_n_s_args); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 1542, __pyx_L29_error)
                  __Pyx_GOTREF(__pyx_t_19);
                  __pyx_t_20 = PySequence_Tuple(__pyx_t_19); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 1542, __pyx_L29_error)
                  __Pyx_GOTREF(__pyx_t_20);
                  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
                  __pyx_t_19 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_20, NULL); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 1542, __pyx_L29_error)
                  __Pyx_GOTREF(__pyx_t_19);
                  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                  __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
                  __pyx_t_20 = NULL;
                  __pyx_t_16 = 0;
                  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
                    __pyx_t_20 = PyMethod_GET_SELF(__pyx_t_4);
                    if (likely(__pyx_t_20)) {
                      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
                      __Pyx_INCREF(__pyx_t_20);
                      __Pyx_INCREF(function);
                      __Pyx_DECREF_SET(__pyx_t_4, function);
                      __pyx_t_16 = 1;
                    }
                  }
                  #if CYTHON_FAST_PYCALL
                  if (PyFunction_Check(__pyx_t_4)) {
                    PyObject *__pyx_temp[3] = {__pyx_t_20, __pyx_v_lookup, __pyx_t_19};
                    __pyx_t_18 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_16, 2+__pyx_t_16); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1542, __pyx_L29_error)
                    __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
                    __Pyx_GOTREF(__pyx_t_18);
                    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
                  } else
                  #endif
                  #if CYTHON_FAST_PYCCALL
                  if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
                    PyObject *__pyx_temp[3] = {__pyx_t_20, __pyx_v_lookup, __pyx_t_19};
                    __pyx_t_18 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_16, 2+__pyx_t_16); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1542, __pyx_L29_error)
                    __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
                    __Pyx_GOTREF(__pyx_t_18);
                    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
                  } else
                  #endif
                  {
                    __pyx_t_6 = PyTuple_New(2+__pyx_t_16); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1542, __pyx_L29_error)
                    __Pyx_GOTREF(__pyx_t_6);
                    if (__pyx_t_20) {
                      __Pyx_GIVEREF(__pyx_t_20); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_20); __pyx_t_20 = NULL;
                    }
                    __Pyx_INCREF(__pyx_v_lookup);
                    __Pyx_GIVEREF(__pyx_v_lookup);
                    PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_16, __pyx_v_lookup);
                    __Pyx_GIVEREF(__pyx_t_19);
                    PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_16, __pyx_t_19);
                    __pyx_t_19 = 0;
                    __pyx_t_18 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1542, __pyx_L29_error)
                    __Pyx_GOTREF(__pyx_t_18);
                    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                  }
                  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                  __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;

                  /* "cPyparsing.pyx":1543
 *                     # cache a copy of the exception, without the traceback
 *                     cache.set(lookup, pe.__class__(*pe.args))
 *                     raise             # <<<<<<<<<<<<<<
 *                 else:
 *                     cache.set(lookup, (value[0], value[1].copy()))
 */
                  __Pyx_GIVEREF(__pyx_t_3);
                  __Pyx_GIVEREF(__pyx_t_7);
                  __Pyx_XGIVEREF(__pyx_t_17);
                  __Pyx_ErrRestoreWithState(__pyx_t_3, __pyx_t_7, __pyx_t_17);
                  __pyx_t_3 = 0; __pyx_t_7 = 0; __pyx_t_17 = 0; 
                  __PYX_ERR(0, 1543, __pyx_L29_error)
                }

                /* "cPyparsing.pyx":1540
 *                 try:
 *                     value = self._parseNoCache(instring, loc, doActions, callPreParse)
 *                 except ParseBaseException as pe:             # <<<<<<<<<<<<<<
 *                     # cache a copy of the exception, without the traceback
 *                     cache.set(lookup, pe.__class__(*pe.args))
 */
                /*finally:*/ {
                  /*exception exit:*/{
                    __Pyx_PyThreadState_declare
                    __pyx_L29_error:;
                    __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0; __pyx_t_26 = 0; __pyx_t_27 = 0; __pyx_t_28 = 0;
                    __Pyx_PyThreadState_assign
                    __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
                    __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
                    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
                    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                    __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
                    if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_26, &__pyx_t_27, &__pyx_t_28);
                    if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_23, &__pyx_t_24, &__pyx_t_25) < 0)) __Pyx_ErrFetch(&__pyx_t_23, &__pyx_t_24, &__pyx_t_25);
                    __Pyx_XGOTREF(__pyx_t_23);
                    __Pyx_XGOTREF(__pyx_t_24);
                    __Pyx_XGOTREF(__pyx_t_25);
                    __Pyx_XGOTREF(__pyx_t_26);
                    __Pyx_XGOTREF(__pyx_t_27);
                    __Pyx_XGOTREF(__pyx_t_28);
                    __pyx_t_16 = __pyx_lineno; __pyx_t_21 = __pyx_clineno; __pyx_t_22 = __pyx_filename;
                    {
                      __Pyx_DECREF(__pyx_v_pe);
                      __pyx_v_pe = NULL;
                    }
                    __Pyx_PyThreadState_assign
                    if (PY_MAJOR_VERSION >= 3) {
                      __Pyx_XGIVEREF(__pyx_t_26);
                      __Pyx_XGIVEREF(__pyx_t_27);
                      __Pyx_XGIVEREF(__pyx_t_28);
                      __Pyx_ExceptionReset(__pyx_t_26, __pyx_t_27, __pyx_t_28);
                    }
                    __Pyx_XGIVEREF(__pyx_t_23);
                    __Pyx_XGIVEREF(__pyx_t_24);
                    __Pyx_XGIVEREF(__pyx_t_25);
                    __Pyx_ErrRestore(__pyx_t_23, __pyx_t_24, __pyx_t_25);
                    __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0; __pyx_t_26 = 0; __pyx_t_27 = 0; __pyx_t_28 = 0;
                    __pyx_lineno = __pyx_t_16; __pyx_clineno = __pyx_t_21; __pyx_filename = __pyx_t_22;
                    goto __pyx_L18_except_error;
                  }
                }
              }
              goto __pyx_L18_except_error;
              __pyx_L18_except_error:;

              /* "cPyparsing.pyx":1538
 *             if value is cache.not_in_cache:
 *                 ParserElement.packrat_cache_stats[MISS] += 1
 *                 try:             # <<<<<<<<<<<<<<
 *                     value = self._parseNoCache(instring, loc, doActions, callPreParse)
 *                 except ParseBaseException as pe:
 */
              __Pyx_PyThreadState_assign
              __Pyx_XGIVEREF(__pyx_t_13);
              __Pyx_XGIVEREF(__pyx_t_14);
              __Pyx_XGIVEREF(__pyx_t_15);
              __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
              goto __pyx_L7_error;
              __pyx_L19_except_return:;
              __Pyx_PyThreadState_assign
              __Pyx_XGIVEREF(__pyx_t_13);
              __Pyx_XGIVEREF(__pyx_t_14);
              __Pyx_XGIVEREF(__pyx_t_15);
              __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
              goto __pyx_L11_try_return;
            }

            /* "cPyparsing.pyx":1536
 *             cache = ParserElement.packrat_cache
 *             value = cache.get(lookup)
 *             if value is cache.not_in_cache:             # <<<<<<<<<<<<<<
 *                 ParserElement.packrat_cache_stats[MISS] += 1
 *                 try:
 */
          }

          /* "cPyparsing.pyx":1548
 *                     return value
 *             else:
 *                 ParserElement.packrat_cache_stats[HIT] += 1             # <<<<<<<<<<<<<<
 *                 if isinstance(value, Exception):
 *                     raise value
 */
          /*else*/ {
            __pyx_t_17 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1548, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_17);
            __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_packrat_cache_stats); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1548, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
            __pyx_t_2 = __pyx_v_HIT;
            __pyx_t_17 = __Pyx_GetItemInt(__pyx_t_7, __pyx_t_2, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1548, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_17);
            __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_t_17, __pyx_int_1, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1548, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
            if (unlikely(__Pyx_SetItemInt(__pyx_t_7, __pyx_t_2, __pyx_t_3, long, 1, __Pyx_PyInt_From_long, 0, 1, 1) < 0)) __PYX_ERR(0, 1548, __pyx_L7_error)
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

            /* "cPyparsing.pyx":1549
 *             else:
 *                 ParserElement.packrat_cache_stats[HIT] += 1
 *                 if isinstance(value, Exception):             # <<<<<<<<<<<<<<
 *                     raise value
 *                 return (value[0], value[1].copy())
 */
            __pyx_t_12 = __Pyx_PyException_Check(__pyx_v_value); 
            __pyx_t_11 = (__pyx_t_12 != 0);
            if (__pyx_t_11) {

              /* "cPyparsing.pyx":1550
 *                 ParserElement.packrat_cache_stats[HIT] += 1
 *                 if isinstance(value, Exception):
 *                     raise value             # <<<<<<<<<<<<<<
 *                 return (value[0], value[1].copy())
 * 
 */
              __Pyx_Raise(__pyx_v_value, 0, 0, 0);
              __PYX_ERR(0, 1550, __pyx_L7_error)

              /* "cPyparsing.pyx":1549
 *             else:
 *                 ParserElement.packrat_cache_stats[HIT] += 1
 *                 if isinstance(value, Exception):             # <<<<<<<<<<<<<<
 *                     raise value
 *                 return (value[0], value[1].copy())
 */
            }

            /* "cPyparsing.pyx":1551
 *                 if isinstance(value, Exception):
 *                     raise value
 *                 return (value[0], value[1].copy())             # <<<<<<<<<<<<<<
 * 
 *     _parse = _parseNoCache
 */
            __Pyx_XDECREF(__pyx_r);
            __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_value, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1551, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_7);
            __pyx_t_17 = __Pyx_GetItemInt(__pyx_v_value, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1551, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_17);
            __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_copy); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1551, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_18);
            __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
            __pyx_t_17 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_18))) {
              __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_18);
              if (likely(__pyx_t_17)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_18);
                __Pyx_INCREF(__pyx_t_17);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_18, function);
              }
            }
            if (__pyx_t_17) {
              __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_18, __pyx_t_17); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1551, __pyx_L7_error)
              __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
            } else {
              __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_18); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1551, __pyx_L7_error)
            }
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
            __pyx_t_18 = PyTuple_New(2); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1551, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_18);
            __Pyx_GIVEREF(__pyx_t_7);
            PyTuple_SET_ITEM(__pyx_t_18, 0, __pyx_t_7);
            __Pyx_GIVEREF(__pyx_t_3);
            PyTuple_SET_ITEM(__pyx_t_18, 1, __pyx_t_3);
            __pyx_t_7 = 0;
            __pyx_t_3 = 0;
            __pyx_r = __pyx_t_18;
            __pyx_t_18 = 0;
            goto __pyx_L11_try_return;
          }

          /* "cPyparsing.pyx":1533
 *         HIT, MISS = 0, 1
 *         lookup = (self, instring, loc, callPreParse, doActions)
 *         with ParserElement.packrat_cache_lock:             # <<<<<<<<<<<<<<
 *             cache = ParserElement.packrat_cache
 *             value = cache.get(lookup)
 */
        }
        __pyx_L7_error:;
        __Pyx_PyThreadState_assign
        __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
        __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
        /*except:*/ {
          __Pyx_AddTraceback("cPyparsing.ParserElement._parseCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_18, &__pyx_t_3, &__pyx_t_7) < 0) __PYX_ERR(0, 1533, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_18);
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_17 = PyTuple_Pack(3, __pyx_t_18, __pyx_t_3, __pyx_t_7); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1533, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_17);
          __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_17, NULL);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1533, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_15);
          __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_15);
          __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
          if (__pyx_t_11 < 0) __PYX_ERR(0, 1533, __pyx_L9_except_error)
          __pyx_t_12 = ((!(__pyx_t_11 != 0)) != 0);
          if (__pyx_t_12) {
            __Pyx_GIVEREF(__pyx_t_18);
            __Pyx_GIVEREF(__pyx_t_3);
            __Pyx_XGIVEREF(__pyx_t_7);
            __Pyx_ErrRestoreWithState(__pyx_t_18, __pyx_t_3, __pyx_t_7);
            __pyx_t_18 = 0; __pyx_t_3 = 0; __pyx_t_7 = 0; 
            __PYX_ERR(0, 1533, __pyx_L9_except_error)
          }
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          goto __pyx_L8_exception_handled;
        }
        __pyx_L9_except_error:;
        __Pyx_PyThreadState_assign
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
        goto __pyx_L1_error;
        __pyx_L11_try_return:;
        __Pyx_PyThreadState_assign
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
        goto __pyx_L4_return;
        __pyx_L8_exception_handled:;
        __Pyx_PyThreadState_assign
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      }
    }
    /*finally:*/ {
      /*normal exit:*/{
        if (__pyx_t_5) {
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__71, NULL);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1533, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        }
        goto __pyx_L6;
      }
      __pyx_L4_return: {
        __pyx_t_10 = __pyx_r;
        __pyx_r = 0;
        if (__pyx_t_5) {
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__72, NULL);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1533, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
        __pyx_r = __pyx_t_10;
        __pyx_t_10 = 0;
        goto __pyx_L0;
      }
      __pyx_L6:;
    }
    goto __pyx_L39;
    __pyx_L3_error:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L1_error;
    __pyx_L39:;
  }

  /* "cPyparsing.pyx":1530
 *     # this method gets repeatedly called during backtracking with the same arguments -
 *     # we can cache these arguments and save ourselves the trouble of re-parsing the contained expression
 *     def _parseCache(self, instring, int loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *         HIT, MISS = 0, 1
 *         lookup = (self, instring, loc, callPreParse, doActions)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_XDECREF(__pyx_t_20);
  __Pyx_AddTraceback("cPyparsing.ParserElement._parseCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_lookup);
  __Pyx_XDECREF(__pyx_v_cache);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_pe);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1556
 * 
 *     @staticmethod
 *     def resetCache():             # <<<<<<<<<<<<<<
 *         ParserElement.packrat_cache.clear()
 *         ParserElement.packrat_cache_stats[:] = [0] * len(ParserElement.packrat_cache_stats)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_39resetCache(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_39resetCache = {"resetCache", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_39resetCache, METH_NOARGS, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_39resetCache(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("resetCache (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_38resetCache(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_38resetCache(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  __Pyx_RefNannySetupContext("resetCache", 0);

  /* "cPyparsing.pyx":1557
 *     @staticmethod
 *     def resetCache():
 *         ParserElement.packrat_cache.clear()             # <<<<<<<<<<<<<<
 *         ParserElement.packrat_cache_stats[:] = [0] * len(ParserElement.packrat_cache_stats)
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_packrat_cache); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_clear); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1557, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1557, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1558
 *     def resetCache():
 *         ParserElement.packrat_cache.clear()
 *         ParserElement.packrat_cache_stats[:] = [0] * len(ParserElement.packrat_cache_stats)             # <<<<<<<<<<<<<<
 * 
 *     _packratEnabled = False
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_packrat_cache_stats); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = PyObject_Length(__pyx_t_2); if (unlikely(__pyx_t_4 == -1)) __PYX_ERR(0, 1558, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyList_New(1 * ((__pyx_t_4<0) ? 0:__pyx_t_4)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  { Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < __pyx_t_4; __pyx_temp++) {
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_GIVEREF(__pyx_int_0);
      PyList_SET_ITEM(__pyx_t_2, __pyx_temp, __pyx_int_0);
    }
  }
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_packrat_cache_stats); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetSlice(__pyx_t_3, __pyx_t_2, 0, 0, NULL, NULL, &__pyx_slice__73, 0, 0, 1) < 0) __PYX_ERR(0, 1558, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1556
 * 
 *     @staticmethod
 *     def resetCache():             # <<<<<<<<<<<<<<
 *         ParserElement.packrat_cache.clear()
 *         ParserElement.packrat_cache_stats[:] = [0] * len(ParserElement.packrat_cache_stats)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParserElement.resetCache", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1563
 * 
 *     @staticmethod
 *     def enablePackrat(cache_size_limit=128):             # <<<<<<<<<<<<<<
 *         """Enables "packrat" parsing, which adds memoizing to the parsing logic.
 *            Repeated parse attempts at the same string location (which happens
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_41enablePackrat(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_40enablePackrat[] = "Enables \"packrat\" parsing, which adds memoizing to the parsing logic.\n           Repeated parse attempts at the same string location (which happens\n           often in many complex grammars) can immediately return a cached value,\n           instead of re-executing parsing/validating code.  Memoizing is done of\n           both valid results and parsing exceptions.\n\n           Parameters:\n            - cache_size_limit - (default=C{128}) - if an integer value is provided\n              will limit the size of the packrat cache; if None is passed, then\n              the cache size will be unbounded; if 0 is passed, the cache will\n              be effectively disabled.\n\n           This speedup may break existing programs that use parse actions that\n           have side-effects.  For this reason, packrat parsing is disabled when\n           you first import pyparsing.  To activate the packrat feature, your\n           program must call the class method C{ParserElement.enablePackrat()}.  If\n           your program uses C{psyco} to \"compile as you go\", you must call\n           C{enablePackrat} before calling C{psyco.full()}.  If you do not do this,\n           Python will crash.  For best results, call C{enablePackrat()} immediately\n           after importing pyparsing.\n\n           Example::\n               import pyparsing\n               pyparsing.ParserElement.enablePackrat()\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_41enablePackrat = {"enablePackrat", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_41enablePackrat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_40enablePackrat};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_41enablePackrat(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_cache_size_limit = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("enablePackrat (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cache_size_limit,0};
    PyObject* values[1] = {0};
    values[0] = ((PyObject *)((PyObject *)__pyx_int_128));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_cache_size_limit);
          if (value) { values[0] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "enablePackrat") < 0)) __PYX_ERR(0, 1563, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_cache_size_limit = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("enablePackrat", 0, 0, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1563, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.enablePackrat", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_40enablePackrat(__pyx_self, __pyx_v_cache_size_limit);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_40enablePackrat(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cache_size_limit) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("enablePackrat", 0);

  /* "cPyparsing.pyx":1589
 *                pyparsing.ParserElement.enablePackrat()
 *         """
 *         if not ParserElement._packratEnabled:             # <<<<<<<<<<<<<<
 *             ParserElement._packratEnabled = True
 *             if cache_size_limit is None:
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_packratEnabled); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1589, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = ((!__pyx_t_3) != 0);
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":1590
 *         """
 *         if not ParserElement._packratEnabled:
 *             ParserElement._packratEnabled = True             # <<<<<<<<<<<<<<
 *             if cache_size_limit is None:
 *                 ParserElement.packrat_cache = ParserElement._UnboundedCache()
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1590, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_PyObject_SetAttrStr(__pyx_t_2, __pyx_n_s_packratEnabled, Py_True) < 0) __PYX_ERR(0, 1590, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":1591
 *         if not ParserElement._packratEnabled:
 *             ParserElement._packratEnabled = True
 *             if cache_size_limit is None:             # <<<<<<<<<<<<<<
 *                 ParserElement.packrat_cache = ParserElement._UnboundedCache()
 *             else:
 */
    __pyx_t_4 = (__pyx_v_cache_size_limit == Py_None);
    __pyx_t_3 = (__pyx_t_4 != 0);
    if (__pyx_t_3) {

      /* "cPyparsing.pyx":1592
 *             ParserElement._packratEnabled = True
 *             if cache_size_limit is None:
 *                 ParserElement.packrat_cache = ParserElement._UnboundedCache()             # <<<<<<<<<<<<<<
 *             else:
 *                 ParserElement.packrat_cache = ParserElement._FifoCache(cache_size_limit)
 */
      __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1592, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_UnboundedCache); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1592, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (__pyx_t_1) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1592, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else {
        __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1592, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1592, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_PyObject_SetAttrStr(__pyx_t_5, __pyx_n_s_packrat_cache, __pyx_t_2) < 0) __PYX_ERR(0, 1592, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "cPyparsing.pyx":1591
 *         if not ParserElement._packratEnabled:
 *             ParserElement._packratEnabled = True
 *             if cache_size_limit is None:             # <<<<<<<<<<<<<<
 *                 ParserElement.packrat_cache = ParserElement._UnboundedCache()
 *             else:
 */
      goto __pyx_L4;
    }

    /* "cPyparsing.pyx":1594
 *                 ParserElement.packrat_cache = ParserElement._UnboundedCache()
 *             else:
 *                 ParserElement.packrat_cache = ParserElement._FifoCache(cache_size_limit)             # <<<<<<<<<<<<<<
 *             ParserElement._parse = ParserElement._parseCache
 * 
 */
    /*else*/ {
      __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1594, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_FifoCache); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1594, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      if (!__pyx_t_2) {
        __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_cache_size_limit); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1594, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_1)) {
          PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_cache_size_limit};
          __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1594, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_GOTREF(__pyx_t_5);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
          PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_cache_size_limit};
          __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1594, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_GOTREF(__pyx_t_5);
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1594, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2); __pyx_t_2 = NULL;
          __Pyx_INCREF(__pyx_v_cache_size_limit);
          __Pyx_GIVEREF(__pyx_v_cache_size_limit);
          PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_cache_size_limit);
          __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1594, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1594, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_n_s_packrat_cache, __pyx_t_5) < 0) __PYX_ERR(0, 1594, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_L4:;

    /* "cPyparsing.pyx":1595
 *             else:
 *                 ParserElement.packrat_cache = ParserElement._FifoCache(cache_size_limit)
 *             ParserElement._parse = ParserElement._parseCache             # <<<<<<<<<<<<<<
 * 
 *     def parseString(self, instring, parseAll=False):
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1595, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_parseCache); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1595, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1595, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_n_s_parse, __pyx_t_5) < 0) __PYX_ERR(0, 1595, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1589
 *                pyparsing.ParserElement.enablePackrat()
 *         """
 *         if not ParserElement._packratEnabled:             # <<<<<<<<<<<<<<
 *             ParserElement._packratEnabled = True
 *             if cache_size_limit is None:
 */
  }

  /* "cPyparsing.pyx":1563
 * 
 *     @staticmethod
 *     def enablePackrat(cache_size_limit=128):             # <<<<<<<<<<<<<<
 *         """Enables "packrat" parsing, which adds memoizing to the parsing logic.
 *            Repeated parse attempts at the same string location (which happens
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParserElement.enablePackrat", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1597
 *             ParserElement._parse = ParserElement._parseCache
 * 
 *     def parseString(self, instring, parseAll=False):             # <<<<<<<<<<<<<<
 *         """
 *         Execute the parse expression with the given string.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_43parseString(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_42parseString[] = "\n        Execute the parse expression with the given string.\n        This is the main interface to the client code, once the complete\n        expression has been built.\n\n        If you want the grammar to require that the entire input string be\n        successfully parsed, then set C{parseAll} to True (equivalent to ending\n        the grammar with C{L{StringEnd()}}).\n\n        Note: C{parseString} implicitly calls C{expandtabs()} on the input string,\n        in order to report proper column numbers in parse actions.\n        If the input string contains tabs and\n        the grammar uses parse actions that use the C{loc} argument to index into the\n        string being parsed, you can ensure you have a consistent view of the input\n        string by:\n         - calling C{parseWithTabs} on your grammar before calling C{parseString}\n           (see L{I{parseWithTabs}<parseWithTabs>})\n         - define your parse action using the full C{(s,loc,toks)} signature, and\n           reference the input string using the parse action's C{s} argument\n         - explictly expand the tabs in your input string before calling\n           C{parseString}\n\n        Example::\n            Word('a').parseString('aaaaabaaa')  # -> ['aaaaa']\n            Word('a').parseString('aaaaabaaa', parseAll=True)  # -> Exception: Expected end of text\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_43parseString = {"parseString", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_43parseString, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_42parseString};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_43parseString(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_parseAll = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseString (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_parseAll,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_False));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseString", 0, 2, 3, 1); __PYX_ERR(0, 1597, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_parseAll);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseString") < 0)) __PYX_ERR(0, 1597, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_parseAll = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseString", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1597, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.parseString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_42parseString(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_parseAll);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_42parseString(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_parseAll) {
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_v_loc = NULL;
  PyObject *__pyx_v_tokens = NULL;
  PyObject *__pyx_v_se = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *(*__pyx_t_13)(PyObject *);
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  char const *__pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  __Pyx_RefNannySetupContext("parseString", 0);
  __Pyx_INCREF(__pyx_v_instring);

  /* "cPyparsing.pyx":1624
 *             Word('a').parseString('aaaaabaaa', parseAll=True)  # -> Exception: Expected end of text
 *         """
 *         ParserElement.resetCache()             # <<<<<<<<<<<<<<
 *         if not self.streamlined:
 *             self.streamline()
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_resetCache); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1624, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1624, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1625
 *         """
 *         ParserElement.resetCache()
 *         if not self.streamlined:             # <<<<<<<<<<<<<<
 *             self.streamline()
 *             #~ self.saveAsList = True
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_streamlined); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 1625, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = ((!__pyx_t_4) != 0);
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":1626
 *         ParserElement.resetCache()
 *         if not self.streamlined:
 *             self.streamline()             # <<<<<<<<<<<<<<
 *             #~ self.saveAsList = True
 *         for e in self.ignoreExprs:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_streamline); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1626, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (__pyx_t_2) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1626, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1626, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1625
 *         """
 *         ParserElement.resetCache()
 *         if not self.streamlined:             # <<<<<<<<<<<<<<
 *             self.streamline()
 *             #~ self.saveAsList = True
 */
  }

  /* "cPyparsing.pyx":1628
 *             self.streamline()
 *             #~ self.saveAsList = True
 *         for e in self.ignoreExprs:             # <<<<<<<<<<<<<<
 *             e.streamline()
 *         if not self.keepTabs:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_3 = __pyx_t_1; __Pyx_INCREF(__pyx_t_3); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1628, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1628, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 1628, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1628, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 1628, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1628, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_7(__pyx_t_3);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 1628, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1629
 *             #~ self.saveAsList = True
 *         for e in self.ignoreExprs:
 *             e.streamline()             # <<<<<<<<<<<<<<
 *         if not self.keepTabs:
 *             instring = instring.expandtabs()
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_streamline); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1629, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (__pyx_t_8) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1629, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1629, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1628
 *             self.streamline()
 *             #~ self.saveAsList = True
 *         for e in self.ignoreExprs:             # <<<<<<<<<<<<<<
 *             e.streamline()
 *         if not self.keepTabs:
 */
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":1630
 *         for e in self.ignoreExprs:
 *             e.streamline()
 *         if not self.keepTabs:             # <<<<<<<<<<<<<<
 *             instring = instring.expandtabs()
 *         try:
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_keepTabs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 1630, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_4 = ((!__pyx_t_5) != 0);
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":1631
 *             e.streamline()
 *         if not self.keepTabs:
 *             instring = instring.expandtabs()             # <<<<<<<<<<<<<<
 *         try:
 *             loc, tokens = self._parse(instring, 0)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_instring, __pyx_n_s_expandtabs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1631, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (__pyx_t_2) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1631, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1631, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_instring, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":1630
 *         for e in self.ignoreExprs:
 *             e.streamline()
 *         if not self.keepTabs:             # <<<<<<<<<<<<<<
 *             instring = instring.expandtabs()
 *         try:
 */
  }

  /* "cPyparsing.pyx":1632
 *         if not self.keepTabs:
 *             instring = instring.expandtabs()
 *         try:             # <<<<<<<<<<<<<<
 *             loc, tokens = self._parse(instring, 0)
 *             if parseAll:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
    __Pyx_XGOTREF(__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_11);
    /*try:*/ {

      /* "cPyparsing.pyx":1633
 *             instring = instring.expandtabs()
 *         try:
 *             loc, tokens = self._parse(instring, 0)             # <<<<<<<<<<<<<<
 *             if parseAll:
 *                 loc = self.preParse(instring, loc)
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1633, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_instring, __pyx_int_0};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1633, __pyx_L7_error)
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_instring, __pyx_int_0};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1633, __pyx_L7_error)
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1633, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_2) {
          __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_2); __pyx_t_2 = NULL;
        }
        __Pyx_INCREF(__pyx_v_instring);
        __Pyx_GIVEREF(__pyx_v_instring);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_12, __pyx_v_instring);
        __Pyx_INCREF(__pyx_int_0);
        __Pyx_GIVEREF(__pyx_int_0);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_12, __pyx_int_0);
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_8, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1633, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
        PyObject* sequence = __pyx_t_3;
        #if !CYTHON_COMPILING_IN_PYPY
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 1633, __pyx_L7_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_8 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_8 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_8);
        #else
        __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1633, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_8 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1633, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_8);
        #endif
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1633, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_13 = Py_TYPE(__pyx_t_2)->tp_iternext;
        index = 0; __pyx_t_1 = __pyx_t_13(__pyx_t_2); if (unlikely(!__pyx_t_1)) goto __pyx_L15_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_1);
        index = 1; __pyx_t_8 = __pyx_t_13(__pyx_t_2); if (unlikely(!__pyx_t_8)) goto __pyx_L15_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_8);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_13(__pyx_t_2), 2) < 0) __PYX_ERR(0, 1633, __pyx_L7_error)
        __pyx_t_13 = NULL;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        goto __pyx_L16_unpacking_done;
        __pyx_L15_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_13 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 1633, __pyx_L7_error)
        __pyx_L16_unpacking_done:;
      }
      __pyx_v_loc = __pyx_t_1;
      __pyx_t_1 = 0;
      __pyx_v_tokens = __pyx_t_8;
      __pyx_t_8 = 0;

      /* "cPyparsing.pyx":1634
 *         try:
 *             loc, tokens = self._parse(instring, 0)
 *             if parseAll:             # <<<<<<<<<<<<<<
 *                 loc = self.preParse(instring, loc)
 *                 se = Empty() + StringEnd()
 */
      __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_parseAll); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 1634, __pyx_L7_error)
      if (__pyx_t_4) {

        /* "cPyparsing.pyx":1635
 *             loc, tokens = self._parse(instring, 0)
 *             if parseAll:
 *                 loc = self.preParse(instring, loc)             # <<<<<<<<<<<<<<
 *                 se = Empty() + StringEnd()
 *                 se._parse(instring, loc)
 */
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_preParse); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1635, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_1 = NULL;
        __pyx_t_12 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_1)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
            __pyx_t_12 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_8)) {
          PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_v_instring, __pyx_v_loc};
          __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1635, __pyx_L7_error)
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
          PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_v_instring, __pyx_v_loc};
          __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1635, __pyx_L7_error)
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else
        #endif
        {
          __pyx_t_2 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1635, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_2);
          if (__pyx_t_1) {
            __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1); __pyx_t_1 = NULL;
          }
          __Pyx_INCREF(__pyx_v_instring);
          __Pyx_GIVEREF(__pyx_v_instring);
          PyTuple_SET_ITEM(__pyx_t_2, 0+__pyx_t_12, __pyx_v_instring);
          __Pyx_INCREF(__pyx_v_loc);
          __Pyx_GIVEREF(__pyx_v_loc);
          PyTuple_SET_ITEM(__pyx_t_2, 1+__pyx_t_12, __pyx_v_loc);
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1635, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF_SET(__pyx_v_loc, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "cPyparsing.pyx":1636
 *             if parseAll:
 *                 loc = self.preParse(instring, loc)
 *                 se = Empty() + StringEnd()             # <<<<<<<<<<<<<<
 *                 se._parse(instring, loc)
 *         except ParseBaseException as exc:
 */
        __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_Empty); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1636, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_2 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_2)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_2);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
          }
        }
        if (__pyx_t_2) {
          __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1636, __pyx_L7_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        } else {
          __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1636, __pyx_L7_error)
        }
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_StringEnd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1636, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_1)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
          }
        }
        if (__pyx_t_1) {
          __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1636, __pyx_L7_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        } else {
          __pyx_t_8 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1636, __pyx_L7_error)
        }
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1636, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_v_se = __pyx_t_2;
        __pyx_t_2 = 0;

        /* "cPyparsing.pyx":1637
 *                 loc = self.preParse(instring, loc)
 *                 se = Empty() + StringEnd()
 *                 se._parse(instring, loc)             # <<<<<<<<<<<<<<
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:
 */
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_se, __pyx_n_s_parse); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1637, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_3 = NULL;
        __pyx_t_12 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
            __pyx_t_12 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_8)) {
          PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_instring, __pyx_v_loc};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1637, __pyx_L7_error)
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
          PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_instring, __pyx_v_loc};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1637, __pyx_L7_error)
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_1 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1637, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_1);
          if (__pyx_t_3) {
            __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3); __pyx_t_3 = NULL;
          }
          __Pyx_INCREF(__pyx_v_instring);
          __Pyx_GIVEREF(__pyx_v_instring);
          PyTuple_SET_ITEM(__pyx_t_1, 0+__pyx_t_12, __pyx_v_instring);
          __Pyx_INCREF(__pyx_v_loc);
          __Pyx_GIVEREF(__pyx_v_loc);
          PyTuple_SET_ITEM(__pyx_t_1, 1+__pyx_t_12, __pyx_v_loc);
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1637, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "cPyparsing.pyx":1634
 *         try:
 *             loc, tokens = self._parse(instring, 0)
 *             if parseAll:             # <<<<<<<<<<<<<<
 *                 loc = self.preParse(instring, loc)
 *                 se = Empty() + StringEnd()
 */
      }

      /* "cPyparsing.pyx":1632
 *         if not self.keepTabs:
 *             instring = instring.expandtabs()
 *         try:             # <<<<<<<<<<<<<<
 *             loc, tokens = self._parse(instring, 0)
 *             if parseAll:
 */
    }

    /* "cPyparsing.pyx":1645
 *                 raise exc
 *         else:
 *             return tokens             # <<<<<<<<<<<<<<
 * 
 *     def scanString(self, instring, maxMatches=_MAX_INT, overlap=False):
 */
    /*else:*/ {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_tokens);
      __pyx_r = __pyx_v_tokens;
      goto __pyx_L10_except_return;
    }
    __pyx_L7_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":1638
 *                 se = Empty() + StringEnd()
 *                 se._parse(instring, loc)
 *         except ParseBaseException as exc:             # <<<<<<<<<<<<<<
 *             if ParserElement.verbose_stacktrace:
 *                 raise
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1638, __pyx_L9_except_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_12 = __Pyx_PyErr_ExceptionMatches(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_12) {
      __Pyx_AddTraceback("cPyparsing.ParserElement.parseString", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_8, &__pyx_t_1) < 0) __PYX_ERR(0, 1638, __pyx_L9_except_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_8);
      __pyx_v_exc = __pyx_t_8;
      /*try:*/ {

        /* "cPyparsing.pyx":1639
 *                 se._parse(instring, loc)
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:             # <<<<<<<<<<<<<<
 *                 raise
 *             else:
 */
        __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1639, __pyx_L23_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_verbose_stacktrace); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1639, __pyx_L23_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_14); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 1639, __pyx_L23_error)
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        if (__pyx_t_4) {

          /* "cPyparsing.pyx":1640
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:
 *                 raise             # <<<<<<<<<<<<<<
 *             else:
 *                 # catch and re-raise exception from here, clears out pyparsing internal stack trace
 */
          __Pyx_GIVEREF(__pyx_t_2);
          __Pyx_GIVEREF(__pyx_t_8);
          __Pyx_XGIVEREF(__pyx_t_1);
          __Pyx_ErrRestoreWithState(__pyx_t_2, __pyx_t_8, __pyx_t_1);
          __pyx_t_2 = 0; __pyx_t_8 = 0; __pyx_t_1 = 0; 
          __PYX_ERR(0, 1640, __pyx_L23_error)

          /* "cPyparsing.pyx":1639
 *                 se._parse(instring, loc)
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:             # <<<<<<<<<<<<<<
 *                 raise
 *             else:
 */
        }

        /* "cPyparsing.pyx":1643
 *             else:
 *                 # catch and re-raise exception from here, clears out pyparsing internal stack trace
 *                 raise exc             # <<<<<<<<<<<<<<
 *         else:
 *             return tokens
 */
        /*else*/ {
          __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
          __PYX_ERR(0, 1643, __pyx_L23_error)
        }
      }

      /* "cPyparsing.pyx":1638
 *                 se = Empty() + StringEnd()
 *                 se._parse(instring, loc)
 *         except ParseBaseException as exc:             # <<<<<<<<<<<<<<
 *             if ParserElement.verbose_stacktrace:
 *                 raise
 */
      /*finally:*/ {
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __pyx_L23_error:;
          __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
          __Pyx_PyThreadState_assign
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19) < 0)) __Pyx_ErrFetch(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_22);
          __pyx_t_12 = __pyx_lineno; __pyx_t_15 = __pyx_clineno; __pyx_t_16 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
          }
          __Pyx_PyThreadState_assign
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_XGIVEREF(__pyx_t_22);
            __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_21, __pyx_t_22);
          }
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_ErrRestore(__pyx_t_17, __pyx_t_18, __pyx_t_19);
          __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
          __pyx_lineno = __pyx_t_12; __pyx_clineno = __pyx_t_15; __pyx_filename = __pyx_t_16;
          goto __pyx_L9_except_error;
        }
      }
    }
    goto __pyx_L9_except_error;
    __pyx_L9_except_error:;

    /* "cPyparsing.pyx":1632
 *         if not self.keepTabs:
 *             instring = instring.expandtabs()
 *         try:             # <<<<<<<<<<<<<<
 *             loc, tokens = self._parse(instring, 0)
 *             if parseAll:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_11);
    __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
    goto __pyx_L1_error;
    __pyx_L10_except_return:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_11);
    __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":1597
 *             ParserElement._parse = ParserElement._parseCache
 * 
 *     def parseString(self, instring, parseAll=False):             # <<<<<<<<<<<<<<
 *         """
 *         Execute the parse expression with the given string.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("cPyparsing.ParserElement.parseString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_loc);
  __Pyx_XDECREF(__pyx_v_tokens);
  __Pyx_XDECREF(__pyx_v_se);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XDECREF(__pyx_v_instring);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_13ParserElement_46generator(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":1647
 *             return tokens
 * 
 *     def scanString(self, instring, maxMatches=_MAX_INT, overlap=False):             # <<<<<<<<<<<<<<
 *         """
 *         Scan the input string for expression matches.  Each match will return the
 */

static PyObject *__pyx_pf_10cPyparsing_87__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults2, __pyx_self)->__pyx_arg_maxMatches);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults2, __pyx_self)->__pyx_arg_maxMatches);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults2, __pyx_self)->__pyx_arg_maxMatches);
  __Pyx_INCREF(((PyObject *)Py_False));
  __Pyx_GIVEREF(((PyObject *)Py_False));
  PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)Py_False));
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_45scanString(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_44scanString[] = "\n        Scan the input string for expression matches.  Each match will return the\n        matching tokens, start location, and end location.  May be called with optional\n        C{maxMatches} argument, to clip scanning after 'n' matches are found.  If\n        C{overlap} is specified, then overlapping matches will be reported.\n\n        Note that the start and end locations are reported relative to the string\n        being parsed.  See L{I{parseString}<parseString>} for more information on parsing\n        strings with embedded tabs.\n\n        Example::\n            source = \"sldjf123lsdjjkf345sldkjf879lkjsfd987\"\n            print(source)\n            for tokens,start,end in Word(alphas).scanString(source):\n                print(' '*start + '^'*(end-start))\n                print(' '*start + tokens[0])\n\n        prints::\n\n            sldjf123lsdjjkf345sldkjf879lkjsfd987\n            ^^^^^\n            sldjf\n                    ^^^^^^^\n                    lsdjjkf\n                              ^^^^^^\n                              sldkjf\n                                       ^^^^^^\n                                       lkjsfd\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_45scanString = {"scanString", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_45scanString, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_44scanString};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_45scanString(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_maxMatches = 0;
  PyObject *__pyx_v_overlap = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("scanString (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_maxMatches,&__pyx_n_s_overlap,0};
    PyObject* values[4] = {0,0,0,0};
    __pyx_defaults2 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults2, __pyx_self);
    values[2] = __pyx_dynamic_args->__pyx_arg_maxMatches;
    values[3] = ((PyObject *)((PyObject *)Py_False));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("scanString", 0, 2, 4, 1); __PYX_ERR(0, 1647, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_maxMatches);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_overlap);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "scanString") < 0)) __PYX_ERR(0, 1647, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_maxMatches = values[2];
    __pyx_v_overlap = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("scanString", 0, 2, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1647, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.scanString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_44scanString(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_maxMatches, __pyx_v_overlap);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_44scanString(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_maxMatches, PyObject *__pyx_v_overlap) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_23_scanString *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("scanString", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_23_scanString *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_23_scanString(__pyx_ptype_10cPyparsing___pyx_scope_struct_23_scanString, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_23_scanString *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1647, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_instring = __pyx_v_instring;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_instring);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_instring);
  __pyx_cur_scope->__pyx_v_maxMatches = __pyx_v_maxMatches;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_maxMatches);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_maxMatches);
  __pyx_cur_scope->__pyx_v_overlap = __pyx_v_overlap;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_overlap);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_overlap);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_13ParserElement_46generator, (PyObject *) __pyx_cur_scope, __pyx_n_s_scanString, __pyx_n_s_ParserElement_scanString, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 1647, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.scanString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_13ParserElement_46generator(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_23_scanString *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_23_scanString *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_t_16;
  PyObject *(*__pyx_t_17)(PyObject *);
  long __pyx_t_18;
  int __pyx_t_19;
  char const *__pyx_t_20;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L31_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1647, __pyx_L1_error)

  /* "cPyparsing.pyx":1677
 *                                        lkjsfd
 *         """
 *         if not self.streamlined:             # <<<<<<<<<<<<<<
 *             self.streamline()
 *         for e in self.ignoreExprs:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_streamlined); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1677, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = ((!__pyx_t_2) != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":1678
 *         """
 *         if not self.streamlined:
 *             self.streamline()             # <<<<<<<<<<<<<<
 *         for e in self.ignoreExprs:
 *             e.streamline()
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_streamline); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1678, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (__pyx_t_5) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1678, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1678, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1677
 *                                        lkjsfd
 *         """
 *         if not self.streamlined:             # <<<<<<<<<<<<<<
 *             self.streamline()
 *         for e in self.ignoreExprs:
 */
  }

  /* "cPyparsing.pyx":1679
 *         if not self.streamlined:
 *             self.streamline()
 *         for e in self.ignoreExprs:             # <<<<<<<<<<<<<<
 *             e.streamline()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_4 = __pyx_t_1; __Pyx_INCREF(__pyx_t_4); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1679, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1679, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_4))) {
        if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 1679, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_4, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1679, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 1679, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_4, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1679, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_7(__pyx_t_4);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 1679, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1680
 *             self.streamline()
 *         for e in self.ignoreExprs:
 *             e.streamline()             # <<<<<<<<<<<<<<
 * 
 *         if not self.keepTabs:
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_e, __pyx_n_s_streamline); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1680, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (__pyx_t_8) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1680, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1680, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1679
 *         if not self.streamlined:
 *             self.streamline()
 *         for e in self.ignoreExprs:             # <<<<<<<<<<<<<<
 *             e.streamline()
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":1682
 *             e.streamline()
 * 
 *         if not self.keepTabs:             # <<<<<<<<<<<<<<
 *             instring = _ustr(instring).expandtabs()
 *         instrlen = len(instring)
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_keepTabs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1682, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = ((!__pyx_t_3) != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1683
 * 
 *         if not self.keepTabs:
 *             instring = _ustr(instring).expandtabs()             # <<<<<<<<<<<<<<
 *         instrlen = len(instring)
 *         loc = 0
 */
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1683, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_8) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_cur_scope->__pyx_v_instring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1683, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_cur_scope->__pyx_v_instring};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1683, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_cur_scope->__pyx_v_instring};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1683, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1683, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_instring);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_instring);
        PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_cur_scope->__pyx_v_instring);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1683, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_expandtabs); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1683, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (__pyx_t_1) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1683, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1683, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_instring);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_instring, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":1682
 *             e.streamline()
 * 
 *         if not self.keepTabs:             # <<<<<<<<<<<<<<
 *             instring = _ustr(instring).expandtabs()
 *         instrlen = len(instring)
 */
  }

  /* "cPyparsing.pyx":1684
 *         if not self.keepTabs:
 *             instring = _ustr(instring).expandtabs()
 *         instrlen = len(instring)             # <<<<<<<<<<<<<<
 *         loc = 0
 *         preparseFn = self.preParse
 */
  __pyx_t_6 = PyObject_Length(__pyx_cur_scope->__pyx_v_instring); if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 1684, __pyx_L1_error)
  __pyx_cur_scope->__pyx_v_instrlen = __pyx_t_6;

  /* "cPyparsing.pyx":1685
 *             instring = _ustr(instring).expandtabs()
 *         instrlen = len(instring)
 *         loc = 0             # <<<<<<<<<<<<<<
 *         preparseFn = self.preParse
 *         parseFn = self._parse
 */
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __pyx_cur_scope->__pyx_v_loc = __pyx_int_0;

  /* "cPyparsing.pyx":1686
 *         instrlen = len(instring)
 *         loc = 0
 *         preparseFn = self.preParse             # <<<<<<<<<<<<<<
 *         parseFn = self._parse
 *         ParserElement.resetCache()
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_preParse); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_cur_scope->__pyx_v_preparseFn = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":1687
 *         loc = 0
 *         preparseFn = self.preParse
 *         parseFn = self._parse             # <<<<<<<<<<<<<<
 *         ParserElement.resetCache()
 *         matches = 0
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_parse); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_cur_scope->__pyx_v_parseFn = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":1688
 *         preparseFn = self.preParse
 *         parseFn = self._parse
 *         ParserElement.resetCache()             # <<<<<<<<<<<<<<
 *         matches = 0
 *         try:
 */
  __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_resetCache); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1688, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1688, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":1689
 *         parseFn = self._parse
 *         ParserElement.resetCache()
 *         matches = 0             # <<<<<<<<<<<<<<
 *         try:
 *             while loc <= instrlen and matches < maxMatches:
 */
  __pyx_cur_scope->__pyx_v_matches = 0;

  /* "cPyparsing.pyx":1690
 *         ParserElement.resetCache()
 *         matches = 0
 *         try:             # <<<<<<<<<<<<<<
 *             while loc <= instrlen and matches < maxMatches:
 *                 try:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
    __Pyx_XGOTREF(__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_11);
    __Pyx_XGOTREF(__pyx_t_12);
    /*try:*/ {

      /* "cPyparsing.pyx":1691
 *         matches = 0
 *         try:
 *             while loc <= instrlen and matches < maxMatches:             # <<<<<<<<<<<<<<
 *                 try:
 *                     preloc = preparseFn(instring, loc)
 */
      while (1) {
        __pyx_t_4 = PyInt_FromSsize_t(__pyx_cur_scope->__pyx_v_instrlen); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1691, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_1 = PyObject_RichCompare(__pyx_cur_scope->__pyx_v_loc, __pyx_t_4, Py_LE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1691, __pyx_L8_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1691, __pyx_L8_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_3) {
        } else {
          __pyx_t_2 = __pyx_t_3;
          goto __pyx_L18_bool_binop_done;
        }
        __pyx_t_1 = __Pyx_PyInt_From_long(__pyx_cur_scope->__pyx_v_matches); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1691, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_4 = PyObject_RichCompare(__pyx_t_1, __pyx_cur_scope->__pyx_v_maxMatches, Py_LT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1691, __pyx_L8_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1691, __pyx_L8_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_2 = __pyx_t_3;
        __pyx_L18_bool_binop_done:;
        if (!__pyx_t_2) break;

        /* "cPyparsing.pyx":1692
 *         try:
 *             while loc <= instrlen and matches < maxMatches:
 *                 try:             # <<<<<<<<<<<<<<
 *                     preloc = preparseFn(instring, loc)
 *                     nextLoc, tokens = parseFn(instring, preloc, callPreParse=False)
 */
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_15);
          /*try:*/ {

            /* "cPyparsing.pyx":1693
 *             while loc <= instrlen and matches < maxMatches:
 *                 try:
 *                     preloc = preparseFn(instring, loc)             # <<<<<<<<<<<<<<
 *                     nextLoc, tokens = parseFn(instring, preloc, callPreParse=False)
 *                 except ParseException:
 */
            __Pyx_INCREF(__pyx_cur_scope->__pyx_v_preparseFn);
            __pyx_t_1 = __pyx_cur_scope->__pyx_v_preparseFn; __pyx_t_5 = NULL;
            __pyx_t_16 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
              __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
              if (likely(__pyx_t_5)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                __Pyx_INCREF(__pyx_t_5);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_1, function);
                __pyx_t_16 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_cur_scope->__pyx_v_instring, __pyx_cur_scope->__pyx_v_loc};
              __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_16, 2+__pyx_t_16); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1693, __pyx_L20_error)
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_GOTREF(__pyx_t_4);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_cur_scope->__pyx_v_instring, __pyx_cur_scope->__pyx_v_loc};
              __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_16, 2+__pyx_t_16); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1693, __pyx_L20_error)
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_GOTREF(__pyx_t_4);
            } else
            #endif
            {
              __pyx_t_9 = PyTuple_New(2+__pyx_t_16); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1693, __pyx_L20_error)
              __Pyx_GOTREF(__pyx_t_9);
              if (__pyx_t_5) {
                __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_5); __pyx_t_5 = NULL;
              }
              __Pyx_INCREF(__pyx_cur_scope->__pyx_v_instring);
              __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_instring);
              PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_16, __pyx_cur_scope->__pyx_v_instring);
              __Pyx_INCREF(__pyx_cur_scope->__pyx_v_loc);
              __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_loc);
              PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_16, __pyx_cur_scope->__pyx_v_loc);
              __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_9, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1693, __pyx_L20_error)
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            }
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_preloc);
            __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_preloc, __pyx_t_4);
            __Pyx_GIVEREF(__pyx_t_4);
            __pyx_t_4 = 0;

            /* "cPyparsing.pyx":1694
 *                 try:
 *                     preloc = preparseFn(instring, loc)
 *                     nextLoc, tokens = parseFn(instring, preloc, callPreParse=False)             # <<<<<<<<<<<<<<
 *                 except ParseException:
 *                     loc = preloc + 1
 */
            __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1694, __pyx_L20_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_INCREF(__pyx_cur_scope->__pyx_v_instring);
            __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_instring);
            PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_cur_scope->__pyx_v_instring);
            __Pyx_INCREF(__pyx_cur_scope->__pyx_v_preloc);
            __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_preloc);
            PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_cur_scope->__pyx_v_preloc);
            __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1694, __pyx_L20_error)
            __Pyx_GOTREF(__pyx_t_1);
            if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_callPreParse, Py_False) < 0) __PYX_ERR(0, 1694, __pyx_L20_error)
            __pyx_t_9 = __Pyx_PyObject_Call(__pyx_cur_scope->__pyx_v_parseFn, __pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1694, __pyx_L20_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            if ((likely(PyTuple_CheckExact(__pyx_t_9))) || (PyList_CheckExact(__pyx_t_9))) {
              PyObject* sequence = __pyx_t_9;
              #if !CYTHON_COMPILING_IN_PYPY
              Py_ssize_t size = Py_SIZE(sequence);
              #else
              Py_ssize_t size = PySequence_Size(sequence);
              #endif
              if (unlikely(size != 2)) {
                if (size > 2) __Pyx_RaiseTooManyValuesError(2);
                else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                __PYX_ERR(0, 1694, __pyx_L20_error)
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              if (likely(PyTuple_CheckExact(sequence))) {
                __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
                __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
              } else {
                __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
                __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
              }
              __Pyx_INCREF(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_4);
              #else
              __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1694, __pyx_L20_error)
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1694, __pyx_L20_error)
              __Pyx_GOTREF(__pyx_t_4);
              #endif
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            } else {
              Py_ssize_t index = -1;
              __pyx_t_5 = PyObject_GetIter(__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1694, __pyx_L20_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
              __pyx_t_17 = Py_TYPE(__pyx_t_5)->tp_iternext;
              index = 0; __pyx_t_1 = __pyx_t_17(__pyx_t_5); if (unlikely(!__pyx_t_1)) goto __pyx_L28_unpacking_failed;
              __Pyx_GOTREF(__pyx_t_1);
              index = 1; __pyx_t_4 = __pyx_t_17(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L28_unpacking_failed;
              __Pyx_GOTREF(__pyx_t_4);
              if (__Pyx_IternextUnpackEndCheck(__pyx_t_17(__pyx_t_5), 2) < 0) __PYX_ERR(0, 1694, __pyx_L20_error)
              __pyx_t_17 = NULL;
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              goto __pyx_L29_unpacking_done;
              __pyx_L28_unpacking_failed:;
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              __pyx_t_17 = NULL;
              if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
              __PYX_ERR(0, 1694, __pyx_L20_error)
              __pyx_L29_unpacking_done:;
            }
            __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_nextLoc);
            __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_nextLoc, __pyx_t_1);
            __Pyx_GIVEREF(__pyx_t_1);
            __pyx_t_1 = 0;
            __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_tokens);
            __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_tokens, __pyx_t_4);
            __Pyx_GIVEREF(__pyx_t_4);
            __pyx_t_4 = 0;

            /* "cPyparsing.pyx":1692
 *         try:
 *             while loc <= instrlen and matches < maxMatches:
 *                 try:             # <<<<<<<<<<<<<<
 *                     preloc = preparseFn(instring, loc)
 *                     nextLoc, tokens = parseFn(instring, preloc, callPreParse=False)
 */
          }

          /* "cPyparsing.pyx":1698
 *                     loc = preloc + 1
 *                 else:
 *                     if nextLoc > loc:             # <<<<<<<<<<<<<<
 *                         matches += 1
 *                         yield tokens, preloc, nextLoc
 */
          /*else:*/ {
            __pyx_t_9 = PyObject_RichCompare(__pyx_cur_scope->__pyx_v_nextLoc, __pyx_cur_scope->__pyx_v_loc, Py_GT); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1698, __pyx_L22_except_error)
            __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1698, __pyx_L22_except_error)
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            if (__pyx_t_2) {

              /* "cPyparsing.pyx":1699
 *                 else:
 *                     if nextLoc > loc:
 *                         matches += 1             # <<<<<<<<<<<<<<
 *                         yield tokens, preloc, nextLoc
 *                         if overlap:
 */
              __pyx_t_16 = 0;
              __pyx_t_18 = __Pyx_add_const_long_checking_overflow(__pyx_cur_scope->__pyx_v_matches, 1, &__pyx_t_16);
              if (unlikely(__pyx_t_16)) {
                PyErr_SetString(PyExc_OverflowError, "value too large");
                __PYX_ERR(0, 1699, __pyx_L22_except_error)
              }
              __pyx_cur_scope->__pyx_v_matches = __pyx_t_18;

              /* "cPyparsing.pyx":1700
 *                     if nextLoc > loc:
 *                         matches += 1
 *                         yield tokens, preloc, nextLoc             # <<<<<<<<<<<<<<
 *                         if overlap:
 *                             nextloc = preparseFn(instring, loc)
 */
              __pyx_t_9 = PyTuple_New(3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1700, __pyx_L22_except_error)
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_INCREF(__pyx_cur_scope->__pyx_v_tokens);
              __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_tokens);
              PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_cur_scope->__pyx_v_tokens);
              __Pyx_INCREF(__pyx_cur_scope->__pyx_v_preloc);
              __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_preloc);
              PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_cur_scope->__pyx_v_preloc);
              __Pyx_INCREF(__pyx_cur_scope->__pyx_v_nextLoc);
              __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_nextLoc);
              PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_cur_scope->__pyx_v_nextLoc);
              __pyx_r = __pyx_t_9;
              __pyx_t_9 = 0;
              __Pyx_XGIVEREF(__pyx_t_10);
              __pyx_cur_scope->__pyx_t_0 = __pyx_t_10;
              __Pyx_XGIVEREF(__pyx_t_11);
              __pyx_cur_scope->__pyx_t_1 = __pyx_t_11;
              __Pyx_XGIVEREF(__pyx_t_12);
              __pyx_cur_scope->__pyx_t_2 = __pyx_t_12;
              __Pyx_XGIVEREF(__pyx_t_13);
              __pyx_cur_scope->__pyx_t_3 = __pyx_t_13;
              __Pyx_XGIVEREF(__pyx_t_14);
              __pyx_cur_scope->__pyx_t_4 = __pyx_t_14;
              __Pyx_XGIVEREF(__pyx_t_15);
              __pyx_cur_scope->__pyx_t_5 = __pyx_t_15;
              __Pyx_XGIVEREF(__pyx_r);
              __Pyx_RefNannyFinishContext();
              /* return from generator, yielding value */
              __pyx_generator->resume_label = 1;
              return __pyx_r;
              __pyx_L31_resume_from_yield:;
              __pyx_t_10 = __pyx_cur_scope->__pyx_t_0;
              __pyx_cur_scope->__pyx_t_0 = 0;
              __Pyx_XGOTREF(__pyx_t_10);
              __pyx_t_11 = __pyx_cur_scope->__pyx_t_1;
              __pyx_cur_scope->__pyx_t_1 = 0;
              __Pyx_XGOTREF(__pyx_t_11);
              __pyx_t_12 = __pyx_cur_scope->__pyx_t_2;
              __pyx_cur_scope->__pyx_t_2 = 0;
              __Pyx_XGOTREF(__pyx_t_12);
              __pyx_t_13 = __pyx_cur_scope->__pyx_t_3;
              __pyx_cur_scope->__pyx_t_3 = 0;
              __Pyx_XGOTREF(__pyx_t_13);
              __pyx_t_14 = __pyx_cur_scope->__pyx_t_4;
              __pyx_cur_scope->__pyx_t_4 = 0;
              __Pyx_XGOTREF(__pyx_t_14);
              __pyx_t_15 = __pyx_cur_scope->__pyx_t_5;
              __pyx_cur_scope->__pyx_t_5 = 0;
              __Pyx_XGOTREF(__pyx_t_15);
              if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1700, __pyx_L22_except_error)

              /* "cPyparsing.pyx":1701
 *                         matches += 1
 *                         yield tokens, preloc, nextLoc
 *                         if overlap:             # <<<<<<<<<<<<<<
 *                             nextloc = preparseFn(instring, loc)
 *                             if nextloc > loc:
 */
              __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_overlap); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1701, __pyx_L22_except_error)
              if (__pyx_t_2) {

                /* "cPyparsing.pyx":1702
 *                         yield tokens, preloc, nextLoc
 *                         if overlap:
 *                             nextloc = preparseFn(instring, loc)             # <<<<<<<<<<<<<<
 *                             if nextloc > loc:
 *                                 loc = nextLoc
 */
                __Pyx_INCREF(__pyx_cur_scope->__pyx_v_preparseFn);
                __pyx_t_4 = __pyx_cur_scope->__pyx_v_preparseFn; __pyx_t_1 = NULL;
                __pyx_t_16 = 0;
                if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
                  __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
                  if (likely(__pyx_t_1)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
                    __Pyx_INCREF(__pyx_t_1);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_4, function);
                    __pyx_t_16 = 1;
                  }
                }
                #if CYTHON_FAST_PYCALL
                if (PyFunction_Check(__pyx_t_4)) {
                  PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_cur_scope->__pyx_v_instring, __pyx_cur_scope->__pyx_v_loc};
                  __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_16, 2+__pyx_t_16); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1702, __pyx_L22_except_error)
                  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                  __Pyx_GOTREF(__pyx_t_9);
                } else
                #endif
                #if CYTHON_FAST_PYCCALL
                if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
                  PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_cur_scope->__pyx_v_instring, __pyx_cur_scope->__pyx_v_loc};
                  __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_16, 2+__pyx_t_16); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1702, __pyx_L22_except_error)
                  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                  __Pyx_GOTREF(__pyx_t_9);
                } else
                #endif
                {
                  __pyx_t_5 = PyTuple_New(2+__pyx_t_16); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1702, __pyx_L22_except_error)
                  __Pyx_GOTREF(__pyx_t_5);
                  if (__pyx_t_1) {
                    __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1); __pyx_t_1 = NULL;
                  }
                  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_instring);
                  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_instring);
                  PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_16, __pyx_cur_scope->__pyx_v_instring);
                  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_loc);
                  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_loc);
                  PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_16, __pyx_cur_scope->__pyx_v_loc);
                  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1702, __pyx_L22_except_error)
                  __Pyx_GOTREF(__pyx_t_9);
                  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                }
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_nextloc);
                __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_nextloc, __pyx_t_9);
                __Pyx_GIVEREF(__pyx_t_9);
                __pyx_t_9 = 0;

                /* "cPyparsing.pyx":1703
 *                         if overlap:
 *                             nextloc = preparseFn(instring, loc)
 *                             if nextloc > loc:             # <<<<<<<<<<<<<<
 *                                 loc = nextLoc
 *                             else:
 */
                __pyx_t_9 = PyObject_RichCompare(__pyx_cur_scope->__pyx_v_nextloc, __pyx_cur_scope->__pyx_v_loc, Py_GT); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1703, __pyx_L22_except_error)
                __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1703, __pyx_L22_except_error)
                __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
                if (__pyx_t_2) {

                  /* "cPyparsing.pyx":1704
 *                             nextloc = preparseFn(instring, loc)
 *                             if nextloc > loc:
 *                                 loc = nextLoc             # <<<<<<<<<<<<<<
 *                             else:
 *                                 loc += 1
 */
                  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_nextLoc);
                  __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_loc);
                  __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_loc, __pyx_cur_scope->__pyx_v_nextLoc);
                  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_nextLoc);

                  /* "cPyparsing.pyx":1703
 *                         if overlap:
 *                             nextloc = preparseFn(instring, loc)
 *                             if nextloc > loc:             # <<<<<<<<<<<<<<
 *                                 loc = nextLoc
 *                             else:
 */
                  goto __pyx_L33;
                }

                /* "cPyparsing.pyx":1706
 *                                 loc = nextLoc
 *                             else:
 *                                 loc += 1             # <<<<<<<<<<<<<<
 *                         else:
 *                             loc = nextLoc
 */
                /*else*/ {
                  __pyx_t_9 = __Pyx_PyInt_AddObjC(__pyx_cur_scope->__pyx_v_loc, __pyx_int_1, 1, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1706, __pyx_L22_except_error)
                  __Pyx_GOTREF(__pyx_t_9);
                  __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_loc);
                  __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_loc, __pyx_t_9);
                  __Pyx_GIVEREF(__pyx_t_9);
                  __pyx_t_9 = 0;
                }
                __pyx_L33:;

                /* "cPyparsing.pyx":1701
 *                         matches += 1
 *                         yield tokens, preloc, nextLoc
 *                         if overlap:             # <<<<<<<<<<<<<<
 *                             nextloc = preparseFn(instring, loc)
 *                             if nextloc > loc:
 */
                goto __pyx_L32;
              }

              /* "cPyparsing.pyx":1708
 *                                 loc += 1
 *                         else:
 *                             loc = nextLoc             # <<<<<<<<<<<<<<
 *                     else:
 *                         loc = preloc + 1
 */
              /*else*/ {
                __Pyx_INCREF(__pyx_cur_scope->__pyx_v_nextLoc);
                __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_loc);
                __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_loc, __pyx_cur_scope->__pyx_v_nextLoc);
                __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_nextLoc);
              }
              __pyx_L32:;

              /* "cPyparsing.pyx":1698
 *                     loc = preloc + 1
 *                 else:
 *                     if nextLoc > loc:             # <<<<<<<<<<<<<<
 *                         matches += 1
 *                         yield tokens, preloc, nextLoc
 */
              goto __pyx_L30;
            }

            /* "cPyparsing.pyx":1710
 *                             loc = nextLoc
 *                     else:
 *                         loc = preloc + 1             # <<<<<<<<<<<<<<
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:
 */
            /*else*/ {
              __pyx_t_9 = __Pyx_PyInt_AddObjC(__pyx_cur_scope->__pyx_v_preloc, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1710, __pyx_L22_except_error)
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_loc);
              __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_loc, __pyx_t_9);
              __Pyx_GIVEREF(__pyx_t_9);
              __pyx_t_9 = 0;
            }
            __pyx_L30:;
          }
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          goto __pyx_L27_try_end;
          __pyx_L20_error:;
          __Pyx_PyThreadState_assign
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

          /* "cPyparsing.pyx":1695
 *                     preloc = preparseFn(instring, loc)
 *                     nextLoc, tokens = parseFn(instring, preloc, callPreParse=False)
 *                 except ParseException:             # <<<<<<<<<<<<<<
 *                     loc = preloc + 1
 *                 else:
 */
          __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1695, __pyx_L22_except_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_16 = __Pyx_PyErr_ExceptionMatches(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (__pyx_t_16) {
            __Pyx_AddTraceback("cPyparsing.ParserElement.scanString", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_4, &__pyx_t_5) < 0) __PYX_ERR(0, 1695, __pyx_L22_except_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_GOTREF(__pyx_t_5);

            /* "cPyparsing.pyx":1696
 *                     nextLoc, tokens = parseFn(instring, preloc, callPreParse=False)
 *                 except ParseException:
 *                     loc = preloc + 1             # <<<<<<<<<<<<<<
 *                 else:
 *                     if nextLoc > loc:
 */
            if (unlikely(!__pyx_cur_scope->__pyx_v_preloc)) { __Pyx_RaiseUnboundLocalError("preloc"); __PYX_ERR(0, 1696, __pyx_L22_except_error) }
            __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_cur_scope->__pyx_v_preloc, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1696, __pyx_L22_except_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_loc);
            __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_loc, __pyx_t_1);
            __Pyx_GIVEREF(__pyx_t_1);
            __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            goto __pyx_L21_exception_handled;
          }
          goto __pyx_L22_except_error;
          __pyx_L22_except_error:;

          /* "cPyparsing.pyx":1692
 *         try:
 *             while loc <= instrlen and matches < maxMatches:
 *                 try:             # <<<<<<<<<<<<<<
 *                     preloc = preparseFn(instring, loc)
 *                     nextLoc, tokens = parseFn(instring, preloc, callPreParse=False)
 */
          __Pyx_PyThreadState_assign
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
          goto __pyx_L8_error;
          __pyx_L21_exception_handled:;
          __Pyx_PyThreadState_assign
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
          __pyx_L27_try_end:;
        }
      }

      /* "cPyparsing.pyx":1690
 *         ParserElement.resetCache()
 *         matches = 0
 *         try:             # <<<<<<<<<<<<<<
 *             while loc <= instrlen and matches < maxMatches:
 *                 try:
 */
    }
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    goto __pyx_L15_try_end;
    __pyx_L8_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "cPyparsing.pyx":1711
 *                     else:
 *                         loc = preloc + 1
 *         except ParseBaseException as exc:             # <<<<<<<<<<<<<<
 *             if ParserElement.verbose_stacktrace:
 *                 raise
 */
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1711, __pyx_L10_except_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_16 = __Pyx_PyErr_ExceptionMatches(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_16) {
      __Pyx_AddTraceback("cPyparsing.ParserElement.scanString", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_9) < 0) __PYX_ERR(0, 1711, __pyx_L10_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      __pyx_cur_scope->__pyx_v_exc = __pyx_t_4;
      /*try:*/ {

        /* "cPyparsing.pyx":1712
 *                         loc = preloc + 1
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:             # <<<<<<<<<<<<<<
 *                 raise
 *             else:
 */
        __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1712, __pyx_L41_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_verbose_stacktrace); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1712, __pyx_L41_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1712, __pyx_L41_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (__pyx_t_2) {

          /* "cPyparsing.pyx":1713
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:
 *                 raise             # <<<<<<<<<<<<<<
 *             else:
 *                 # catch and re-raise exception from here, clears out pyparsing internal stack trace
 */
          __Pyx_GIVEREF(__pyx_t_5);
          __Pyx_GIVEREF(__pyx_t_4);
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_ErrRestoreWithState(__pyx_t_5, __pyx_t_4, __pyx_t_9);
          __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_9 = 0; 
          __PYX_ERR(0, 1713, __pyx_L41_error)

          /* "cPyparsing.pyx":1712
 *                         loc = preloc + 1
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:             # <<<<<<<<<<<<<<
 *                 raise
 *             else:
 */
        }

        /* "cPyparsing.pyx":1716
 *             else:
 *                 # catch and re-raise exception from here, clears out pyparsing internal stack trace
 *                 raise exc             # <<<<<<<<<<<<<<
 * 
 *     def transformString(self, instring):
 */
        /*else*/ {
          __Pyx_Raise(__pyx_cur_scope->__pyx_v_exc, 0, 0, 0);
          __PYX_ERR(0, 1716, __pyx_L41_error)
        }
      }

      /* "cPyparsing.pyx":1711
 *                     else:
 *                         loc = preloc + 1
 *         except ParseBaseException as exc:             # <<<<<<<<<<<<<<
 *             if ParserElement.verbose_stacktrace:
 *                 raise
 */
      /*finally:*/ {
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __pyx_L41_error:;
          __pyx_t_15 = 0; __pyx_t_14 = 0; __pyx_t_13 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
          __Pyx_PyThreadState_assign
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_21, &__pyx_t_22, &__pyx_t_23);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_15, &__pyx_t_14, &__pyx_t_13) < 0)) __Pyx_ErrFetch(&__pyx_t_15, &__pyx_t_14, &__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_22);
          __Pyx_XGOTREF(__pyx_t_23);
          __pyx_t_16 = __pyx_lineno; __pyx_t_19 = __pyx_clineno; __pyx_t_20 = __pyx_filename;
          {
            __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_exc);
            __Pyx_DECREF(__pyx_cur_scope->__pyx_v_exc);
            __pyx_cur_scope->__pyx_v_exc = NULL;
          }
          __Pyx_PyThreadState_assign
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_XGIVEREF(__pyx_t_22);
            __Pyx_XGIVEREF(__pyx_t_23);
            __Pyx_ExceptionReset(__pyx_t_21, __pyx_t_22, __pyx_t_23);
          }
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_ErrRestore(__pyx_t_15, __pyx_t_14, __pyx_t_13);
          __pyx_t_15 = 0; __pyx_t_14 = 0; __pyx_t_13 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
          __pyx_lineno = __pyx_t_16; __pyx_clineno = __pyx_t_19; __pyx_filename = __pyx_t_20;
          goto __pyx_L10_except_error;
        }
      }
    }
    goto __pyx_L10_except_error;
    __pyx_L10_except_error:;

    /* "cPyparsing.pyx":1690
 *         ParserElement.resetCache()
 *         matches = 0
 *         try:             # <<<<<<<<<<<<<<
 *             while loc <= instrlen and matches < maxMatches:
 *                 try:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_11);
    __Pyx_XGIVEREF(__pyx_t_12);
    __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
    goto __pyx_L1_error;
    __pyx_L15_try_end:;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "cPyparsing.pyx":1647
 *             return tokens
 * 
 *     def scanString(self, instring, maxMatches=_MAX_INT, overlap=False):             # <<<<<<<<<<<<<<
 *         """
 *         Scan the input string for expression matches.  Each match will return the
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("scanString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1718
 *                 raise exc
 * 
 *     def transformString(self, instring):             # <<<<<<<<<<<<<<
 *         """
 *         Extension to C{L{scanString}}, to modify matching text with modified tokens that may
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_48transformString(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_47transformString[] = "\n        Extension to C{L{scanString}}, to modify matching text with modified tokens that may\n        be returned from a parse action.  To use C{transformString}, define a grammar and\n        attach a parse action to it that modifies the returned token list.\n        Invoking C{transformString()} on a target string will then scan for matches,\n        and replace the matched text patterns according to the logic in the parse\n        action.  C{transformString()} returns the resulting transformed string.\n\n        Example::\n            wd = Word(alphas)\n            wd.setParseAction(lambda toks: toks[0].title())\n\n            print(wd.transformString(\"now is the winter of our discontent made glorious summer by this sun of york.\"))\n        Prints::\n            Now Is The Winter Of Our Discontent Made Glorious Summer By This Sun Of York.\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_48transformString = {"transformString", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_48transformString, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_47transformString};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_48transformString(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("transformString (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("transformString", 1, 2, 2, 1); __PYX_ERR(0, 1718, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "transformString") < 0)) __PYX_ERR(0, 1718, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("transformString", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1718, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.transformString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_47transformString(__pyx_self, __pyx_v_self, __pyx_v_instring);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_47transformString(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring) {
  PyObject *__pyx_v_out = NULL;
  PyObject *__pyx_v_lastE = NULL;
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_v_s = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *(*__pyx_t_12)(PyObject *);
  int __pyx_t_13;
  int __pyx_t_14;
  int __pyx_t_15;
  int __pyx_t_16;
  int __pyx_t_17;
  char const *__pyx_t_18;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  __Pyx_RefNannySetupContext("transformString", 0);

  /* "cPyparsing.pyx":1735
 *             Now Is The Winter Of Our Discontent Made Glorious Summer By This Sun Of York.
 *         """
 *         out = []             # <<<<<<<<<<<<<<
 *         lastE = 0
 *         # force preservation of <TAB>s, to minimize unwanted transformation of string, and to
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_out = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":1736
 *         """
 *         out = []
 *         lastE = 0             # <<<<<<<<<<<<<<
 *         # force preservation of <TAB>s, to minimize unwanted transformation of string, and to
 *         # keep string locs straight between transformString and scanString
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_lastE = __pyx_int_0;

  /* "cPyparsing.pyx":1739
 *         # force preservation of <TAB>s, to minimize unwanted transformation of string, and to
 *         # keep string locs straight between transformString and scanString
 *         self.keepTabs = True             # <<<<<<<<<<<<<<
 *         try:
 *             for t, s, e in self.scanString(instring):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_keepTabs, Py_True) < 0) __PYX_ERR(0, 1739, __pyx_L1_error)

  /* "cPyparsing.pyx":1740
 *         # keep string locs straight between transformString and scanString
 *         self.keepTabs = True
 *         try:             # <<<<<<<<<<<<<<
 *             for t, s, e in self.scanString(instring):
 *                 out.append(instring[lastE:s])
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "cPyparsing.pyx":1741
 *         self.keepTabs = True
 *         try:
 *             for t, s, e in self.scanString(instring):             # <<<<<<<<<<<<<<
 *                 out.append(instring[lastE:s])
 *                 if t:
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_scanString); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1741, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (!__pyx_t_6) {
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_instring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1741, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_1);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_instring};
          __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1741, __pyx_L3_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_1);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_instring};
          __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1741, __pyx_L3_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_1);
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1741, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
          __Pyx_INCREF(__pyx_v_instring);
          __Pyx_GIVEREF(__pyx_v_instring);
          PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_instring);
          __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1741, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
        __pyx_t_5 = __pyx_t_1; __Pyx_INCREF(__pyx_t_5); __pyx_t_8 = 0;
        __pyx_t_9 = NULL;
      } else {
        __pyx_t_8 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1741, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_9 = Py_TYPE(__pyx_t_5)->tp_iternext; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1741, __pyx_L3_error)
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      for (;;) {
        if (likely(!__pyx_t_9)) {
          if (likely(PyList_CheckExact(__pyx_t_5))) {
            if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_5)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_8); __Pyx_INCREF(__pyx_t_1); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 1741, __pyx_L3_error)
            #else
            __pyx_t_1 = PySequence_ITEM(__pyx_t_5, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1741, __pyx_L3_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          } else {
            if (__pyx_t_8 >= PyTuple_GET_SIZE(__pyx_t_5)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_8); __Pyx_INCREF(__pyx_t_1); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 1741, __pyx_L3_error)
            #else
            __pyx_t_1 = PySequence_ITEM(__pyx_t_5, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1741, __pyx_L3_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          }
        } else {
          __pyx_t_1 = __pyx_t_9(__pyx_t_5);
          if (unlikely(!__pyx_t_1)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1741, __pyx_L3_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_1);
        }
        if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
          PyObject* sequence = __pyx_t_1;
          #if !CYTHON_COMPILING_IN_PYPY
          Py_ssize_t size = Py_SIZE(sequence);
          #else
          Py_ssize_t size = PySequence_Size(sequence);
          #endif
          if (unlikely(size != 3)) {
            if (size > 3) __Pyx_RaiseTooManyValuesError(3);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 1741, __pyx_L3_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_7 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
            __pyx_t_10 = PyTuple_GET_ITEM(sequence, 2); 
          } else {
            __pyx_t_7 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
            __pyx_t_10 = PyList_GET_ITEM(sequence, 2); 
          }
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_10);
          #else
          __pyx_t_7 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1741, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1741, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_10 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1741, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_10);
          #endif
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_11 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1741, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_12 = Py_TYPE(__pyx_t_11)->tp_iternext;
          index = 0; __pyx_t_7 = __pyx_t_12(__pyx_t_11); if (unlikely(!__pyx_t_7)) goto __pyx_L13_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_7);
          index = 1; __pyx_t_6 = __pyx_t_12(__pyx_t_11); if (unlikely(!__pyx_t_6)) goto __pyx_L13_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_6);
          index = 2; __pyx_t_10 = __pyx_t_12(__pyx_t_11); if (unlikely(!__pyx_t_10)) goto __pyx_L13_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_10);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_12(__pyx_t_11), 3) < 0) __PYX_ERR(0, 1741, __pyx_L3_error)
          __pyx_t_12 = NULL;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          goto __pyx_L14_unpacking_done;
          __pyx_L13_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_12 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 1741, __pyx_L3_error)
          __pyx_L14_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_t, __pyx_t_7);
        __pyx_t_7 = 0;
        __Pyx_XDECREF_SET(__pyx_v_s, __pyx_t_6);
        __pyx_t_6 = 0;
        __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_10);
        __pyx_t_10 = 0;

        /* "cPyparsing.pyx":1742
 *         try:
 *             for t, s, e in self.scanString(instring):
 *                 out.append(instring[lastE:s])             # <<<<<<<<<<<<<<
 *                 if t:
 *                     if isinstance(t, ParseResults):
 */
        __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_instring, 0, 0, &__pyx_v_lastE, &__pyx_v_s, NULL, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1742, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_13 = __Pyx_PyObject_Append(__pyx_v_out, __pyx_t_1); if (unlikely(__pyx_t_13 == -1)) __PYX_ERR(0, 1742, __pyx_L3_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "cPyparsing.pyx":1743
 *             for t, s, e in self.scanString(instring):
 *                 out.append(instring[lastE:s])
 *                 if t:             # <<<<<<<<<<<<<<
 *                     if isinstance(t, ParseResults):
 *                         out += t.asList()
 */
        __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_v_t); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 1743, __pyx_L3_error)
        if (__pyx_t_14) {

          /* "cPyparsing.pyx":1744
 *                 out.append(instring[lastE:s])
 *                 if t:
 *                     if isinstance(t, ParseResults):             # <<<<<<<<<<<<<<
 *                         out += t.asList()
 *                     elif isinstance(t, list):
 */
          __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1744, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_14 = PyObject_IsInstance(__pyx_v_t, __pyx_t_1); if (unlikely(__pyx_t_14 == -1)) __PYX_ERR(0, 1744, __pyx_L3_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_15 = (__pyx_t_14 != 0);
          if (__pyx_t_15) {

            /* "cPyparsing.pyx":1745
 *                 if t:
 *                     if isinstance(t, ParseResults):
 *                         out += t.asList()             # <<<<<<<<<<<<<<
 *                     elif isinstance(t, list):
 *                         out += t
 */
            __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_asList); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1745, __pyx_L3_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_6 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
              __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_10);
              if (likely(__pyx_t_6)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
                __Pyx_INCREF(__pyx_t_6);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_10, function);
              }
            }
            if (__pyx_t_6) {
              __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1745, __pyx_L3_error)
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            } else {
              __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1745, __pyx_L3_error)
            }
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __pyx_t_10 = PyNumber_InPlaceAdd(__pyx_v_out, __pyx_t_1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1745, __pyx_L3_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF_SET(__pyx_v_out, __pyx_t_10);
            __pyx_t_10 = 0;

            /* "cPyparsing.pyx":1744
 *                 out.append(instring[lastE:s])
 *                 if t:
 *                     if isinstance(t, ParseResults):             # <<<<<<<<<<<<<<
 *                         out += t.asList()
 *                     elif isinstance(t, list):
 */
            goto __pyx_L16;
          }

          /* "cPyparsing.pyx":1746
 *                     if isinstance(t, ParseResults):
 *                         out += t.asList()
 *                     elif isinstance(t, list):             # <<<<<<<<<<<<<<
 *                         out += t
 *                     else:
 */
          __pyx_t_15 = PyList_Check(__pyx_v_t); 
          __pyx_t_14 = (__pyx_t_15 != 0);
          if (__pyx_t_14) {

            /* "cPyparsing.pyx":1747
 *                         out += t.asList()
 *                     elif isinstance(t, list):
 *                         out += t             # <<<<<<<<<<<<<<
 *                     else:
 *                         out.append(t)
 */
            __pyx_t_10 = PyNumber_InPlaceAdd(__pyx_v_out, __pyx_v_t); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1747, __pyx_L3_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF_SET(__pyx_v_out, __pyx_t_10);
            __pyx_t_10 = 0;

            /* "cPyparsing.pyx":1746
 *                     if isinstance(t, ParseResults):
 *                         out += t.asList()
 *                     elif isinstance(t, list):             # <<<<<<<<<<<<<<
 *                         out += t
 *                     else:
 */
            goto __pyx_L16;
          }

          /* "cPyparsing.pyx":1749
 *                         out += t
 *                     else:
 *                         out.append(t)             # <<<<<<<<<<<<<<
 *                 lastE = e
 *             out.append(instring[lastE:])
 */
          /*else*/ {
            __pyx_t_13 = __Pyx_PyObject_Append(__pyx_v_out, __pyx_v_t); if (unlikely(__pyx_t_13 == -1)) __PYX_ERR(0, 1749, __pyx_L3_error)
          }
          __pyx_L16:;

          /* "cPyparsing.pyx":1743
 *             for t, s, e in self.scanString(instring):
 *                 out.append(instring[lastE:s])
 *                 if t:             # <<<<<<<<<<<<<<
 *                     if isinstance(t, ParseResults):
 *                         out += t.asList()
 */
        }

        /* "cPyparsing.pyx":1750
 *                     else:
 *                         out.append(t)
 *                 lastE = e             # <<<<<<<<<<<<<<
 *             out.append(instring[lastE:])
 *             out = [o for o in out if o]
 */
        __Pyx_INCREF(__pyx_v_e);
        __Pyx_DECREF_SET(__pyx_v_lastE, __pyx_v_e);

        /* "cPyparsing.pyx":1741
 *         self.keepTabs = True
 *         try:
 *             for t, s, e in self.scanString(instring):             # <<<<<<<<<<<<<<
 *                 out.append(instring[lastE:s])
 *                 if t:
 */
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "cPyparsing.pyx":1751
 *                         out.append(t)
 *                 lastE = e
 *             out.append(instring[lastE:])             # <<<<<<<<<<<<<<
 *             out = [o for o in out if o]
 *             return "".join(map(_ustr, _flatten(out)))
 */
      __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_v_instring, 0, 0, &__pyx_v_lastE, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1751, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_13 = __Pyx_PyObject_Append(__pyx_v_out, __pyx_t_5); if (unlikely(__pyx_t_13 == -1)) __PYX_ERR(0, 1751, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "cPyparsing.pyx":1752
 *                 lastE = e
 *             out.append(instring[lastE:])
 *             out = [o for o in out if o]             # <<<<<<<<<<<<<<
 *             return "".join(map(_ustr, _flatten(out)))
 *         except ParseBaseException as exc:
 */
      { /* enter inner scope */
        PyObject *__pyx_9genexpr14__pyx_v_o = NULL;
        __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1752, __pyx_L19_error)
        __Pyx_GOTREF(__pyx_t_5);
        if (likely(PyList_CheckExact(__pyx_v_out)) || PyTuple_CheckExact(__pyx_v_out)) {
          __pyx_t_10 = __pyx_v_out; __Pyx_INCREF(__pyx_t_10); __pyx_t_8 = 0;
          __pyx_t_9 = NULL;
        } else {
          __pyx_t_8 = -1; __pyx_t_10 = PyObject_GetIter(__pyx_v_out); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1752, __pyx_L19_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_9 = Py_TYPE(__pyx_t_10)->tp_iternext; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1752, __pyx_L19_error)
        }
        for (;;) {
          if (likely(!__pyx_t_9)) {
            if (likely(PyList_CheckExact(__pyx_t_10))) {
              if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_10)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_1 = PyList_GET_ITEM(__pyx_t_10, __pyx_t_8); __Pyx_INCREF(__pyx_t_1); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 1752, __pyx_L19_error)
              #else
              __pyx_t_1 = PySequence_ITEM(__pyx_t_10, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1752, __pyx_L19_error)
              __Pyx_GOTREF(__pyx_t_1);
              #endif
            } else {
              if (__pyx_t_8 >= PyTuple_GET_SIZE(__pyx_t_10)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_10, __pyx_t_8); __Pyx_INCREF(__pyx_t_1); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 1752, __pyx_L19_error)
              #else
              __pyx_t_1 = PySequence_ITEM(__pyx_t_10, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1752, __pyx_L19_error)
              __Pyx_GOTREF(__pyx_t_1);
              #endif
            }
          } else {
            __pyx_t_1 = __pyx_t_9(__pyx_t_10);
            if (unlikely(!__pyx_t_1)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(0, 1752, __pyx_L19_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_XDECREF_SET(__pyx_9genexpr14__pyx_v_o, __pyx_t_1);
          __pyx_t_1 = 0;
          __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_9genexpr14__pyx_v_o); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 1752, __pyx_L19_error)
          if (__pyx_t_14) {
            if (unlikely(__Pyx_ListComp_Append(__pyx_t_5, (PyObject*)__pyx_9genexpr14__pyx_v_o))) __PYX_ERR(0, 1752, __pyx_L19_error)
          }
        }
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_9genexpr14__pyx_v_o);
        goto __pyx_L23_exit_scope;
        __pyx_L19_error:;
        __Pyx_XDECREF(__pyx_9genexpr14__pyx_v_o);
        goto __pyx_L3_error;
        __pyx_L23_exit_scope:;
      } /* exit inner scope */
      __Pyx_DECREF_SET(__pyx_v_out, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "cPyparsing.pyx":1753
 *             out.append(instring[lastE:])
 *             out = [o for o in out if o]
 *             return "".join(map(_ustr, _flatten(out)))             # <<<<<<<<<<<<<<
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1753, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_flatten); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1753, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      if (!__pyx_t_6) {
        __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_out); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1753, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_1)) {
          PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_out};
          __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1753, __pyx_L3_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_10);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
          PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_out};
          __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1753, __pyx_L3_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_10);
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1753, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
          __Pyx_INCREF(__pyx_v_out);
          __Pyx_GIVEREF(__pyx_v_out);
          PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_out);
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_7, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1753, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1753, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_10);
      PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_10);
      __pyx_t_5 = 0;
      __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_Call(__pyx_builtin_map, __pyx_t_1, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1753, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__9, __pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1753, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":1740
 *         # keep string locs straight between transformString and scanString
 *         self.keepTabs = True
 *         try:             # <<<<<<<<<<<<<<
 *             for t, s, e in self.scanString(instring):
 *                 out.append(instring[lastE:s])
 */
    }
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1754
 *             out = [o for o in out if o]
 *             return "".join(map(_ustr, _flatten(out)))
 *         except ParseBaseException as exc:             # <<<<<<<<<<<<<<
 *             if ParserElement.verbose_stacktrace:
 *                 raise
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1754, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_16 = __Pyx_PyErr_ExceptionMatches(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_16) {
      __Pyx_AddTraceback("cPyparsing.ParserElement.transformString", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_10, &__pyx_t_5) < 0) __PYX_ERR(0, 1754, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_10);
      __pyx_v_exc = __pyx_t_10;
      /*try:*/ {

        /* "cPyparsing.pyx":1755
 *             return "".join(map(_ustr, _flatten(out)))
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:             # <<<<<<<<<<<<<<
 *                 raise
 *             else:
 */
        __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1755, __pyx_L29_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_verbose_stacktrace); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1755, __pyx_L29_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 1755, __pyx_L29_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (__pyx_t_14) {

          /* "cPyparsing.pyx":1756
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:
 *                 raise             # <<<<<<<<<<<<<<
 *             else:
 *                 # catch and re-raise exception from here, clears out pyparsing internal stack trace
 */
          __Pyx_GIVEREF(__pyx_t_1);
          __Pyx_GIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_5);
          __Pyx_ErrRestoreWithState(__pyx_t_1, __pyx_t_10, __pyx_t_5);
          __pyx_t_1 = 0; __pyx_t_10 = 0; __pyx_t_5 = 0; 
          __PYX_ERR(0, 1756, __pyx_L29_error)

          /* "cPyparsing.pyx":1755
 *             return "".join(map(_ustr, _flatten(out)))
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:             # <<<<<<<<<<<<<<
 *                 raise
 *             else:
 */
        }

        /* "cPyparsing.pyx":1759
 *             else:
 *                 # catch and re-raise exception from here, clears out pyparsing internal stack trace
 *                 raise exc             # <<<<<<<<<<<<<<
 * 
 *     def searchString(self, instring, maxMatches=_MAX_INT):
 */
        /*else*/ {
          __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
          __PYX_ERR(0, 1759, __pyx_L29_error)
        }
      }

      /* "cPyparsing.pyx":1754
 *             out = [o for o in out if o]
 *             return "".join(map(_ustr, _flatten(out)))
 *         except ParseBaseException as exc:             # <<<<<<<<<<<<<<
 *             if ParserElement.verbose_stacktrace:
 *                 raise
 */
      /*finally:*/ {
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __pyx_L29_error:;
          __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0;
          __Pyx_PyThreadState_assign
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_22, &__pyx_t_23, &__pyx_t_24);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21) < 0)) __Pyx_ErrFetch(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_22);
          __Pyx_XGOTREF(__pyx_t_23);
          __Pyx_XGOTREF(__pyx_t_24);
          __pyx_t_16 = __pyx_lineno; __pyx_t_17 = __pyx_clineno; __pyx_t_18 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
          }
          __Pyx_PyThreadState_assign
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_22);
            __Pyx_XGIVEREF(__pyx_t_23);
            __Pyx_XGIVEREF(__pyx_t_24);
            __Pyx_ExceptionReset(__pyx_t_22, __pyx_t_23, __pyx_t_24);
          }
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_XGIVEREF(__pyx_t_21);
          __Pyx_ErrRestore(__pyx_t_19, __pyx_t_20, __pyx_t_21);
          __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0;
          __pyx_lineno = __pyx_t_16; __pyx_clineno = __pyx_t_17; __pyx_filename = __pyx_t_18;
          goto __pyx_L5_except_error;
        }
      }
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cPyparsing.pyx":1740
 *         # keep string locs straight between transformString and scanString
 *         self.keepTabs = True
 *         try:             # <<<<<<<<<<<<<<
 *             for t, s, e in self.scanString(instring):
 *                 out.append(instring[lastE:s])
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":1718
 *                 raise exc
 * 
 *     def transformString(self, instring):             # <<<<<<<<<<<<<<
 *         """
 *         Extension to C{L{scanString}}, to modify matching text with modified tokens that may
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("cPyparsing.ParserElement.transformString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_out);
  __Pyx_XDECREF(__pyx_v_lastE);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XDECREF(__pyx_v_s);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1761
 *                 raise exc
 * 
 *     def searchString(self, instring, maxMatches=_MAX_INT):             # <<<<<<<<<<<<<<
 *         """
 *         Another extension to C{L{scanString}}, simplifying the access to the tokens found
 */

static PyObject *__pyx_pf_10cPyparsing_89__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults3, __pyx_self)->__pyx_arg_maxMatches);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults3, __pyx_self)->__pyx_arg_maxMatches);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults3, __pyx_self)->__pyx_arg_maxMatches);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_50searchString(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_49searchString[] = "\n        Another extension to C{L{scanString}}, simplifying the access to the tokens found\n        to match the given parse expression.  May be called with optional\n        C{maxMatches} argument, to clip searching after 'n' matches are found.\n\n        Example::\n            # a capitalized word starts with an uppercase letter, followed by zero or more lowercase letters\n            cap_word = Word(alphas.upper(), alphas.lower())\n\n            print(cap_word.searchString(\"More than Iron, more than Lead, more than Gold I need Electricity\"))\n\n            # the sum() builtin can be used to merge results into a single ParseResults object\n            print(sum(cap_word.searchString(\"More than Iron, more than Lead, more than Gold I need Electricity\")))\n        prints::\n            [['More'], ['Iron'], ['Lead'], ['Gold'], ['I'], ['Electricity']]\n            ['More', 'Iron', 'Lead', 'Gold', 'I', 'Electricity']\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_50searchString = {"searchString", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_50searchString, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_49searchString};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_50searchString(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_maxMatches = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("searchString (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_maxMatches,0};
    PyObject* values[3] = {0,0,0};
    __pyx_defaults3 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults3, __pyx_self);
    values[2] = __pyx_dynamic_args->__pyx_arg_maxMatches;
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("searchString", 0, 2, 3, 1); __PYX_ERR(0, 1761, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_maxMatches);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "searchString") < 0)) __PYX_ERR(0, 1761, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_maxMatches = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("searchString", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1761, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.searchString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_49searchString(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_maxMatches);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_49searchString(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_maxMatches) {
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  Py_ssize_t __pyx_t_12;
  PyObject *(*__pyx_t_13)(PyObject *);
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *(*__pyx_t_16)(PyObject *);
  int __pyx_t_17;
  int __pyx_t_18;
  char const *__pyx_t_19;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  __Pyx_RefNannySetupContext("searchString", 0);

  /* "cPyparsing.pyx":1779
 *             ['More', 'Iron', 'Lead', 'Gold', 'I', 'Electricity']
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             return ParseResults([t for t, s, e in self.scanString(instring, maxMatches)])
 *         except ParseBaseException as exc:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":1780
 *         """
 *         try:
 *             return ParseResults([t for t, s, e in self.scanString(instring, maxMatches)])             # <<<<<<<<<<<<<<
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1780, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      { /* enter inner scope */
        PyObject *__pyx_9genexpr15__pyx_v_t = NULL;
        CYTHON_UNUSED PyObject *__pyx_9genexpr15__pyx_v_s = NULL;
        CYTHON_UNUSED PyObject *__pyx_9genexpr15__pyx_v_e = NULL;
        __pyx_t_6 = PyList_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1780, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_scanString); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1780, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_9 = NULL;
        __pyx_t_10 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
            __pyx_t_10 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_8)) {
          PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_v_instring, __pyx_v_maxMatches};
          __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1780, __pyx_L13_error)
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_GOTREF(__pyx_t_7);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
          PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_v_instring, __pyx_v_maxMatches};
          __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1780, __pyx_L13_error)
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_GOTREF(__pyx_t_7);
        } else
        #endif
        {
          __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1780, __pyx_L13_error)
          __Pyx_GOTREF(__pyx_t_11);
          if (__pyx_t_9) {
            __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
          }
          __Pyx_INCREF(__pyx_v_instring);
          __Pyx_GIVEREF(__pyx_v_instring);
          PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_v_instring);
          __Pyx_INCREF(__pyx_v_maxMatches);
          __Pyx_GIVEREF(__pyx_v_maxMatches);
          PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_v_maxMatches);
          __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1780, __pyx_L13_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (likely(PyList_CheckExact(__pyx_t_7)) || PyTuple_CheckExact(__pyx_t_7)) {
          __pyx_t_8 = __pyx_t_7; __Pyx_INCREF(__pyx_t_8); __pyx_t_12 = 0;
          __pyx_t_13 = NULL;
        } else {
          __pyx_t_12 = -1; __pyx_t_8 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1780, __pyx_L13_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_13 = Py_TYPE(__pyx_t_8)->tp_iternext; if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1780, __pyx_L13_error)
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        for (;;) {
          if (likely(!__pyx_t_13)) {
            if (likely(PyList_CheckExact(__pyx_t_8))) {
              if (__pyx_t_12 >= PyList_GET_SIZE(__pyx_t_8)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_7 = PyList_GET_ITEM(__pyx_t_8, __pyx_t_12); __Pyx_INCREF(__pyx_t_7); __pyx_t_12++; if (unlikely(0 < 0)) __PYX_ERR(0, 1780, __pyx_L13_error)
              #else
              __pyx_t_7 = PySequence_ITEM(__pyx_t_8, __pyx_t_12); __pyx_t_12++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1780, __pyx_L13_error)
              __Pyx_GOTREF(__pyx_t_7);
              #endif
            } else {
              if (__pyx_t_12 >= PyTuple_GET_SIZE(__pyx_t_8)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_8, __pyx_t_12); __Pyx_INCREF(__pyx_t_7); __pyx_t_12++; if (unlikely(0 < 0)) __PYX_ERR(0, 1780, __pyx_L13_error)
              #else
              __pyx_t_7 = PySequence_ITEM(__pyx_t_8, __pyx_t_12); __pyx_t_12++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1780, __pyx_L13_error)
              __Pyx_GOTREF(__pyx_t_7);
              #endif
            }
          } else {
            __pyx_t_7 = __pyx_t_13(__pyx_t_8);
            if (unlikely(!__pyx_t_7)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(0, 1780, __pyx_L13_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_7);
          }
          if ((likely(PyTuple_CheckExact(__pyx_t_7))) || (PyList_CheckExact(__pyx_t_7))) {
            PyObject* sequence = __pyx_t_7;
            #if !CYTHON_COMPILING_IN_PYPY
            Py_ssize_t size = Py_SIZE(sequence);
            #else
            Py_ssize_t size = PySequence_Size(sequence);
            #endif
            if (unlikely(size != 3)) {
              if (size > 3) __Pyx_RaiseTooManyValuesError(3);
              else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
              __PYX_ERR(0, 1780, __pyx_L13_error)
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            if (likely(PyTuple_CheckExact(sequence))) {
              __pyx_t_11 = PyTuple_GET_ITEM(sequence, 0); 
              __pyx_t_9 = PyTuple_GET_ITEM(sequence, 1); 
              __pyx_t_14 = PyTuple_GET_ITEM(sequence, 2); 
            } else {
              __pyx_t_11 = PyList_GET_ITEM(sequence, 0); 
              __pyx_t_9 = PyList_GET_ITEM(sequence, 1); 
              __pyx_t_14 = PyList_GET_ITEM(sequence, 2); 
            }
            __Pyx_INCREF(__pyx_t_11);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(__pyx_t_14);
            #else
            __pyx_t_11 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1780, __pyx_L13_error)
            __Pyx_GOTREF(__pyx_t_11);
            __pyx_t_9 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1780, __pyx_L13_error)
            __Pyx_GOTREF(__pyx_t_9);
            __pyx_t_14 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1780, __pyx_L13_error)
            __Pyx_GOTREF(__pyx_t_14);
            #endif
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          } else {
            Py_ssize_t index = -1;
            __pyx_t_15 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1780, __pyx_L13_error)
            __Pyx_GOTREF(__pyx_t_15);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __pyx_t_16 = Py_TYPE(__pyx_t_15)->tp_iternext;
            index = 0; __pyx_t_11 = __pyx_t_16(__pyx_t_15); if (unlikely(!__pyx_t_11)) goto __pyx_L16_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_11);
            index = 1; __pyx_t_9 = __pyx_t_16(__pyx_t_15); if (unlikely(!__pyx_t_9)) goto __pyx_L16_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_9);
            index = 2; __pyx_t_14 = __pyx_t_16(__pyx_t_15); if (unlikely(!__pyx_t_14)) goto __pyx_L16_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_14);
            if (__Pyx_IternextUnpackEndCheck(__pyx_t_16(__pyx_t_15), 3) < 0) __PYX_ERR(0, 1780, __pyx_L13_error)
            __pyx_t_16 = NULL;
            __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
            goto __pyx_L17_unpacking_done;
            __pyx_L16_unpacking_failed:;
            __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
            __pyx_t_16 = NULL;
            if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
            __PYX_ERR(0, 1780, __pyx_L13_error)
            __pyx_L17_unpacking_done:;
          }
          __Pyx_XDECREF_SET(__pyx_9genexpr15__pyx_v_t, __pyx_t_11);
          __pyx_t_11 = 0;
          __Pyx_XDECREF_SET(__pyx_9genexpr15__pyx_v_s, __pyx_t_9);
          __pyx_t_9 = 0;
          __Pyx_XDECREF_SET(__pyx_9genexpr15__pyx_v_e, __pyx_t_14);
          __pyx_t_14 = 0;
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_6, (PyObject*)__pyx_9genexpr15__pyx_v_t))) __PYX_ERR(0, 1780, __pyx_L13_error)
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_9genexpr15__pyx_v_t);
        __Pyx_XDECREF(__pyx_9genexpr15__pyx_v_s);
        __Pyx_XDECREF(__pyx_9genexpr15__pyx_v_e);
        goto __pyx_L18_exit_scope;
        __pyx_L13_error:;
        __Pyx_XDECREF(__pyx_9genexpr15__pyx_v_t);
        __Pyx_XDECREF(__pyx_9genexpr15__pyx_v_s);
        __Pyx_XDECREF(__pyx_9genexpr15__pyx_v_e);
        goto __pyx_L3_error;
        __pyx_L18_exit_scope:;
      } /* exit inner scope */
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (!__pyx_t_8) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1780, __pyx_L3_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_6};
          __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1780, __pyx_L3_error)
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_6};
          __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1780, __pyx_L3_error)
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1780, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_8); __pyx_t_8 = NULL;
          __Pyx_GIVEREF(__pyx_t_6);
          PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_6);
          __pyx_t_6 = 0;
          __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1780, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":1779
 *             ['More', 'Iron', 'Lead', 'Gold', 'I', 'Electricity']
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             return ParseResults([t for t, s, e in self.scanString(instring, maxMatches)])
 *         except ParseBaseException as exc:
 */
    }
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":1781
 *         try:
 *             return ParseResults([t for t, s, e in self.scanString(instring, maxMatches)])
 *         except ParseBaseException as exc:             # <<<<<<<<<<<<<<
 *             if ParserElement.verbose_stacktrace:
 *                 raise
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1781, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_10) {
      __Pyx_AddTraceback("cPyparsing.ParserElement.searchString", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_7) < 0) __PYX_ERR(0, 1781, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_v_exc = __pyx_t_5;
      /*try:*/ {

        /* "cPyparsing.pyx":1782
 *             return ParseResults([t for t, s, e in self.scanString(instring, maxMatches)])
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:             # <<<<<<<<<<<<<<
 *                 raise
 *             else:
 */
        __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1782, __pyx_L24_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_verbose_stacktrace); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1782, __pyx_L24_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_17 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely(__pyx_t_17 < 0)) __PYX_ERR(0, 1782, __pyx_L24_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (__pyx_t_17) {

          /* "cPyparsing.pyx":1783
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:
 *                 raise             # <<<<<<<<<<<<<<
 *             else:
 *                 # catch and re-raise exception from here, clears out pyparsing internal stack trace
 */
          __Pyx_GIVEREF(__pyx_t_4);
          __Pyx_GIVEREF(__pyx_t_5);
          __Pyx_XGIVEREF(__pyx_t_7);
          __Pyx_ErrRestoreWithState(__pyx_t_4, __pyx_t_5, __pyx_t_7);
          __pyx_t_4 = 0; __pyx_t_5 = 0; __pyx_t_7 = 0; 
          __PYX_ERR(0, 1783, __pyx_L24_error)

          /* "cPyparsing.pyx":1782
 *             return ParseResults([t for t, s, e in self.scanString(instring, maxMatches)])
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:             # <<<<<<<<<<<<<<
 *                 raise
 *             else:
 */
        }

        /* "cPyparsing.pyx":1786
 *             else:
 *                 # catch and re-raise exception from here, clears out pyparsing internal stack trace
 *                 raise exc             # <<<<<<<<<<<<<<
 * 
 *     def split(self, instring, maxsplit=_MAX_INT, includeSeparators=False):
 */
        /*else*/ {
          __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
          __PYX_ERR(0, 1786, __pyx_L24_error)
        }
      }

      /* "cPyparsing.pyx":1781
 *         try:
 *             return ParseResults([t for t, s, e in self.scanString(instring, maxMatches)])
 *         except ParseBaseException as exc:             # <<<<<<<<<<<<<<
 *             if ParserElement.verbose_stacktrace:
 *                 raise
 */
      /*finally:*/ {
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __pyx_L24_error:;
          __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0;
          __Pyx_PyThreadState_assign
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_23, &__pyx_t_24, &__pyx_t_25);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22) < 0)) __Pyx_ErrFetch(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_22);
          __Pyx_XGOTREF(__pyx_t_23);
          __Pyx_XGOTREF(__pyx_t_24);
          __Pyx_XGOTREF(__pyx_t_25);
          __pyx_t_10 = __pyx_lineno; __pyx_t_18 = __pyx_clineno; __pyx_t_19 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
          }
          __Pyx_PyThreadState_assign
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_23);
            __Pyx_XGIVEREF(__pyx_t_24);
            __Pyx_XGIVEREF(__pyx_t_25);
            __Pyx_ExceptionReset(__pyx_t_23, __pyx_t_24, __pyx_t_25);
          }
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_XGIVEREF(__pyx_t_21);
          __Pyx_XGIVEREF(__pyx_t_22);
          __Pyx_ErrRestore(__pyx_t_20, __pyx_t_21, __pyx_t_22);
          __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0;
          __pyx_lineno = __pyx_t_10; __pyx_clineno = __pyx_t_18; __pyx_filename = __pyx_t_19;
          goto __pyx_L5_except_error;
        }
      }
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cPyparsing.pyx":1779
 *             ['More', 'Iron', 'Lead', 'Gold', 'I', 'Electricity']
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             return ParseResults([t for t, s, e in self.scanString(instring, maxMatches)])
 *         except ParseBaseException as exc:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":1761
 *                 raise exc
 * 
 *     def searchString(self, instring, maxMatches=_MAX_INT):             # <<<<<<<<<<<<<<
 *         """
 *         Another extension to C{L{scanString}}, simplifying the access to the tokens found
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("cPyparsing.ParserElement.searchString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_13ParserElement_53generator1(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":1788
 *                 raise exc
 * 
 *     def split(self, instring, maxsplit=_MAX_INT, includeSeparators=False):             # <<<<<<<<<<<<<<
 *         """
 *         Generator method to split a string using the given expression as a separator.
 */

static PyObject *__pyx_pf_10cPyparsing_91__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults4, __pyx_self)->__pyx_arg_maxsplit);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults4, __pyx_self)->__pyx_arg_maxsplit);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults4, __pyx_self)->__pyx_arg_maxsplit);
  __Pyx_INCREF(((PyObject *)Py_False));
  __Pyx_GIVEREF(((PyObject *)Py_False));
  PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)Py_False));
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_52split(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_51split[] = "\n        Generator method to split a string using the given expression as a separator.\n        May be called with optional C{maxsplit} argument, to limit the number of splits;\n        and the optional C{includeSeparators} argument (default=C{False}), if the separating\n        matching text should be included in the split results.\n\n        Example::\n            punc = oneOf(list(\".,;:/-!?\"))\n            print(list(punc.split(\"This, this?, this sentence, is badly punctuated!\")))\n        prints::\n            ['This', ' this', '', ' this sentence', ' is badly punctuated', '']\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_52split = {"split", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_52split, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_51split};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_52split(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  PyObject *__pyx_v_maxsplit = 0;
  PyObject *__pyx_v_includeSeparators = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("split (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_maxsplit,&__pyx_n_s_includeSeparators,0};
    PyObject* values[4] = {0,0,0,0};
    __pyx_defaults4 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults4, __pyx_self);
    values[2] = __pyx_dynamic_args->__pyx_arg_maxsplit;
    values[3] = ((PyObject *)((PyObject *)Py_False));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("split", 0, 2, 4, 1); __PYX_ERR(0, 1788, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_maxsplit);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_includeSeparators);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "split") < 0)) __PYX_ERR(0, 1788, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_maxsplit = values[2];
    __pyx_v_includeSeparators = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("split", 0, 2, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1788, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.split", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_51split(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_maxsplit, __pyx_v_includeSeparators);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_51split(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, PyObject *__pyx_v_maxsplit, PyObject *__pyx_v_includeSeparators) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_24_split *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("split", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_24_split *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_24_split(__pyx_ptype_10cPyparsing___pyx_scope_struct_24_split, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_24_split *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1788, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_instring = __pyx_v_instring;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_instring);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_instring);
  __pyx_cur_scope->__pyx_v_maxsplit = __pyx_v_maxsplit;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_maxsplit);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_maxsplit);
  __pyx_cur_scope->__pyx_v_includeSeparators = __pyx_v_includeSeparators;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_includeSeparators);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_includeSeparators);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_13ParserElement_53generator1, (PyObject *) __pyx_cur_scope, __pyx_n_s_split, __pyx_n_s_ParserElement_split, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 1788, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.split", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_13ParserElement_53generator1(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_24_split *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_24_split *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_t_10;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L8_resume_from_yield;
    case 2: goto __pyx_L10_resume_from_yield;
    case 3: goto __pyx_L11_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1788, __pyx_L1_error)

  /* "cPyparsing.pyx":1801
 *             ['This', ' this', '', ' this sentence', ' is badly punctuated', '']
 *         """
 *         splits = 0             # <<<<<<<<<<<<<<
 *         last = 0
 *         for t, s, e in self.scanString(instring, maxMatches=maxsplit):
 */
  __pyx_cur_scope->__pyx_v_splits = 0;

  /* "cPyparsing.pyx":1802
 *         """
 *         splits = 0
 *         last = 0             # <<<<<<<<<<<<<<
 *         for t, s, e in self.scanString(instring, maxMatches=maxsplit):
 *             yield instring[last:s]
 */
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __pyx_cur_scope->__pyx_v_last = __pyx_int_0;

  /* "cPyparsing.pyx":1803
 *         splits = 0
 *         last = 0
 *         for t, s, e in self.scanString(instring, maxMatches=maxsplit):             # <<<<<<<<<<<<<<
 *             yield instring[last:s]
 *             if includeSeparators:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_scanString); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_instring);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_instring);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_cur_scope->__pyx_v_instring);
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_maxMatches, __pyx_cur_scope->__pyx_v_maxsplit) < 0) __PYX_ERR(0, 1803, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
    __pyx_t_3 = __pyx_t_4; __Pyx_INCREF(__pyx_t_3); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
  } else {
    __pyx_t_5 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1803, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1803, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  for (;;) {
    if (likely(!__pyx_t_6)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 1803, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1803, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 1803, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1803, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_6(__pyx_t_3);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 1803, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
      PyObject* sequence = __pyx_t_4;
      #if !CYTHON_COMPILING_IN_PYPY
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 1803, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1); 
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 2); 
      } else {
        __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_1 = PyList_GET_ITEM(sequence, 1); 
        __pyx_t_7 = PyList_GET_ITEM(sequence, 2); 
      }
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_7);
      #else
      __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1803, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1803, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1803, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      #endif
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_8 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1803, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_9 = Py_TYPE(__pyx_t_8)->tp_iternext;
      index = 0; __pyx_t_2 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_2)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_2);
      index = 1; __pyx_t_1 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_1)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_1);
      index = 2; __pyx_t_7 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 3) < 0) __PYX_ERR(0, 1803, __pyx_L1_error)
      __pyx_t_9 = NULL;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 1803, __pyx_L1_error)
      __pyx_L7_unpacking_done:;
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_t);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_t, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_s);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_s, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_7);
    __pyx_t_7 = 0;

    /* "cPyparsing.pyx":1804
 *         last = 0
 *         for t, s, e in self.scanString(instring, maxMatches=maxsplit):
 *             yield instring[last:s]             # <<<<<<<<<<<<<<
 *             if includeSeparators:
 *                 yield t[0]
 */
    __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_cur_scope->__pyx_v_instring, 0, 0, &__pyx_cur_scope->__pyx_v_last, &__pyx_cur_scope->__pyx_v_s, NULL, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1804, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    __Pyx_XGIVEREF(__pyx_t_3);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_3;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_5;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_6;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L8_resume_from_yield:;
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_3);
    __pyx_t_5 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_6 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1804, __pyx_L1_error)

    /* "cPyparsing.pyx":1805
 *         for t, s, e in self.scanString(instring, maxMatches=maxsplit):
 *             yield instring[last:s]
 *             if includeSeparators:             # <<<<<<<<<<<<<<
 *                 yield t[0]
 *             last = e
 */
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_includeSeparators); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(0, 1805, __pyx_L1_error)
    if (__pyx_t_10) {

      /* "cPyparsing.pyx":1806
 *             yield instring[last:s]
 *             if includeSeparators:
 *                 yield t[0]             # <<<<<<<<<<<<<<
 *             last = e
 *         yield instring[last:]
 */
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1806, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      __Pyx_XGIVEREF(__pyx_t_3);
      __pyx_cur_scope->__pyx_t_0 = __pyx_t_3;
      __pyx_cur_scope->__pyx_t_1 = __pyx_t_5;
      __pyx_cur_scope->__pyx_t_2 = __pyx_t_6;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 2;
      return __pyx_r;
      __pyx_L10_resume_from_yield:;
      __pyx_t_3 = __pyx_cur_scope->__pyx_t_0;
      __pyx_cur_scope->__pyx_t_0 = 0;
      __Pyx_XGOTREF(__pyx_t_3);
      __pyx_t_5 = __pyx_cur_scope->__pyx_t_1;
      __pyx_t_6 = __pyx_cur_scope->__pyx_t_2;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1806, __pyx_L1_error)

      /* "cPyparsing.pyx":1805
 *         for t, s, e in self.scanString(instring, maxMatches=maxsplit):
 *             yield instring[last:s]
 *             if includeSeparators:             # <<<<<<<<<<<<<<
 *                 yield t[0]
 *             last = e
 */
    }

    /* "cPyparsing.pyx":1807
 *             if includeSeparators:
 *                 yield t[0]
 *             last = e             # <<<<<<<<<<<<<<
 *         yield instring[last:]
 * 
 */
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_last);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_last, __pyx_cur_scope->__pyx_v_e);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_e);

    /* "cPyparsing.pyx":1803
 *         splits = 0
 *         last = 0
 *         for t, s, e in self.scanString(instring, maxMatches=maxsplit):             # <<<<<<<<<<<<<<
 *             yield instring[last:s]
 *             if includeSeparators:
 */
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":1808
 *                 yield t[0]
 *             last = e
 *         yield instring[last:]             # <<<<<<<<<<<<<<
 * 
 *     def __add__(self, other):
 */
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_cur_scope->__pyx_v_instring, 0, 0, &__pyx_cur_scope->__pyx_v_last, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  /* return from generator, yielding value */
  __pyx_generator->resume_label = 3;
  return __pyx_r;
  __pyx_L11_resume_from_yield:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1808, __pyx_L1_error)
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "cPyparsing.pyx":1788
 *                 raise exc
 * 
 *     def split(self, instring, maxsplit=_MAX_INT, includeSeparators=False):             # <<<<<<<<<<<<<<
 *         """
 *         Generator method to split a string using the given expression as a separator.
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("split", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1810
 *         yield instring[last:]
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of + operator - returns C{L{And}}. Adding strings to a ParserElement
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_55__add__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_54__add__[] = "\n        Implementation of + operator - returns C{L{And}}. Adding strings to a ParserElement\n        converts them to L{Literal}s by default.\n\n        Example::\n            greet = Word(alphas) + \",\" + Word(alphas) + \"!\"\n            hello = \"Hello, World!\"\n            print (hello, \"->\", greet.parseString(hello))\n        Prints::\n            Hello, World! -> ['Hello', ',', 'World', '!']\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_55__add__ = {"__add__", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_55__add__, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_54__add__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_55__add__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__add__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__add__", 1, 2, 2, 1); __PYX_ERR(0, 1810, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__add__") < 0)) __PYX_ERR(0, 1810, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__add__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1810, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.__add__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_54__add__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_54__add__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("__add__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":1822
 *             Hello, World! -> ['Hello', ',', 'World', '!']
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 1822, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":1823
 *         """
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1823, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1823, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1823, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1823, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1823, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1823, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_other);
        __Pyx_GIVEREF(__pyx_v_other);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_other);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1823, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1822
 *             Hello, World! -> ['Hello', ',', 'World', '!']
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  }

  /* "cPyparsing.pyx":1824
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1824, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_3 == -1)) __PYX_ERR(0, 1824, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = ((!(__pyx_t_3 != 0)) != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1825
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1825, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1825, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyUnicode_Format(__pyx_kp_u_Cannot_combine_element_of_type_s, ((PyObject *)Py_TYPE(__pyx_v_other))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1825, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "cPyparsing.pyx":1826
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             return None
 *         return And([self, other])
 */
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1825, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
    __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
    __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_builtin_SyntaxWarning);
    __pyx_t_1 = 0;
    __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 1826, __pyx_L1_error)

    /* "cPyparsing.pyx":1825
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1825, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":1827
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 *             return None             # <<<<<<<<<<<<<<
 *         return And([self, other])
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;

    /* "cPyparsing.pyx":1824
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  }

  /* "cPyparsing.pyx":1828
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 *         return And([self, other])             # <<<<<<<<<<<<<<
 * 
 *     def __radd__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_And); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyList_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyList_SET_ITEM(__pyx_t_6, 0, __pyx_v_self);
  __Pyx_INCREF(__pyx_v_other);
  __Pyx_GIVEREF(__pyx_v_other);
  PyList_SET_ITEM(__pyx_t_6, 1, __pyx_v_other);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (!__pyx_t_5) {
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1828, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_6};
      __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1828, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_6};
      __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1828, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1828, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1828, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1810
 *         yield instring[last:]
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of + operator - returns C{L{And}}. Adding strings to a ParserElement
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__add__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1830
 *         return And([self, other])
 * 
 *     def __radd__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of + operator when left operand is not a C{L{ParserElement}}
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_57__radd__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_56__radd__[] = "\n        Implementation of + operator when left operand is not a C{L{ParserElement}}\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_57__radd__ = {"__radd__", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_57__radd__, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_56__radd__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_57__radd__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__radd__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__radd__", 1, 2, 2, 1); __PYX_ERR(0, 1830, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__radd__") < 0)) __PYX_ERR(0, 1830, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__radd__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1830, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.__radd__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_56__radd__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_56__radd__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("__radd__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":1834
 *         Implementation of + operator when left operand is not a C{L{ParserElement}}
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 1834, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":1835
 *         """
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1835, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1835, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1835, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1835, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1835, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1835, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_other);
        __Pyx_GIVEREF(__pyx_v_other);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_other);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1835, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1834
 *         Implementation of + operator when left operand is not a C{L{ParserElement}}
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  }

  /* "cPyparsing.pyx":1836
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_3 == -1)) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = ((!(__pyx_t_3 != 0)) != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1837
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1837, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1837, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyUnicode_Format(__pyx_kp_u_Cannot_combine_element_of_type_s, ((PyObject *)Py_TYPE(__pyx_v_other))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1837, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "cPyparsing.pyx":1838
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             return None
 *         return other + self
 */
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1837, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
    __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
    __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_builtin_SyntaxWarning);
    __pyx_t_1 = 0;
    __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1838, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 1838, __pyx_L1_error)

    /* "cPyparsing.pyx":1837
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1837, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":1839
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 *             return None             # <<<<<<<<<<<<<<
 *         return other + self
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;

    /* "cPyparsing.pyx":1836
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  }

  /* "cPyparsing.pyx":1840
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 *         return other + self             # <<<<<<<<<<<<<<
 * 
 *     def __sub__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = PyNumber_Add(__pyx_v_other, __pyx_v_self); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1830
 *         return And([self, other])
 * 
 *     def __radd__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of + operator when left operand is not a C{L{ParserElement}}
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__radd__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1842
 *         return other + self
 * 
 *     def __sub__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of - operator, returns C{L{And}} with error stop
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_59__sub__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_58__sub__[] = "\n        Implementation of - operator, returns C{L{And}} with error stop\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_59__sub__ = {"__sub__", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_59__sub__, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_58__sub__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_59__sub__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__sub__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__sub__", 1, 2, 2, 1); __PYX_ERR(0, 1842, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__sub__") < 0)) __PYX_ERR(0, 1842, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__sub__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1842, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.__sub__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_58__sub__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_58__sub__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("__sub__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":1846
 *         Implementation of - operator, returns C{L{And}} with error stop
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 1846, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":1847
 *         """
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1847, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1847, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1847, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1847, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1847, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1847, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_other);
        __Pyx_GIVEREF(__pyx_v_other);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_other);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1847, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1846
 *         Implementation of - operator, returns C{L{And}} with error stop
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  }

  /* "cPyparsing.pyx":1848
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_3 == -1)) __PYX_ERR(0, 1848, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = ((!(__pyx_t_3 != 0)) != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1849
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1849, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1849, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyUnicode_Format(__pyx_kp_u_Cannot_combine_element_of_type_s, ((PyObject *)Py_TYPE(__pyx_v_other))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1849, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "cPyparsing.pyx":1850
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             return None
 *         return self + And._ErrorStop() + other
 */
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1849, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
    __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
    __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_builtin_SyntaxWarning);
    __pyx_t_1 = 0;
    __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1850, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 1850, __pyx_L1_error)

    /* "cPyparsing.pyx":1849
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1849, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":1851
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 *             return None             # <<<<<<<<<<<<<<
 *         return self + And._ErrorStop() + other
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;

    /* "cPyparsing.pyx":1848
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  }

  /* "cPyparsing.pyx":1852
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 *         return self + And._ErrorStop() + other             # <<<<<<<<<<<<<<
 * 
 *     def __rsub__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_And); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_ErrorStop); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  if (__pyx_t_1) {
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1852, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1852, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Add(__pyx_v_self, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_Add(__pyx_t_6, __pyx_v_other); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1842
 *         return other + self
 * 
 *     def __sub__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of - operator, returns C{L{And}} with error stop
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__sub__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1854
 *         return self + And._ErrorStop() + other
 * 
 *     def __rsub__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of - operator when left operand is not a C{L{ParserElement}}
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_61__rsub__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_60__rsub__[] = "\n        Implementation of - operator when left operand is not a C{L{ParserElement}}\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_61__rsub__ = {"__rsub__", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_61__rsub__, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_60__rsub__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_61__rsub__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__rsub__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__rsub__", 1, 2, 2, 1); __PYX_ERR(0, 1854, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__rsub__") < 0)) __PYX_ERR(0, 1854, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__rsub__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1854, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.__rsub__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_60__rsub__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_60__rsub__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("__rsub__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":1858
 *         Implementation of - operator when left operand is not a C{L{ParserElement}}
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 1858, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":1859
 *         """
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1859, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1859, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1859, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1859, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1859, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1859, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_other);
        __Pyx_GIVEREF(__pyx_v_other);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_other);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1859, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1858
 *         Implementation of - operator when left operand is not a C{L{ParserElement}}
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  }

  /* "cPyparsing.pyx":1860
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_3 == -1)) __PYX_ERR(0, 1860, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = ((!(__pyx_t_3 != 0)) != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1861
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1861, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1861, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyUnicode_Format(__pyx_kp_u_Cannot_combine_element_of_type_s, ((PyObject *)Py_TYPE(__pyx_v_other))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1861, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "cPyparsing.pyx":1862
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             return None
 *         return other - self
 */
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1861, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
    __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
    __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_builtin_SyntaxWarning);
    __pyx_t_1 = 0;
    __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1862, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 1862, __pyx_L1_error)

    /* "cPyparsing.pyx":1861
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1861, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":1863
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 *             return None             # <<<<<<<<<<<<<<
 *         return other - self
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;

    /* "cPyparsing.pyx":1860
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  }

  /* "cPyparsing.pyx":1864
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 *         return other - self             # <<<<<<<<<<<<<<
 * 
 *     def __mul__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = PyNumber_Subtract(__pyx_v_other, __pyx_v_self); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1854
 *         return self + And._ErrorStop() + other
 * 
 *     def __rsub__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of - operator when left operand is not a C{L{ParserElement}}
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__rsub__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1866
 *         return other - self
 * 
 *     def __mul__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of * operator, allows use of C{expr * 3} in place of
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_63__mul__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_62__mul__[] = "\n        Implementation of * operator, allows use of C{expr * 3} in place of\n        C{expr + expr + expr}.  Expressions may also me multiplied by a 2-integer\n        tuple, similar to C{{min,max}} multipliers in regular expressions.  Tuples\n        may also include C{None} as in:\n         - C{expr*(n,None)} or C{expr*(n,)} is equivalent\n              to C{expr*n + L{ZeroOrMore}(expr)}\n              (read as \"at least n instances of C{expr}\")\n         - C{expr*(None,n)} is equivalent to C{expr*(0,n)}\n              (read as \"0 to n instances of C{expr}\")\n         - C{expr*(None,None)} is equivalent to C{L{ZeroOrMore}(expr)}\n         - C{expr*(1,None)} is equivalent to C{L{OneOrMore}(expr)}\n\n        Note that C{expr*(None,n)} does not raise an exception if\n        more than n exprs exist in the input stream; that is,\n        C{expr*(None,n)} does not enforce a maximum number of expr\n        occurrences.  If this behavior is desired, then write\n        C{expr*(None,n) + ~expr}\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_63__mul__ = {"__mul__", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_63__mul__, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_62__mul__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_63__mul__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__mul__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__mul__", 1, 2, 2, 1); __PYX_ERR(0, 1866, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__mul__") < 0)) __PYX_ERR(0, 1866, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__mul__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1866, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.__mul__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_62__mul__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1915
 * 
 *         if (optElements):
 *             def makeOptionalList(n):             # <<<<<<<<<<<<<<
 *                 if n > 1:
 *                     return Optional(self + makeOptionalList(n - 1))
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_7__mul___1makeOptionalList(PyObject *__pyx_self, PyObject *__pyx_v_n); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_7__mul___1makeOptionalList = {"makeOptionalList", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_7__mul___1makeOptionalList, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_7__mul___1makeOptionalList(PyObject *__pyx_self, PyObject *__pyx_v_n) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("makeOptionalList (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_7__mul___makeOptionalList(__pyx_self, ((PyObject *)__pyx_v_n));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_7__mul___makeOptionalList(PyObject *__pyx_self, PyObject *__pyx_v_n) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_25___mul__ *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_25___mul__ *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("makeOptionalList", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_25___mul__ *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":1916
 *         if (optElements):
 *             def makeOptionalList(n):
 *                 if n > 1:             # <<<<<<<<<<<<<<
 *                     return Optional(self + makeOptionalList(n - 1))
 *                 else:
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_n, __pyx_int_1, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1916, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1916, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1917
 *             def makeOptionalList(n):
 *                 if n > 1:
 *                     return Optional(self + makeOptionalList(n - 1))             # <<<<<<<<<<<<<<
 *                 else:
 *                     return Optional(self)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 1917, __pyx_L1_error) }
    __pyx_t_4 = __Pyx_PyInt_SubtractObjC(__pyx_v_n, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (unlikely(!__pyx_cur_scope->__pyx_v_makeOptionalList)) { __Pyx_RaiseClosureNameError("makeOptionalList"); __PYX_ERR(0, 1917, __pyx_L1_error) }
    __pyx_t_5 = __pyx_pf_10cPyparsing_13ParserElement_7__mul___makeOptionalList(__pyx_cur_scope->__pyx_v_makeOptionalList, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Add(__pyx_cur_scope->__pyx_v_self, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1917, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1917, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1917, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1917, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1917, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":1916
 *         if (optElements):
 *             def makeOptionalList(n):
 *                 if n > 1:             # <<<<<<<<<<<<<<
 *                     return Optional(self + makeOptionalList(n - 1))
 *                 else:
 */
  }

  /* "cPyparsing.pyx":1919
 *                     return Optional(self + makeOptionalList(n - 1))
 *                 else:
 *                     return Optional(self)             # <<<<<<<<<<<<<<
 *             if minElements:
 *                 if minElements == 1:
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1919, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 1919, __pyx_L1_error) }
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_cur_scope->__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1919, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_self};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1919, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_self};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1919, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1919, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
        PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_cur_scope->__pyx_v_self);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1919, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":1915
 * 
 *         if (optElements):
 *             def makeOptionalList(n):             # <<<<<<<<<<<<<<
 *                 if n > 1:
 *                     return Optional(self + makeOptionalList(n - 1))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__mul__.makeOptionalList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1866
 *         return other - self
 * 
 *     def __mul__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of * operator, allows use of C{expr * 3} in place of
 */

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_62__mul__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_25___mul__ *__pyx_cur_scope;
  PyObject *__pyx_v_minElements = NULL;
  PyObject *__pyx_v_optElements = NULL;
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  __Pyx_RefNannySetupContext("__mul__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_25___mul__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_25___mul__(__pyx_ptype_10cPyparsing___pyx_scope_struct_25___mul__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_25___mul__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1866, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":1886
 *         C{expr*(None,n) + ~expr}
 *         """
 *         if isinstance(other, int):             # <<<<<<<<<<<<<<
 *             minElements, optElements = other, 0
 *         elif isinstance(other, tuple):
 */
  __pyx_t_1 = PyInt_Check(__pyx_v_other); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1887
 *         """
 *         if isinstance(other, int):
 *             minElements, optElements = other, 0             # <<<<<<<<<<<<<<
 *         elif isinstance(other, tuple):
 *             other = (other + (None, None))[:2]
 */
    __pyx_t_3 = __pyx_v_other;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = __pyx_int_0;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_v_minElements = __pyx_t_3;
    __pyx_t_3 = 0;
    __pyx_v_optElements = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":1886
 *         C{expr*(None,n) + ~expr}
 *         """
 *         if isinstance(other, int):             # <<<<<<<<<<<<<<
 *             minElements, optElements = other, 0
 *         elif isinstance(other, tuple):
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":1888
 *         if isinstance(other, int):
 *             minElements, optElements = other, 0
 *         elif isinstance(other, tuple):             # <<<<<<<<<<<<<<
 *             other = (other + (None, None))[:2]
 *             if other[0] is None:
 */
  __pyx_t_2 = PyTuple_Check(__pyx_v_other); 
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":1889
 *             minElements, optElements = other, 0
 *         elif isinstance(other, tuple):
 *             other = (other + (None, None))[:2]             # <<<<<<<<<<<<<<
 *             if other[0] is None:
 *                 other = (0, other[1])
 */
    __pyx_t_4 = PyNumber_Add(__pyx_v_other, __pyx_tuple__74); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1889, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_4, 0, 2, NULL, NULL, &__pyx_slice__75, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1889, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":1890
 *         elif isinstance(other, tuple):
 *             other = (other + (None, None))[:2]
 *             if other[0] is None:             # <<<<<<<<<<<<<<
 *                 other = (0, other[1])
 *             if isinstance(other[0], int) and other[1] is None:
 */
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_other, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1890, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = (__pyx_t_3 == Py_None);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_2 = (__pyx_t_1 != 0);
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":1891
 *             other = (other + (None, None))[:2]
 *             if other[0] is None:
 *                 other = (0, other[1])             # <<<<<<<<<<<<<<
 *             if isinstance(other[0], int) and other[1] is None:
 *                 if other[0] == 0:
 */
      __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_other, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1891, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1891, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_GIVEREF(__pyx_int_0);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_int_0);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3);
      __pyx_t_3 = 0;
      __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "cPyparsing.pyx":1890
 *         elif isinstance(other, tuple):
 *             other = (other + (None, None))[:2]
 *             if other[0] is None:             # <<<<<<<<<<<<<<
 *                 other = (0, other[1])
 *             if isinstance(other[0], int) and other[1] is None:
 */
    }

    /* "cPyparsing.pyx":1892
 *             if other[0] is None:
 *                 other = (0, other[1])
 *             if isinstance(other[0], int) and other[1] is None:             # <<<<<<<<<<<<<<
 *                 if other[0] == 0:
 *                     return ZeroOrMore(self)
 */
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_other, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1892, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyInt_Check(__pyx_t_4); 
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = (__pyx_t_1 != 0);
    if (__pyx_t_5) {
    } else {
      __pyx_t_2 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_other, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1892, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = (__pyx_t_4 == Py_None);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_1 = (__pyx_t_5 != 0);
    __pyx_t_2 = __pyx_t_1;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":1893
 *                 other = (0, other[1])
 *             if isinstance(other[0], int) and other[1] is None:
 *                 if other[0] == 0:             # <<<<<<<<<<<<<<
 *                     return ZeroOrMore(self)
 *                 if other[0] == 1:
 */
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_other, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1893, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = __Pyx_PyInt_EqObjC(__pyx_t_4, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1893, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1893, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_2) {

        /* "cPyparsing.pyx":1894
 *             if isinstance(other[0], int) and other[1] is None:
 *                 if other[0] == 0:
 *                     return ZeroOrMore(self)             # <<<<<<<<<<<<<<
 *                 if other[0] == 1:
 *                     return OneOrMore(self)
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1894, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_6 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
          }
        }
        if (!__pyx_t_6) {
          __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_cur_scope->__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1894, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_4)) {
            PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_self};
            __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1894, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_GOTREF(__pyx_t_3);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
            PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_self};
            __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1894, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_GOTREF(__pyx_t_3);
          } else
          #endif
          {
            __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1894, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
            __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
            __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
            PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_cur_scope->__pyx_v_self);
            __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1894, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

        /* "cPyparsing.pyx":1893
 *                 other = (0, other[1])
 *             if isinstance(other[0], int) and other[1] is None:
 *                 if other[0] == 0:             # <<<<<<<<<<<<<<
 *                     return ZeroOrMore(self)
 *                 if other[0] == 1:
 */
      }

      /* "cPyparsing.pyx":1895
 *                 if other[0] == 0:
 *                     return ZeroOrMore(self)
 *                 if other[0] == 1:             # <<<<<<<<<<<<<<
 *                     return OneOrMore(self)
 *                 else:
 */
      __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_other, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1895, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyInt_EqObjC(__pyx_t_3, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1895, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1895, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_2) {

        /* "cPyparsing.pyx":1896
 *                     return ZeroOrMore(self)
 *                 if other[0] == 1:
 *                     return OneOrMore(self)             # <<<<<<<<<<<<<<
 *                 else:
 *                     return self * other[0] + ZeroOrMore(self)
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1896, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_7 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        if (!__pyx_t_7) {
          __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_cur_scope->__pyx_v_self); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1896, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_3)) {
            PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_cur_scope->__pyx_v_self};
            __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1896, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_GOTREF(__pyx_t_4);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
            PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_cur_scope->__pyx_v_self};
            __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1896, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_GOTREF(__pyx_t_4);
          } else
          #endif
          {
            __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1896, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_7); __pyx_t_7 = NULL;
            __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
            __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
            PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_cur_scope->__pyx_v_self);
            __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1896, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_4;
        __pyx_t_4 = 0;
        goto __pyx_L0;

        /* "cPyparsing.pyx":1895
 *                 if other[0] == 0:
 *                     return ZeroOrMore(self)
 *                 if other[0] == 1:             # <<<<<<<<<<<<<<
 *                     return OneOrMore(self)
 *                 else:
 */
      }

      /* "cPyparsing.pyx":1898
 *                     return OneOrMore(self)
 *                 else:
 *                     return self * other[0] + ZeroOrMore(self)             # <<<<<<<<<<<<<<
 *             elif isinstance(other[0], int) and isinstance(other[1], int):
 *                 minElements, optElements = other
 */
      /*else*/ {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_other, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1898, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_3 = PyNumber_Multiply(__pyx_cur_scope->__pyx_v_self, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1898, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1898, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
          }
        }
        if (!__pyx_t_7) {
          __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_cur_scope->__pyx_v_self); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1898, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_6)) {
            PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_cur_scope->__pyx_v_self};
            __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1898, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_GOTREF(__pyx_t_4);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
            PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_cur_scope->__pyx_v_self};
            __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1898, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_GOTREF(__pyx_t_4);
          } else
          #endif
          {
            __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1898, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_7); __pyx_t_7 = NULL;
            __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
            __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
            PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_cur_scope->__pyx_v_self);
            __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_8, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1898, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = PyNumber_Add(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1898, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_r = __pyx_t_6;
        __pyx_t_6 = 0;
        goto __pyx_L0;
      }

      /* "cPyparsing.pyx":1892
 *             if other[0] is None:
 *                 other = (0, other[1])
 *             if isinstance(other[0], int) and other[1] is None:             # <<<<<<<<<<<<<<
 *                 if other[0] == 0:
 *                     return ZeroOrMore(self)
 */
    }

    /* "cPyparsing.pyx":1899
 *                 else:
 *                     return self * other[0] + ZeroOrMore(self)
 *             elif isinstance(other[0], int) and isinstance(other[1], int):             # <<<<<<<<<<<<<<
 *                 minElements, optElements = other
 *                 optElements -= minElements
 */
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_other, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1899, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = PyInt_Check(__pyx_t_6); 
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_5 = (__pyx_t_1 != 0);
    if (__pyx_t_5) {
    } else {
      __pyx_t_2 = __pyx_t_5;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_other, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1899, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = PyInt_Check(__pyx_t_6); 
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_1 = (__pyx_t_5 != 0);
    __pyx_t_2 = __pyx_t_1;
    __pyx_L10_bool_binop_done:;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":1900
 *                     return self * other[0] + ZeroOrMore(self)
 *             elif isinstance(other[0], int) and isinstance(other[1], int):
 *                 minElements, optElements = other             # <<<<<<<<<<<<<<
 *                 optElements -= minElements
 *             else:
 */
      if ((likely(PyTuple_CheckExact(__pyx_v_other))) || (PyList_CheckExact(__pyx_v_other))) {
        PyObject* sequence = __pyx_v_other;
        #if !CYTHON_COMPILING_IN_PYPY
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 1900, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_6 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_4);
        #else
        __pyx_t_6 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1900, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1900, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        Py_ssize_t index = -1;
        __pyx_t_3 = PyObject_GetIter(__pyx_v_other); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1900, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_9 = Py_TYPE(__pyx_t_3)->tp_iternext;
        index = 0; __pyx_t_6 = __pyx_t_9(__pyx_t_3); if (unlikely(!__pyx_t_6)) goto __pyx_L12_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_6);
        index = 1; __pyx_t_4 = __pyx_t_9(__pyx_t_3); if (unlikely(!__pyx_t_4)) goto __pyx_L12_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_4);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_3), 2) < 0) __PYX_ERR(0, 1900, __pyx_L1_error)
        __pyx_t_9 = NULL;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        goto __pyx_L13_unpacking_done;
        __pyx_L12_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_9 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 1900, __pyx_L1_error)
        __pyx_L13_unpacking_done:;
      }
      __pyx_v_minElements = __pyx_t_6;
      __pyx_t_6 = 0;
      __pyx_v_optElements = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "cPyparsing.pyx":1901
 *             elif isinstance(other[0], int) and isinstance(other[1], int):
 *                 minElements, optElements = other
 *                 optElements -= minElements             # <<<<<<<<<<<<<<
 *             else:
 *                 raise TypeError("cannot multiply 'ParserElement' and ('%s','%s') objects", type(other[0]), type(other[1]))
 */
      __pyx_t_4 = PyNumber_InPlaceSubtract(__pyx_v_optElements, __pyx_v_minElements); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1901, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_optElements, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "cPyparsing.pyx":1899
 *                 else:
 *                     return self * other[0] + ZeroOrMore(self)
 *             elif isinstance(other[0], int) and isinstance(other[1], int):             # <<<<<<<<<<<<<<
 *                 minElements, optElements = other
 *                 optElements -= minElements
 */
      goto __pyx_L5;
    }

    /* "cPyparsing.pyx":1903
 *                 optElements -= minElements
 *             else:
 *                 raise TypeError("cannot multiply 'ParserElement' and ('%s','%s') objects", type(other[0]), type(other[1]))             # <<<<<<<<<<<<<<
 *         else:
 *             raise TypeError("cannot multiply 'ParserElement' and '%s' objects", type(other))
 */
    /*else*/ {
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_other, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1903, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_other, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1903, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1903, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_kp_u_cannot_multiply_ParserElement_an);
      __Pyx_GIVEREF(__pyx_kp_u_cannot_multiply_ParserElement_an);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_u_cannot_multiply_ParserElement_an);
      __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_t_4)));
      __Pyx_GIVEREF(((PyObject *)Py_TYPE(__pyx_t_4)));
      PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)Py_TYPE(__pyx_t_4)));
      __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_t_6)));
      __Pyx_GIVEREF(((PyObject *)Py_TYPE(__pyx_t_6)));
      PyTuple_SET_ITEM(__pyx_t_3, 2, ((PyObject *)Py_TYPE(__pyx_t_6)));
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_t_3, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1903, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(0, 1903, __pyx_L1_error)
    }
    __pyx_L5:;

    /* "cPyparsing.pyx":1888
 *         if isinstance(other, int):
 *             minElements, optElements = other, 0
 *         elif isinstance(other, tuple):             # <<<<<<<<<<<<<<
 *             other = (other + (None, None))[:2]
 *             if other[0] is None:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":1905
 *                 raise TypeError("cannot multiply 'ParserElement' and ('%s','%s') objects", type(other[0]), type(other[1]))
 *         else:
 *             raise TypeError("cannot multiply 'ParserElement' and '%s' objects", type(other))             # <<<<<<<<<<<<<<
 * 
 *         if minElements < 0:
 */
  /*else*/ {
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1905, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_kp_u_cannot_multiply_ParserElement_an_2);
    __Pyx_GIVEREF(__pyx_kp_u_cannot_multiply_ParserElement_an_2);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_kp_u_cannot_multiply_ParserElement_an_2);
    __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_other)));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(__pyx_v_other)));
    PyTuple_SET_ITEM(__pyx_t_6, 1, ((PyObject *)Py_TYPE(__pyx_v_other)));
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1905, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1905, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":1907
 *             raise TypeError("cannot multiply 'ParserElement' and '%s' objects", type(other))
 * 
 *         if minElements < 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("cannot multiply ParserElement by negative value")
 *         if optElements < 0:
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_minElements, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1907, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1907, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1908
 * 
 *         if minElements < 0:
 *             raise ValueError("cannot multiply ParserElement by negative value")             # <<<<<<<<<<<<<<
 *         if optElements < 0:
 *             raise ValueError("second tuple value must be greater or equal to first tuple value")
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__76, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1908, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1908, __pyx_L1_error)

    /* "cPyparsing.pyx":1907
 *             raise TypeError("cannot multiply 'ParserElement' and '%s' objects", type(other))
 * 
 *         if minElements < 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("cannot multiply ParserElement by negative value")
 *         if optElements < 0:
 */
  }

  /* "cPyparsing.pyx":1909
 *         if minElements < 0:
 *             raise ValueError("cannot multiply ParserElement by negative value")
 *         if optElements < 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("second tuple value must be greater or equal to first tuple value")
 *         if minElements == optElements == 0:
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_optElements, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1909, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1909, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1910
 *             raise ValueError("cannot multiply ParserElement by negative value")
 *         if optElements < 0:
 *             raise ValueError("second tuple value must be greater or equal to first tuple value")             # <<<<<<<<<<<<<<
 *         if minElements == optElements == 0:
 *             raise ValueError("cannot multiply ParserElement by 0 or (0,0)")
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__77, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1910, __pyx_L1_error)

    /* "cPyparsing.pyx":1909
 *         if minElements < 0:
 *             raise ValueError("cannot multiply ParserElement by negative value")
 *         if optElements < 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("second tuple value must be greater or equal to first tuple value")
 *         if minElements == optElements == 0:
 */
  }

  /* "cPyparsing.pyx":1911
 *         if optElements < 0:
 *             raise ValueError("second tuple value must be greater or equal to first tuple value")
 *         if minElements == optElements == 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("cannot multiply ParserElement by 0 or (0,0)")
 * 
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_minElements, __pyx_v_optElements, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1911, __pyx_L1_error)
  if (__Pyx_PyObject_IsTrue(__pyx_t_3)) {
    __Pyx_DECREF(__pyx_t_3);
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_optElements, __pyx_int_0, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1911, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1911, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1912
 *             raise ValueError("second tuple value must be greater or equal to first tuple value")
 *         if minElements == optElements == 0:
 *             raise ValueError("cannot multiply ParserElement by 0 or (0,0)")             # <<<<<<<<<<<<<<
 * 
 *         if (optElements):
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__78, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1912, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1912, __pyx_L1_error)

    /* "cPyparsing.pyx":1911
 *         if optElements < 0:
 *             raise ValueError("second tuple value must be greater or equal to first tuple value")
 *         if minElements == optElements == 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("cannot multiply ParserElement by 0 or (0,0)")
 * 
 */
  }

  /* "cPyparsing.pyx":1914
 *             raise ValueError("cannot multiply ParserElement by 0 or (0,0)")
 * 
 *         if (optElements):             # <<<<<<<<<<<<<<
 *             def makeOptionalList(n):
 *                 if n > 1:
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_optElements); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1914, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1915
 * 
 *         if (optElements):
 *             def makeOptionalList(n):             # <<<<<<<<<<<<<<
 *                 if n > 1:
 *                     return Optional(self + makeOptionalList(n - 1))
 */
    __pyx_t_3 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_7__mul___1makeOptionalList, 0, __pyx_n_s_ParserElement___mul___locals_mak, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__80)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1915, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_cur_scope->__pyx_v_makeOptionalList = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":1920
 *                 else:
 *                     return Optional(self)
 *             if minElements:             # <<<<<<<<<<<<<<
 *                 if minElements == 1:
 *                     ret = self + makeOptionalList(optElements)
 */
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_minElements); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1920, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":1921
 *                     return Optional(self)
 *             if minElements:
 *                 if minElements == 1:             # <<<<<<<<<<<<<<
 *                     ret = self + makeOptionalList(optElements)
 *                 else:
 */
      __pyx_t_3 = __Pyx_PyInt_EqObjC(__pyx_v_minElements, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1921, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1921, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_2) {

        /* "cPyparsing.pyx":1922
 *             if minElements:
 *                 if minElements == 1:
 *                     ret = self + makeOptionalList(optElements)             # <<<<<<<<<<<<<<
 *                 else:
 *                     ret = And([self] * minElements) + makeOptionalList(optElements)
 */
        __pyx_t_3 = __pyx_pf_10cPyparsing_13ParserElement_7__mul___makeOptionalList(__pyx_cur_scope->__pyx_v_makeOptionalList, __pyx_v_optElements); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1922, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_6 = PyNumber_Add(__pyx_cur_scope->__pyx_v_self, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1922, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_v_ret = __pyx_t_6;
        __pyx_t_6 = 0;

        /* "cPyparsing.pyx":1921
 *                     return Optional(self)
 *             if minElements:
 *                 if minElements == 1:             # <<<<<<<<<<<<<<
 *                     ret = self + makeOptionalList(optElements)
 *                 else:
 */
        goto __pyx_L19;
      }

      /* "cPyparsing.pyx":1924
 *                     ret = self + makeOptionalList(optElements)
 *                 else:
 *                     ret = And([self] * minElements) + makeOptionalList(optElements)             # <<<<<<<<<<<<<<
 *             else:
 *                 ret = makeOptionalList(optElements)
 */
      /*else*/ {
        __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_And); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1924, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1924, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
        PyList_SET_ITEM(__pyx_t_4, 0, __pyx_cur_scope->__pyx_v_self);
        { PyObject* __pyx_temp = PyNumber_InPlaceMultiply(__pyx_t_4, __pyx_v_minElements); if (unlikely(!__pyx_temp)) __PYX_ERR(0, 1924, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_temp);
          __Pyx_DECREF(__pyx_t_4);
          __pyx_t_4 = __pyx_temp;
        }
        __pyx_t_8 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        if (!__pyx_t_8) {
          __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1924, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_6);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_3)) {
            PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_4};
            __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1924, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
            PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_4};
            __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1924, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          } else
          #endif
          {
            __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1924, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_8); __pyx_t_8 = NULL;
            __Pyx_GIVEREF(__pyx_t_4);
            PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_4);
            __pyx_t_4 = 0;
            __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_7, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1924, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __pyx_pf_10cPyparsing_13ParserElement_7__mul___makeOptionalList(__pyx_cur_scope->__pyx_v_makeOptionalList, __pyx_v_optElements); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1924, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_7 = PyNumber_Add(__pyx_t_6, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1924, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_v_ret = __pyx_t_7;
        __pyx_t_7 = 0;
      }
      __pyx_L19:;

      /* "cPyparsing.pyx":1920
 *                 else:
 *                     return Optional(self)
 *             if minElements:             # <<<<<<<<<<<<<<
 *                 if minElements == 1:
 *                     ret = self + makeOptionalList(optElements)
 */
      goto __pyx_L18;
    }

    /* "cPyparsing.pyx":1926
 *                     ret = And([self] * minElements) + makeOptionalList(optElements)
 *             else:
 *                 ret = makeOptionalList(optElements)             # <<<<<<<<<<<<<<
 *         else:
 *             if minElements == 1:
 */
    /*else*/ {
      __pyx_t_7 = __pyx_pf_10cPyparsing_13ParserElement_7__mul___makeOptionalList(__pyx_cur_scope->__pyx_v_makeOptionalList, __pyx_v_optElements); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1926, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_v_ret = __pyx_t_7;
      __pyx_t_7 = 0;
    }
    __pyx_L18:;

    /* "cPyparsing.pyx":1914
 *             raise ValueError("cannot multiply ParserElement by 0 or (0,0)")
 * 
 *         if (optElements):             # <<<<<<<<<<<<<<
 *             def makeOptionalList(n):
 *                 if n > 1:
 */
    goto __pyx_L17;
  }

  /* "cPyparsing.pyx":1928
 *                 ret = makeOptionalList(optElements)
 *         else:
 *             if minElements == 1:             # <<<<<<<<<<<<<<
 *                 ret = self
 *             else:
 */
  /*else*/ {
    __pyx_t_7 = __Pyx_PyInt_EqObjC(__pyx_v_minElements, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1928, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1928, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":1929
 *         else:
 *             if minElements == 1:
 *                 ret = self             # <<<<<<<<<<<<<<
 *             else:
 *                 ret = And([self] * minElements)
 */
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
      __pyx_v_ret = __pyx_cur_scope->__pyx_v_self;

      /* "cPyparsing.pyx":1928
 *                 ret = makeOptionalList(optElements)
 *         else:
 *             if minElements == 1:             # <<<<<<<<<<<<<<
 *                 ret = self
 *             else:
 */
      goto __pyx_L20;
    }

    /* "cPyparsing.pyx":1931
 *                 ret = self
 *             else:
 *                 ret = And([self] * minElements)             # <<<<<<<<<<<<<<
 *         return ret
 * 
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_And); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1931, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1931, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
      PyList_SET_ITEM(__pyx_t_6, 0, __pyx_cur_scope->__pyx_v_self);
      { PyObject* __pyx_temp = PyNumber_InPlaceMultiply(__pyx_t_6, __pyx_v_minElements); if (unlikely(!__pyx_temp)) __PYX_ERR(0, 1931, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_temp);
        __Pyx_DECREF(__pyx_t_6);
        __pyx_t_6 = __pyx_temp;
      }
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_4) {
        __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1931, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_7);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_6};
          __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1931, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_6};
          __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1931, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        } else
        #endif
        {
          __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1931, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_4); __pyx_t_4 = NULL;
          __Pyx_GIVEREF(__pyx_t_6);
          PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_6);
          __pyx_t_6 = 0;
          __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_8, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1931, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_ret = __pyx_t_7;
      __pyx_t_7 = 0;
    }
    __pyx_L20:;
  }
  __pyx_L17:;

  /* "cPyparsing.pyx":1932
 *             else:
 *                 ret = And([self] * minElements)
 *         return ret             # <<<<<<<<<<<<<<
 * 
 *     def __rmul__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ret);
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1866
 *         return other - self
 * 
 *     def __mul__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of * operator, allows use of C{expr * 3} in place of
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__mul__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_minElements);
  __Pyx_XDECREF(__pyx_v_optElements);
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1934
 *         return ret
 * 
 *     def __rmul__(self, other):             # <<<<<<<<<<<<<<
 *         return self.__mul__(other)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_65__rmul__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_65__rmul__ = {"__rmul__", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_65__rmul__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_65__rmul__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__rmul__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__rmul__", 1, 2, 2, 1); __PYX_ERR(0, 1934, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__rmul__") < 0)) __PYX_ERR(0, 1934, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__rmul__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1934, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.__rmul__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_64__rmul__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_64__rmul__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("__rmul__", 0);

  /* "cPyparsing.pyx":1935
 * 
 *     def __rmul__(self, other):
 *         return self.__mul__(other)             # <<<<<<<<<<<<<<
 * 
 *     def __or__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mul); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1935, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1935, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1935, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1935, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_v_other);
      __Pyx_GIVEREF(__pyx_v_other);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_other);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1935, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1934
 *         return ret
 * 
 *     def __rmul__(self, other):             # <<<<<<<<<<<<<<
 *         return self.__mul__(other)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__rmul__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1937
 *         return self.__mul__(other)
 * 
 *     def __or__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of | operator - returns C{L{MatchFirst}}
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_67__or__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_66__or__[] = "\n        Implementation of | operator - returns C{L{MatchFirst}}\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_67__or__ = {"__or__", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_67__or__, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_66__or__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_67__or__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__or__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__or__", 1, 2, 2, 1); __PYX_ERR(0, 1937, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__or__") < 0)) __PYX_ERR(0, 1937, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__or__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1937, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.__or__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_66__or__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_66__or__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("__or__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":1941
 *         Implementation of | operator - returns C{L{MatchFirst}}
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 1941, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":1942
 *         """
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1942, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1942, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1942, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1942, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1942, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1942, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_other);
        __Pyx_GIVEREF(__pyx_v_other);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_other);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1942, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1941
 *         Implementation of | operator - returns C{L{MatchFirst}}
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  }

  /* "cPyparsing.pyx":1943
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_3 == -1)) __PYX_ERR(0, 1943, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = ((!(__pyx_t_3 != 0)) != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1944
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1944, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1944, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyUnicode_Format(__pyx_kp_u_Cannot_combine_element_of_type_s, ((PyObject *)Py_TYPE(__pyx_v_other))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1944, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "cPyparsing.pyx":1945
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             return None
 *         return MatchFirst([self, other])
 */
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1944, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
    __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
    __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_builtin_SyntaxWarning);
    __pyx_t_1 = 0;
    __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1945, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 1945, __pyx_L1_error)

    /* "cPyparsing.pyx":1944
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1944, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":1946
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 *             return None             # <<<<<<<<<<<<<<
 *         return MatchFirst([self, other])
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;

    /* "cPyparsing.pyx":1943
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  }

  /* "cPyparsing.pyx":1947
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 *         return MatchFirst([self, other])             # <<<<<<<<<<<<<<
 * 
 *     def __ror__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_MatchFirst); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1947, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyList_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1947, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyList_SET_ITEM(__pyx_t_6, 0, __pyx_v_self);
  __Pyx_INCREF(__pyx_v_other);
  __Pyx_GIVEREF(__pyx_v_other);
  PyList_SET_ITEM(__pyx_t_6, 1, __pyx_v_other);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (!__pyx_t_5) {
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1947, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_6};
      __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1947, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_6};
      __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1947, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1947, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1947, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1937
 *         return self.__mul__(other)
 * 
 *     def __or__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of | operator - returns C{L{MatchFirst}}
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__or__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1949
 *         return MatchFirst([self, other])
 * 
 *     def __ror__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of | operator when left operand is not a C{L{ParserElement}}
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_69__ror__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_68__ror__[] = "\n        Implementation of | operator when left operand is not a C{L{ParserElement}}\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_69__ror__ = {"__ror__", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_69__ror__, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_68__ror__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_69__ror__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__ror__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__ror__", 1, 2, 2, 1); __PYX_ERR(0, 1949, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__ror__") < 0)) __PYX_ERR(0, 1949, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__ror__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1949, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.__ror__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_68__ror__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_68__ror__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("__ror__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":1953
 *         Implementation of | operator when left operand is not a C{L{ParserElement}}
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 1953, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":1954
 *         """
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1954, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1954, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1954, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1954, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1954, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1954, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_other);
        __Pyx_GIVEREF(__pyx_v_other);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_other);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1954, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1953
 *         Implementation of | operator when left operand is not a C{L{ParserElement}}
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  }

  /* "cPyparsing.pyx":1955
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_3 == -1)) __PYX_ERR(0, 1955, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = ((!(__pyx_t_3 != 0)) != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1956
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1956, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1956, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyUnicode_Format(__pyx_kp_u_Cannot_combine_element_of_type_s, ((PyObject *)Py_TYPE(__pyx_v_other))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1956, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "cPyparsing.pyx":1957
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             return None
 *         return other | self
 */
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1956, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
    __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
    __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_builtin_SyntaxWarning);
    __pyx_t_1 = 0;
    __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1957, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 1957, __pyx_L1_error)

    /* "cPyparsing.pyx":1956
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1956, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":1958
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 *             return None             # <<<<<<<<<<<<<<
 *         return other | self
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;

    /* "cPyparsing.pyx":1955
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  }

  /* "cPyparsing.pyx":1959
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 *         return other | self             # <<<<<<<<<<<<<<
 * 
 *     def __xor__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = PyNumber_Or(__pyx_v_other, __pyx_v_self); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1959, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1949
 *         return MatchFirst([self, other])
 * 
 *     def __ror__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of | operator when left operand is not a C{L{ParserElement}}
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__ror__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1961
 *         return other | self
 * 
 *     def __xor__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of ^ operator - returns C{L{Or}}
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_71__xor__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_70__xor__[] = "\n        Implementation of ^ operator - returns C{L{Or}}\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_71__xor__ = {"__xor__", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_71__xor__, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_70__xor__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_71__xor__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__xor__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__xor__", 1, 2, 2, 1); __PYX_ERR(0, 1961, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__xor__") < 0)) __PYX_ERR(0, 1961, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__xor__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1961, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.__xor__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_70__xor__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_70__xor__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("__xor__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":1965
 *         Implementation of ^ operator - returns C{L{Or}}
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 1965, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":1966
 *         """
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1966, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1966, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1966, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1966, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1966, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1966, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_other);
        __Pyx_GIVEREF(__pyx_v_other);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_other);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1966, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1965
 *         Implementation of ^ operator - returns C{L{Or}}
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  }

  /* "cPyparsing.pyx":1967
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_3 == -1)) __PYX_ERR(0, 1967, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = ((!(__pyx_t_3 != 0)) != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1968
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1968, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1968, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyUnicode_Format(__pyx_kp_u_Cannot_combine_element_of_type_s, ((PyObject *)Py_TYPE(__pyx_v_other))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1968, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "cPyparsing.pyx":1969
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             return None
 *         return Or([self, other])
 */
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1968, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
    __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
    __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_builtin_SyntaxWarning);
    __pyx_t_1 = 0;
    __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1969, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 1969, __pyx_L1_error)

    /* "cPyparsing.pyx":1968
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1968, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":1970
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 *             return None             # <<<<<<<<<<<<<<
 *         return Or([self, other])
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;

    /* "cPyparsing.pyx":1967
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  }

  /* "cPyparsing.pyx":1971
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 *         return Or([self, other])             # <<<<<<<<<<<<<<
 * 
 *     def __rxor__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Or); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyList_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyList_SET_ITEM(__pyx_t_6, 0, __pyx_v_self);
  __Pyx_INCREF(__pyx_v_other);
  __Pyx_GIVEREF(__pyx_v_other);
  PyList_SET_ITEM(__pyx_t_6, 1, __pyx_v_other);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (!__pyx_t_5) {
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1971, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_6};
      __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1971, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_6};
      __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1971, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1971, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1971, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1961
 *         return other | self
 * 
 *     def __xor__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of ^ operator - returns C{L{Or}}
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__xor__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1973
 *         return Or([self, other])
 * 
 *     def __rxor__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of ^ operator when left operand is not a C{L{ParserElement}}
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_73__rxor__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_72__rxor__[] = "\n        Implementation of ^ operator when left operand is not a C{L{ParserElement}}\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_73__rxor__ = {"__rxor__", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_73__rxor__, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_72__rxor__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_73__rxor__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__rxor__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__rxor__", 1, 2, 2, 1); __PYX_ERR(0, 1973, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__rxor__") < 0)) __PYX_ERR(0, 1973, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__rxor__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1973, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.__rxor__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_72__rxor__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_72__rxor__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("__rxor__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":1977
 *         Implementation of ^ operator when left operand is not a C{L{ParserElement}}
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 1977, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":1978
 *         """
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1978, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1978, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1978, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1978, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1978, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1978, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_other);
        __Pyx_GIVEREF(__pyx_v_other);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_other);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1978, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1977
 *         Implementation of ^ operator when left operand is not a C{L{ParserElement}}
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  }

  /* "cPyparsing.pyx":1979
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_3 == -1)) __PYX_ERR(0, 1979, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = ((!(__pyx_t_3 != 0)) != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1980
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1980, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1980, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyUnicode_Format(__pyx_kp_u_Cannot_combine_element_of_type_s, ((PyObject *)Py_TYPE(__pyx_v_other))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1980, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "cPyparsing.pyx":1981
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             return None
 *         return other ^ self
 */
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1980, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
    __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
    __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_builtin_SyntaxWarning);
    __pyx_t_1 = 0;
    __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1981, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 1981, __pyx_L1_error)

    /* "cPyparsing.pyx":1980
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1980, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":1982
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 *             return None             # <<<<<<<<<<<<<<
 *         return other ^ self
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;

    /* "cPyparsing.pyx":1979
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  }

  /* "cPyparsing.pyx":1983
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 *         return other ^ self             # <<<<<<<<<<<<<<
 * 
 *     def __and__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = PyNumber_Xor(__pyx_v_other, __pyx_v_self); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1973
 *         return Or([self, other])
 * 
 *     def __rxor__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of ^ operator when left operand is not a C{L{ParserElement}}
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__rxor__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1985
 *         return other ^ self
 * 
 *     def __and__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of & operator - returns C{L{Each}}
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_75__and__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_74__and__[] = "\n        Implementation of & operator - returns C{L{Each}}\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_75__and__ = {"__and__", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_75__and__, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_74__and__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_75__and__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__and__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__and__", 1, 2, 2, 1); __PYX_ERR(0, 1985, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__and__") < 0)) __PYX_ERR(0, 1985, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__and__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1985, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.__and__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_74__and__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_74__and__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("__and__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":1989
 *         Implementation of & operator - returns C{L{Each}}
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 1989, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":1990
 *         """
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1990, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1990, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1990, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1990, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1990, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1990, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_other);
        __Pyx_GIVEREF(__pyx_v_other);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_other);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1990, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":1989
 *         Implementation of & operator - returns C{L{Each}}
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  }

  /* "cPyparsing.pyx":1991
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1991, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_3 == -1)) __PYX_ERR(0, 1991, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = ((!(__pyx_t_3 != 0)) != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":1992
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1992, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1992, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyUnicode_Format(__pyx_kp_u_Cannot_combine_element_of_type_s, ((PyObject *)Py_TYPE(__pyx_v_other))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1992, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "cPyparsing.pyx":1993
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             return None
 *         return Each([self, other])
 */
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1992, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
    __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
    __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_builtin_SyntaxWarning);
    __pyx_t_1 = 0;
    __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1993, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 1993, __pyx_L1_error)

    /* "cPyparsing.pyx":1992
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1992, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":1994
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 *             return None             # <<<<<<<<<<<<<<
 *         return Each([self, other])
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;

    /* "cPyparsing.pyx":1991
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  }

  /* "cPyparsing.pyx":1995
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 *         return Each([self, other])             # <<<<<<<<<<<<<<
 * 
 *     def __rand__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Each); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyList_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyList_SET_ITEM(__pyx_t_6, 0, __pyx_v_self);
  __Pyx_INCREF(__pyx_v_other);
  __Pyx_GIVEREF(__pyx_v_other);
  PyList_SET_ITEM(__pyx_t_6, 1, __pyx_v_other);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (!__pyx_t_5) {
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1995, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_6};
      __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1995, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_6};
      __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1995, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1995, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1995, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1985
 *         return other ^ self
 * 
 *     def __and__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of & operator - returns C{L{Each}}
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__and__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":1997
 *         return Each([self, other])
 * 
 *     def __rand__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of & operator when left operand is not a C{L{ParserElement}}
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_77__rand__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_76__rand__[] = "\n        Implementation of & operator when left operand is not a C{L{ParserElement}}\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_77__rand__ = {"__rand__", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_77__rand__, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_76__rand__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_77__rand__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__rand__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__rand__", 1, 2, 2, 1); __PYX_ERR(0, 1997, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__rand__") < 0)) __PYX_ERR(0, 1997, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__rand__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1997, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.__rand__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_76__rand__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_76__rand__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("__rand__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":2001
 *         Implementation of & operator when left operand is not a C{L{ParserElement}}
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2001, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 2001, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":2002
 *         """
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2002, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2002, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2002, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2002, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2002, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2002, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_other);
        __Pyx_GIVEREF(__pyx_v_other);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_other);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2002, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2001
 *         Implementation of & operator when left operand is not a C{L{ParserElement}}
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 */
  }

  /* "cPyparsing.pyx":2003
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2003, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_3 == -1)) __PYX_ERR(0, 2003, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = ((!(__pyx_t_3 != 0)) != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":2004
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyUnicode_Format(__pyx_kp_u_Cannot_combine_element_of_type_s, ((PyObject *)Py_TYPE(__pyx_v_other))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "cPyparsing.pyx":2005
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             return None
 *         return other & self
 */
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
    __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
    __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_builtin_SyntaxWarning);
    __pyx_t_1 = 0;
    __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 2005, __pyx_L1_error)

    /* "cPyparsing.pyx":2004
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":2006
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 *             return None             # <<<<<<<<<<<<<<
 *         return other & self
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;

    /* "cPyparsing.pyx":2003
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 *         if not isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             warnings.warn("Cannot combine element of type %s with ParserElement" % type(other),
 *                           SyntaxWarning, stacklevel=2)
 */
  }

  /* "cPyparsing.pyx":2007
 *                           SyntaxWarning, stacklevel=2)
 *             return None
 *         return other & self             # <<<<<<<<<<<<<<
 * 
 *     def __invert__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = PyNumber_And(__pyx_v_other, __pyx_v_self); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":1997
 *         return Each([self, other])
 * 
 *     def __rand__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of & operator when left operand is not a C{L{ParserElement}}
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__rand__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2009
 *         return other & self
 * 
 *     def __invert__(self):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of ~ operator - returns C{L{NotAny}}
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_79__invert__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_78__invert__[] = "\n        Implementation of ~ operator - returns C{L{NotAny}}\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_79__invert__ = {"__invert__", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_79__invert__, METH_O, __pyx_doc_10cPyparsing_13ParserElement_78__invert__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_79__invert__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__invert__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_78__invert__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_78__invert__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("__invert__", 0);

  /* "cPyparsing.pyx":2013
 *         Implementation of ~ operator - returns C{L{NotAny}}
 *         """
 *         return NotAny(self)             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, name=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_NotAny); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2013, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2013, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2013, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2013, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_self);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2013, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2009
 *         return other & self
 * 
 *     def __invert__(self):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of ~ operator - returns C{L{NotAny}}
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__invert__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2015
 *         return NotAny(self)
 * 
 *     def __call__(self, name=None):             # <<<<<<<<<<<<<<
 *         """
 *         Shortcut for C{L{setResultsName}}, with C{listAllMatches=False}.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_81__call__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_80__call__[] = "\n        Shortcut for C{L{setResultsName}}, with C{listAllMatches=False}.\n\n        If C{name} is given with a trailing C{'*'} character, then C{listAllMatches} will be\n        passed as C{True}.\n\n        If C{name} is omitted, same as calling C{L{copy}}.\n\n        Example::\n            # these are equivalent\n            userdata = Word(alphas).setResultsName(\"name\") + Word(nums+\"-\").setResultsName(\"socsecno\")\n            userdata = Word(alphas)(\"name\") + Word(nums+\"-\")(\"socsecno\")\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_81__call__ = {"__call__", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_81__call__, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_80__call__};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_81__call__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_name,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__call__") < 0)) __PYX_ERR(0, 2015, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_name = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2015, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_80__call__(__pyx_self, __pyx_v_self, __pyx_v_name);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_80__call__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "cPyparsing.pyx":2029
 *             userdata = Word(alphas)("name") + Word(nums+"-")("socsecno")
 *         """
 *         if name is not None:             # <<<<<<<<<<<<<<
 *             return self.setResultsName(name)
 *         else:
 */
  __pyx_t_1 = (__pyx_v_name != Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":2030
 *         """
 *         if name is not None:
 *             return self.setResultsName(name)             # <<<<<<<<<<<<<<
 *         else:
 *             return self.copy()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_setResultsName); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2030, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2030, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_name};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2030, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_name};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2030, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2030, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_INCREF(__pyx_v_name);
        __Pyx_GIVEREF(__pyx_v_name);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_name);
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2030, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":2029
 *             userdata = Word(alphas)("name") + Word(nums+"-")("socsecno")
 *         """
 *         if name is not None:             # <<<<<<<<<<<<<<
 *             return self.setResultsName(name)
 *         else:
 */
  }

  /* "cPyparsing.pyx":2032
 *             return self.setResultsName(name)
 *         else:
 *             return self.copy()             # <<<<<<<<<<<<<<
 * 
 *     def suppress(self):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_copy); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2032, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (__pyx_t_6) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2032, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else {
      __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2032, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":2015
 *         return NotAny(self)
 * 
 *     def __call__(self, name=None):             # <<<<<<<<<<<<<<
 *         """
 *         Shortcut for C{L{setResultsName}}, with C{listAllMatches=False}.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2034
 *             return self.copy()
 * 
 *     def suppress(self):             # <<<<<<<<<<<<<<
 *         """
 *         Suppresses the output of this C{ParserElement}; useful to keep punctuation from
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_83suppress(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_82suppress[] = "\n        Suppresses the output of this C{ParserElement}; useful to keep punctuation from\n        cluttering up returned output.\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_83suppress = {"suppress", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_83suppress, METH_O, __pyx_doc_10cPyparsing_13ParserElement_82suppress};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_83suppress(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("suppress (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_82suppress(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_82suppress(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("suppress", 0);

  /* "cPyparsing.pyx":2039
 *         cluttering up returned output.
 *         """
 *         return Suppress(self)             # <<<<<<<<<<<<<<
 * 
 *     def leaveWhitespace(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Suppress); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2039, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2039, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2039, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2039, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2039, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_self);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2039, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2034
 *             return self.copy()
 * 
 *     def suppress(self):             # <<<<<<<<<<<<<<
 *         """
 *         Suppresses the output of this C{ParserElement}; useful to keep punctuation from
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParserElement.suppress", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2041
 *         return Suppress(self)
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         """
 *         Disables the skipping of whitespace before matching the characters in the
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_85leaveWhitespace(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_84leaveWhitespace[] = "\n        Disables the skipping of whitespace before matching the characters in the\n        C{ParserElement}'s defined pattern.  This is normally only used internally by\n        the pyparsing module, but may be needed in some whitespace-sensitive grammars.\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_85leaveWhitespace = {"leaveWhitespace", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_85leaveWhitespace, METH_O, __pyx_doc_10cPyparsing_13ParserElement_84leaveWhitespace};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_85leaveWhitespace(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("leaveWhitespace (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_84leaveWhitespace(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_84leaveWhitespace(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("leaveWhitespace", 0);

  /* "cPyparsing.pyx":2047
 *         the pyparsing module, but may be needed in some whitespace-sensitive grammars.
 *         """
 *         self.skipWhitespace = False             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, Py_False) < 0) __PYX_ERR(0, 2047, __pyx_L1_error)

  /* "cPyparsing.pyx":2048
 *         """
 *         self.skipWhitespace = False
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def setWhitespaceChars(self, chars):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2041
 *         return Suppress(self)
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         """
 *         Disables the skipping of whitespace before matching the characters in the
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.leaveWhitespace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2050
 *         return self
 * 
 *     def setWhitespaceChars(self, chars):             # <<<<<<<<<<<<<<
 *         """
 *         Overrides the default whitespace chars
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_87setWhitespaceChars(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_86setWhitespaceChars[] = "\n        Overrides the default whitespace chars\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_87setWhitespaceChars = {"setWhitespaceChars", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_87setWhitespaceChars, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_86setWhitespaceChars};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_87setWhitespaceChars(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_chars = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setWhitespaceChars (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_chars,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_chars)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("setWhitespaceChars", 1, 2, 2, 1); __PYX_ERR(0, 2050, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "setWhitespaceChars") < 0)) __PYX_ERR(0, 2050, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_chars = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setWhitespaceChars", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2050, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.setWhitespaceChars", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_86setWhitespaceChars(__pyx_self, __pyx_v_self, __pyx_v_chars);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_86setWhitespaceChars(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_chars) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setWhitespaceChars", 0);

  /* "cPyparsing.pyx":2054
 *         Overrides the default whitespace chars
 *         """
 *         self.skipWhitespace = True             # <<<<<<<<<<<<<<
 *         self.whiteChars = chars
 *         self.copyDefaultWhiteChars = False
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, Py_True) < 0) __PYX_ERR(0, 2054, __pyx_L1_error)

  /* "cPyparsing.pyx":2055
 *         """
 *         self.skipWhitespace = True
 *         self.whiteChars = chars             # <<<<<<<<<<<<<<
 *         self.copyDefaultWhiteChars = False
 *         return self
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_whiteChars, __pyx_v_chars) < 0) __PYX_ERR(0, 2055, __pyx_L1_error)

  /* "cPyparsing.pyx":2056
 *         self.skipWhitespace = True
 *         self.whiteChars = chars
 *         self.copyDefaultWhiteChars = False             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_copyDefaultWhiteChars, Py_False) < 0) __PYX_ERR(0, 2056, __pyx_L1_error)

  /* "cPyparsing.pyx":2057
 *         self.whiteChars = chars
 *         self.copyDefaultWhiteChars = False
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def parseWithTabs(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2050
 *         return self
 * 
 *     def setWhitespaceChars(self, chars):             # <<<<<<<<<<<<<<
 *         """
 *         Overrides the default whitespace chars
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.setWhitespaceChars", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2059
 *         return self
 * 
 *     def parseWithTabs(self):             # <<<<<<<<<<<<<<
 *         """
 *         Overrides default behavior to expand C{<TAB>}s to spaces before parsing the input string.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_89parseWithTabs(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_88parseWithTabs[] = "\n        Overrides default behavior to expand C{<TAB>}s to spaces before parsing the input string.\n        Must be called before C{parseString} when the input grammar contains elements that\n        match C{<TAB>} characters.\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_89parseWithTabs = {"parseWithTabs", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_89parseWithTabs, METH_O, __pyx_doc_10cPyparsing_13ParserElement_88parseWithTabs};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_89parseWithTabs(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseWithTabs (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_88parseWithTabs(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_88parseWithTabs(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseWithTabs", 0);

  /* "cPyparsing.pyx":2065
 *         match C{<TAB>} characters.
 *         """
 *         self.keepTabs = True             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_keepTabs, Py_True) < 0) __PYX_ERR(0, 2065, __pyx_L1_error)

  /* "cPyparsing.pyx":2066
 *         """
 *         self.keepTabs = True
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def ignore(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2059
 *         return self
 * 
 *     def parseWithTabs(self):             # <<<<<<<<<<<<<<
 *         """
 *         Overrides default behavior to expand C{<TAB>}s to spaces before parsing the input string.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.parseWithTabs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2068
 *         return self
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Define expression to be ignored (e.g., comments) while doing pattern
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_91ignore(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_90ignore[] = "\n        Define expression to be ignored (e.g., comments) while doing pattern\n        matching; may be called repeatedly, to define multiple comment or other\n        ignorable patterns.\n\n        Example::\n            patt = OneOrMore(Word(alphas))\n            patt.parseString('ablaj /* comment */ lskjd') # -> ['ablaj']\n\n            patt.ignore(cStyleComment)\n            patt.parseString('ablaj /* comment */ lskjd') # -> ['ablaj', 'lskjd']\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_91ignore = {"ignore", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_91ignore, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_90ignore};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_91ignore(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ignore (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ignore", 1, 2, 2, 1); __PYX_ERR(0, 2068, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "ignore") < 0)) __PYX_ERR(0, 2068, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("ignore", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2068, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.ignore", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_90ignore(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_90ignore(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("ignore", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":2081
 *             patt.parseString('ablaj /[inserted by cython to avoid comment start]* comment *[inserted by cython to avoid comment closer]/ lskjd') # -> ['ablaj', 'lskjd']
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = Suppress(other)
 * 
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2081, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 2081, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":2082
 *         """
 *         if isinstance(other, basestring):
 *             other = Suppress(other)             # <<<<<<<<<<<<<<
 * 
 *         if isinstance(other, Suppress):
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_Suppress); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2082, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2082, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2082, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2082, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2082, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_INCREF(__pyx_v_other);
        __Pyx_GIVEREF(__pyx_v_other);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_other);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2082, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2081
 *             patt.parseString('ablaj /[inserted by cython to avoid comment start]* comment *[inserted by cython to avoid comment closer]/ lskjd') # -> ['ablaj', 'lskjd']
 *         """
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = Suppress(other)
 * 
 */
  }

  /* "cPyparsing.pyx":2084
 *             other = Suppress(other)
 * 
 *         if isinstance(other, Suppress):             # <<<<<<<<<<<<<<
 *             if other not in self.ignoreExprs:
 *                 self.ignoreExprs.append(other)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Suppress); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_3 == -1)) __PYX_ERR(0, 2084, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":2085
 * 
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:             # <<<<<<<<<<<<<<
 *                 self.ignoreExprs.append(other)
 *         else:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2085, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_other, __pyx_t_1, Py_NE)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2085, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = (__pyx_t_2 != 0);
    if (__pyx_t_3) {

      /* "cPyparsing.pyx":2086
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:
 *                 self.ignoreExprs.append(other)             # <<<<<<<<<<<<<<
 *         else:
 *             self.ignoreExprs.append(Suppress(other.copy()))
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2086, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_v_other); if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 2086, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":2085
 * 
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:             # <<<<<<<<<<<<<<
 *                 self.ignoreExprs.append(other)
 *         else:
 */
    }

    /* "cPyparsing.pyx":2084
 *             other = Suppress(other)
 * 
 *         if isinstance(other, Suppress):             # <<<<<<<<<<<<<<
 *             if other not in self.ignoreExprs:
 *                 self.ignoreExprs.append(other)
 */
    goto __pyx_L4;
  }

  /* "cPyparsing.pyx":2088
 *                 self.ignoreExprs.append(other)
 *         else:
 *             self.ignoreExprs.append(Suppress(other.copy()))             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2088, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_Suppress); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2088, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_copy); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2088, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    if (__pyx_t_9) {
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2088, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else {
      __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2088, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    if (!__pyx_t_8) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2088, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2088, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2088, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2088, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_9, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2088, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_4); if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 2088, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_L4:;

  /* "cPyparsing.pyx":2089
 *         else:
 *             self.ignoreExprs.append(Suppress(other.copy()))
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def setDebugActions(self, startAction, successAction, exceptionAction):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2068
 *         return self
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Define expression to be ignored (e.g., comments) while doing pattern
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.ParserElement.ignore", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2091
 *         return self
 * 
 *     def setDebugActions(self, startAction, successAction, exceptionAction):             # <<<<<<<<<<<<<<
 *         """
 *         Enable display of debugging messages while doing pattern matching.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_93setDebugActions(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_92setDebugActions[] = "\n        Enable display of debugging messages while doing pattern matching.\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_93setDebugActions = {"setDebugActions", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_93setDebugActions, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_92setDebugActions};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_93setDebugActions(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_startAction = 0;
  PyObject *__pyx_v_successAction = 0;
  PyObject *__pyx_v_exceptionAction = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setDebugActions (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_startAction,&__pyx_n_s_successAction,&__pyx_n_s_exceptionAction,0};
    PyObject* values[4] = {0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_startAction)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("setDebugActions", 1, 4, 4, 1); __PYX_ERR(0, 2091, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_successAction)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("setDebugActions", 1, 4, 4, 2); __PYX_ERR(0, 2091, __pyx_L3_error)
        }
        case  3:
        if (likely((values[3] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_exceptionAction)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("setDebugActions", 1, 4, 4, 3); __PYX_ERR(0, 2091, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "setDebugActions") < 0)) __PYX_ERR(0, 2091, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 4) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
    }
    __pyx_v_self = values[0];
    __pyx_v_startAction = values[1];
    __pyx_v_successAction = values[2];
    __pyx_v_exceptionAction = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setDebugActions", 1, 4, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2091, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.setDebugActions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_92setDebugActions(__pyx_self, __pyx_v_self, __pyx_v_startAction, __pyx_v_successAction, __pyx_v_exceptionAction);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_92setDebugActions(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_startAction, PyObject *__pyx_v_successAction, PyObject *__pyx_v_exceptionAction) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("setDebugActions", 0);

  /* "cPyparsing.pyx":2095
 *         Enable display of debugging messages while doing pattern matching.
 *         """
 *         self.debugActions = (startAction or _defaultStartDebugAction,             # <<<<<<<<<<<<<<
 *                              successAction or _defaultSuccessDebugAction,
 *                              exceptionAction or _defaultExceptionDebugAction)
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_startAction); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2095, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __Pyx_INCREF(__pyx_v_startAction);
    __pyx_t_1 = __pyx_v_startAction;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_defaultStartDebugAction); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2095, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_1 = __pyx_t_3;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_L3_bool_binop_done:;

  /* "cPyparsing.pyx":2096
 *         """
 *         self.debugActions = (startAction or _defaultStartDebugAction,
 *                              successAction or _defaultSuccessDebugAction,             # <<<<<<<<<<<<<<
 *                              exceptionAction or _defaultExceptionDebugAction)
 *         self.debug = True
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_successAction); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2096, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __Pyx_INCREF(__pyx_v_successAction);
    __pyx_t_3 = __pyx_v_successAction;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_defaultSuccessDebugAction); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2096, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_3 = __pyx_t_4;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_L5_bool_binop_done:;

  /* "cPyparsing.pyx":2097
 *         self.debugActions = (startAction or _defaultStartDebugAction,
 *                              successAction or _defaultSuccessDebugAction,
 *                              exceptionAction or _defaultExceptionDebugAction)             # <<<<<<<<<<<<<<
 *         self.debug = True
 *         return self
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_exceptionAction); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2097, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __Pyx_INCREF(__pyx_v_exceptionAction);
    __pyx_t_4 = __pyx_v_exceptionAction;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_defaultExceptionDebugAction); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_4 = __pyx_t_5;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_L7_bool_binop_done:;

  /* "cPyparsing.pyx":2095
 *         Enable display of debugging messages while doing pattern matching.
 *         """
 *         self.debugActions = (startAction or _defaultStartDebugAction,             # <<<<<<<<<<<<<<
 *                              successAction or _defaultSuccessDebugAction,
 *                              exceptionAction or _defaultExceptionDebugAction)
 */
  __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2095, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_4);
  __pyx_t_1 = 0;
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_debugActions, __pyx_t_5) < 0) __PYX_ERR(0, 2095, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cPyparsing.pyx":2098
 *                              successAction or _defaultSuccessDebugAction,
 *                              exceptionAction or _defaultExceptionDebugAction)
 *         self.debug = True             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_debug, Py_True) < 0) __PYX_ERR(0, 2098, __pyx_L1_error)

  /* "cPyparsing.pyx":2099
 *                              exceptionAction or _defaultExceptionDebugAction)
 *         self.debug = True
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def setDebug(self, flag=True):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2091
 *         return self
 * 
 *     def setDebugActions(self, startAction, successAction, exceptionAction):             # <<<<<<<<<<<<<<
 *         """
 *         Enable display of debugging messages while doing pattern matching.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ParserElement.setDebugActions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2101
 *         return self
 * 
 *     def setDebug(self, flag=True):             # <<<<<<<<<<<<<<
 *         """
 *         Enable display of debugging messages while doing pattern matching.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_95setDebug(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_94setDebug[] = "\n        Enable display of debugging messages while doing pattern matching.\n        Set C{flag} to True to enable, False to disable.\n\n        Example::\n            wd = Word(alphas).setName(\"alphaword\")\n            integer = Word(nums).setName(\"numword\")\n            term = wd | integer\n\n            # turn on debugging for wd\n            wd.setDebug()\n\n            OneOrMore(term).parseString(\"abc 123 xyz 890\")\n\n        prints::\n            Match alphaword at loc 0(1,1)\n            Matched alphaword -> ['abc']\n            Match alphaword at loc 3(1,4)\n            Exception raised:Expected alphaword (at char 4), (line:1, col:5)\n            Match alphaword at loc 7(1,8)\n            Matched alphaword -> ['xyz']\n            Match alphaword at loc 11(1,12)\n            Exception raised:Expected alphaword (at char 12), (line:1, col:13)\n            Match alphaword at loc 15(1,16)\n            Exception raised:Expected alphaword (at char 15), (line:1, col:16)\n\n        The output shown is that produced by the default debug actions - custom debug actions can be\n        specified using L{setDebugActions}. Prior to attempting\n        to match the C{wd} expression, the debugging message C{\"Match <exprname> at loc <n>(<line>,<col>)\"}\n        is shown. Then if the parse succeeds, a C{\"Matched\"} message is shown, or an C{\"Exception raised\"}\n        message is shown. Also note the use of L{setName} to assign a human-readable name to the expression,\n        which makes debugging and exception messages easier to understand - for instance, the default\n        name created for the C{Word} expression without calling C{setName} is C{\"W:(ABCD...)\"}.\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_95setDebug = {"setDebug", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_95setDebug, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_94setDebug};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_95setDebug(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_flag = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setDebug (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_flag,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_flag);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "setDebug") < 0)) __PYX_ERR(0, 2101, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_flag = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setDebug", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2101, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.setDebug", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_94setDebug(__pyx_self, __pyx_v_self, __pyx_v_flag);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_94setDebug(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_flag) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("setDebug", 0);

  /* "cPyparsing.pyx":2136
 *         name created for the C{Word} expression without calling C{setName} is C{"W:(ABCD...)"}.
 *         """
 *         if flag:             # <<<<<<<<<<<<<<
 *             self.setDebugActions(_defaultStartDebugAction, _defaultSuccessDebugAction, _defaultExceptionDebugAction)
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_flag); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 2136, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":2137
 *         """
 *         if flag:
 *             self.setDebugActions(_defaultStartDebugAction, _defaultSuccessDebugAction, _defaultExceptionDebugAction)             # <<<<<<<<<<<<<<
 *         else:
 *             self.debug = False
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_setDebugActions); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2137, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_defaultStartDebugAction); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2137, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_defaultSuccessDebugAction); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2137, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_defaultExceptionDebugAction); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2137, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_8 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_t_4, __pyx_t_5, __pyx_t_6};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_8, 3+__pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2137, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_t_4, __pyx_t_5, __pyx_t_6};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_8, 3+__pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2137, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(3+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2137, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (__pyx_t_7) {
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_8, __pyx_t_6);
      __pyx_t_4 = 0;
      __pyx_t_5 = 0;
      __pyx_t_6 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_9, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2137, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":2136
 *         name created for the C{Word} expression without calling C{setName} is C{"W:(ABCD...)"}.
 *         """
 *         if flag:             # <<<<<<<<<<<<<<
 *             self.setDebugActions(_defaultStartDebugAction, _defaultSuccessDebugAction, _defaultExceptionDebugAction)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":2139
 *             self.setDebugActions(_defaultStartDebugAction, _defaultSuccessDebugAction, _defaultExceptionDebugAction)
 *         else:
 *             self.debug = False             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_debug, Py_False) < 0) __PYX_ERR(0, 2139, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":2140
 *         else:
 *             self.debug = False
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2101
 *         return self
 * 
 *     def setDebug(self, flag=True):             # <<<<<<<<<<<<<<
 *         """
 *         Enable display of debugging messages while doing pattern matching.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.ParserElement.setDebug", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2142
 *         return self
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return self.name
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_97__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_97__str__ = {"__str__", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_97__str__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_97__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_96__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_96__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "cPyparsing.pyx":2143
 * 
 *     def __str__(self):
 *         return self.name             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2142
 *         return self
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return self.name
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2145
 *         return self.name
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return _ustr(self)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_99__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_99__repr__ = {"__repr__", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_99__repr__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_99__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_98__repr__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_98__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "cPyparsing.pyx":2146
 * 
 *     def __repr__(self):
 *         return _ustr(self)             # <<<<<<<<<<<<<<
 * 
 *     def streamline(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2146, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2146, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2146, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2146, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_self);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2146, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2145
 *         return self.name
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return _ustr(self)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2148
 *         return _ustr(self)
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         self.streamlined = True
 *         self.strRepr = None
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_101streamline(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_101streamline = {"streamline", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_101streamline, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_101streamline(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("streamline (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_100streamline(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_100streamline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("streamline", 0);

  /* "cPyparsing.pyx":2149
 * 
 *     def streamline(self):
 *         self.streamlined = True             # <<<<<<<<<<<<<<
 *         self.strRepr = None
 *         return self
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_streamlined, Py_True) < 0) __PYX_ERR(0, 2149, __pyx_L1_error)

  /* "cPyparsing.pyx":2150
 *     def streamline(self):
 *         self.streamlined = True
 *         self.strRepr = None             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, Py_None) < 0) __PYX_ERR(0, 2150, __pyx_L1_error)

  /* "cPyparsing.pyx":2151
 *         self.streamlined = True
 *         self.strRepr = None
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def checkRecursion(self, parseElementList):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2148
 *         return _ustr(self)
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         self.streamlined = True
 *         self.strRepr = None
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.streamline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2153
 *         return self
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         pass
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_103checkRecursion(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_103checkRecursion = {"checkRecursion", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_103checkRecursion, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_103checkRecursion(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  CYTHON_UNUSED PyObject *__pyx_v_parseElementList = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("checkRecursion (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_parseElementList,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_parseElementList)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("checkRecursion", 1, 2, 2, 1); __PYX_ERR(0, 2153, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "checkRecursion") < 0)) __PYX_ERR(0, 2153, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_parseElementList = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("checkRecursion", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2153, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.checkRecursion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_102checkRecursion(__pyx_self, __pyx_v_self, __pyx_v_parseElementList);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_102checkRecursion(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_parseElementList) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("checkRecursion", 0);

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2156
 *         pass
 * 
 *     def validate(self, validateTrace=[]):             # <<<<<<<<<<<<<<
 *         """
 *         Check defined expressions for valid structure, check for infinite recursive definitions.
 */

static PyObject *__pyx_pf_10cPyparsing_93__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults5, __pyx_self)->__pyx_arg_validateTrace);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults5, __pyx_self)->__pyx_arg_validateTrace);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults5, __pyx_self)->__pyx_arg_validateTrace);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_105validate(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_104validate[] = "\n        Check defined expressions for valid structure, check for infinite recursive definitions.\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_105validate = {"validate", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_105validate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_104validate};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_105validate(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  CYTHON_UNUSED PyObject *__pyx_v_validateTrace = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("validate (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_validateTrace,0};
    PyObject* values[2] = {0,0};
    __pyx_defaults5 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults5, __pyx_self);
    values[1] = __pyx_dynamic_args->__pyx_arg_validateTrace;
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_validateTrace);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "validate") < 0)) __PYX_ERR(0, 2156, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_validateTrace = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("validate", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2156, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.validate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_104validate(__pyx_self, __pyx_v_self, __pyx_v_validateTrace);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_104validate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_validateTrace) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("validate", 0);

  /* "cPyparsing.pyx":2160
 *         Check defined expressions for valid structure, check for infinite recursive definitions.
 *         """
 *         self.checkRecursion([])             # <<<<<<<<<<<<<<
 * 
 *     def parseFile(self, file_or_filename, parseAll=False):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_checkRecursion); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2160, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2160, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2160, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2160, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2160, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2156
 *         pass
 * 
 *     def validate(self, validateTrace=[]):             # <<<<<<<<<<<<<<
 *         """
 *         Check defined expressions for valid structure, check for infinite recursive definitions.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ParserElement.validate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2162
 *         self.checkRecursion([])
 * 
 *     def parseFile(self, file_or_filename, parseAll=False):             # <<<<<<<<<<<<<<
 *         """
 *         Execute the parse expression on the given file or filename.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_107parseFile(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_106parseFile[] = "\n        Execute the parse expression on the given file or filename.\n        If a filename is specified (instead of a file object),\n        the entire file is opened, read, and closed before parsing.\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_107parseFile = {"parseFile", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_107parseFile, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_106parseFile};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_107parseFile(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_file_or_filename = 0;
  PyObject *__pyx_v_parseAll = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseFile (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_file_or_filename,&__pyx_n_s_parseAll,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_False));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_file_or_filename)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseFile", 0, 2, 3, 1); __PYX_ERR(0, 2162, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_parseAll);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseFile") < 0)) __PYX_ERR(0, 2162, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_file_or_filename = values[1];
    __pyx_v_parseAll = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseFile", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2162, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.parseFile", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_106parseFile(__pyx_self, __pyx_v_self, __pyx_v_file_or_filename, __pyx_v_parseAll);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_106parseFile(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_file_or_filename, PyObject *__pyx_v_parseAll) {
  PyObject *__pyx_v_file_contents = NULL;
  PyObject *__pyx_v_f = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_t_17;
  int __pyx_t_18;
  int __pyx_t_19;
  char const *__pyx_t_20;
  PyObject *__pyx_t_21 = NULL;
  __Pyx_RefNannySetupContext("parseFile", 0);

  /* "cPyparsing.pyx":2168
 *         the entire file is opened, read, and closed before parsing.
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             file_contents = file_or_filename.read()
 *         except AttributeError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":2169
 *         """
 *         try:
 *             file_contents = file_or_filename.read()             # <<<<<<<<<<<<<<
 *         except AttributeError:
 *             with open(file_or_filename, "r") as f:
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_file_or_filename, __pyx_n_s_read); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2169, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (__pyx_t_6) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2169, __pyx_L3_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else {
        __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2169, __pyx_L3_error)
      }
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_file_contents = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "cPyparsing.pyx":2168
 *         the entire file is opened, read, and closed before parsing.
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             file_contents = file_or_filename.read()
 *         except AttributeError:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L10_try_end;
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":2170
 *         try:
 *             file_contents = file_or_filename.read()
 *         except AttributeError:             # <<<<<<<<<<<<<<
 *             with open(file_or_filename, "r") as f:
 *                 file_contents = f.read()
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
    if (__pyx_t_7) {
      __Pyx_AddTraceback("cPyparsing.ParserElement.parseFile", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6) < 0) __PYX_ERR(0, 2170, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);

      /* "cPyparsing.pyx":2171
 *             file_contents = file_or_filename.read()
 *         except AttributeError:
 *             with open(file_or_filename, "r") as f:             # <<<<<<<<<<<<<<
 *                 file_contents = f.read()
 *         try:
 */
      /*with:*/ {
        __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2171, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_INCREF(__pyx_v_file_or_filename);
        __Pyx_GIVEREF(__pyx_v_file_or_filename);
        PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_file_or_filename);
        __Pyx_INCREF(__pyx_n_u_r);
        __Pyx_GIVEREF(__pyx_n_u_r);
        PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_n_u_r);
        __pyx_t_9 = __Pyx_PyObject_Call(__pyx_builtin_open, __pyx_t_8, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2171, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_10 = __Pyx_PyObject_LookupSpecial(__pyx_t_9, __pyx_n_s_exit); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2171, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_11 = __Pyx_PyObject_LookupSpecial(__pyx_t_9, __pyx_n_s_enter); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2171, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_12 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
          __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
          if (likely(__pyx_t_12)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
            __Pyx_INCREF(__pyx_t_12);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_11, function);
          }
        }
        if (__pyx_t_12) {
          __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2171, __pyx_L13_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        } else {
          __pyx_t_8 = __Pyx_PyObject_CallNoArg(__pyx_t_11); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2171, __pyx_L13_error)
        }
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_11 = __pyx_t_8;
        __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        /*try:*/ {
          {
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __Pyx_ExceptionSave(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
            __Pyx_XGOTREF(__pyx_t_13);
            __Pyx_XGOTREF(__pyx_t_14);
            __Pyx_XGOTREF(__pyx_t_15);
            /*try:*/ {
              __pyx_v_f = __pyx_t_11;
              __pyx_t_11 = 0;

              /* "cPyparsing.pyx":2172
 *         except AttributeError:
 *             with open(file_or_filename, "r") as f:
 *                 file_contents = f.read()             # <<<<<<<<<<<<<<
 *         try:
 *             return self.parseString(file_contents, parseAll)
 */
              __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_f, __pyx_n_s_read); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2172, __pyx_L19_error)
              __Pyx_GOTREF(__pyx_t_9);
              __pyx_t_8 = NULL;
              if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
                __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
                if (likely(__pyx_t_8)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
                  __Pyx_INCREF(__pyx_t_8);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_9, function);
                }
              }
              if (__pyx_t_8) {
                __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_8); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2172, __pyx_L19_error)
                __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
              } else {
                __pyx_t_11 = __Pyx_PyObject_CallNoArg(__pyx_t_9); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2172, __pyx_L19_error)
              }
              __Pyx_GOTREF(__pyx_t_11);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_XDECREF_SET(__pyx_v_file_contents, __pyx_t_11);
              __pyx_t_11 = 0;

              /* "cPyparsing.pyx":2171
 *             file_contents = file_or_filename.read()
 *         except AttributeError:
 *             with open(file_or_filename, "r") as f:             # <<<<<<<<<<<<<<
 *                 file_contents = f.read()
 *         try:
 */
            }
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            goto __pyx_L26_try_end;
            __pyx_L19_error:;
            __Pyx_PyThreadState_assign
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            /*except:*/ {
              __Pyx_AddTraceback("cPyparsing.ParserElement.parseFile", __pyx_clineno, __pyx_lineno, __pyx_filename);
              if (__Pyx_GetException(&__pyx_t_11, &__pyx_t_9, &__pyx_t_8) < 0) __PYX_ERR(0, 2171, __pyx_L21_except_error)
              __Pyx_GOTREF(__pyx_t_11);
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_GOTREF(__pyx_t_8);
              __pyx_t_12 = PyTuple_Pack(3, __pyx_t_11, __pyx_t_9, __pyx_t_8); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2171, __pyx_L21_except_error)
              __Pyx_GOTREF(__pyx_t_12);
              __pyx_t_16 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_12, NULL);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2171, __pyx_L21_except_error)
              __Pyx_GOTREF(__pyx_t_16);
              __pyx_t_17 = __Pyx_PyObject_IsTrue(__pyx_t_16);
              __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
              if (__pyx_t_17 < 0) __PYX_ERR(0, 2171, __pyx_L21_except_error)
              __pyx_t_18 = ((!(__pyx_t_17 != 0)) != 0);
              if (__pyx_t_18) {
                __Pyx_GIVEREF(__pyx_t_11);
                __Pyx_GIVEREF(__pyx_t_9);
                __Pyx_XGIVEREF(__pyx_t_8);
                __Pyx_ErrRestoreWithState(__pyx_t_11, __pyx_t_9, __pyx_t_8);
                __pyx_t_11 = 0; __pyx_t_9 = 0; __pyx_t_8 = 0; 
                __PYX_ERR(0, 2171, __pyx_L21_except_error)
              }
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
              goto __pyx_L20_exception_handled;
            }
            __pyx_L21_except_error:;
            __Pyx_PyThreadState_assign
            __Pyx_XGIVEREF(__pyx_t_13);
            __Pyx_XGIVEREF(__pyx_t_14);
            __Pyx_XGIVEREF(__pyx_t_15);
            __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
            goto __pyx_L5_except_error;
            __pyx_L20_exception_handled:;
            __Pyx_PyThreadState_assign
            __Pyx_XGIVEREF(__pyx_t_13);
            __Pyx_XGIVEREF(__pyx_t_14);
            __Pyx_XGIVEREF(__pyx_t_15);
            __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
            __pyx_L26_try_end:;
          }
        }
        /*finally:*/ {
          /*normal exit:*/{
            if (__pyx_t_10) {
              __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_tuple__81, NULL);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
              if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2171, __pyx_L5_except_error)
              __Pyx_GOTREF(__pyx_t_15);
              __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
            }
            goto __pyx_L18;
          }
          __pyx_L18:;
        }
        goto __pyx_L30;
        __pyx_L13_error:;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        goto __pyx_L5_except_error;
        __pyx_L30:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cPyparsing.pyx":2168
 *         the entire file is opened, read, and closed before parsing.
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             file_contents = file_or_filename.read()
 *         except AttributeError:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L10_try_end:;
  }

  /* "cPyparsing.pyx":2173
 *             with open(file_or_filename, "r") as f:
 *                 file_contents = f.read()
 *         try:             # <<<<<<<<<<<<<<
 *             return self.parseString(file_contents, parseAll)
 *         except ParseBaseException as exc:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_2, &__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_1);
    /*try:*/ {

      /* "cPyparsing.pyx":2174
 *                 file_contents = f.read()
 *         try:
 *             return self.parseString(file_contents, parseAll)             # <<<<<<<<<<<<<<
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseString); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2174, __pyx_L31_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (unlikely(!__pyx_v_file_contents)) { __Pyx_RaiseUnboundLocalError("file_contents"); __PYX_ERR(0, 2174, __pyx_L31_error) }
      __pyx_t_4 = NULL;
      __pyx_t_7 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_7 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_file_contents, __pyx_v_parseAll};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2174, __pyx_L31_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_file_contents, __pyx_v_parseAll};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2174, __pyx_L31_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2174, __pyx_L31_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_4) {
          __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_4); __pyx_t_4 = NULL;
        }
        __Pyx_INCREF(__pyx_v_file_contents);
        __Pyx_GIVEREF(__pyx_v_file_contents);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_v_file_contents);
        __Pyx_INCREF(__pyx_v_parseAll);
        __Pyx_GIVEREF(__pyx_v_parseAll);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_v_parseAll);
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_8, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2174, __pyx_L31_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_r = __pyx_t_6;
      __pyx_t_6 = 0;
      goto __pyx_L35_try_return;

      /* "cPyparsing.pyx":2173
 *             with open(file_or_filename, "r") as f:
 *                 file_contents = f.read()
 *         try:             # <<<<<<<<<<<<<<
 *             return self.parseString(file_contents, parseAll)
 *         except ParseBaseException as exc:
 */
    }
    __pyx_L31_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":2175
 *         try:
 *             return self.parseString(file_contents, parseAll)
 *         except ParseBaseException as exc:             # <<<<<<<<<<<<<<
 *             if ParserElement.verbose_stacktrace:
 *                 raise
 */
    __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2175, __pyx_L33_except_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (__pyx_t_7) {
      __Pyx_AddTraceback("cPyparsing.ParserElement.parseFile", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_5, &__pyx_t_8) < 0) __PYX_ERR(0, 2175, __pyx_L33_except_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_v_exc = __pyx_t_5;
      /*try:*/ {

        /* "cPyparsing.pyx":2176
 *             return self.parseString(file_contents, parseAll)
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:             # <<<<<<<<<<<<<<
 *                 raise
 *             else:
 */
        __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2176, __pyx_L44_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_verbose_stacktrace); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2176, __pyx_L44_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_18 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_18 < 0)) __PYX_ERR(0, 2176, __pyx_L44_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (__pyx_t_18) {

          /* "cPyparsing.pyx":2177
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:
 *                 raise             # <<<<<<<<<<<<<<
 *             else:
 *                 # catch and re-raise exception from here, clears out pyparsing internal stack trace
 */
          __Pyx_GIVEREF(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_5);
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_ErrRestoreWithState(__pyx_t_6, __pyx_t_5, __pyx_t_8);
          __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_8 = 0; 
          __PYX_ERR(0, 2177, __pyx_L44_error)

          /* "cPyparsing.pyx":2176
 *             return self.parseString(file_contents, parseAll)
 *         except ParseBaseException as exc:
 *             if ParserElement.verbose_stacktrace:             # <<<<<<<<<<<<<<
 *                 raise
 *             else:
 */
        }

        /* "cPyparsing.pyx":2180
 *             else:
 *                 # catch and re-raise exception from here, clears out pyparsing internal stack trace
 *                 raise exc             # <<<<<<<<<<<<<<
 * 
 *     def __eq__(self, other):
 */
        /*else*/ {
          __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
          __PYX_ERR(0, 2180, __pyx_L44_error)
        }
      }

      /* "cPyparsing.pyx":2175
 *         try:
 *             return self.parseString(file_contents, parseAll)
 *         except ParseBaseException as exc:             # <<<<<<<<<<<<<<
 *             if ParserElement.verbose_stacktrace:
 *                 raise
 */
      /*finally:*/ {
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __pyx_L44_error:;
          __pyx_t_10 = 0; __pyx_t_15 = 0; __pyx_t_14 = 0; __pyx_t_13 = 0; __pyx_t_16 = 0; __pyx_t_21 = 0;
          __Pyx_PyThreadState_assign
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_13, &__pyx_t_16, &__pyx_t_21);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_10, &__pyx_t_15, &__pyx_t_14) < 0)) __Pyx_ErrFetch(&__pyx_t_10, &__pyx_t_15, &__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_21);
          __pyx_t_7 = __pyx_lineno; __pyx_t_19 = __pyx_clineno; __pyx_t_20 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
          }
          __Pyx_PyThreadState_assign
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_13);
            __Pyx_XGIVEREF(__pyx_t_16);
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_16, __pyx_t_21);
          }
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_ErrRestore(__pyx_t_10, __pyx_t_15, __pyx_t_14);
          __pyx_t_10 = 0; __pyx_t_15 = 0; __pyx_t_14 = 0; __pyx_t_13 = 0; __pyx_t_16 = 0; __pyx_t_21 = 0;
          __pyx_lineno = __pyx_t_7; __pyx_clineno = __pyx_t_19; __pyx_filename = __pyx_t_20;
          goto __pyx_L33_except_error;
        }
      }
    }
    goto __pyx_L33_except_error;
    __pyx_L33_except_error:;

    /* "cPyparsing.pyx":2173
 *             with open(file_or_filename, "r") as f:
 *                 file_contents = f.read()
 *         try:             # <<<<<<<<<<<<<<
 *             return self.parseString(file_contents, parseAll)
 *         except ParseBaseException as exc:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    goto __pyx_L1_error;
    __pyx_L35_try_return:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":2162
 *         self.checkRecursion([])
 * 
 *     def parseFile(self, file_or_filename, parseAll=False):             # <<<<<<<<<<<<<<
 *         """
 *         Execute the parse expression on the given file or filename.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("cPyparsing.ParserElement.parseFile", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_file_contents);
  __Pyx_XDECREF(__pyx_v_f);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2182
 *                 raise exc
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, ParserElement):
 *             return self is other or vars(self) == vars(other)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_109__eq__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_109__eq__ = {"__eq__", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_109__eq__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_109__eq__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__eq__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__eq__", 1, 2, 2, 1); __PYX_ERR(0, 2182, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__eq__") < 0)) __PYX_ERR(0, 2182, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__eq__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2182, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_108__eq__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_108__eq__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("__eq__", 0);

  /* "cPyparsing.pyx":2183
 * 
 *     def __eq__(self, other):
 *         if isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             return self is other or vars(self) == vars(other)
 *         elif isinstance(other, basestring):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 2183, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":2184
 *     def __eq__(self, other):
 *         if isinstance(other, ParserElement):
 *             return self is other or vars(self) == vars(other)             # <<<<<<<<<<<<<<
 *         elif isinstance(other, basestring):
 *             return self.matches(other)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = (__pyx_v_self == __pyx_v_other);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2184, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2184, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_self);
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_vars, __pyx_t_4, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2184, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2184, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_other);
    __Pyx_GIVEREF(__pyx_v_other);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_other);
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_vars, __pyx_t_4, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2184, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_5, __pyx_t_6, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2184, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_1 = __pyx_t_4;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_L4_bool_binop_done:;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":2183
 * 
 *     def __eq__(self, other):
 *         if isinstance(other, ParserElement):             # <<<<<<<<<<<<<<
 *             return self is other or vars(self) == vars(other)
 *         elif isinstance(other, basestring):
 */
  }

  /* "cPyparsing.pyx":2185
 *         if isinstance(other, ParserElement):
 *             return self is other or vars(self) == vars(other)
 *         elif isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             return self.matches(other)
 *         else:
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_3 == -1)) __PYX_ERR(0, 2185, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":2186
 *             return self is other or vars(self) == vars(other)
 *         elif isinstance(other, basestring):
 *             return self.matches(other)             # <<<<<<<<<<<<<<
 *         else:
 *             return super(ParserElement, self) == other
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matches); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2186, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2186, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2186, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2186, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2186, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_v_other);
        __Pyx_GIVEREF(__pyx_v_other);
        PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_other);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2186, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":2185
 *         if isinstance(other, ParserElement):
 *             return self is other or vars(self) == vars(other)
 *         elif isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             return self.matches(other)
 *         else:
 */
  }

  /* "cPyparsing.pyx":2188
 *             return self.matches(other)
 *         else:
 *             return super(ParserElement, self) == other             # <<<<<<<<<<<<<<
 * 
 *     def __ne__(self, other):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2188, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2188, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_self);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2188, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_1, __pyx_v_other, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2188, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":2182
 *                 raise exc
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, ParserElement):
 *             return self is other or vars(self) == vars(other)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2190
 *             return super(ParserElement, self) == other
 * 
 *     def __ne__(self, other):             # <<<<<<<<<<<<<<
 *         return not (self == other)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_111__ne__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_111__ne__ = {"__ne__", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_111__ne__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_111__ne__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__ne__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__ne__", 1, 2, 2, 1); __PYX_ERR(0, 2190, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__ne__") < 0)) __PYX_ERR(0, 2190, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__ne__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2190, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.__ne__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_110__ne__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_110__ne__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("__ne__", 0);

  /* "cPyparsing.pyx":2191
 * 
 *     def __ne__(self, other):
 *         return not (self == other)             # <<<<<<<<<<<<<<
 * 
 *     def __hash__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_self, __pyx_v_other, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2191, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2191, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyBool_FromLong((!__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2190
 *             return super(ParserElement, self) == other
 * 
 *     def __ne__(self, other):             # <<<<<<<<<<<<<<
 *         return not (self == other)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__ne__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2193
 *         return not (self == other)
 * 
 *     def __hash__(self):             # <<<<<<<<<<<<<<
 *         return hash(id(self))
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_113__hash__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_113__hash__ = {"__hash__", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_113__hash__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_113__hash__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__hash__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_112__hash__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_112__hash__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_hash_t __pyx_t_3;
  __Pyx_RefNannySetupContext("__hash__", 0);

  /* "cPyparsing.pyx":2194
 * 
 *     def __hash__(self):
 *         return hash(id(self))             # <<<<<<<<<<<<<<
 * 
 *     def __req__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_id, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = PyObject_Hash(__pyx_t_2); if (unlikely(__pyx_t_3 == -1)) __PYX_ERR(0, 2194, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_FromHash_t(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2193
 *         return not (self == other)
 * 
 *     def __hash__(self):             # <<<<<<<<<<<<<<
 *         return hash(id(self))
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__hash__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2196
 *         return hash(id(self))
 * 
 *     def __req__(self, other):             # <<<<<<<<<<<<<<
 *         return self == other
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_115__req__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_115__req__ = {"__req__", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_115__req__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_115__req__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__req__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__req__", 1, 2, 2, 1); __PYX_ERR(0, 2196, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__req__") < 0)) __PYX_ERR(0, 2196, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__req__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2196, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.__req__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_114__req__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_114__req__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__req__", 0);

  /* "cPyparsing.pyx":2197
 * 
 *     def __req__(self, other):
 *         return self == other             # <<<<<<<<<<<<<<
 * 
 *     def __rne__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_self, __pyx_v_other, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2197, __pyx_L1_error)
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2196
 *         return hash(id(self))
 * 
 *     def __req__(self, other):             # <<<<<<<<<<<<<<
 *         return self == other
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__req__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2199
 *         return self == other
 * 
 *     def __rne__(self, other):             # <<<<<<<<<<<<<<
 *         return not (self == other)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_117__rne__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_117__rne__ = {"__rne__", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_117__rne__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_117__rne__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__rne__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__rne__", 1, 2, 2, 1); __PYX_ERR(0, 2199, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__rne__") < 0)) __PYX_ERR(0, 2199, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__rne__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2199, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.__rne__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_116__rne__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_116__rne__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("__rne__", 0);

  /* "cPyparsing.pyx":2200
 * 
 *     def __rne__(self, other):
 *         return not (self == other)             # <<<<<<<<<<<<<<
 * 
 *     def matches(self, testString, parseAll=True):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_self, __pyx_v_other, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2200, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2200, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyBool_FromLong((!__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2199
 *         return self == other
 * 
 *     def __rne__(self, other):             # <<<<<<<<<<<<<<
 *         return not (self == other)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParserElement.__rne__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2202
 *         return not (self == other)
 * 
 *     def matches(self, testString, parseAll=True):             # <<<<<<<<<<<<<<
 *         """
 *         Method for quick testing of a parser against a test string. Good for simple
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_119matches(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_118matches[] = "\n        Method for quick testing of a parser against a test string. Good for simple\n        inline microtests of sub expressions while building up larger parser.\n\n        Parameters:\n         - testString - to test against this expression for a match\n         - parseAll - (default=C{True}) - flag to pass to C{L{parseString}} when running tests\n\n        Example::\n            expr = Word(nums)\n            assert expr.matches(\"100\")\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_119matches = {"matches", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_119matches, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_118matches};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_119matches(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_testString = 0;
  PyObject *__pyx_v_parseAll = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("matches (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_testString,&__pyx_n_s_parseAll,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_testString)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("matches", 0, 2, 3, 1); __PYX_ERR(0, 2202, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_parseAll);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "matches") < 0)) __PYX_ERR(0, 2202, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_testString = values[1];
    __pyx_v_parseAll = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("matches", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2202, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.matches", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_118matches(__pyx_self, __pyx_v_self, __pyx_v_testString, __pyx_v_parseAll);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_118matches(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_testString, PyObject *__pyx_v_parseAll) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("matches", 0);

  /* "cPyparsing.pyx":2215
 *             assert expr.matches("100")
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             self.parseString(_ustr(testString), parseAll=parseAll)
 *             return True
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":2216
 *         """
 *         try:
 *             self.parseString(_ustr(testString), parseAll=parseAll)             # <<<<<<<<<<<<<<
 *             return True
 *         except ParseBaseException:
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseString); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2216, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2216, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      if (!__pyx_t_7) {
        __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_testString); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2216, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_testString};
          __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2216, __pyx_L3_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_5);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_testString};
          __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2216, __pyx_L3_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_5);
        } else
        #endif
        {
          __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2216, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_7); __pyx_t_7 = NULL;
          __Pyx_INCREF(__pyx_v_testString);
          __Pyx_GIVEREF(__pyx_v_testString);
          PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_v_testString);
          __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_8, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2216, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2216, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5);
      __pyx_t_5 = 0;
      __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2216, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_parseAll, __pyx_v_parseAll) < 0) __PYX_ERR(0, 2216, __pyx_L3_error)
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2216, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "cPyparsing.pyx":2217
 *         try:
 *             self.parseString(_ustr(testString), parseAll=parseAll)
 *             return True             # <<<<<<<<<<<<<<
 *         except ParseBaseException:
 *             return False
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":2215
 *             assert expr.matches("100")
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             self.parseString(_ustr(testString), parseAll=parseAll)
 *             return True
 */
    }
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":2218
 *             self.parseString(_ustr(testString), parseAll=parseAll)
 *             return True
 *         except ParseBaseException:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
    __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2218, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (__pyx_t_9) {
      __Pyx_AddTraceback("cPyparsing.ParserElement.matches", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_8, &__pyx_t_5, &__pyx_t_6) < 0) __PYX_ERR(0, 2218, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);

      /* "cPyparsing.pyx":2219
 *             return True
 *         except ParseBaseException:
 *             return False             # <<<<<<<<<<<<<<
 * 
 *     def runTests(self, tests, parseAll=True, comment='#', fullDump=True, printResults=True, failureTests=False):
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cPyparsing.pyx":2215
 *             assert expr.matches("100")
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             self.parseString(_ustr(testString), parseAll=parseAll)
 *             return True
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":2202
 *         return not (self == other)
 * 
 *     def matches(self, testString, parseAll=True):             # <<<<<<<<<<<<<<
 *         """
 *         Method for quick testing of a parser against a test string. Good for simple
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing.ParserElement.matches", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2221
 *             return False
 * 
 *     def runTests(self, tests, parseAll=True, comment='#', fullDump=True, printResults=True, failureTests=False):             # <<<<<<<<<<<<<<
 *         """
 *         Execute the parse expression on a series of test strings, showing each
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_121runTests(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_13ParserElement_120runTests[] = "\n        Execute the parse expression on a series of test strings, showing each\n        test, the parsed results or where the parse failed. Quick and easy way to\n        run a parse expression against a list of sample strings.\n\n        Parameters:\n         - tests - a list of separate test strings, or a multiline string of test strings\n         - parseAll - (default=C{True}) - flag to pass to C{L{parseString}} when running tests\n         - comment - (default=C{'#'}) - expression for indicating embedded comments in the test\n              string; pass None to disable comment filtering\n         - fullDump - (default=C{True}) - dump results as list followed by results names in nested outline;\n              if False, only dump nested list\n         - printResults - (default=C{True}) prints test output to stdout\n         - failureTests - (default=C{False}) indicates if these tests are expected to fail parsing\n\n        Returns: a (success, results) tuple, where success indicates that all tests succeeded\n        (or failed if C{failureTests} is True), and the results contain a list of lines of each\n        test's output\n\n        Example::\n            number_expr = pyparsing_common.number.copy()\n\n            result = number_expr.runTests('''\n                # unsigned integer\n                100\n                # negative integer\n                -100\n                # float with scientific notation\n                6.02e23\n                # integer with scientific notation\n                1e-12\n                ''')\n            print(\"Success\" if result[0] else \"Failed!\")\n\n            result = number_expr.runTests('''\n                # stray character\n                100Z\n                # missing leading digit before '.'\n                -.100\n                # too many '.'\n                3.14.159\n                ''', failureTests=True)\n            print(\"Success\" if result[0] else \"Failed!\")\n        prints::\n            # un""signed integer\n            100\n            [100]\n\n            # negative integer\n            -100\n            [-100]\n\n            # float with scientific notation\n            6.02e23\n            [6.02e+23]\n\n            # integer with scientific notation\n            1e-12\n            [1e-12]\n\n            Success\n\n            # stray character\n            100Z\n               ^\n            FAIL: Expected end of text (at char 3), (line:1, col:4)\n\n            # missing leading digit before '.'\n            -.100\n            ^\n            FAIL: Expected {real number with scientific notation | real number | signed integer} (at char 0), (line:1, col:1)\n\n            # too many '.'\n            3.14.159\n                ^\n            FAIL: Expected end of text (at char 4), (line:1, col:5)\n\n            Success\n\n        Each test string must be on a single line. If you want to test a string that spans multiple\n        lines, create a test like this::\n\n            expr.runTest(r\"this is a test\\n of strings that spans \\n 3 lines\")\n\n        (Note that this is a raw string literal, you must include the leading 'r'.)\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_13ParserElement_121runTests = {"runTests", (PyCFunction)__pyx_pw_10cPyparsing_13ParserElement_121runTests, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_13ParserElement_120runTests};
static PyObject *__pyx_pw_10cPyparsing_13ParserElement_121runTests(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_tests = 0;
  PyObject *__pyx_v_parseAll = 0;
  PyObject *__pyx_v_comment = 0;
  PyObject *__pyx_v_fullDump = 0;
  PyObject *__pyx_v_printResults = 0;
  PyObject *__pyx_v_failureTests = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("runTests (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_tests,&__pyx_n_s_parseAll,&__pyx_n_s_comment,&__pyx_n_s_fullDump,&__pyx_n_s_printResults,&__pyx_n_s_failureTests,0};
    PyObject* values[7] = {0,0,0,0,0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_True));
    values[3] = ((PyObject *)((PyObject*)__pyx_kp_u__82));
    values[4] = ((PyObject *)((PyObject *)Py_True));
    values[5] = ((PyObject *)((PyObject *)Py_True));
    values[6] = ((PyObject *)((PyObject *)Py_False));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_tests)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("runTests", 0, 2, 7, 1); __PYX_ERR(0, 2221, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_parseAll);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_comment);
          if (value) { values[3] = value; kw_args--; }
        }
        case  4:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_fullDump);
          if (value) { values[4] = value; kw_args--; }
        }
        case  5:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_printResults);
          if (value) { values[5] = value; kw_args--; }
        }
        case  6:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_failureTests);
          if (value) { values[6] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "runTests") < 0)) __PYX_ERR(0, 2221, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_tests = values[1];
    __pyx_v_parseAll = values[2];
    __pyx_v_comment = values[3];
    __pyx_v_fullDump = values[4];
    __pyx_v_printResults = values[5];
    __pyx_v_failureTests = values[6];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("runTests", 0, 2, 7, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2221, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParserElement.runTests", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13ParserElement_120runTests(__pyx_self, __pyx_v_self, __pyx_v_tests, __pyx_v_parseAll, __pyx_v_comment, __pyx_v_fullDump, __pyx_v_printResults, __pyx_v_failureTests);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13ParserElement_120runTests(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_tests, PyObject *__pyx_v_parseAll, PyObject *__pyx_v_comment, PyObject *__pyx_v_fullDump, PyObject *__pyx_v_printResults, PyObject *__pyx_v_failureTests) {
  PyObject *__pyx_v_allResults = NULL;
  PyObject *__pyx_v_comments = NULL;
  PyObject *__pyx_v_success = NULL;
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_v_out = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_pe = NULL;
  PyObject *__pyx_v_fatal = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  int __pyx_t_20;
  char const *__pyx_t_21;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  PyObject *__pyx_t_27 = NULL;
  char const *__pyx_t_28;
  __Pyx_RefNannySetupContext("runTests", 0);
  __Pyx_INCREF(__pyx_v_tests);
  __Pyx_INCREF(__pyx_v_comment);

  /* "cPyparsing.pyx":2308
 *         (Note that this is a raw string literal, you must include the leading 'r'.)
 *         """
 *         if isinstance(tests, basestring):             # <<<<<<<<<<<<<<
 *             tests = list(map(str.strip, tests.rstrip().splitlines()))
 *         if isinstance(comment, basestring):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_tests, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 2308, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":2309
 *         """
 *         if isinstance(tests, basestring):
 *             tests = list(map(str.strip, tests.rstrip().splitlines()))             # <<<<<<<<<<<<<<
 *         if isinstance(comment, basestring):
 *             comment = Literal(comment)
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_str); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2309, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_strip); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2309, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_tests, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2309, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    if (__pyx_t_7) {
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2309, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else {
      __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2309, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_splitlines); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2309, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    if (__pyx_t_5) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2309, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2309, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2309, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_1);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_map, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2309, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PySequence_List(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2309, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_tests, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "cPyparsing.pyx":2308
 *         (Note that this is a raw string literal, you must include the leading 'r'.)
 *         """
 *         if isinstance(tests, basestring):             # <<<<<<<<<<<<<<
 *             tests = list(map(str.strip, tests.rstrip().splitlines()))
 *         if isinstance(comment, basestring):
 */
  }

  /* "cPyparsing.pyx":2310
 *         if isinstance(tests, basestring):
 *             tests = list(map(str.strip, tests.rstrip().splitlines()))
 *         if isinstance(comment, basestring):             # <<<<<<<<<<<<<<
 *             comment = Literal(comment)
 *         allResults = []
 */
  __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_3 = PyObject_IsInstance(__pyx_v_comment, __pyx_t_6); if (unlikely(__pyx_t_3 == -1)) __PYX_ERR(0, 2310, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":2311
 *             tests = list(map(str.strip, tests.rstrip().splitlines()))
 *         if isinstance(comment, basestring):
 *             comment = Literal(comment)             # <<<<<<<<<<<<<<
 *         allResults = []
 *         comments = []
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Literal); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2311, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_comment); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2311, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_comment};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2311, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_comment};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2311, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else
      #endif
      {
        __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2311, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_comment);
        __Pyx_GIVEREF(__pyx_v_comment);
        PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_comment);
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2311, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_comment, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "cPyparsing.pyx":2310
 *         if isinstance(tests, basestring):
 *             tests = list(map(str.strip, tests.rstrip().splitlines()))
 *         if isinstance(comment, basestring):             # <<<<<<<<<<<<<<
 *             comment = Literal(comment)
 *         allResults = []
 */
  }

  /* "cPyparsing.pyx":2312
 *         if isinstance(comment, basestring):
 *             comment = Literal(comment)
 *         allResults = []             # <<<<<<<<<<<<<<
 *         comments = []
 *         success = True
 */
  __pyx_t_6 = PyList_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_v_allResults = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "cPyparsing.pyx":2313
 *             comment = Literal(comment)
 *         allResults = []
 *         comments = []             # <<<<<<<<<<<<<<
 *         success = True
 *         for t in tests:
 */
  __pyx_t_6 = PyList_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_v_comments = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "cPyparsing.pyx":2314
 *         allResults = []
 *         comments = []
 *         success = True             # <<<<<<<<<<<<<<
 *         for t in tests:
 *             if comment is not None and comment.matches(t, False) or comments and not t:
 */
  __Pyx_INCREF(Py_True);
  __pyx_v_success = Py_True;

  /* "cPyparsing.pyx":2315
 *         comments = []
 *         success = True
 *         for t in tests:             # <<<<<<<<<<<<<<
 *             if comment is not None and comment.matches(t, False) or comments and not t:
 *                 comments.append(t)
 */
  if (likely(PyList_CheckExact(__pyx_v_tests)) || PyTuple_CheckExact(__pyx_v_tests)) {
    __pyx_t_6 = __pyx_v_tests; __Pyx_INCREF(__pyx_t_6); __pyx_t_8 = 0;
    __pyx_t_9 = NULL;
  } else {
    __pyx_t_8 = -1; __pyx_t_6 = PyObject_GetIter(__pyx_v_tests); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2315, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_9 = Py_TYPE(__pyx_t_6)->tp_iternext; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2315, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_9)) {
      if (likely(PyList_CheckExact(__pyx_t_6))) {
        if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_6)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_8); __Pyx_INCREF(__pyx_t_1); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 2315, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_6, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2315, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_8 >= PyTuple_GET_SIZE(__pyx_t_6)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_6, __pyx_t_8); __Pyx_INCREF(__pyx_t_1); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 2315, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_6, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2315, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_9(__pyx_t_6);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 2315, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_t, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2316
 *         success = True
 *         for t in tests:
 *             if comment is not None and comment.matches(t, False) or comments and not t:             # <<<<<<<<<<<<<<
 *                 comments.append(t)
 *                 continue
 */
    __pyx_t_3 = (__pyx_v_comment != Py_None);
    __pyx_t_10 = (__pyx_t_3 != 0);
    if (!__pyx_t_10) {
      goto __pyx_L9_next_or;
    } else {
    }
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_comment, __pyx_n_s_matches); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2316, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = NULL;
    __pyx_t_11 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_11 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_t, Py_False};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2316, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_t, Py_False};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2316, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2316, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__pyx_t_4) {
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_4); __pyx_t_4 = NULL;
      }
      __Pyx_INCREF(__pyx_v_t);
      __Pyx_GIVEREF(__pyx_v_t);
      PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_11, __pyx_v_t);
      __Pyx_INCREF(Py_False);
      __Pyx_GIVEREF(Py_False);
      PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_11, Py_False);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2316, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(0, 2316, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (!__pyx_t_10) {
    } else {
      __pyx_t_2 = __pyx_t_10;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_L9_next_or:;
    __pyx_t_10 = (__pyx_v_comments != Py_None) && (PyList_GET_SIZE(__pyx_v_comments) != 0);
    if (__pyx_t_10) {
    } else {
      __pyx_t_2 = __pyx_t_10;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_v_t); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(0, 2316, __pyx_L1_error)
    __pyx_t_3 = ((!__pyx_t_10) != 0);
    __pyx_t_2 = __pyx_t_3;
    __pyx_L8_bool_binop_done:;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":2317
 *         for t in tests:
 *             if comment is not None and comment.matches(t, False) or comments and not t:
 *                 comments.append(t)             # <<<<<<<<<<<<<<
 *                 continue
 *             if not t:
 */
      __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_comments, __pyx_v_t); if (unlikely(__pyx_t_12 == -1)) __PYX_ERR(0, 2317, __pyx_L1_error)

      /* "cPyparsing.pyx":2318
 *             if comment is not None and comment.matches(t, False) or comments and not t:
 *                 comments.append(t)
 *                 continue             # <<<<<<<<<<<<<<
 *             if not t:
 *                 continue
 */
      goto __pyx_L5_continue;

      /* "cPyparsing.pyx":2316
 *         success = True
 *         for t in tests:
 *             if comment is not None and comment.matches(t, False) or comments and not t:             # <<<<<<<<<<<<<<
 *                 comments.append(t)
 *                 continue
 */
    }

    /* "cPyparsing.pyx":2319
 *                 comments.append(t)
 *                 continue
 *             if not t:             # <<<<<<<<<<<<<<
 *                 continue
 *             out = ['\n'.join(comments), t]
 */
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_t); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2319, __pyx_L1_error)
    __pyx_t_3 = ((!__pyx_t_2) != 0);
    if (__pyx_t_3) {

      /* "cPyparsing.pyx":2320
 *                 continue
 *             if not t:
 *                 continue             # <<<<<<<<<<<<<<
 *             out = ['\n'.join(comments), t]
 *             comments = []
 */
      goto __pyx_L5_continue;

      /* "cPyparsing.pyx":2319
 *                 comments.append(t)
 *                 continue
 *             if not t:             # <<<<<<<<<<<<<<
 *                 continue
 *             out = ['\n'.join(comments), t]
 */
    }

    /* "cPyparsing.pyx":2321
 *             if not t:
 *                 continue
 *             out = ['\n'.join(comments), t]             # <<<<<<<<<<<<<<
 *             comments = []
 *             try:
 */
    __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__21, __pyx_v_comments); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2321, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyList_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2321, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_1);
    PyList_SET_ITEM(__pyx_t_5, 0, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_t);
    __Pyx_GIVEREF(__pyx_v_t);
    PyList_SET_ITEM(__pyx_t_5, 1, __pyx_v_t);
    __pyx_t_1 = 0;
    __Pyx_XDECREF_SET(__pyx_v_out, ((PyObject*)__pyx_t_5));
    __pyx_t_5 = 0;

    /* "cPyparsing.pyx":2322
 *                 continue
 *             out = ['\n'.join(comments), t]
 *             comments = []             # <<<<<<<<<<<<<<
 *             try:
 *                 t = t.replace(r'\n', '\n')
 */
    __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2322, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF_SET(__pyx_v_comments, ((PyObject*)__pyx_t_5));
    __pyx_t_5 = 0;

    /* "cPyparsing.pyx":2323
 *             out = ['\n'.join(comments), t]
 *             comments = []
 *             try:             # <<<<<<<<<<<<<<
 *                 t = t.replace(r'\n', '\n')
 *                 result = self.parseString(t, parseAll=parseAll)
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_15);
      /*try:*/ {

        /* "cPyparsing.pyx":2324
 *             comments = []
 *             try:
 *                 t = t.replace(r'\n', '\n')             # <<<<<<<<<<<<<<
 *                 result = self.parseString(t, parseAll=parseAll)
 *                 out.append(result.dump(full=fullDump))
 */
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_replace); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2324, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__83, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2324, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF_SET(__pyx_v_t, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "cPyparsing.pyx":2325
 *             try:
 *                 t = t.replace(r'\n', '\n')
 *                 result = self.parseString(t, parseAll=parseAll)             # <<<<<<<<<<<<<<
 *                 out.append(result.dump(full=fullDump))
 *                 success = success and not failureTests
 */
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parseString); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2325, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2325, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_v_t);
        __Pyx_GIVEREF(__pyx_v_t);
        PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_t);
        __pyx_t_7 = PyDict_New(); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2325, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_parseAll, __pyx_v_parseAll) < 0) __PYX_ERR(0, 2325, __pyx_L13_error)
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2325, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF_SET(__pyx_v_result, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "cPyparsing.pyx":2326
 *                 t = t.replace(r'\n', '\n')
 *                 result = self.parseString(t, parseAll=parseAll)
 *                 out.append(result.dump(full=fullDump))             # <<<<<<<<<<<<<<
 *                 success = success and not failureTests
 *             except ParseBaseException as pe:
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_dump); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2326, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_7 = PyDict_New(); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2326, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_full, __pyx_v_fullDump) < 0) __PYX_ERR(0, 2326, __pyx_L13_error)
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2326, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_5); if (unlikely(__pyx_t_12 == -1)) __PYX_ERR(0, 2326, __pyx_L13_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "cPyparsing.pyx":2327
 *                 result = self.parseString(t, parseAll=parseAll)
 *                 out.append(result.dump(full=fullDump))
 *                 success = success and not failureTests             # <<<<<<<<<<<<<<
 *             except ParseBaseException as pe:
 *                 fatal = "(FATAL)" if isinstance(pe, ParseFatalException) else ""
 */
        __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_success); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 2327, __pyx_L13_error)
        if (__pyx_t_3) {
        } else {
          __Pyx_INCREF(__pyx_v_success);
          __pyx_t_5 = __pyx_v_success;
          goto __pyx_L21_bool_binop_done;
        }
        __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_failureTests); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 2327, __pyx_L13_error)
        __pyx_t_2 = (!__pyx_t_3);
        __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2327, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_5 = __pyx_t_7;
        __pyx_t_7 = 0;
        __pyx_L21_bool_binop_done:;
        __Pyx_DECREF_SET(__pyx_v_success, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "cPyparsing.pyx":2323
 *             out = ['\n'.join(comments), t]
 *             comments = []
 *             try:             # <<<<<<<<<<<<<<
 *                 t = t.replace(r'\n', '\n')
 *                 result = self.parseString(t, parseAll=parseAll)
 */
      }
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
      goto __pyx_L20_try_end;
      __pyx_L13_error:;
      __Pyx_PyThreadState_assign
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "cPyparsing.pyx":2328
 *                 out.append(result.dump(full=fullDump))
 *                 success = success and not failureTests
 *             except ParseBaseException as pe:             # <<<<<<<<<<<<<<
 *                 fatal = "(FATAL)" if isinstance(pe, ParseFatalException) else ""
 *                 if '\n' in t:
 */
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2328, __pyx_L15_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_11 = __Pyx_PyErr_ExceptionMatches(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_11) {
        __Pyx_AddTraceback("cPyparsing.ParserElement.runTests", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_7, &__pyx_t_4) < 0) __PYX_ERR(0, 2328, __pyx_L15_except_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_7);
        __pyx_v_pe = __pyx_t_7;
        /*try:*/ {

          /* "cPyparsing.pyx":2329
 *                 success = success and not failureTests
 *             except ParseBaseException as pe:
 *                 fatal = "(FATAL)" if isinstance(pe, ParseFatalException) else ""             # <<<<<<<<<<<<<<
 *                 if '\n' in t:
 *                     out.append(line(pe.loc, t))
 */
          __pyx_t_16 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseFatalException); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2329, __pyx_L28_error)
          __Pyx_GOTREF(__pyx_t_16);
          __pyx_t_2 = PyObject_IsInstance(__pyx_v_pe, __pyx_t_16); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 2329, __pyx_L28_error)
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          if ((__pyx_t_2 != 0)) {
            __Pyx_INCREF(__pyx_kp_u_FATAL);
            __pyx_t_1 = __pyx_kp_u_FATAL;
          } else {
            __Pyx_INCREF(__pyx_kp_u__9);
            __pyx_t_1 = __pyx_kp_u__9;
          }
          __Pyx_XDECREF_SET(__pyx_v_fatal, ((PyObject*)__pyx_t_1));
          __pyx_t_1 = 0;

          /* "cPyparsing.pyx":2330
 *             except ParseBaseException as pe:
 *                 fatal = "(FATAL)" if isinstance(pe, ParseFatalException) else ""
 *                 if '\n' in t:             # <<<<<<<<<<<<<<
 *                     out.append(line(pe.loc, t))
 *                     out.append(' ' * (col(pe.loc, t) - 1) + '^' + fatal)
 */
          __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u__21, __pyx_v_t, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2330, __pyx_L28_error)
          __pyx_t_3 = (__pyx_t_2 != 0);
          if (__pyx_t_3) {

            /* "cPyparsing.pyx":2331
 *                 fatal = "(FATAL)" if isinstance(pe, ParseFatalException) else ""
 *                 if '\n' in t:
 *                     out.append(line(pe.loc, t))             # <<<<<<<<<<<<<<
 *                     out.append(' ' * (col(pe.loc, t) - 1) + '^' + fatal)
 *                 else:
 */
            __pyx_t_16 = __Pyx_GetModuleGlobalName(__pyx_n_s_line); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2331, __pyx_L28_error)
            __Pyx_GOTREF(__pyx_t_16);
            __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_v_pe, __pyx_n_s_loc); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 2331, __pyx_L28_error)
            __Pyx_GOTREF(__pyx_t_17);
            __pyx_t_18 = NULL;
            __pyx_t_11 = 0;
            if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_16))) {
              __pyx_t_18 = PyMethod_GET_SELF(__pyx_t_16);
              if (likely(__pyx_t_18)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
                __Pyx_INCREF(__pyx_t_18);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_16, function);
                __pyx_t_11 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_16)) {
              PyObject *__pyx_temp[3] = {__pyx_t_18, __pyx_t_17, __pyx_v_t};
              __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_16, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2331, __pyx_L28_error)
              __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_16)) {
              PyObject *__pyx_temp[3] = {__pyx_t_18, __pyx_t_17, __pyx_v_t};
              __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_16, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2331, __pyx_L28_error)
              __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
            } else
            #endif
            {
              __pyx_t_19 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2331, __pyx_L28_error)
              __Pyx_GOTREF(__pyx_t_19);
              if (__pyx_t_18) {
                __Pyx_GIVEREF(__pyx_t_18); PyTuple_SET_ITEM(__pyx_t_19, 0, __pyx_t_18); __pyx_t_18 = NULL;
              }
              __Pyx_GIVEREF(__pyx_t_17);
              PyTuple_SET_ITEM(__pyx_t_19, 0+__pyx_t_11, __pyx_t_17);
              __Pyx_INCREF(__pyx_v_t);
              __Pyx_GIVEREF(__pyx_v_t);
              PyTuple_SET_ITEM(__pyx_t_19, 1+__pyx_t_11, __pyx_v_t);
              __pyx_t_17 = 0;
              __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_16, __pyx_t_19, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2331, __pyx_L28_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
            }
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_1); if (unlikely(__pyx_t_12 == -1)) __PYX_ERR(0, 2331, __pyx_L28_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

            /* "cPyparsing.pyx":2332
 *                 if '\n' in t:
 *                     out.append(line(pe.loc, t))
 *                     out.append(' ' * (col(pe.loc, t) - 1) + '^' + fatal)             # <<<<<<<<<<<<<<
 *                 else:
 *                     out.append(' ' * pe.loc + '^' + fatal)
 */
            __pyx_t_16 = __Pyx_GetModuleGlobalName(__pyx_n_s_col); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2332, __pyx_L28_error)
            __Pyx_GOTREF(__pyx_t_16);
            __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_v_pe, __pyx_n_s_loc); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2332, __pyx_L28_error)
            __Pyx_GOTREF(__pyx_t_19);
            __pyx_t_17 = NULL;
            __pyx_t_11 = 0;
            if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_16))) {
              __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_16);
              if (likely(__pyx_t_17)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
                __Pyx_INCREF(__pyx_t_17);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_16, function);
                __pyx_t_11 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_16)) {
              PyObject *__pyx_temp[3] = {__pyx_t_17, __pyx_t_19, __pyx_v_t};
              __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_16, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2332, __pyx_L28_error)
              __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_16)) {
              PyObject *__pyx_temp[3] = {__pyx_t_17, __pyx_t_19, __pyx_v_t};
              __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_16, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2332, __pyx_L28_error)
              __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
            } else
            #endif
            {
              __pyx_t_18 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 2332, __pyx_L28_error)
              __Pyx_GOTREF(__pyx_t_18);
              if (__pyx_t_17) {
                __Pyx_GIVEREF(__pyx_t_17); PyTuple_SET_ITEM(__pyx_t_18, 0, __pyx_t_17); __pyx_t_17 = NULL;
              }
              __Pyx_GIVEREF(__pyx_t_19);
              PyTuple_SET_ITEM(__pyx_t_18, 0+__pyx_t_11, __pyx_t_19);
              __Pyx_INCREF(__pyx_v_t);
              __Pyx_GIVEREF(__pyx_v_t);
              PyTuple_SET_ITEM(__pyx_t_18, 1+__pyx_t_11, __pyx_v_t);
              __pyx_t_19 = 0;
              __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_16, __pyx_t_18, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2332, __pyx_L28_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
            }
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            __pyx_t_16 = __Pyx_PyInt_SubtractObjC(__pyx_t_1, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2332, __pyx_L28_error)
            __Pyx_GOTREF(__pyx_t_16);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_1 = PyNumber_Multiply(__pyx_kp_u__84, __pyx_t_16); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2332, __pyx_L28_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            __pyx_t_16 = PyNumber_Add(__pyx_t_1, __pyx_kp_u__85); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2332, __pyx_L28_error)
            __Pyx_GOTREF(__pyx_t_16);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_1 = PyNumber_Add(__pyx_t_16, __pyx_v_fatal); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2332, __pyx_L28_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_1); if (unlikely(__pyx_t_12 == -1)) __PYX_ERR(0, 2332, __pyx_L28_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

            /* "cPyparsing.pyx":2330
 *             except ParseBaseException as pe:
 *                 fatal = "(FATAL)" if isinstance(pe, ParseFatalException) else ""
 *                 if '\n' in t:             # <<<<<<<<<<<<<<
 *                     out.append(line(pe.loc, t))
 *                     out.append(' ' * (col(pe.loc, t) - 1) + '^' + fatal)
 */
            goto __pyx_L30;
          }

          /* "cPyparsing.pyx":2334
 *                     out.append(' ' * (col(pe.loc, t) - 1) + '^' + fatal)
 *                 else:
 *                     out.append(' ' * pe.loc + '^' + fatal)             # <<<<<<<<<<<<<<
 *                 out.append("FAIL: " + str(pe))
 *                 success = success and failureTests
 */
          /*else*/ {
            __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_pe, __pyx_n_s_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2334, __pyx_L28_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_16 = PyNumber_Multiply(__pyx_kp_u__84, __pyx_t_1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2334, __pyx_L28_error)
            __Pyx_GOTREF(__pyx_t_16);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_1 = PyNumber_Add(__pyx_t_16, __pyx_kp_u__85); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2334, __pyx_L28_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            __pyx_t_16 = PyNumber_Add(__pyx_t_1, __pyx_v_fatal); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2334, __pyx_L28_error)
            __Pyx_GOTREF(__pyx_t_16);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_16); if (unlikely(__pyx_t_12 == -1)) __PYX_ERR(0, 2334, __pyx_L28_error)
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          }
          __pyx_L30:;

          /* "cPyparsing.pyx":2335
 *                 else:
 *                     out.append(' ' * pe.loc + '^' + fatal)
 *                 out.append("FAIL: " + str(pe))             # <<<<<<<<<<<<<<
 *                 success = success and failureTests
 *                 result = pe
 */
          __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_str); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2335, __pyx_L28_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_18 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_18 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_18)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_18);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
            }
          }
          if (!__pyx_t_18) {
            __pyx_t_16 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_pe); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2335, __pyx_L28_error)
            __Pyx_GOTREF(__pyx_t_16);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[2] = {__pyx_t_18, __pyx_v_pe};
              __pyx_t_16 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2335, __pyx_L28_error)
              __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
              __Pyx_GOTREF(__pyx_t_16);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[2] = {__pyx_t_18, __pyx_v_pe};
              __pyx_t_16 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2335, __pyx_L28_error)
              __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
              __Pyx_GOTREF(__pyx_t_16);
            } else
            #endif
            {
              __pyx_t_19 = PyTuple_New(1+1); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2335, __pyx_L28_error)
              __Pyx_GOTREF(__pyx_t_19);
              __Pyx_GIVEREF(__pyx_t_18); PyTuple_SET_ITEM(__pyx_t_19, 0, __pyx_t_18); __pyx_t_18 = NULL;
              __Pyx_INCREF(__pyx_v_pe);
              __Pyx_GIVEREF(__pyx_v_pe);
              PyTuple_SET_ITEM(__pyx_t_19, 0+1, __pyx_v_pe);
              __pyx_t_16 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_19, NULL); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2335, __pyx_L28_error)
              __Pyx_GOTREF(__pyx_t_16);
              __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_1 = PyNumber_Add(__pyx_kp_u_FAIL, __pyx_t_16); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2335, __pyx_L28_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_1); if (unlikely(__pyx_t_12 == -1)) __PYX_ERR(0, 2335, __pyx_L28_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "cPyparsing.pyx":2336
 *                     out.append(' ' * pe.loc + '^' + fatal)
 *                 out.append("FAIL: " + str(pe))
 *                 success = success and failureTests             # <<<<<<<<<<<<<<
 *                 result = pe
 *             except Exception as exc:
 */
          __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_success); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 2336, __pyx_L28_error)
          if (__pyx_t_3) {
          } else {
            __Pyx_INCREF(__pyx_v_success);
            __pyx_t_1 = __pyx_v_success;
            goto __pyx_L31_bool_binop_done;
          }
          __Pyx_INCREF(__pyx_v_failureTests);
          __pyx_t_1 = __pyx_v_failureTests;
          __pyx_L31_bool_binop_done:;
          __Pyx_DECREF_SET(__pyx_v_success, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "cPyparsing.pyx":2337
 *                 out.append("FAIL: " + str(pe))
 *                 success = success and failureTests
 *                 result = pe             # <<<<<<<<<<<<<<
 *             except Exception as exc:
 *                 out.append("FAIL-EXCEPTION: " + str(exc))
 */
          __Pyx_INCREF(__pyx_v_pe);
          __Pyx_XDECREF_SET(__pyx_v_result, __pyx_v_pe);
        }

        /* "cPyparsing.pyx":2328
 *                 out.append(result.dump(full=fullDump))
 *                 success = success and not failureTests
 *             except ParseBaseException as pe:             # <<<<<<<<<<<<<<
 *                 fatal = "(FATAL)" if isinstance(pe, ParseFatalException) else ""
 *                 if '\n' in t:
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_pe);
            __pyx_v_pe = NULL;
            goto __pyx_L29;
          }
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __pyx_L28_error:;
            __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0; __pyx_t_26 = 0; __pyx_t_27 = 0;
            __Pyx_PyThreadState_assign
            __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
            __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
            __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
            __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_25, &__pyx_t_26, &__pyx_t_27);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_22, &__pyx_t_23, &__pyx_t_24) < 0)) __Pyx_ErrFetch(&__pyx_t_22, &__pyx_t_23, &__pyx_t_24);
            __Pyx_XGOTREF(__pyx_t_22);
            __Pyx_XGOTREF(__pyx_t_23);
            __Pyx_XGOTREF(__pyx_t_24);
            __Pyx_XGOTREF(__pyx_t_25);
            __Pyx_XGOTREF(__pyx_t_26);
            __Pyx_XGOTREF(__pyx_t_27);
            __pyx_t_11 = __pyx_lineno; __pyx_t_20 = __pyx_clineno; __pyx_t_21 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_pe);
              __pyx_v_pe = NULL;
            }
            __Pyx_PyThreadState_assign
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_25);
              __Pyx_XGIVEREF(__pyx_t_26);
              __Pyx_XGIVEREF(__pyx_t_27);
              __Pyx_ExceptionReset(__pyx_t_25, __pyx_t_26, __pyx_t_27);
            }
            __Pyx_XGIVEREF(__pyx_t_22);
            __Pyx_XGIVEREF(__pyx_t_23);
            __Pyx_XGIVEREF(__pyx_t_24);
            __Pyx_ErrRestore(__pyx_t_22, __pyx_t_23, __pyx_t_24);
            __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0; __pyx_t_26 = 0; __pyx_t_27 = 0;
            __pyx_lineno = __pyx_t_11; __pyx_clineno = __pyx_t_20; __pyx_filename = __pyx_t_21;
            goto __pyx_L15_except_error;
          }
          __pyx_L29:;
        }
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        goto __pyx_L14_exception_handled;
      }

      /* "cPyparsing.pyx":2338
 *                 success = success and failureTests
 *                 result = pe
 *             except Exception as exc:             # <<<<<<<<<<<<<<
 *                 out.append("FAIL-EXCEPTION: " + str(exc))
 *                 success = success and failureTests
 */
      __pyx_t_20 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_20) {
        __Pyx_AddTraceback("cPyparsing.ParserElement.runTests", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 2338, __pyx_L15_except_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_7);
        __pyx_v_exc = __pyx_t_7;
        /*try:*/ {

          /* "cPyparsing.pyx":2339
 *                 result = pe
 *             except Exception as exc:
 *                 out.append("FAIL-EXCEPTION: " + str(exc))             # <<<<<<<<<<<<<<
 *                 success = success and failureTests
 *                 result = exc
 */
          __pyx_t_16 = __Pyx_GetModuleGlobalName(__pyx_n_s_str); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2339, __pyx_L42_error)
          __Pyx_GOTREF(__pyx_t_16);
          __pyx_t_19 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_16))) {
            __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_16);
            if (likely(__pyx_t_19)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
              __Pyx_INCREF(__pyx_t_19);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_16, function);
            }
          }
          if (!__pyx_t_19) {
            __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_v_exc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2339, __pyx_L42_error)
            __Pyx_GOTREF(__pyx_t_1);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_16)) {
              PyObject *__pyx_temp[2] = {__pyx_t_19, __pyx_v_exc};
              __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_16, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2339, __pyx_L42_error)
              __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
              __Pyx_GOTREF(__pyx_t_1);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_16)) {
              PyObject *__pyx_temp[2] = {__pyx_t_19, __pyx_v_exc};
              __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_16, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2339, __pyx_L42_error)
              __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
              __Pyx_GOTREF(__pyx_t_1);
            } else
            #endif
            {
              __pyx_t_18 = PyTuple_New(1+1); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 2339, __pyx_L42_error)
              __Pyx_GOTREF(__pyx_t_18);
              __Pyx_GIVEREF(__pyx_t_19); PyTuple_SET_ITEM(__pyx_t_18, 0, __pyx_t_19); __pyx_t_19 = NULL;
              __Pyx_INCREF(__pyx_v_exc);
              __Pyx_GIVEREF(__pyx_v_exc);
              PyTuple_SET_ITEM(__pyx_t_18, 0+1, __pyx_v_exc);
              __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_16, __pyx_t_18, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2339, __pyx_L42_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __pyx_t_16 = PyNumber_Add(__pyx_kp_u_FAIL_EXCEPTION, __pyx_t_1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2339, __pyx_L42_error)
          __Pyx_GOTREF(__pyx_t_16);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_out, __pyx_t_16); if (unlikely(__pyx_t_12 == -1)) __PYX_ERR(0, 2339, __pyx_L42_error)
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;

          /* "cPyparsing.pyx":2340
 *             except Exception as exc:
 *                 out.append("FAIL-EXCEPTION: " + str(exc))
 *                 success = success and failureTests             # <<<<<<<<<<<<<<
 *                 result = exc
 * 
 */
          __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_success); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 2340, __pyx_L42_error)
          if (__pyx_t_3) {
          } else {
            __Pyx_INCREF(__pyx_v_success);
            __pyx_t_16 = __pyx_v_success;
            goto __pyx_L44_bool_binop_done;
          }
          __Pyx_INCREF(__pyx_v_failureTests);
          __pyx_t_16 = __pyx_v_failureTests;
          __pyx_L44_bool_binop_done:;
          __Pyx_DECREF_SET(__pyx_v_success, __pyx_t_16);
          __pyx_t_16 = 0;

          /* "cPyparsing.pyx":2341
 *                 out.append("FAIL-EXCEPTION: " + str(exc))
 *                 success = success and failureTests
 *                 result = exc             # <<<<<<<<<<<<<<
 * 
 *             if printResults:
 */
          __Pyx_INCREF(__pyx_v_exc);
          __Pyx_XDECREF_SET(__pyx_v_result, __pyx_v_exc);
        }

        /* "cPyparsing.pyx":2338
 *                 success = success and failureTests
 *                 result = pe
 *             except Exception as exc:             # <<<<<<<<<<<<<<
 *                 out.append("FAIL-EXCEPTION: " + str(exc))
 *                 success = success and failureTests
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
            goto __pyx_L43;
          }
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __pyx_L42_error:;
            __pyx_t_27 = 0; __pyx_t_26 = 0; __pyx_t_25 = 0; __pyx_t_24 = 0; __pyx_t_23 = 0; __pyx_t_22 = 0;
            __Pyx_PyThreadState_assign
            __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
            __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
            __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_24, &__pyx_t_23, &__pyx_t_22);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_27, &__pyx_t_26, &__pyx_t_25) < 0)) __Pyx_ErrFetch(&__pyx_t_27, &__pyx_t_26, &__pyx_t_25);
            __Pyx_XGOTREF(__pyx_t_27);
            __Pyx_XGOTREF(__pyx_t_26);
            __Pyx_XGOTREF(__pyx_t_25);
            __Pyx_XGOTREF(__pyx_t_24);
            __Pyx_XGOTREF(__pyx_t_23);
            __Pyx_XGOTREF(__pyx_t_22);
            __pyx_t_20 = __pyx_lineno; __pyx_t_11 = __pyx_clineno; __pyx_t_28 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_exc);
              __pyx_v_exc = NULL;
            }
            __Pyx_PyThreadState_assign
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_24);
              __Pyx_XGIVEREF(__pyx_t_23);
              __Pyx_XGIVEREF(__pyx_t_22);
              __Pyx_ExceptionReset(__pyx_t_24, __pyx_t_23, __pyx_t_22);
            }
            __Pyx_XGIVEREF(__pyx_t_27);
            __Pyx_XGIVEREF(__pyx_t_26);
            __Pyx_XGIVEREF(__pyx_t_25);
            __Pyx_ErrRestore(__pyx_t_27, __pyx_t_26, __pyx_t_25);
            __pyx_t_27 = 0; __pyx_t_26 = 0; __pyx_t_25 = 0; __pyx_t_24 = 0; __pyx_t_23 = 0; __pyx_t_22 = 0;
            __pyx_lineno = __pyx_t_20; __pyx_clineno = __pyx_t_11; __pyx_filename = __pyx_t_28;
            goto __pyx_L15_except_error;
          }
          __pyx_L43:;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        goto __pyx_L14_exception_handled;
      }
      goto __pyx_L15_except_error;
      __pyx_L15_except_error:;

      /* "cPyparsing.pyx":2323
 *             out = ['\n'.join(comments), t]
 *             comments = []
 *             try:             # <<<<<<<<<<<<<<
 *                 t = t.replace(r'\n', '\n')
 *                 result = self.parseString(t, parseAll=parseAll)
 */
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
      goto __pyx_L1_error;
      __pyx_L14_exception_handled:;
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
      __pyx_L20_try_end:;
    }

    /* "cPyparsing.pyx":2343
 *                 result = exc
 * 
 *             if printResults:             # <<<<<<<<<<<<<<
 *                 if fullDump:
 *                     out.append('')
 */
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_printResults); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 2343, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "cPyparsing.pyx":2344
 * 
 *             if printResults:
 *                 if fullDump:             # <<<<<<<<<<<<<<
 *                     out.append('')
 *                 print('\n'.join(out))
 */
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_fullDump); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 2344, __pyx_L1_error)
      if (__pyx_t_3) {

        /* "cPyparsing.pyx":2345
 *             if printResults:
 *                 if fullDump:
 *                     out.append('')             # <<<<<<<<<<<<<<
 *                 print('\n'.join(out))
 * 
 */
        __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_out, __pyx_kp_u__9); if (unlikely(__pyx_t_12 == -1)) __PYX_ERR(0, 2345, __pyx_L1_error)

        /* "cPyparsing.pyx":2344
 * 
 *             if printResults:
 *                 if fullDump:             # <<<<<<<<<<<<<<
 *                     out.append('')
 *                 print('\n'.join(out))
 */
      }

      /* "cPyparsing.pyx":2346
 *                 if fullDump:
 *                     out.append('')
 *                 print('\n'.join(out))             # <<<<<<<<<<<<<<
 * 
 *             allResults.append((t, result))
 */
      __pyx_t_5 = PyUnicode_Join(__pyx_kp_u__21, __pyx_v_out); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2346, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2346, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5);
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_t_7, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2346, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "cPyparsing.pyx":2343
 *                 result = exc
 * 
 *             if printResults:             # <<<<<<<<<<<<<<
 *                 if fullDump:
 *                     out.append('')
 */
    }

    /* "cPyparsing.pyx":2348
 *                 print('\n'.join(out))
 * 
 *             allResults.append((t, result))             # <<<<<<<<<<<<<<
 * 
 *         return success, allResults
 */
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2348, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_t);
    __Pyx_GIVEREF(__pyx_v_t);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_t);
    __Pyx_INCREF(__pyx_v_result);
    __Pyx_GIVEREF(__pyx_v_result);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_result);
    __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_allResults, __pyx_t_5); if (unlikely(__pyx_t_12 == -1)) __PYX_ERR(0, 2348, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "cPyparsing.pyx":2315
 *         comments = []
 *         success = True
 *         for t in tests:             # <<<<<<<<<<<<<<
 *             if comment is not None and comment.matches(t, False) or comments and not t:
 *                 comments.append(t)
 */
    __pyx_L5_continue:;
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "cPyparsing.pyx":2350
 *             allResults.append((t, result))
 * 
 *         return success, allResults             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_success);
  __Pyx_GIVEREF(__pyx_v_success);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_success);
  __Pyx_INCREF(__pyx_v_allResults);
  __Pyx_GIVEREF(__pyx_v_allResults);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_allResults);
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2221
 *             return False
 * 
 *     def runTests(self, tests, parseAll=True, comment='#', fullDump=True, printResults=True, failureTests=False):             # <<<<<<<<<<<<<<
 *         """
 *         Execute the parse expression on a series of test strings, showing each
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_AddTraceback("cPyparsing.ParserElement.runTests", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_allResults);
  __Pyx_XDECREF(__pyx_v_comments);
  __Pyx_XDECREF(__pyx_v_success);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XDECREF(__pyx_v_out);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_pe);
  __Pyx_XDECREF(__pyx_v_fatal);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XDECREF(__pyx_v_tests);
  __Pyx_XDECREF(__pyx_v_comment);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2358
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(Token, self).__init__(savelist=False)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5Token_1__init__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_5Token_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_5Token_1__init__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_5Token_1__init__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_5Token___init__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_5Token___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":2359
 * 
 *     def __init__(self):
 *         super(Token, self).__init__(savelist=False)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Token); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_self);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_savelist, Py_False) < 0) __PYX_ERR(0, 2359, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":2358
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(Token, self).__init__(savelist=False)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.Token.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2367
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(Empty, self).__init__()
 *         self.name = "Empty"
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5Empty_1__init__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_5Empty_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_5Empty_1__init__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_5Empty_1__init__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_5Empty___init__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_5Empty___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":2368
 * 
 *     def __init__(self):
 *         super(Empty, self).__init__()             # <<<<<<<<<<<<<<
 *         self.name = "Empty"
 *         self.mayReturnEmpty = True
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Empty); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2368, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2368, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2369
 *     def __init__(self):
 *         super(Empty, self).__init__()
 *         self.name = "Empty"             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 *         self.mayIndexError = False
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name, __pyx_n_u_Empty) < 0) __PYX_ERR(0, 2369, __pyx_L1_error)

  /* "cPyparsing.pyx":2370
 *         super(Empty, self).__init__()
 *         self.name = "Empty"
 *         self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 *         self.mayIndexError = False
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 2370, __pyx_L1_error)

  /* "cPyparsing.pyx":2371
 *         self.name = "Empty"
 *         self.mayReturnEmpty = True
 *         self.mayIndexError = False             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, Py_False) < 0) __PYX_ERR(0, 2371, __pyx_L1_error)

  /* "cPyparsing.pyx":2367
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(Empty, self).__init__()
 *         self.name = "Empty"
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.Empty.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2379
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(NoMatch, self).__init__()
 *         self.name = "NoMatch"
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7NoMatch_1__init__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_7NoMatch_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_7NoMatch_1__init__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_7NoMatch_1__init__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_7NoMatch___init__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7NoMatch___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":2380
 * 
 *     def __init__(self):
 *         super(NoMatch, self).__init__()             # <<<<<<<<<<<<<<
 *         self.name = "NoMatch"
 *         self.mayReturnEmpty = True
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_NoMatch); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2380, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2380, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2381
 *     def __init__(self):
 *         super(NoMatch, self).__init__()
 *         self.name = "NoMatch"             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 *         self.mayIndexError = False
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name, __pyx_n_u_NoMatch) < 0) __PYX_ERR(0, 2381, __pyx_L1_error)

  /* "cPyparsing.pyx":2382
 *         super(NoMatch, self).__init__()
 *         self.name = "NoMatch"
 *         self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 *         self.mayIndexError = False
 *         self.errmsg = "Unmatchable token"
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 2382, __pyx_L1_error)

  /* "cPyparsing.pyx":2383
 *         self.name = "NoMatch"
 *         self.mayReturnEmpty = True
 *         self.mayIndexError = False             # <<<<<<<<<<<<<<
 *         self.errmsg = "Unmatchable token"
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, Py_False) < 0) __PYX_ERR(0, 2383, __pyx_L1_error)

  /* "cPyparsing.pyx":2384
 *         self.mayReturnEmpty = True
 *         self.mayIndexError = False
 *         self.errmsg = "Unmatchable token"             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_kp_u_Unmatchable_token) < 0) __PYX_ERR(0, 2384, __pyx_L1_error)

  /* "cPyparsing.pyx":2379
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(NoMatch, self).__init__()
 *         self.name = "NoMatch"
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.NoMatch.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2386
 *         self.errmsg = "Unmatchable token"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7NoMatch_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_7NoMatch_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_7NoMatch_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_7NoMatch_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 2386, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 2386, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 2386, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2386, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2386, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.NoMatch.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7NoMatch_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7NoMatch_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":2387
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[5] = {__pyx_t_5, __pyx_v_instring, __pyx_t_3, __pyx_t_4, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 4+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2387, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[5] = {__pyx_t_5, __pyx_v_instring, __pyx_t_3, __pyx_t_4, __pyx_v_self};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 4+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2387, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else
  #endif
  {
    __pyx_t_7 = PyTuple_New(4+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2387, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__pyx_t_5) {
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
    }
    __Pyx_INCREF(__pyx_v_instring);
    __Pyx_GIVEREF(__pyx_v_instring);
    PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_instring);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_6, __pyx_t_4);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_7, 3+__pyx_t_6, __pyx_v_self);
    __pyx_t_3 = 0;
    __pyx_t_4 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2387, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 2387, __pyx_L1_error)

  /* "cPyparsing.pyx":2386
 *         self.errmsg = "Unmatchable token"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.NoMatch.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2405
 *     """
 * 
 *     def __init__(self, matchString):             # <<<<<<<<<<<<<<
 *         super(Literal, self).__init__()
 *         self.match = matchString
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Literal_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_7Literal_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_7Literal_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_7Literal_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_matchString = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_matchString,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_matchString)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 2405, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 2405, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_matchString = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2405, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Literal.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Literal___init__(__pyx_self, __pyx_v_self, __pyx_v_matchString);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Literal___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_matchString) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":2406
 * 
 *     def __init__(self, matchString):
 *         super(Literal, self).__init__()             # <<<<<<<<<<<<<<
 *         self.match = matchString
 *         self.matchLen = len(matchString)
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Literal); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2406, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2406, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2407
 *     def __init__(self, matchString):
 *         super(Literal, self).__init__()
 *         self.match = matchString             # <<<<<<<<<<<<<<
 *         self.matchLen = len(matchString)
 *         try:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_match, __pyx_v_matchString) < 0) __PYX_ERR(0, 2407, __pyx_L1_error)

  /* "cPyparsing.pyx":2408
 *         super(Literal, self).__init__()
 *         self.match = matchString
 *         self.matchLen = len(matchString)             # <<<<<<<<<<<<<<
 *         try:
 *             self.firstMatchChar = matchString[0]
 */
  __pyx_t_4 = PyObject_Length(__pyx_v_matchString); if (unlikely(__pyx_t_4 == -1)) __PYX_ERR(0, 2408, __pyx_L1_error)
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_matchLen, __pyx_t_1) < 0) __PYX_ERR(0, 2408, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2409
 *         self.match = matchString
 *         self.matchLen = len(matchString)
 *         try:             # <<<<<<<<<<<<<<
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_7);
    /*try:*/ {

      /* "cPyparsing.pyx":2410
 *         self.matchLen = len(matchString)
 *         try:
 *             self.firstMatchChar = matchString[0]             # <<<<<<<<<<<<<<
 *         except IndexError:
 *             warnings.warn("null string passed to Literal; use Empty() instead",
 */
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_matchString, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2410, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_firstMatchChar, __pyx_t_1) < 0) __PYX_ERR(0, 2410, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":2409
 *         self.match = matchString
 *         self.matchLen = len(matchString)
 *         try:             # <<<<<<<<<<<<<<
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:
 */
    }
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    goto __pyx_L10_try_end;
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2411
 *         try:
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:             # <<<<<<<<<<<<<<
 *             warnings.warn("null string passed to Literal; use Empty() instead",
 *                           SyntaxWarning, stacklevel=2)
 */
    __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
    if (__pyx_t_8) {
      __Pyx_AddTraceback("cPyparsing.Literal.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_3, &__pyx_t_2) < 0) __PYX_ERR(0, 2411, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_t_2);

      /* "cPyparsing.pyx":2412
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:
 *             warnings.warn("null string passed to Literal; use Empty() instead",             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             self.__class__ = Empty
 */
      __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_warnings); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2412, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_warn); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2412, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "cPyparsing.pyx":2413
 *         except IndexError:
 *             warnings.warn("null string passed to Literal; use Empty() instead",
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             self.__class__ = Empty
 *         self.name = '"%s"' % _ustr(self.match)
 */
      __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2412, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_kp_u_null_string_passed_to_Literal_us);
      __Pyx_GIVEREF(__pyx_kp_u_null_string_passed_to_Literal_us);
      PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_kp_u_null_string_passed_to_Literal_us);
      __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
      __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
      PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_builtin_SyntaxWarning);
      __pyx_t_11 = PyDict_New(); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2413, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 2413, __pyx_L5_except_error)

      /* "cPyparsing.pyx":2412
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:
 *             warnings.warn("null string passed to Literal; use Empty() instead",             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             self.__class__ = Empty
 */
      __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_9, __pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2412, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

      /* "cPyparsing.pyx":2414
 *             warnings.warn("null string passed to Literal; use Empty() instead",
 *                           SyntaxWarning, stacklevel=2)
 *             self.__class__ = Empty             # <<<<<<<<<<<<<<
 *         self.name = '"%s"' % _ustr(self.match)
 *         self.errmsg = "Expected " + self.name
 */
      __pyx_t_12 = __Pyx_GetModuleGlobalName(__pyx_n_s_Empty); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2414, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_12);
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_class, __pyx_t_12) < 0) __PYX_ERR(0, 2414, __pyx_L5_except_error)
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cPyparsing.pyx":2409
 *         self.match = matchString
 *         self.matchLen = len(matchString)
 *         try:             # <<<<<<<<<<<<<<
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
    __pyx_L10_try_end:;
  }

  /* "cPyparsing.pyx":2415
 *                           SyntaxWarning, stacklevel=2)
 *             self.__class__ = Empty
 *         self.name = '"%s"' % _ustr(self.match)             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected " + self.name
 *         self.mayReturnEmpty = False
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_12) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2415, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_1};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2415, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_1};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2415, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    {
      __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_12); __pyx_t_12 = NULL;
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_11, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyUnicode_Format(__pyx_kp_u_s_2, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name, __pyx_t_3) < 0) __PYX_ERR(0, 2415, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":2416
 *             self.__class__ = Empty
 *         self.name = '"%s"' % _ustr(self.match)
 *         self.errmsg = "Expected " + self.name             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = False
 *         self.mayIndexError = False
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyNumber_Add(__pyx_kp_u_Expected, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_2) < 0) __PYX_ERR(0, 2416, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2417
 *         self.name = '"%s"' % _ustr(self.match)
 *         self.errmsg = "Expected " + self.name
 *         self.mayReturnEmpty = False             # <<<<<<<<<<<<<<
 *         self.mayIndexError = False
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_False) < 0) __PYX_ERR(0, 2417, __pyx_L1_error)

  /* "cPyparsing.pyx":2418
 *         self.errmsg = "Expected " + self.name
 *         self.mayReturnEmpty = False
 *         self.mayIndexError = False             # <<<<<<<<<<<<<<
 * 
 *     # Performance tuning: this routine gets called a *lot*
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, Py_False) < 0) __PYX_ERR(0, 2418, __pyx_L1_error)

  /* "cPyparsing.pyx":2405
 *     """
 * 
 *     def __init__(self, matchString):             # <<<<<<<<<<<<<<
 *         super(Literal, self).__init__()
 *         self.match = matchString
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("cPyparsing.Literal.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2424
 *     # short-circuit as quickly as possible, and avoid calling startswith
 *     #~ @profile
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if (instring[loc] == self.firstMatchChar and
 *                 (self.matchLen == 1 or instring.startswith(self.match, loc))):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Literal_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_7Literal_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_7Literal_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_7Literal_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 2424, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 2424, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 2424, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2424, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2424, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Literal.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Literal_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Literal_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":2425
 *     #~ @profile
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if (instring[loc] == self.firstMatchChar and             # <<<<<<<<<<<<<<
 *                 (self.matchLen == 1 or instring.startswith(self.match, loc))):
 *             return loc + self.matchLen, self.match
 */
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_instring, __pyx_v_loc, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_firstMatchChar); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_2, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2425, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 2425, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_5) {
  } else {
    __pyx_t_1 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }

  /* "cPyparsing.pyx":2426
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if (instring[loc] == self.firstMatchChar and
 *                 (self.matchLen == 1 or instring.startswith(self.match, loc))):             # <<<<<<<<<<<<<<
 *             return loc + self.matchLen, self.match
 *         raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyInt_EqObjC(__pyx_t_4, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 2426, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (!__pyx_t_5) {
  } else {
    __pyx_t_1 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_instring, __pyx_n_s_startswith); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = NULL;
  __pyx_t_8 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_8 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_4)) {
    PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_t_2, __pyx_t_6};
    __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2426, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
    PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_t_2, __pyx_t_6};
    __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2426, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else
  #endif
  {
    __pyx_t_9 = PyTuple_New(2+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2426, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (__pyx_t_7) {
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, __pyx_t_6);
    __pyx_t_2 = 0;
    __pyx_t_6 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_9, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2426, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 2426, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;

  /* "cPyparsing.pyx":2425
 *     #~ @profile
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if (instring[loc] == self.firstMatchChar and             # <<<<<<<<<<<<<<
 *                 (self.matchLen == 1 or instring.startswith(self.match, loc))):
 *             return loc + self.matchLen, self.match
 */
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":2427
 *         if (instring[loc] == self.firstMatchChar and
 *                 (self.matchLen == 1 or instring.startswith(self.match, loc))):
 *             return loc + self.matchLen, self.match             # <<<<<<<<<<<<<<
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2427, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2427, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_9 = PyNumber_Add(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2427, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2427, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2427, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_9);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_9);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_4);
    __pyx_t_9 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":2425
 *     #~ @profile
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if (instring[loc] == self.firstMatchChar and             # <<<<<<<<<<<<<<
 *                 (self.matchLen == 1 or instring.startswith(self.match, loc))):
 *             return loc + self.matchLen, self.match
 */
  }

  /* "cPyparsing.pyx":2428
 *                 (self.matchLen == 1 or instring.startswith(self.match, loc))):
 *             return loc + self.matchLen, self.match
 *         raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2428, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2428, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2428, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = NULL;
  __pyx_t_8 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_8 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_4)) {
    PyObject *__pyx_temp[5] = {__pyx_t_2, __pyx_v_instring, __pyx_t_9, __pyx_t_6, __pyx_v_self};
    __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_8, 4+__pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2428, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
    PyObject *__pyx_temp[5] = {__pyx_t_2, __pyx_v_instring, __pyx_t_9, __pyx_t_6, __pyx_v_self};
    __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_8, 4+__pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2428, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else
  #endif
  {
    __pyx_t_7 = PyTuple_New(4+__pyx_t_8); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2428, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__pyx_t_2) {
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_2); __pyx_t_2 = NULL;
    }
    __Pyx_INCREF(__pyx_v_instring);
    __Pyx_GIVEREF(__pyx_v_instring);
    PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_8, __pyx_v_instring);
    __Pyx_GIVEREF(__pyx_t_9);
    PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_8, __pyx_t_9);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_8, __pyx_t_6);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_7, 3+__pyx_t_8, __pyx_v_self);
    __pyx_t_9 = 0;
    __pyx_t_6 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2428, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __PYX_ERR(0, 2428, __pyx_L1_error)

  /* "cPyparsing.pyx":2424
 *     # short-circuit as quickly as possible, and avoid calling startswith
 *     #~ @profile
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if (instring[loc] == self.firstMatchChar and
 *                 (self.matchLen == 1 or instring.startswith(self.match, loc))):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.Literal.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2454
 *     DEFAULT_KEYWORD_CHARS = alphanums + "_$"
 * 
 *     def __init__(self, matchString, identChars=None, caseless=False):             # <<<<<<<<<<<<<<
 *         super(Keyword, self).__init__()
 *         if identChars is None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Keyword_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_7Keyword_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_7Keyword_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_7Keyword_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_matchString = 0;
  PyObject *__pyx_v_identChars = 0;
  PyObject *__pyx_v_caseless = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_matchString,&__pyx_n_s_identChars,&__pyx_n_s_caseless,0};
    PyObject* values[4] = {0,0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_None));
    values[3] = ((PyObject *)((PyObject *)Py_False));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_matchString)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 4, 1); __PYX_ERR(0, 2454, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_identChars);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_caseless);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 2454, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_matchString = values[1];
    __pyx_v_identChars = values[2];
    __pyx_v_caseless = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2454, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Keyword.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Keyword___init__(__pyx_self, __pyx_v_self, __pyx_v_matchString, __pyx_v_identChars, __pyx_v_caseless);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Keyword___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_matchString, PyObject *__pyx_v_identChars, PyObject *__pyx_v_caseless) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);
  __Pyx_INCREF(__pyx_v_identChars);

  /* "cPyparsing.pyx":2455
 * 
 *     def __init__(self, matchString, identChars=None, caseless=False):
 *         super(Keyword, self).__init__()             # <<<<<<<<<<<<<<
 *         if identChars is None:
 *             identChars = Keyword.DEFAULT_KEYWORD_CHARS
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Keyword); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2455, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2455, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2456
 *     def __init__(self, matchString, identChars=None, caseless=False):
 *         super(Keyword, self).__init__()
 *         if identChars is None:             # <<<<<<<<<<<<<<
 *             identChars = Keyword.DEFAULT_KEYWORD_CHARS
 *         self.match = matchString
 */
  __pyx_t_4 = (__pyx_v_identChars == Py_None);
  __pyx_t_5 = (__pyx_t_4 != 0);
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":2457
 *         super(Keyword, self).__init__()
 *         if identChars is None:
 *             identChars = Keyword.DEFAULT_KEYWORD_CHARS             # <<<<<<<<<<<<<<
 *         self.match = matchString
 *         self.matchLen = len(matchString)
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Keyword); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2457, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DEFAULT_KEYWORD_CHARS); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2457, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_identChars, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":2456
 *     def __init__(self, matchString, identChars=None, caseless=False):
 *         super(Keyword, self).__init__()
 *         if identChars is None:             # <<<<<<<<<<<<<<
 *             identChars = Keyword.DEFAULT_KEYWORD_CHARS
 *         self.match = matchString
 */
  }

  /* "cPyparsing.pyx":2458
 *         if identChars is None:
 *             identChars = Keyword.DEFAULT_KEYWORD_CHARS
 *         self.match = matchString             # <<<<<<<<<<<<<<
 *         self.matchLen = len(matchString)
 *         try:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_match, __pyx_v_matchString) < 0) __PYX_ERR(0, 2458, __pyx_L1_error)

  /* "cPyparsing.pyx":2459
 *             identChars = Keyword.DEFAULT_KEYWORD_CHARS
 *         self.match = matchString
 *         self.matchLen = len(matchString)             # <<<<<<<<<<<<<<
 *         try:
 *             self.firstMatchChar = matchString[0]
 */
  __pyx_t_6 = PyObject_Length(__pyx_v_matchString); if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 2459, __pyx_L1_error)
  __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_matchLen, __pyx_t_3) < 0) __PYX_ERR(0, 2459, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":2460
 *         self.match = matchString
 *         self.matchLen = len(matchString)
 *         try:             # <<<<<<<<<<<<<<
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_9);
    /*try:*/ {

      /* "cPyparsing.pyx":2461
 *         self.matchLen = len(matchString)
 *         try:
 *             self.firstMatchChar = matchString[0]             # <<<<<<<<<<<<<<
 *         except IndexError:
 *             warnings.warn("null string passed to Keyword; use Empty() instead",
 */
      __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_matchString, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2461, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_firstMatchChar, __pyx_t_3) < 0) __PYX_ERR(0, 2461, __pyx_L4_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "cPyparsing.pyx":2460
 *         self.match = matchString
 *         self.matchLen = len(matchString)
 *         try:             # <<<<<<<<<<<<<<
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:
 */
    }
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    goto __pyx_L11_try_end;
    __pyx_L4_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":2462
 *         try:
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:             # <<<<<<<<<<<<<<
 *             warnings.warn("null string passed to Keyword; use Empty() instead",
 *                           SyntaxWarning, stacklevel=2)
 */
    __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
    if (__pyx_t_10) {
      __Pyx_AddTraceback("cPyparsing.Keyword.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_1, &__pyx_t_2) < 0) __PYX_ERR(0, 2462, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_2);

      /* "cPyparsing.pyx":2463
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:
 *             warnings.warn("null string passed to Keyword; use Empty() instead",             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *         self.name = '"%s"' % self.match
 */
      __pyx_t_11 = __Pyx_GetModuleGlobalName(__pyx_n_s_warnings); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2463, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_warn); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2463, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

      /* "cPyparsing.pyx":2464
 *         except IndexError:
 *             warnings.warn("null string passed to Keyword; use Empty() instead",
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *         self.name = '"%s"' % self.match
 *         self.errmsg = "Expected " + self.name
 */
      __pyx_t_11 = PyTuple_New(2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2463, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_INCREF(__pyx_kp_u_null_string_passed_to_Keyword_us);
      __Pyx_GIVEREF(__pyx_kp_u_null_string_passed_to_Keyword_us);
      PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_kp_u_null_string_passed_to_Keyword_us);
      __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
      __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
      PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_builtin_SyntaxWarning);
      __pyx_t_13 = PyDict_New(); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2464, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_13);
      if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 2464, __pyx_L6_except_error)

      /* "cPyparsing.pyx":2463
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:
 *             warnings.warn("null string passed to Keyword; use Empty() instead",             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *         self.name = '"%s"' % self.match
 */
      __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_11, __pyx_t_13); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2463, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L5_exception_handled;
    }
    goto __pyx_L6_except_error;
    __pyx_L6_except_error:;

    /* "cPyparsing.pyx":2460
 *         self.match = matchString
 *         self.matchLen = len(matchString)
 *         try:             # <<<<<<<<<<<<<<
 *             self.firstMatchChar = matchString[0]
 *         except IndexError:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
    goto __pyx_L1_error;
    __pyx_L5_exception_handled:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
    __pyx_L11_try_end:;
  }

  /* "cPyparsing.pyx":2465
 *             warnings.warn("null string passed to Keyword; use Empty() instead",
 *                           SyntaxWarning, stacklevel=2)
 *         self.name = '"%s"' % self.match             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected " + self.name
 *         self.mayReturnEmpty = False
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyUnicode_Format(__pyx_kp_u_s_2, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name, __pyx_t_1) < 0) __PYX_ERR(0, 2465, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2466
 *                           SyntaxWarning, stacklevel=2)
 *         self.name = '"%s"' % self.match
 *         self.errmsg = "Expected " + self.name             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = False
 *         self.mayIndexError = False
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Add(__pyx_kp_u_Expected, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_2) < 0) __PYX_ERR(0, 2466, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2467
 *         self.name = '"%s"' % self.match
 *         self.errmsg = "Expected " + self.name
 *         self.mayReturnEmpty = False             # <<<<<<<<<<<<<<
 *         self.mayIndexError = False
 *         self.caseless = caseless
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_False) < 0) __PYX_ERR(0, 2467, __pyx_L1_error)

  /* "cPyparsing.pyx":2468
 *         self.errmsg = "Expected " + self.name
 *         self.mayReturnEmpty = False
 *         self.mayIndexError = False             # <<<<<<<<<<<<<<
 *         self.caseless = caseless
 *         if caseless:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, Py_False) < 0) __PYX_ERR(0, 2468, __pyx_L1_error)

  /* "cPyparsing.pyx":2469
 *         self.mayReturnEmpty = False
 *         self.mayIndexError = False
 *         self.caseless = caseless             # <<<<<<<<<<<<<<
 *         if caseless:
 *             self.caselessmatch = matchString.upper()
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_caseless, __pyx_v_caseless) < 0) __PYX_ERR(0, 2469, __pyx_L1_error)

  /* "cPyparsing.pyx":2470
 *         self.mayIndexError = False
 *         self.caseless = caseless
 *         if caseless:             # <<<<<<<<<<<<<<
 *             self.caselessmatch = matchString.upper()
 *             identChars = identChars.upper()
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_caseless); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 2470, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":2471
 *         self.caseless = caseless
 *         if caseless:
 *             self.caselessmatch = matchString.upper()             # <<<<<<<<<<<<<<
 *             identChars = identChars.upper()
 *         self.identChars = set(identChars)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_matchString, __pyx_n_s_upper); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2471, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (__pyx_t_3) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2471, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2471, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_caselessmatch, __pyx_t_2) < 0) __PYX_ERR(0, 2471, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":2472
 *         if caseless:
 *             self.caselessmatch = matchString.upper()
 *             identChars = identChars.upper()             # <<<<<<<<<<<<<<
 *         self.identChars = set(identChars)
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_identChars, __pyx_n_s_upper); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2472, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (__pyx_t_3) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2472, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2472, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_identChars, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":2470
 *         self.mayIndexError = False
 *         self.caseless = caseless
 *         if caseless:             # <<<<<<<<<<<<<<
 *             self.caselessmatch = matchString.upper()
 *             identChars = identChars.upper()
 */
  }

  /* "cPyparsing.pyx":2473
 *             self.caselessmatch = matchString.upper()
 *             identChars = identChars.upper()
 *         self.identChars = set(identChars)             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  __pyx_t_2 = PySet_New(__pyx_v_identChars); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_identChars, __pyx_t_2) < 0) __PYX_ERR(0, 2473, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2454
 *     DEFAULT_KEYWORD_CHARS = alphanums + "_$"
 * 
 *     def __init__(self, matchString, identChars=None, caseless=False):             # <<<<<<<<<<<<<<
 *         super(Keyword, self).__init__()
 *         if identChars is None:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("cPyparsing.Keyword.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_identChars);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2475
 *         self.identChars = set(identChars)
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.caseless:
 *             if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch) and
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Keyword_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_7Keyword_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_7Keyword_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_7Keyword_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 2475, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 2475, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 2475, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2475, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2475, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Keyword.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Keyword_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Keyword_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  long __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":2476
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if self.caseless:             # <<<<<<<<<<<<<<
 *             if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch) and
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen].upper() not in self.identChars) and
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_caseless); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2476, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":2477
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if self.caseless:
 *             if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch) and             # <<<<<<<<<<<<<<
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen].upper() not in self.identChars) and
 *                     (loc == 0 or instring[loc - 1].upper() not in self.identChars)):
 */
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2477, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2477, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyNumber_Add(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2477, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_v_instring, __pyx_v_loc, 0, NULL, &__pyx_t_5, NULL, 1, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2477, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_upper); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2477, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2477, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2477, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_caselessmatch); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2477, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_1, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2477, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 2477, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_6) {
    } else {
      __pyx_t_2 = __pyx_t_6;
      goto __pyx_L5_bool_binop_done;
    }

    /* "cPyparsing.pyx":2478
 *         if self.caseless:
 *             if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch) and
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen].upper() not in self.identChars) and             # <<<<<<<<<<<<<<
 *                     (loc == 0 or instring[loc - 1].upper() not in self.identChars)):
 *                 return loc + self.matchLen, self.match
 */
    __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2478, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 2478, __pyx_L1_error)
    __pyx_t_5 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2478, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2478, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyNumber_Subtract(__pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2478, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyObject_RichCompare(__pyx_t_4, __pyx_t_3, Py_GE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2478, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 2478, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (!__pyx_t_6) {
    } else {
      goto __pyx_L7_next_and;
    }
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2478, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2478, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyNumber_Add(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2478, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_GetItem(__pyx_v_instring, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2478, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_upper); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2478, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2478, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2478, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_identChars); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2478, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_t_5, Py_NE)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 2478, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_8 = (__pyx_t_6 != 0);
    if (__pyx_t_8) {
    } else {
      __pyx_t_2 = __pyx_t_8;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_L7_next_and:;

    /* "cPyparsing.pyx":2479
 *             if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch) and
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen].upper() not in self.identChars) and
 *                     (loc == 0 or instring[loc - 1].upper() not in self.identChars)):             # <<<<<<<<<<<<<<
 *                 return loc + self.matchLen, self.match
 *         else:
 */
    __pyx_t_8 = ((__pyx_v_loc == 0) != 0);
    if (!__pyx_t_8) {
    } else {
      __pyx_t_2 = __pyx_t_8;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_9 = 0;
    __pyx_t_10 = __Pyx_sub_const_long_checking_overflow(__pyx_v_loc, 1, &__pyx_t_9);
    if (unlikely(__pyx_t_9)) {
      PyErr_SetString(PyExc_OverflowError, "value too large");
      __PYX_ERR(0, 2479, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_instring, __pyx_t_10, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2479, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_upper); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2479, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (__pyx_t_1) {
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2479, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2479, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_identChars); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2479, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_t_5, __pyx_t_4, Py_NE)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 2479, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = (__pyx_t_8 != 0);
    __pyx_t_2 = __pyx_t_6;
    __pyx_L5_bool_binop_done:;

    /* "cPyparsing.pyx":2477
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if self.caseless:
 *             if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch) and             # <<<<<<<<<<<<<<
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen].upper() not in self.identChars) and
 *                     (loc == 0 or instring[loc - 1].upper() not in self.identChars)):
 */
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":2480
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen].upper() not in self.identChars) and
 *                     (loc == 0 or instring[loc - 1].upper() not in self.identChars)):
 *                 return loc + self.matchLen, self.match             # <<<<<<<<<<<<<<
 *         else:
 *             if (instring[loc] == self.firstMatchChar and
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2480, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2480, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_1 = PyNumber_Add(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2480, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2480, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2480, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_5);
      __pyx_t_1 = 0;
      __pyx_t_5 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L0;

      /* "cPyparsing.pyx":2477
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if self.caseless:
 *             if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch) and             # <<<<<<<<<<<<<<
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen].upper() not in self.identChars) and
 *                     (loc == 0 or instring[loc - 1].upper() not in self.identChars)):
 */
    }

    /* "cPyparsing.pyx":2476
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if self.caseless:             # <<<<<<<<<<<<<<
 *             if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch) and
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen].upper() not in self.identChars) and
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":2482
 *                 return loc + self.matchLen, self.match
 *         else:
 *             if (instring[loc] == self.firstMatchChar and             # <<<<<<<<<<<<<<
 *                 (self.matchLen == 1 or instring.startswith(self.match, loc)) and
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen] not in self.identChars) and
 */
  /*else*/ {
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_instring, __pyx_v_loc, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2482, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_firstMatchChar); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2482, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyObject_RichCompare(__pyx_t_4, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2482, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 2482, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_6) {
    } else {
      __pyx_t_2 = __pyx_t_6;
      goto __pyx_L11_bool_binop_done;
    }

    /* "cPyparsing.pyx":2483
 *         else:
 *             if (instring[loc] == self.firstMatchChar and
 *                 (self.matchLen == 1 or instring.startswith(self.match, loc)) and             # <<<<<<<<<<<<<<
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen] not in self.identChars) and
 *                     (loc == 0 or instring[loc - 1] not in self.identChars)):
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2483, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyInt_EqObjC(__pyx_t_1, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2483, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 2483, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (!__pyx_t_6) {
    } else {
      goto __pyx_L13_next_and;
    }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_instring, __pyx_n_s_startswith); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2483, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2483, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2483, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_11 = NULL;
    __pyx_t_9 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_9 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_t_4, __pyx_t_3};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2483, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_t_4, __pyx_t_3};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2483, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_12 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2483, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      if (__pyx_t_11) {
        __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_11); __pyx_t_11 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_9, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_9, __pyx_t_3);
      __pyx_t_4 = 0;
      __pyx_t_3 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_12, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2483, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 2483, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_6) {
    } else {
      __pyx_t_2 = __pyx_t_6;
      goto __pyx_L11_bool_binop_done;
    }
    __pyx_L13_next_and:;

    /* "cPyparsing.pyx":2484
 *             if (instring[loc] == self.firstMatchChar and
 *                 (self.matchLen == 1 or instring.startswith(self.match, loc)) and
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen] not in self.identChars) and             # <<<<<<<<<<<<<<
 *                     (loc == 0 or instring[loc - 1] not in self.identChars)):
 *                 return loc + self.matchLen, self.match
 */
    __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2484, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 2484, __pyx_L1_error)
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2484, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2484, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_3 = PyNumber_Subtract(__pyx_t_1, __pyx_t_12); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2484, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_12 = PyObject_RichCompare(__pyx_t_5, __pyx_t_3, Py_GE); __Pyx_XGOTREF(__pyx_t_12); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2484, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 2484, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    if (!__pyx_t_6) {
    } else {
      goto __pyx_L15_next_and;
    }
    __pyx_t_12 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2484, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2484, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyNumber_Add(__pyx_t_12, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2484, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_GetItem(__pyx_v_instring, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2484, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_identChars); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2484, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_t_3, __pyx_t_5, Py_NE)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 2484, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_8 = (__pyx_t_6 != 0);
    if (__pyx_t_8) {
    } else {
      __pyx_t_2 = __pyx_t_8;
      goto __pyx_L11_bool_binop_done;
    }
    __pyx_L15_next_and:;

    /* "cPyparsing.pyx":2485
 *                 (self.matchLen == 1 or instring.startswith(self.match, loc)) and
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen] not in self.identChars) and
 *                     (loc == 0 or instring[loc - 1] not in self.identChars)):             # <<<<<<<<<<<<<<
 *                 return loc + self.matchLen, self.match
 *         raise ParseException(instring, loc, self.errmsg, self)
 */
    __pyx_t_8 = ((__pyx_v_loc == 0) != 0);
    if (!__pyx_t_8) {
    } else {
      __pyx_t_2 = __pyx_t_8;
      goto __pyx_L11_bool_binop_done;
    }
    __pyx_t_9 = 0;
    __pyx_t_10 = __Pyx_sub_const_long_checking_overflow(__pyx_v_loc, 1, &__pyx_t_9);
    if (unlikely(__pyx_t_9)) {
      PyErr_SetString(PyExc_OverflowError, "value too large");
      __PYX_ERR(0, 2485, __pyx_L1_error)
    }
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_instring, __pyx_t_10, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2485, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_identChars); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2485, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_t_5, __pyx_t_3, Py_NE)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 2485, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = (__pyx_t_8 != 0);
    __pyx_t_2 = __pyx_t_6;
    __pyx_L11_bool_binop_done:;

    /* "cPyparsing.pyx":2482
 *                 return loc + self.matchLen, self.match
 *         else:
 *             if (instring[loc] == self.firstMatchChar and             # <<<<<<<<<<<<<<
 *                 (self.matchLen == 1 or instring.startswith(self.match, loc)) and
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen] not in self.identChars) and
 */
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":2486
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen] not in self.identChars) and
 *                     (loc == 0 or instring[loc - 1] not in self.identChars)):
 *                 return loc + self.matchLen, self.match             # <<<<<<<<<<<<<<
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_12 = PyNumber_Add(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_12);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_12);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_5);
      __pyx_t_12 = 0;
      __pyx_t_5 = 0;
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L0;

      /* "cPyparsing.pyx":2482
 *                 return loc + self.matchLen, self.match
 *         else:
 *             if (instring[loc] == self.firstMatchChar and             # <<<<<<<<<<<<<<
 *                 (self.matchLen == 1 or instring.startswith(self.match, loc)) and
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen] not in self.identChars) and
 */
    }
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":2487
 *                     (loc == 0 or instring[loc - 1] not in self.identChars)):
 *                 return loc + self.matchLen, self.match
 *         raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *     def copy(self):
 */
  __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_12 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = NULL;
  __pyx_t_9 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_9 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_5)) {
    PyObject *__pyx_temp[5] = {__pyx_t_4, __pyx_v_instring, __pyx_t_12, __pyx_t_1, __pyx_v_self};
    __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_9, 4+__pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2487, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
    PyObject *__pyx_temp[5] = {__pyx_t_4, __pyx_v_instring, __pyx_t_12, __pyx_t_1, __pyx_v_self};
    __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_9, 4+__pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2487, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else
  #endif
  {
    __pyx_t_11 = PyTuple_New(4+__pyx_t_9); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2487, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_INCREF(__pyx_v_instring);
    __Pyx_GIVEREF(__pyx_v_instring);
    PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_9, __pyx_v_instring);
    __Pyx_GIVEREF(__pyx_t_12);
    PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_9, __pyx_t_12);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_11, 2+__pyx_t_9, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_11, 3+__pyx_t_9, __pyx_v_self);
    __pyx_t_12 = 0;
    __pyx_t_1 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_11, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2487, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __PYX_ERR(0, 2487, __pyx_L1_error)

  /* "cPyparsing.pyx":2475
 *         self.identChars = set(identChars)
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.caseless:
 *             if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch) and
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("cPyparsing.Keyword.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2489
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         c = super(Keyword, self).copy()
 *         c.identChars = Keyword.DEFAULT_KEYWORD_CHARS
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Keyword_5copy(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_7Keyword_5copy = {"copy", (PyCFunction)__pyx_pw_10cPyparsing_7Keyword_5copy, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_7Keyword_5copy(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_7Keyword_4copy(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Keyword_4copy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_c = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("copy", 0);

  /* "cPyparsing.pyx":2490
 * 
 *     def copy(self):
 *         c = super(Keyword, self).copy()             # <<<<<<<<<<<<<<
 *         c.identChars = Keyword.DEFAULT_KEYWORD_CHARS
 *         return c
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Keyword); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_copy); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2490, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2490, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_c = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2491
 *     def copy(self):
 *         c = super(Keyword, self).copy()
 *         c.identChars = Keyword.DEFAULT_KEYWORD_CHARS             # <<<<<<<<<<<<<<
 *         return c
 * 
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Keyword); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DEFAULT_KEYWORD_CHARS); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_c, __pyx_n_s_identChars, __pyx_t_3) < 0) __PYX_ERR(0, 2491, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":2492
 *         c = super(Keyword, self).copy()
 *         c.identChars = Keyword.DEFAULT_KEYWORD_CHARS
 *         return c             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_c);
  __pyx_r = __pyx_v_c;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2489
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         c = super(Keyword, self).copy()
 *         c.identChars = Keyword.DEFAULT_KEYWORD_CHARS
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.Keyword.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_c);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2495
 * 
 *     @staticmethod
 *     def setDefaultKeywordChars(chars):             # <<<<<<<<<<<<<<
 *         """Overrides the default Keyword chars
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Keyword_7setDefaultKeywordChars(PyObject *__pyx_self, PyObject *__pyx_v_chars); /*proto*/
static char __pyx_doc_10cPyparsing_7Keyword_6setDefaultKeywordChars[] = "Overrides the default Keyword chars\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_7Keyword_7setDefaultKeywordChars = {"setDefaultKeywordChars", (PyCFunction)__pyx_pw_10cPyparsing_7Keyword_7setDefaultKeywordChars, METH_O, __pyx_doc_10cPyparsing_7Keyword_6setDefaultKeywordChars};
static PyObject *__pyx_pw_10cPyparsing_7Keyword_7setDefaultKeywordChars(PyObject *__pyx_self, PyObject *__pyx_v_chars) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setDefaultKeywordChars (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_7Keyword_6setDefaultKeywordChars(__pyx_self, ((PyObject *)__pyx_v_chars));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Keyword_6setDefaultKeywordChars(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_chars) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("setDefaultKeywordChars", 0);

  /* "cPyparsing.pyx":2498
 *         """Overrides the default Keyword chars
 *         """
 *         Keyword.DEFAULT_KEYWORD_CHARS = chars             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Keyword); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_n_s_DEFAULT_KEYWORD_CHARS, __pyx_v_chars) < 0) __PYX_ERR(0, 2498, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2495
 * 
 *     @staticmethod
 *     def setDefaultKeywordChars(chars):             # <<<<<<<<<<<<<<
 *         """Overrides the default Keyword chars
 *         """
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.Keyword.setDefaultKeywordChars", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2513
 *     """
 * 
 *     def __init__(self, matchString):             # <<<<<<<<<<<<<<
 *         super(CaselessLiteral, self).__init__(matchString.upper())
 *         # Preserve the defining literal.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15CaselessLiteral_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15CaselessLiteral_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_15CaselessLiteral_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_15CaselessLiteral_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_matchString = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_matchString,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_matchString)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 2513, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 2513, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_matchString = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2513, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.CaselessLiteral.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15CaselessLiteral___init__(__pyx_self, __pyx_v_self, __pyx_v_matchString);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15CaselessLiteral___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_matchString) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":2514
 * 
 *     def __init__(self, matchString):
 *         super(CaselessLiteral, self).__init__(matchString.upper())             # <<<<<<<<<<<<<<
 *         # Preserve the defining literal.
 *         self.returnString = matchString
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_CaselessLiteral); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_matchString, __pyx_n_s_upper); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2514, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2514, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2514, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2514, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2514, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2514, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2514, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2516
 *         super(CaselessLiteral, self).__init__(matchString.upper())
 *         # Preserve the defining literal.
 *         self.returnString = matchString             # <<<<<<<<<<<<<<
 *         self.name = "'%s'" % self.returnString
 *         self.errmsg = "Expected " + self.name
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_returnString, __pyx_v_matchString) < 0) __PYX_ERR(0, 2516, __pyx_L1_error)

  /* "cPyparsing.pyx":2517
 *         # Preserve the defining literal.
 *         self.returnString = matchString
 *         self.name = "'%s'" % self.returnString             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected " + self.name
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_returnString); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyUnicode_Format(__pyx_kp_u_s_3, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name, __pyx_t_3) < 0) __PYX_ERR(0, 2517, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":2518
 *         self.returnString = matchString
 *         self.name = "'%s'" % self.returnString
 *         self.errmsg = "Expected " + self.name             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyNumber_Add(__pyx_kp_u_Expected, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_1) < 0) __PYX_ERR(0, 2518, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2513
 *     """
 * 
 *     def __init__(self, matchString):             # <<<<<<<<<<<<<<
 *         super(CaselessLiteral, self).__init__(matchString.upper())
 *         # Preserve the defining literal.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.CaselessLiteral.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2520
 *         self.errmsg = "Expected " + self.name
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc:loc + self.matchLen].upper() == self.match:
 *             return loc + self.matchLen, self.returnString
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15CaselessLiteral_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15CaselessLiteral_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_15CaselessLiteral_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_15CaselessLiteral_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 2520, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 2520, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 2520, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2520, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2520, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.CaselessLiteral.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15CaselessLiteral_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15CaselessLiteral_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":2521
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if instring[loc:loc + self.matchLen].upper() == self.match:             # <<<<<<<<<<<<<<
 *             return loc + self.matchLen, self.returnString
 *         raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyNumber_Add(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_instring, __pyx_v_loc, 0, NULL, &__pyx_t_4, NULL, 1, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_upper); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2521, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2521, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2521, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 2521, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":2522
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if instring[loc:loc + self.matchLen].upper() == self.match:
 *             return loc + self.matchLen, self.returnString             # <<<<<<<<<<<<<<
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2522, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2522, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyNumber_Add(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2522, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_returnString); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2522, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2522, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_4);
    __pyx_t_1 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":2521
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if instring[loc:loc + self.matchLen].upper() == self.match:             # <<<<<<<<<<<<<<
 *             return loc + self.matchLen, self.returnString
 *         raise ParseException(instring, loc, self.errmsg, self)
 */
  }

  /* "cPyparsing.pyx":2523
 *         if instring[loc:loc + self.matchLen].upper() == self.match:
 *             return loc + self.matchLen, self.returnString
 *         raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_7 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_4)) {
    PyObject *__pyx_temp[5] = {__pyx_t_6, __pyx_v_instring, __pyx_t_1, __pyx_t_2, __pyx_v_self};
    __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_7, 4+__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2523, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
    PyObject *__pyx_temp[5] = {__pyx_t_6, __pyx_v_instring, __pyx_t_1, __pyx_t_2, __pyx_v_self};
    __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_7, 4+__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2523, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  {
    __pyx_t_8 = PyTuple_New(4+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2523, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__pyx_t_6) {
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6); __pyx_t_6 = NULL;
    }
    __Pyx_INCREF(__pyx_v_instring);
    __Pyx_GIVEREF(__pyx_v_instring);
    PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_v_instring);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_7, __pyx_t_2);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_8, 3+__pyx_t_7, __pyx_v_self);
    __pyx_t_1 = 0;
    __pyx_t_2 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_8, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2523, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __PYX_ERR(0, 2523, __pyx_L1_error)

  /* "cPyparsing.pyx":2520
 *         self.errmsg = "Expected " + self.name
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc:loc + self.matchLen].upper() == self.match:
 *             return loc + self.matchLen, self.returnString
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing.CaselessLiteral.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2536
 *     """
 * 
 *     def __init__(self, matchString, identChars=None):             # <<<<<<<<<<<<<<
 *         super(CaselessKeyword, self).__init__(matchString, identChars, caseless=True)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15CaselessKeyword_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15CaselessKeyword_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_15CaselessKeyword_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_15CaselessKeyword_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_matchString = 0;
  PyObject *__pyx_v_identChars = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_matchString,&__pyx_n_s_identChars,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_matchString)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 2536, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_identChars);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 2536, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_matchString = values[1];
    __pyx_v_identChars = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2536, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.CaselessKeyword.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15CaselessKeyword___init__(__pyx_self, __pyx_v_self, __pyx_v_matchString, __pyx_v_identChars);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15CaselessKeyword___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_matchString, PyObject *__pyx_v_identChars) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":2537
 * 
 *     def __init__(self, matchString, identChars=None):
 *         super(CaselessKeyword, self).__init__(matchString, identChars, caseless=True)             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_CaselessKeyword); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_self);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_matchString);
  __Pyx_GIVEREF(__pyx_v_matchString);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_matchString);
  __Pyx_INCREF(__pyx_v_identChars);
  __Pyx_GIVEREF(__pyx_v_identChars);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_identChars);
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_caseless, Py_True) < 0) __PYX_ERR(0, 2537, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":2536
 *     """
 * 
 *     def __init__(self, matchString, identChars=None):             # <<<<<<<<<<<<<<
 *         super(CaselessKeyword, self).__init__(matchString, identChars, caseless=True)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.CaselessKeyword.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2539
 *         super(CaselessKeyword, self).__init__(matchString, identChars, caseless=True)
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch) and
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen].upper() not in self.identChars)):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15CaselessKeyword_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15CaselessKeyword_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_15CaselessKeyword_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_15CaselessKeyword_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 2539, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 2539, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 2539, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2539, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2539, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.CaselessKeyword.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15CaselessKeyword_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15CaselessKeyword_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":2540
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch) and             # <<<<<<<<<<<<<<
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen].upper() not in self.identChars)):
 *             return loc + self.matchLen, self.match
 */
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyNumber_Add(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_v_instring, __pyx_v_loc, 0, NULL, &__pyx_t_5, NULL, 1, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_upper); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2540, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2540, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_caselessmatch); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_2, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2540, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 2540, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_6) {
  } else {
    __pyx_t_1 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }

  /* "cPyparsing.pyx":2541
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch) and
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen].upper() not in self.identChars)):             # <<<<<<<<<<<<<<
 *             return loc + self.matchLen, self.match
 *         raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 2541, __pyx_L1_error)
  __pyx_t_5 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Subtract(__pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_4, __pyx_t_3, Py_GE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2541, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 2541, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_1 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyNumber_Add(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyObject_GetItem(__pyx_v_instring, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_upper); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2541, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2541, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_identChars); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_t_2, __pyx_t_5, Py_NE)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 2541, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_8 = (__pyx_t_6 != 0);
  __pyx_t_1 = __pyx_t_8;
  __pyx_L4_bool_binop_done:;

  /* "cPyparsing.pyx":2540
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch) and             # <<<<<<<<<<<<<<
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen].upper() not in self.identChars)):
 *             return loc + self.matchLen, self.match
 */
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":2542
 *         if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch) and
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen].upper() not in self.identChars)):
 *             return loc + self.matchLen, self.match             # <<<<<<<<<<<<<<
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2542, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchLen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2542, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyNumber_Add(__pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2542, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2542, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2542, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2);
    __pyx_t_4 = 0;
    __pyx_t_2 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":2540
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch) and             # <<<<<<<<<<<<<<
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen].upper() not in self.identChars)):
 *             return loc + self.matchLen, self.match
 */
  }

  /* "cPyparsing.pyx":2543
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen].upper() not in self.identChars)):
 *             return loc + self.matchLen, self.match
 *         raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = NULL;
  __pyx_t_10 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_10 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[5] = {__pyx_t_9, __pyx_v_instring, __pyx_t_4, __pyx_t_3, __pyx_v_self};
    __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_10, 4+__pyx_t_10); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2543, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[5] = {__pyx_t_9, __pyx_v_instring, __pyx_t_4, __pyx_t_3, __pyx_v_self};
    __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_10, 4+__pyx_t_10); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2543, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  {
    __pyx_t_11 = PyTuple_New(4+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2543, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    if (__pyx_t_9) {
      __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
    }
    __Pyx_INCREF(__pyx_v_instring);
    __Pyx_GIVEREF(__pyx_v_instring);
    PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_v_instring);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_11, 2+__pyx_t_10, __pyx_t_3);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_11, 3+__pyx_t_10, __pyx_v_self);
    __pyx_t_4 = 0;
    __pyx_t_3 = 0;
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_11, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2543, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_Raise(__pyx_t_5, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __PYX_ERR(0, 2543, __pyx_L1_error)

  /* "cPyparsing.pyx":2539
 *         super(CaselessKeyword, self).__init__(matchString, identChars, caseless=True)
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch) and
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen].upper() not in self.identChars)):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("cPyparsing.CaselessKeyword.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2572
 *     """
 * 
 *     def __init__(self, match_string, maxMismatches=1):             # <<<<<<<<<<<<<<
 *         super(CloseMatch, self).__init__()
 *         self.name = match_string
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10CloseMatch_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10CloseMatch_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_10CloseMatch_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10CloseMatch_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_match_string = 0;
  PyObject *__pyx_v_maxMismatches = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_match_string,&__pyx_n_s_maxMismatches,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)__pyx_int_1));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_match_string)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 2572, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_maxMismatches);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 2572, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_match_string = values[1];
    __pyx_v_maxMismatches = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2572, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.CloseMatch.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10CloseMatch___init__(__pyx_self, __pyx_v_self, __pyx_v_match_string, __pyx_v_maxMismatches);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10CloseMatch___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_match_string, PyObject *__pyx_v_maxMismatches) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":2573
 * 
 *     def __init__(self, match_string, maxMismatches=1):
 *         super(CloseMatch, self).__init__()             # <<<<<<<<<<<<<<
 *         self.name = match_string
 *         self.match_string = match_string
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_CloseMatch); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2573, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2573, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2574
 *     def __init__(self, match_string, maxMismatches=1):
 *         super(CloseMatch, self).__init__()
 *         self.name = match_string             # <<<<<<<<<<<<<<
 *         self.match_string = match_string
 *         self.maxMismatches = maxMismatches
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name, __pyx_v_match_string) < 0) __PYX_ERR(0, 2574, __pyx_L1_error)

  /* "cPyparsing.pyx":2575
 *         super(CloseMatch, self).__init__()
 *         self.name = match_string
 *         self.match_string = match_string             # <<<<<<<<<<<<<<
 *         self.maxMismatches = maxMismatches
 *         self.errmsg = "Expected %r (with up to %d mismatches)" % (self.match_string, self.maxMismatches)
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_match_string, __pyx_v_match_string) < 0) __PYX_ERR(0, 2575, __pyx_L1_error)

  /* "cPyparsing.pyx":2576
 *         self.name = match_string
 *         self.match_string = match_string
 *         self.maxMismatches = maxMismatches             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected %r (with up to %d mismatches)" % (self.match_string, self.maxMismatches)
 *         self.mayIndexError = False
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_maxMismatches, __pyx_v_maxMismatches) < 0) __PYX_ERR(0, 2576, __pyx_L1_error)

  /* "cPyparsing.pyx":2577
 *         self.match_string = match_string
 *         self.maxMismatches = maxMismatches
 *         self.errmsg = "Expected %r (with up to %d mismatches)" % (self.match_string, self.maxMismatches)             # <<<<<<<<<<<<<<
 *         self.mayIndexError = False
 *         self.mayReturnEmpty = False
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match_string); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_maxMismatches); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3);
  __pyx_t_1 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = PyUnicode_Format(__pyx_kp_u_Expected_r_with_up_to_d_mismatch, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_3) < 0) __PYX_ERR(0, 2577, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":2578
 *         self.maxMismatches = maxMismatches
 *         self.errmsg = "Expected %r (with up to %d mismatches)" % (self.match_string, self.maxMismatches)
 *         self.mayIndexError = False             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = False
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, Py_False) < 0) __PYX_ERR(0, 2578, __pyx_L1_error)

  /* "cPyparsing.pyx":2579
 *         self.errmsg = "Expected %r (with up to %d mismatches)" % (self.match_string, self.maxMismatches)
 *         self.mayIndexError = False
 *         self.mayReturnEmpty = False             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_False) < 0) __PYX_ERR(0, 2579, __pyx_L1_error)

  /* "cPyparsing.pyx":2572
 *     """
 * 
 *     def __init__(self, match_string, maxMismatches=1):             # <<<<<<<<<<<<<<
 *         super(CloseMatch, self).__init__()
 *         self.name = match_string
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.CloseMatch.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2581
 *         self.mayReturnEmpty = False
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         start = loc
 *         instrlen = len(instring)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10CloseMatch_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10CloseMatch_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_10CloseMatch_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10CloseMatch_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 2581, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 2581, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 2581, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2581, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2581, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.CloseMatch.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10CloseMatch_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10CloseMatch_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  int __pyx_v_start;
  Py_ssize_t __pyx_v_instrlen;
  Py_ssize_t __pyx_v_maxloc;
  CYTHON_UNUSED PyObject *__pyx_v_match_string = NULL;
  PyObject *__pyx_v_match_stringloc = NULL;
  PyObject *__pyx_v_mismatches = NULL;
  PyObject *__pyx_v_maxMismatches = NULL;
  PyObject *__pyx_v_s_m = NULL;
  PyObject *__pyx_v_src = NULL;
  PyObject *__pyx_v_mat = NULL;
  PyObject *__pyx_v_results = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  PyObject *__pyx_t_10 = NULL;
  PyObject *(*__pyx_t_11)(PyObject *);
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":2582
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         start = loc             # <<<<<<<<<<<<<<
 *         instrlen = len(instring)
 *         maxloc = start + len(self.match_string)
 */
  __pyx_v_start = __pyx_v_loc;

  /* "cPyparsing.pyx":2583
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         start = loc
 *         instrlen = len(instring)             # <<<<<<<<<<<<<<
 *         maxloc = start + len(self.match_string)
 * 
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 2583, __pyx_L1_error)
  __pyx_v_instrlen = __pyx_t_1;

  /* "cPyparsing.pyx":2584
 *         start = loc
 *         instrlen = len(instring)
 *         maxloc = start + len(self.match_string)             # <<<<<<<<<<<<<<
 * 
 *         if maxloc <= instrlen:
 */
  __pyx_t_2 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match_string); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 2584, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_4 = __Pyx_add_Py_ssize_t_checking_overflow(__pyx_v_start, __pyx_t_1, &__pyx_t_2);
  if (unlikely(__pyx_t_2)) {
    PyErr_SetString(PyExc_OverflowError, "value too large");
    __PYX_ERR(0, 2584, __pyx_L1_error)
  }
  __pyx_v_maxloc = __pyx_t_4;

  /* "cPyparsing.pyx":2586
 *         maxloc = start + len(self.match_string)
 * 
 *         if maxloc <= instrlen:             # <<<<<<<<<<<<<<
 *             match_string = self.match_string
 *             match_stringloc = 0
 */
  __pyx_t_5 = ((__pyx_v_maxloc <= __pyx_v_instrlen) != 0);
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":2587
 * 
 *         if maxloc <= instrlen:
 *             match_string = self.match_string             # <<<<<<<<<<<<<<
 *             match_stringloc = 0
 *             mismatches = []
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match_string); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2587, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_match_string = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":2588
 *         if maxloc <= instrlen:
 *             match_string = self.match_string
 *             match_stringloc = 0             # <<<<<<<<<<<<<<
 *             mismatches = []
 *             maxMismatches = self.maxMismatches
 */
    __Pyx_INCREF(__pyx_int_0);
    __pyx_v_match_stringloc = __pyx_int_0;

    /* "cPyparsing.pyx":2589
 *             match_string = self.match_string
 *             match_stringloc = 0
 *             mismatches = []             # <<<<<<<<<<<<<<
 *             maxMismatches = self.maxMismatches
 * 
 */
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_mismatches = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":2590
 *             match_stringloc = 0
 *             mismatches = []
 *             maxMismatches = self.maxMismatches             # <<<<<<<<<<<<<<
 * 
 *             for match_stringloc, s_m in enumerate(zip(instring[loc:maxloc], self.match_string)):
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_maxMismatches); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2590, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_maxMismatches = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":2592
 *             maxMismatches = self.maxMismatches
 * 
 *             for match_stringloc, s_m in enumerate(zip(instring[loc:maxloc], self.match_string)):             # <<<<<<<<<<<<<<
 *                 src, mat = s_m
 *                 if src != mat:
 */
    __Pyx_INCREF(__pyx_int_0);
    __pyx_t_3 = __pyx_int_0;
    __pyx_t_6 = __Pyx_PyObject_GetSlice(__pyx_v_instring, __pyx_v_loc, __pyx_v_maxloc, NULL, NULL, NULL, 1, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2592, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match_string); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2592, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2592, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_7);
    __pyx_t_6 = 0;
    __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_zip, __pyx_t_8, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2592, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (likely(PyList_CheckExact(__pyx_t_7)) || PyTuple_CheckExact(__pyx_t_7)) {
      __pyx_t_8 = __pyx_t_7; __Pyx_INCREF(__pyx_t_8); __pyx_t_4 = 0;
      __pyx_t_9 = NULL;
    } else {
      __pyx_t_4 = -1; __pyx_t_8 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2592, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = Py_TYPE(__pyx_t_8)->tp_iternext; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2592, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    for (;;) {
      if (likely(!__pyx_t_9)) {
        if (likely(PyList_CheckExact(__pyx_t_8))) {
          if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_8)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_7 = PyList_GET_ITEM(__pyx_t_8, __pyx_t_4); __Pyx_INCREF(__pyx_t_7); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 2592, __pyx_L1_error)
          #else
          __pyx_t_7 = PySequence_ITEM(__pyx_t_8, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2592, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          #endif
        } else {
          if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_8)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_8, __pyx_t_4); __Pyx_INCREF(__pyx_t_7); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 2592, __pyx_L1_error)
          #else
          __pyx_t_7 = PySequence_ITEM(__pyx_t_8, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2592, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          #endif
        }
      } else {
        __pyx_t_7 = __pyx_t_9(__pyx_t_8);
        if (unlikely(!__pyx_t_7)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 2592, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_7);
      }
      __Pyx_XDECREF_SET(__pyx_v_s_m, __pyx_t_7);
      __pyx_t_7 = 0;
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_DECREF_SET(__pyx_v_match_stringloc, __pyx_t_3);
      __pyx_t_7 = __Pyx_PyInt_AddObjC(__pyx_t_3, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2592, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_3);
      __pyx_t_3 = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "cPyparsing.pyx":2593
 * 
 *             for match_stringloc, s_m in enumerate(zip(instring[loc:maxloc], self.match_string)):
 *                 src, mat = s_m             # <<<<<<<<<<<<<<
 *                 if src != mat:
 *                     mismatches.append(match_stringloc)
 */
      if ((likely(PyTuple_CheckExact(__pyx_v_s_m))) || (PyList_CheckExact(__pyx_v_s_m))) {
        PyObject* sequence = __pyx_v_s_m;
        #if !CYTHON_COMPILING_IN_PYPY
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 2593, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_7 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_7 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_6);
        #else
        __pyx_t_7 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2593, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2593, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
      } else {
        Py_ssize_t index = -1;
        __pyx_t_10 = PyObject_GetIter(__pyx_v_s_m); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2593, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_11 = Py_TYPE(__pyx_t_10)->tp_iternext;
        index = 0; __pyx_t_7 = __pyx_t_11(__pyx_t_10); if (unlikely(!__pyx_t_7)) goto __pyx_L6_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_7);
        index = 1; __pyx_t_6 = __pyx_t_11(__pyx_t_10); if (unlikely(!__pyx_t_6)) goto __pyx_L6_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_6);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_11(__pyx_t_10), 2) < 0) __PYX_ERR(0, 2593, __pyx_L1_error)
        __pyx_t_11 = NULL;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        goto __pyx_L7_unpacking_done;
        __pyx_L6_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_11 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 2593, __pyx_L1_error)
        __pyx_L7_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_src, __pyx_t_7);
      __pyx_t_7 = 0;
      __Pyx_XDECREF_SET(__pyx_v_mat, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "cPyparsing.pyx":2594
 *             for match_stringloc, s_m in enumerate(zip(instring[loc:maxloc], self.match_string)):
 *                 src, mat = s_m
 *                 if src != mat:             # <<<<<<<<<<<<<<
 *                     mismatches.append(match_stringloc)
 *                     if len(mismatches) > maxMismatches:
 */
      __pyx_t_6 = PyObject_RichCompare(__pyx_v_src, __pyx_v_mat, Py_NE); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2594, __pyx_L1_error)
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 2594, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (__pyx_t_5) {

        /* "cPyparsing.pyx":2595
 *                 src, mat = s_m
 *                 if src != mat:
 *                     mismatches.append(match_stringloc)             # <<<<<<<<<<<<<<
 *                     if len(mismatches) > maxMismatches:
 *                         break
 */
        __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_mismatches, __pyx_v_match_stringloc); if (unlikely(__pyx_t_12 == -1)) __PYX_ERR(0, 2595, __pyx_L1_error)

        /* "cPyparsing.pyx":2596
 *                 if src != mat:
 *                     mismatches.append(match_stringloc)
 *                     if len(mismatches) > maxMismatches:             # <<<<<<<<<<<<<<
 *                         break
 *             else:
 */
        __pyx_t_1 = PyList_GET_SIZE(__pyx_v_mismatches); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 2596, __pyx_L1_error)
        __pyx_t_6 = PyInt_FromSsize_t(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2596, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = PyObject_RichCompare(__pyx_t_6, __pyx_v_maxMismatches, Py_GT); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2596, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 2596, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (__pyx_t_5) {

          /* "cPyparsing.pyx":2597
 *                     mismatches.append(match_stringloc)
 *                     if len(mismatches) > maxMismatches:
 *                         break             # <<<<<<<<<<<<<<
 *             else:
 *                 loc = match_stringloc + 1
 */
          goto __pyx_L5_break;

          /* "cPyparsing.pyx":2596
 *                 if src != mat:
 *                     mismatches.append(match_stringloc)
 *                     if len(mismatches) > maxMismatches:             # <<<<<<<<<<<<<<
 *                         break
 *             else:
 */
        }

        /* "cPyparsing.pyx":2594
 *             for match_stringloc, s_m in enumerate(zip(instring[loc:maxloc], self.match_string)):
 *                 src, mat = s_m
 *                 if src != mat:             # <<<<<<<<<<<<<<
 *                     mismatches.append(match_stringloc)
 *                     if len(mismatches) > maxMismatches:
 */
      }

      /* "cPyparsing.pyx":2592
 *             maxMismatches = self.maxMismatches
 * 
 *             for match_stringloc, s_m in enumerate(zip(instring[loc:maxloc], self.match_string)):             # <<<<<<<<<<<<<<
 *                 src, mat = s_m
 *                 if src != mat:
 */
    }
    /*else*/ {

      /* "cPyparsing.pyx":2599
 *                         break
 *             else:
 *                 loc = match_stringloc + 1             # <<<<<<<<<<<<<<
 *                 results = ParseResults([instring[start:loc]])
 *                 results['original'] = self.match_string
 */
      __pyx_t_7 = __Pyx_PyInt_AddObjC(__pyx_v_match_stringloc, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2599, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_7); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2599, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_v_loc = __pyx_t_2;

      /* "cPyparsing.pyx":2600
 *             else:
 *                 loc = match_stringloc + 1
 *                 results = ParseResults([instring[start:loc]])             # <<<<<<<<<<<<<<
 *                 results['original'] = self.match_string
 *                 results['mismatches'] = mismatches
 */
      __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2600, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_10 = __Pyx_PyObject_GetSlice(__pyx_v_instring, __pyx_v_start, __pyx_v_loc, NULL, NULL, NULL, 1, 1, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2600, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_13 = PyList_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2600, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_GIVEREF(__pyx_t_10);
      PyList_SET_ITEM(__pyx_t_13, 0, __pyx_t_10);
      __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      if (!__pyx_t_10) {
        __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_13); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2600, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_GOTREF(__pyx_t_7);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_13};
          __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2600, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_13};
          __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2600, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        } else
        #endif
        {
          __pyx_t_14 = PyTuple_New(1+1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 2600, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_10); __pyx_t_10 = NULL;
          __Pyx_GIVEREF(__pyx_t_13);
          PyTuple_SET_ITEM(__pyx_t_14, 0+1, __pyx_t_13);
          __pyx_t_13 = 0;
          __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_14, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2600, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_results = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "cPyparsing.pyx":2601
 *                 loc = match_stringloc + 1
 *                 results = ParseResults([instring[start:loc]])
 *                 results['original'] = self.match_string             # <<<<<<<<<<<<<<
 *                 results['mismatches'] = mismatches
 *                 return loc, results
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_match_string); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2601, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (unlikely(PyObject_SetItem(__pyx_v_results, __pyx_n_u_original, __pyx_t_7) < 0)) __PYX_ERR(0, 2601, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "cPyparsing.pyx":2602
 *                 results = ParseResults([instring[start:loc]])
 *                 results['original'] = self.match_string
 *                 results['mismatches'] = mismatches             # <<<<<<<<<<<<<<
 *                 return loc, results
 * 
 */
      if (unlikely(PyObject_SetItem(__pyx_v_results, __pyx_n_u_mismatches, __pyx_v_mismatches) < 0)) __PYX_ERR(0, 2602, __pyx_L1_error)

      /* "cPyparsing.pyx":2603
 *                 results['original'] = self.match_string
 *                 results['mismatches'] = mismatches
 *                 return loc, results             # <<<<<<<<<<<<<<
 * 
 *         raise ParseException(instring, loc, self.errmsg, self)
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2603, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2603, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_7);
      __Pyx_INCREF(__pyx_v_results);
      __Pyx_GIVEREF(__pyx_v_results);
      PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_results);
      __pyx_t_7 = 0;
      __pyx_r = __pyx_t_6;
      __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L0;
    }

    /* "cPyparsing.pyx":2592
 *             maxMismatches = self.maxMismatches
 * 
 *             for match_stringloc, s_m in enumerate(zip(instring[loc:maxloc], self.match_string)):             # <<<<<<<<<<<<<<
 *                 src, mat = s_m
 *                 if src != mat:
 */
    __pyx_L5_break:;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":2586
 *         maxloc = start + len(self.match_string)
 * 
 *         if maxloc <= instrlen:             # <<<<<<<<<<<<<<
 *             match_string = self.match_string
 *             match_stringloc = 0
 */
  }

  /* "cPyparsing.pyx":2605
 *                 return loc, results
 * 
 *         raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_14 = NULL;
  __pyx_t_2 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_14)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_14);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
      __pyx_t_2 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_8)) {
    PyObject *__pyx_temp[5] = {__pyx_t_14, __pyx_v_instring, __pyx_t_6, __pyx_t_7, __pyx_v_self};
    __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_2, 4+__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2605, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
    PyObject *__pyx_temp[5] = {__pyx_t_14, __pyx_v_instring, __pyx_t_6, __pyx_t_7, __pyx_v_self};
    __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_2, 4+__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2605, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  } else
  #endif
  {
    __pyx_t_13 = PyTuple_New(4+__pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2605, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    if (__pyx_t_14) {
      __Pyx_GIVEREF(__pyx_t_14); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_14); __pyx_t_14 = NULL;
    }
    __Pyx_INCREF(__pyx_v_instring);
    __Pyx_GIVEREF(__pyx_v_instring);
    PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_2, __pyx_v_instring);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_2, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_13, 2+__pyx_t_2, __pyx_t_7);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_13, 3+__pyx_t_2, __pyx_v_self);
    __pyx_t_6 = 0;
    __pyx_t_7 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_13, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2605, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  }
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __PYX_ERR(0, 2605, __pyx_L1_error)

  /* "cPyparsing.pyx":2581
 *         self.mayReturnEmpty = False
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         start = loc
 *         instrlen = len(instring)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("cPyparsing.CloseMatch.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_match_string);
  __Pyx_XDECREF(__pyx_v_match_stringloc);
  __Pyx_XDECREF(__pyx_v_mismatches);
  __Pyx_XDECREF(__pyx_v_maxMismatches);
  __Pyx_XDECREF(__pyx_v_s_m);
  __Pyx_XDECREF(__pyx_v_src);
  __Pyx_XDECREF(__pyx_v_mat);
  __Pyx_XDECREF(__pyx_v_results);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2656
 *     """
 * 
 *     def __init__(self, initChars, bodyChars=None, min=1, max=0, exact=0, asKeyword=False, excludeChars=None):             # <<<<<<<<<<<<<<
 *         super(Word, self).__init__()
 *         if excludeChars:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_4Word_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_4Word_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_4Word_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_4Word_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_initChars = 0;
  PyObject *__pyx_v_bodyChars = 0;
  PyObject *__pyx_v_min = 0;
  PyObject *__pyx_v_max = 0;
  PyObject *__pyx_v_exact = 0;
  PyObject *__pyx_v_asKeyword = 0;
  PyObject *__pyx_v_excludeChars = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_initChars,&__pyx_n_s_bodyChars,&__pyx_n_s_min,&__pyx_n_s_max,&__pyx_n_s_exact,&__pyx_n_s_asKeyword,&__pyx_n_s_excludeChars,0};
    PyObject* values[8] = {0,0,0,0,0,0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_None));
    values[3] = ((PyObject *)((PyObject *)__pyx_int_1));
    values[4] = ((PyObject *)((PyObject *)__pyx_int_0));
    values[5] = ((PyObject *)((PyObject *)__pyx_int_0));
    values[6] = ((PyObject *)((PyObject *)Py_False));
    values[7] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_initChars)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 8, 1); __PYX_ERR(0, 2656, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_bodyChars);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_min);
          if (value) { values[3] = value; kw_args--; }
        }
        case  4:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_max);
          if (value) { values[4] = value; kw_args--; }
        }
        case  5:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_exact);
          if (value) { values[5] = value; kw_args--; }
        }
        case  6:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_asKeyword);
          if (value) { values[6] = value; kw_args--; }
        }
        case  7:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_excludeChars);
          if (value) { values[7] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 2656, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_initChars = values[1];
    __pyx_v_bodyChars = values[2];
    __pyx_v_min = values[3];
    __pyx_v_max = values[4];
    __pyx_v_exact = values[5];
    __pyx_v_asKeyword = values[6];
    __pyx_v_excludeChars = values[7];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 8, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2656, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Word.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_4Word___init__(__pyx_self, __pyx_v_self, __pyx_v_initChars, __pyx_v_bodyChars, __pyx_v_min, __pyx_v_max, __pyx_v_exact, __pyx_v_asKeyword, __pyx_v_excludeChars);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_4Word_8__init___2generator12(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":2659
 *         super(Word, self).__init__()
 *         if excludeChars:
 *             initChars = ''.join(c for c in initChars if c not in excludeChars)             # <<<<<<<<<<<<<<
 *             if bodyChars:
 *                 bodyChars = ''.join(c for c in bodyChars if c not in excludeChars)
 */

static PyObject *__pyx_pf_10cPyparsing_4Word_8__init___genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_27_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_27_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 2659, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_26___init__ *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_4Word_8__init___2generator12, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_Word___init___locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 2659, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.Word.__init__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_4Word_8__init___2generator12(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 2659, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 2659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_initChars)) { __Pyx_RaiseClosureNameError("initChars"); __PYX_ERR(0, 2659, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_initChars)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_initChars)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_outer_scope->__pyx_v_initChars; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_initChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2659, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2659, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 2659, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2659, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 2659, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2659, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 2659, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_c);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_c, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_excludeChars)) { __Pyx_RaiseClosureNameError("excludeChars"); __PYX_ERR(0, 2659, __pyx_L1_error) }
    __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_cur_scope->__pyx_v_c, __pyx_cur_scope->__pyx_outer_scope->__pyx_v_excludeChars, Py_NE)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 2659, __pyx_L1_error)
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {
      if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_cur_scope->__pyx_v_c))) __PYX_ERR(0, 2659, __pyx_L1_error)
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_4Word_8__init___5generator13(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":2661
 *             initChars = ''.join(c for c in initChars if c not in excludeChars)
 *             if bodyChars:
 *                 bodyChars = ''.join(c for c in bodyChars if c not in excludeChars)             # <<<<<<<<<<<<<<
 *         self.initCharsOrig = initChars
 *         self.initChars = set(initChars)
 */

static PyObject *__pyx_pf_10cPyparsing_4Word_8__init___3genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_28_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_28_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_28_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_28_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_28_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 2661, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_26___init__ *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_4Word_8__init___5generator13, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_Word___init___locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 2661, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.Word.__init__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_4Word_8__init___5generator13(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_28_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_28_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 2661, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 2661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_bodyChars)) { __Pyx_RaiseClosureNameError("bodyChars"); __PYX_ERR(0, 2661, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_bodyChars)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_bodyChars)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_outer_scope->__pyx_v_bodyChars; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_bodyChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2661, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2661, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 2661, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2661, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 2661, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2661, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 2661, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_c);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_c, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_excludeChars)) { __Pyx_RaiseClosureNameError("excludeChars"); __PYX_ERR(0, 2661, __pyx_L1_error) }
    __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_cur_scope->__pyx_v_c, __pyx_cur_scope->__pyx_outer_scope->__pyx_v_excludeChars, Py_NE)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 2661, __pyx_L1_error)
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {
      if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_cur_scope->__pyx_v_c))) __PYX_ERR(0, 2661, __pyx_L1_error)
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2656
 *     """
 * 
 *     def __init__(self, initChars, bodyChars=None, min=1, max=0, exact=0, asKeyword=False, excludeChars=None):             # <<<<<<<<<<<<<<
 *         super(Word, self).__init__()
 *         if excludeChars:
 */

static PyObject *__pyx_pf_10cPyparsing_4Word___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_initChars, PyObject *__pyx_v_bodyChars, PyObject *__pyx_v_min, PyObject *__pyx_v_max, PyObject *__pyx_v_exact, PyObject *__pyx_v_asKeyword, PyObject *__pyx_v_excludeChars) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_26___init__ *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  Py_ssize_t __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  __Pyx_RefNannySetupContext("__init__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_26___init__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_26___init__(__pyx_ptype_10cPyparsing___pyx_scope_struct_26___init__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_26___init__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 2656, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_initChars = __pyx_v_initChars;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_initChars);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_initChars);
  __pyx_cur_scope->__pyx_v_bodyChars = __pyx_v_bodyChars;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_bodyChars);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_bodyChars);
  __pyx_cur_scope->__pyx_v_excludeChars = __pyx_v_excludeChars;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_excludeChars);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_excludeChars);

  /* "cPyparsing.pyx":2657
 * 
 *     def __init__(self, initChars, bodyChars=None, min=1, max=0, exact=0, asKeyword=False, excludeChars=None):
 *         super(Word, self).__init__()             # <<<<<<<<<<<<<<
 *         if excludeChars:
 *             initChars = ''.join(c for c in initChars if c not in excludeChars)
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Word); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2657, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2657, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2658
 *     def __init__(self, initChars, bodyChars=None, min=1, max=0, exact=0, asKeyword=False, excludeChars=None):
 *         super(Word, self).__init__()
 *         if excludeChars:             # <<<<<<<<<<<<<<
 *             initChars = ''.join(c for c in initChars if c not in excludeChars)
 *             if bodyChars:
 */
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_excludeChars); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 2658, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":2659
 *         super(Word, self).__init__()
 *         if excludeChars:
 *             initChars = ''.join(c for c in initChars if c not in excludeChars)             # <<<<<<<<<<<<<<
 *             if bodyChars:
 *                 bodyChars = ''.join(c for c in bodyChars if c not in excludeChars)
 */
    __pyx_t_1 = __pyx_pf_10cPyparsing_4Word_8__init___genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2659, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2659, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__9, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2659, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_initChars);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_initChars, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2660
 *         if excludeChars:
 *             initChars = ''.join(c for c in initChars if c not in excludeChars)
 *             if bodyChars:             # <<<<<<<<<<<<<<
 *                 bodyChars = ''.join(c for c in bodyChars if c not in excludeChars)
 *         self.initCharsOrig = initChars
 */
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_bodyChars); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 2660, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "cPyparsing.pyx":2661
 *             initChars = ''.join(c for c in initChars if c not in excludeChars)
 *             if bodyChars:
 *                 bodyChars = ''.join(c for c in bodyChars if c not in excludeChars)             # <<<<<<<<<<<<<<
 *         self.initCharsOrig = initChars
 *         self.initChars = set(initChars)
 */
      __pyx_t_1 = __pyx_pf_10cPyparsing_4Word_8__init___3genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2661, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2661, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__9, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2661, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_bodyChars);
      __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_bodyChars, __pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_1);
      __pyx_t_1 = 0;

      /* "cPyparsing.pyx":2660
 *         if excludeChars:
 *             initChars = ''.join(c for c in initChars if c not in excludeChars)
 *             if bodyChars:             # <<<<<<<<<<<<<<
 *                 bodyChars = ''.join(c for c in bodyChars if c not in excludeChars)
 *         self.initCharsOrig = initChars
 */
    }

    /* "cPyparsing.pyx":2658
 *     def __init__(self, initChars, bodyChars=None, min=1, max=0, exact=0, asKeyword=False, excludeChars=None):
 *         super(Word, self).__init__()
 *         if excludeChars:             # <<<<<<<<<<<<<<
 *             initChars = ''.join(c for c in initChars if c not in excludeChars)
 *             if bodyChars:
 */
  }

  /* "cPyparsing.pyx":2662
 *             if bodyChars:
 *                 bodyChars = ''.join(c for c in bodyChars if c not in excludeChars)
 *         self.initCharsOrig = initChars             # <<<<<<<<<<<<<<
 *         self.initChars = set(initChars)
 *         if bodyChars:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_initCharsOrig, __pyx_cur_scope->__pyx_v_initChars) < 0) __PYX_ERR(0, 2662, __pyx_L1_error)

  /* "cPyparsing.pyx":2663
 *                 bodyChars = ''.join(c for c in bodyChars if c not in excludeChars)
 *         self.initCharsOrig = initChars
 *         self.initChars = set(initChars)             # <<<<<<<<<<<<<<
 *         if bodyChars:
 *             self.bodyCharsOrig = bodyChars
 */
  __pyx_t_1 = PySet_New(__pyx_cur_scope->__pyx_v_initChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_initChars, __pyx_t_1) < 0) __PYX_ERR(0, 2663, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2664
 *         self.initCharsOrig = initChars
 *         self.initChars = set(initChars)
 *         if bodyChars:             # <<<<<<<<<<<<<<
 *             self.bodyCharsOrig = bodyChars
 *             self.bodyChars = set(bodyChars)
 */
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_bodyChars); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 2664, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":2665
 *         self.initChars = set(initChars)
 *         if bodyChars:
 *             self.bodyCharsOrig = bodyChars             # <<<<<<<<<<<<<<
 *             self.bodyChars = set(bodyChars)
 *         else:
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_bodyCharsOrig, __pyx_cur_scope->__pyx_v_bodyChars) < 0) __PYX_ERR(0, 2665, __pyx_L1_error)

    /* "cPyparsing.pyx":2666
 *         if bodyChars:
 *             self.bodyCharsOrig = bodyChars
 *             self.bodyChars = set(bodyChars)             # <<<<<<<<<<<<<<
 *         else:
 *             self.bodyCharsOrig = initChars
 */
    __pyx_t_1 = PySet_New(__pyx_cur_scope->__pyx_v_bodyChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2666, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_bodyChars, __pyx_t_1) < 0) __PYX_ERR(0, 2666, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2664
 *         self.initCharsOrig = initChars
 *         self.initChars = set(initChars)
 *         if bodyChars:             # <<<<<<<<<<<<<<
 *             self.bodyCharsOrig = bodyChars
 *             self.bodyChars = set(bodyChars)
 */
    goto __pyx_L5;
  }

  /* "cPyparsing.pyx":2668
 *             self.bodyChars = set(bodyChars)
 *         else:
 *             self.bodyCharsOrig = initChars             # <<<<<<<<<<<<<<
 *             self.bodyChars = set(initChars)
 * 
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_bodyCharsOrig, __pyx_cur_scope->__pyx_v_initChars) < 0) __PYX_ERR(0, 2668, __pyx_L1_error)

    /* "cPyparsing.pyx":2669
 *         else:
 *             self.bodyCharsOrig = initChars
 *             self.bodyChars = set(initChars)             # <<<<<<<<<<<<<<
 * 
 *         self.maxSpecified = max > 0
 */
    __pyx_t_1 = PySet_New(__pyx_cur_scope->__pyx_v_initChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2669, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_bodyChars, __pyx_t_1) < 0) __PYX_ERR(0, 2669, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L5:;

  /* "cPyparsing.pyx":2671
 *             self.bodyChars = set(initChars)
 * 
 *         self.maxSpecified = max > 0             # <<<<<<<<<<<<<<
 * 
 *         if min < 1:
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_max, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2671, __pyx_L1_error)
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_maxSpecified, __pyx_t_1) < 0) __PYX_ERR(0, 2671, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2673
 *         self.maxSpecified = max > 0
 * 
 *         if min < 1:             # <<<<<<<<<<<<<<
 *             raise ValueError("cannot specify a minimum length < 1; use Optional(Word()) if zero-length word is permitted")
 * 
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_min, __pyx_int_1, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2673, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 2673, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":2674
 * 
 *         if min < 1:
 *             raise ValueError("cannot specify a minimum length < 1; use Optional(Word()) if zero-length word is permitted")             # <<<<<<<<<<<<<<
 * 
 *         self.minLen = min
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__86, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2674, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 2674, __pyx_L1_error)

    /* "cPyparsing.pyx":2673
 *         self.maxSpecified = max > 0
 * 
 *         if min < 1:             # <<<<<<<<<<<<<<
 *             raise ValueError("cannot specify a minimum length < 1; use Optional(Word()) if zero-length word is permitted")
 * 
 */
  }

  /* "cPyparsing.pyx":2676
 *             raise ValueError("cannot specify a minimum length < 1; use Optional(Word()) if zero-length word is permitted")
 * 
 *         self.minLen = min             # <<<<<<<<<<<<<<
 * 
 *         if max > 0:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_minLen, __pyx_v_min) < 0) __PYX_ERR(0, 2676, __pyx_L1_error)

  /* "cPyparsing.pyx":2678
 *         self.minLen = min
 * 
 *         if max > 0:             # <<<<<<<<<<<<<<
 *             self.maxLen = max
 *         else:
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_max, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2678, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 2678, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":2679
 * 
 *         if max > 0:
 *             self.maxLen = max             # <<<<<<<<<<<<<<
 *         else:
 *             self.maxLen = _MAX_INT
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_maxLen, __pyx_v_max) < 0) __PYX_ERR(0, 2679, __pyx_L1_error)

    /* "cPyparsing.pyx":2678
 *         self.minLen = min
 * 
 *         if max > 0:             # <<<<<<<<<<<<<<
 *             self.maxLen = max
 *         else:
 */
    goto __pyx_L7;
  }

  /* "cPyparsing.pyx":2681
 *             self.maxLen = max
 *         else:
 *             self.maxLen = _MAX_INT             # <<<<<<<<<<<<<<
 * 
 *         if exact > 0:
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_MAX_INT); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_maxLen, __pyx_t_1) < 0) __PYX_ERR(0, 2681, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L7:;

  /* "cPyparsing.pyx":2683
 *             self.maxLen = _MAX_INT
 * 
 *         if exact > 0:             # <<<<<<<<<<<<<<
 *             self.maxLen = exact
 *             self.minLen = exact
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_exact, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2683, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 2683, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":2684
 * 
 *         if exact > 0:
 *             self.maxLen = exact             # <<<<<<<<<<<<<<
 *             self.minLen = exact
 * 
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_maxLen, __pyx_v_exact) < 0) __PYX_ERR(0, 2684, __pyx_L1_error)

    /* "cPyparsing.pyx":2685
 *         if exact > 0:
 *             self.maxLen = exact
 *             self.minLen = exact             # <<<<<<<<<<<<<<
 * 
 *         self.name = _ustr(self)
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_minLen, __pyx_v_exact) < 0) __PYX_ERR(0, 2685, __pyx_L1_error)

    /* "cPyparsing.pyx":2683
 *             self.maxLen = _MAX_INT
 * 
 *         if exact > 0:             # <<<<<<<<<<<<<<
 *             self.maxLen = exact
 *             self.minLen = exact
 */
  }

  /* "cPyparsing.pyx":2687
 *             self.minLen = exact
 * 
 *         self.name = _ustr(self)             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected " + self.name
 *         self.mayIndexError = False
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2687, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2687, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2687, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2687, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_self);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2687, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name, __pyx_t_1) < 0) __PYX_ERR(0, 2687, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2688
 * 
 *         self.name = _ustr(self)
 *         self.errmsg = "Expected " + self.name             # <<<<<<<<<<<<<<
 *         self.mayIndexError = False
 *         self.asKeyword = asKeyword
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyNumber_Add(__pyx_kp_u_Expected, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_3) < 0) __PYX_ERR(0, 2688, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":2689
 *         self.name = _ustr(self)
 *         self.errmsg = "Expected " + self.name
 *         self.mayIndexError = False             # <<<<<<<<<<<<<<
 *         self.asKeyword = asKeyword
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, Py_False) < 0) __PYX_ERR(0, 2689, __pyx_L1_error)

  /* "cPyparsing.pyx":2690
 *         self.errmsg = "Expected " + self.name
 *         self.mayIndexError = False
 *         self.asKeyword = asKeyword             # <<<<<<<<<<<<<<
 * 
 *         if ' ' not in self.initCharsOrig + self.bodyCharsOrig and (min == 1 and max == 0 and exact == 0):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_asKeyword, __pyx_v_asKeyword) < 0) __PYX_ERR(0, 2690, __pyx_L1_error)

  /* "cPyparsing.pyx":2692
 *         self.asKeyword = asKeyword
 * 
 *         if ' ' not in self.initCharsOrig + self.bodyCharsOrig and (min == 1 and max == 0 and exact == 0):             # <<<<<<<<<<<<<<
 *             if self.bodyCharsOrig == self.initCharsOrig:
 *                 self.reString = "[%s]+" % _escapeRegexRangeChars(self.initCharsOrig)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_initCharsOrig); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_bodyCharsOrig); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyNumber_Add(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u__84, __pyx_t_5, Py_NE)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 2692, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (__pyx_t_7) {
  } else {
    __pyx_t_4 = __pyx_t_7;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyInt_EqObjC(__pyx_v_min, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 2692, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_7) {
  } else {
    __pyx_t_4 = __pyx_t_7;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyInt_EqObjC(__pyx_v_max, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 2692, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_7) {
  } else {
    __pyx_t_4 = __pyx_t_7;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyInt_EqObjC(__pyx_v_exact, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 2692, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_4 = __pyx_t_7;
  __pyx_L10_bool_binop_done:;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":2693
 * 
 *         if ' ' not in self.initCharsOrig + self.bodyCharsOrig and (min == 1 and max == 0 and exact == 0):
 *             if self.bodyCharsOrig == self.initCharsOrig:             # <<<<<<<<<<<<<<
 *                 self.reString = "[%s]+" % _escapeRegexRangeChars(self.initCharsOrig)
 *             elif len(self.initCharsOrig) == 1:
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_bodyCharsOrig); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2693, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_initCharsOrig); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2693, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_5, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2693, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 2693, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_4) {

      /* "cPyparsing.pyx":2694
 *         if ' ' not in self.initCharsOrig + self.bodyCharsOrig and (min == 1 and max == 0 and exact == 0):
 *             if self.bodyCharsOrig == self.initCharsOrig:
 *                 self.reString = "[%s]+" % _escapeRegexRangeChars(self.initCharsOrig)             # <<<<<<<<<<<<<<
 *             elif len(self.initCharsOrig) == 1:
 *                 self.reString = "%s[%s]*" % \
 */
      __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_escapeRegexRangeChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2694, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_initCharsOrig); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2694, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_2 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      if (!__pyx_t_2) {
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2694, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_1)) {
          PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_5};
          __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2694, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
          PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_5};
          __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2694, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        {
          __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2694, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_2); __pyx_t_2 = NULL;
          __Pyx_GIVEREF(__pyx_t_5);
          PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_5);
          __pyx_t_5 = 0;
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_8, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2694, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyUnicode_Format(__pyx_kp_u_s_4, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2694, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_reString, __pyx_t_1) < 0) __PYX_ERR(0, 2694, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":2693
 * 
 *         if ' ' not in self.initCharsOrig + self.bodyCharsOrig and (min == 1 and max == 0 and exact == 0):
 *             if self.bodyCharsOrig == self.initCharsOrig:             # <<<<<<<<<<<<<<
 *                 self.reString = "[%s]+" % _escapeRegexRangeChars(self.initCharsOrig)
 *             elif len(self.initCharsOrig) == 1:
 */
      goto __pyx_L14;
    }

    /* "cPyparsing.pyx":2695
 *             if self.bodyCharsOrig == self.initCharsOrig:
 *                 self.reString = "[%s]+" % _escapeRegexRangeChars(self.initCharsOrig)
 *             elif len(self.initCharsOrig) == 1:             # <<<<<<<<<<<<<<
 *                 self.reString = "%s[%s]*" % \
 *                     (re.escape(self.initCharsOrig),
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_initCharsOrig); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2695, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_9 == -1)) __PYX_ERR(0, 2695, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_4 = ((__pyx_t_9 == 1) != 0);
    if (__pyx_t_4) {

      /* "cPyparsing.pyx":2697
 *             elif len(self.initCharsOrig) == 1:
 *                 self.reString = "%s[%s]*" % \
 *                     (re.escape(self.initCharsOrig),             # <<<<<<<<<<<<<<
 *                      _escapeRegexRangeChars(self.bodyCharsOrig),)
 *             else:
 */
      __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_re); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2697, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_escape); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2697, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_initCharsOrig); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2697, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      if (!__pyx_t_5) {
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2697, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_8)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2697, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2697, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        {
          __pyx_t_2 = PyTuple_New(1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2697, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_5); __pyx_t_5 = NULL;
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_2, 0+1, __pyx_t_3);
          __pyx_t_3 = 0;
          __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2697, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "cPyparsing.pyx":2698
 *                 self.reString = "%s[%s]*" % \
 *                     (re.escape(self.initCharsOrig),
 *                      _escapeRegexRangeChars(self.bodyCharsOrig),)             # <<<<<<<<<<<<<<
 *             else:
 *                 self.reString = "[%s][%s]*" % \
 */
      __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_escapeRegexRangeChars); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2698, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_bodyCharsOrig); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2698, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      if (!__pyx_t_5) {
        __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2698, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_8);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_2)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2698, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2698, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        {
          __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2698, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_5); __pyx_t_5 = NULL;
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_3);
          __pyx_t_3 = 0;
          __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_10, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2698, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "cPyparsing.pyx":2697
 *             elif len(self.initCharsOrig) == 1:
 *                 self.reString = "%s[%s]*" % \
 *                     (re.escape(self.initCharsOrig),             # <<<<<<<<<<<<<<
 *                      _escapeRegexRangeChars(self.bodyCharsOrig),)
 *             else:
 */
      __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2697, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_8);
      PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_8);
      __pyx_t_1 = 0;
      __pyx_t_8 = 0;

      /* "cPyparsing.pyx":2696
 *                 self.reString = "[%s]+" % _escapeRegexRangeChars(self.initCharsOrig)
 *             elif len(self.initCharsOrig) == 1:
 *                 self.reString = "%s[%s]*" % \             # <<<<<<<<<<<<<<
 *                     (re.escape(self.initCharsOrig),
 *                      _escapeRegexRangeChars(self.bodyCharsOrig),)
 */
      __pyx_t_8 = PyUnicode_Format(__pyx_kp_u_s_s_2, __pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2696, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_reString, __pyx_t_8) < 0) __PYX_ERR(0, 2696, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "cPyparsing.pyx":2695
 *             if self.bodyCharsOrig == self.initCharsOrig:
 *                 self.reString = "[%s]+" % _escapeRegexRangeChars(self.initCharsOrig)
 *             elif len(self.initCharsOrig) == 1:             # <<<<<<<<<<<<<<
 *                 self.reString = "%s[%s]*" % \
 *                     (re.escape(self.initCharsOrig),
 */
      goto __pyx_L14;
    }

    /* "cPyparsing.pyx":2700
 *                      _escapeRegexRangeChars(self.bodyCharsOrig),)
 *             else:
 *                 self.reString = "[%s][%s]*" % \             # <<<<<<<<<<<<<<
 *                     (_escapeRegexRangeChars(self.initCharsOrig),
 *                      _escapeRegexRangeChars(self.bodyCharsOrig),)
 */
    /*else*/ {

      /* "cPyparsing.pyx":2701
 *             else:
 *                 self.reString = "[%s][%s]*" % \
 *                     (_escapeRegexRangeChars(self.initCharsOrig),             # <<<<<<<<<<<<<<
 *                      _escapeRegexRangeChars(self.bodyCharsOrig),)
 *             if self.asKeyword:
 */
      __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_escapeRegexRangeChars); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2701, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_initCharsOrig); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2701, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_10 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      if (!__pyx_t_10) {
        __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2701, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_8);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_2)) {
          PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_1};
          __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2701, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
          PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_1};
          __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2701, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        } else
        #endif
        {
          __pyx_t_3 = PyTuple_New(1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2701, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_10); __pyx_t_10 = NULL;
          __Pyx_GIVEREF(__pyx_t_1);
          PyTuple_SET_ITEM(__pyx_t_3, 0+1, __pyx_t_1);
          __pyx_t_1 = 0;
          __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2701, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "cPyparsing.pyx":2702
 *                 self.reString = "[%s][%s]*" % \
 *                     (_escapeRegexRangeChars(self.initCharsOrig),
 *                      _escapeRegexRangeChars(self.bodyCharsOrig),)             # <<<<<<<<<<<<<<
 *             if self.asKeyword:
 *                 self.reString = r"\b" + self.reString + r"\b"
 */
      __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_escapeRegexRangeChars); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2702, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_bodyCharsOrig); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2702, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_10 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_10) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2702, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_1};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2702, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_1};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2702, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        } else
        #endif
        {
          __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2702, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_10); __pyx_t_10 = NULL;
          __Pyx_GIVEREF(__pyx_t_1);
          PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_1);
          __pyx_t_1 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2702, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "cPyparsing.pyx":2701
 *             else:
 *                 self.reString = "[%s][%s]*" % \
 *                     (_escapeRegexRangeChars(self.initCharsOrig),             # <<<<<<<<<<<<<<
 *                      _escapeRegexRangeChars(self.bodyCharsOrig),)
 *             if self.asKeyword:
 */
      __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2701, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_8);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2);
      __pyx_t_8 = 0;
      __pyx_t_2 = 0;

      /* "cPyparsing.pyx":2700
 *                      _escapeRegexRangeChars(self.bodyCharsOrig),)
 *             else:
 *                 self.reString = "[%s][%s]*" % \             # <<<<<<<<<<<<<<
 *                     (_escapeRegexRangeChars(self.initCharsOrig),
 *                      _escapeRegexRangeChars(self.bodyCharsOrig),)
 */
      __pyx_t_2 = PyUnicode_Format(__pyx_kp_u_s_s_3, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2700, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_reString, __pyx_t_2) < 0) __PYX_ERR(0, 2700, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_L14:;

    /* "cPyparsing.pyx":2703
 *                     (_escapeRegexRangeChars(self.initCharsOrig),
 *                      _escapeRegexRangeChars(self.bodyCharsOrig),)
 *             if self.asKeyword:             # <<<<<<<<<<<<<<
 *                 self.reString = r"\b" + self.reString + r"\b"
 *             try:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_asKeyword); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2703, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 2703, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_4) {

      /* "cPyparsing.pyx":2704
 *                      _escapeRegexRangeChars(self.bodyCharsOrig),)
 *             if self.asKeyword:
 *                 self.reString = r"\b" + self.reString + r"\b"             # <<<<<<<<<<<<<<
 *             try:
 *                 self.re = re.compile(self.reString)
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_reString); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2704, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = PyNumber_Add(__pyx_kp_u_b, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2704, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_kp_u_b); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2704, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_reString, __pyx_t_2) < 0) __PYX_ERR(0, 2704, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "cPyparsing.pyx":2703
 *                     (_escapeRegexRangeChars(self.initCharsOrig),
 *                      _escapeRegexRangeChars(self.bodyCharsOrig),)
 *             if self.asKeyword:             # <<<<<<<<<<<<<<
 *                 self.reString = r"\b" + self.reString + r"\b"
 *             try:
 */
    }

    /* "cPyparsing.pyx":2705
 *             if self.asKeyword:
 *                 self.reString = r"\b" + self.reString + r"\b"
 *             try:             # <<<<<<<<<<<<<<
 *                 self.re = re.compile(self.reString)
 *             except Exception:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      /*try:*/ {

        /* "cPyparsing.pyx":2706
 *                 self.reString = r"\b" + self.reString + r"\b"
 *             try:
 *                 self.re = re.compile(self.reString)             # <<<<<<<<<<<<<<
 *             except Exception:
 *                 self.re = None
 */
        __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_re); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2706, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_compile); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2706, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_reString); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2706, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_5 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
          }
        }
        if (!__pyx_t_5) {
          __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2706, __pyx_L16_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_8)) {
            PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_3};
            __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2706, __pyx_L16_error)
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
            PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_3};
            __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2706, __pyx_L16_error)
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          } else
          #endif
          {
            __pyx_t_1 = PyTuple_New(1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2706, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_5); __pyx_t_5 = NULL;
            __Pyx_GIVEREF(__pyx_t_3);
            PyTuple_SET_ITEM(__pyx_t_1, 0+1, __pyx_t_3);
            __pyx_t_3 = 0;
            __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2706, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_re, __pyx_t_2) < 0) __PYX_ERR(0, 2706, __pyx_L16_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "cPyparsing.pyx":2705
 *             if self.asKeyword:
 *                 self.reString = r"\b" + self.reString + r"\b"
 *             try:             # <<<<<<<<<<<<<<
 *                 self.re = re.compile(self.reString)
 *             except Exception:
 */
      }
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      goto __pyx_L23_try_end;
      __pyx_L16_error:;
      __Pyx_PyThreadState_assign
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "cPyparsing.pyx":2707
 *             try:
 *                 self.re = re.compile(self.reString)
 *             except Exception:             # <<<<<<<<<<<<<<
 *                 self.re = None
 * 
 */
      __pyx_t_14 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_14) {
        __Pyx_AddTraceback("cPyparsing.Word.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_8, &__pyx_t_1) < 0) __PYX_ERR(0, 2707, __pyx_L18_except_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GOTREF(__pyx_t_1);

        /* "cPyparsing.pyx":2708
 *                 self.re = re.compile(self.reString)
 *             except Exception:
 *                 self.re = None             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_re, Py_None) < 0) __PYX_ERR(0, 2708, __pyx_L18_except_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L17_exception_handled;
      }
      goto __pyx_L18_except_error;
      __pyx_L18_except_error:;

      /* "cPyparsing.pyx":2705
 *             if self.asKeyword:
 *                 self.reString = r"\b" + self.reString + r"\b"
 *             try:             # <<<<<<<<<<<<<<
 *                 self.re = re.compile(self.reString)
 *             except Exception:
 */
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
      goto __pyx_L1_error;
      __pyx_L17_exception_handled:;
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
      __pyx_L23_try_end:;
    }

    /* "cPyparsing.pyx":2692
 *         self.asKeyword = asKeyword
 * 
 *         if ' ' not in self.initCharsOrig + self.bodyCharsOrig and (min == 1 and max == 0 and exact == 0):             # <<<<<<<<<<<<<<
 *             if self.bodyCharsOrig == self.initCharsOrig:
 *                 self.reString = "[%s]+" % _escapeRegexRangeChars(self.initCharsOrig)
 */
  }

  /* "cPyparsing.pyx":2656
 *     """
 * 
 *     def __init__(self, initChars, bodyChars=None, min=1, max=0, exact=0, asKeyword=False, excludeChars=None):             # <<<<<<<<<<<<<<
 *         super(Word, self).__init__()
 *         if excludeChars:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("cPyparsing.Word.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2710
 *                 self.re = None
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.re:
 *             result = self.re.match(instring, loc)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_4Word_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_4Word_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_4Word_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_4Word_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 2710, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 2710, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 2710, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2710, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2710, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Word.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_4Word_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_4Word_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_result = NULL;
  int __pyx_v_start;
  Py_ssize_t __pyx_v_instrlen;
  PyObject *__pyx_v_bodychars = NULL;
  PyObject *__pyx_v_maxloc = NULL;
  int __pyx_v_throwException;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  long __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":2711
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if self.re:             # <<<<<<<<<<<<<<
 *             result = self.re.match(instring, loc)
 *             if not result:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_re); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2711, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":2712
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if self.re:
 *             result = self.re.match(instring, loc)             # <<<<<<<<<<<<<<
 *             if not result:
 *                 raise ParseException(instring, loc, self.errmsg, self)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_re); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2712, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_match); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2712, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2712, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_instring, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2712, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_instring, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2712, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2712, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__pyx_t_5) {
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
      }
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_instring);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2712, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_result = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2713
 *         if self.re:
 *             result = self.re.match(instring, loc)
 *             if not result:             # <<<<<<<<<<<<<<
 *                 raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_result); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2713, __pyx_L1_error)
    __pyx_t_8 = ((!__pyx_t_2) != 0);
    if (__pyx_t_8) {

      /* "cPyparsing.pyx":2714
 *             result = self.re.match(instring, loc)
 *             if not result:
 *                 raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *             loc = result.end()
 */
      __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2714, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2714, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2714, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_6 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[5] = {__pyx_t_5, __pyx_v_instring, __pyx_t_7, __pyx_t_3, __pyx_v_self};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 4+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2714, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[5] = {__pyx_t_5, __pyx_v_instring, __pyx_t_7, __pyx_t_3, __pyx_v_self};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 4+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2714, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(4+__pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2714, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        if (__pyx_t_5) {
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_5); __pyx_t_5 = NULL;
        }
        __Pyx_INCREF(__pyx_v_instring);
        __Pyx_GIVEREF(__pyx_v_instring);
        PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_6, __pyx_v_instring);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_6, __pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_3);
        PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_6, __pyx_t_3);
        __Pyx_INCREF(__pyx_v_self);
        __Pyx_GIVEREF(__pyx_v_self);
        PyTuple_SET_ITEM(__pyx_t_9, 3+__pyx_t_6, __pyx_v_self);
        __pyx_t_7 = 0;
        __pyx_t_3 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2714, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 2714, __pyx_L1_error)

      /* "cPyparsing.pyx":2713
 *         if self.re:
 *             result = self.re.match(instring, loc)
 *             if not result:             # <<<<<<<<<<<<<<
 *                 raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
    }

    /* "cPyparsing.pyx":2716
 *                 raise ParseException(instring, loc, self.errmsg, self)
 * 
 *             loc = result.end()             # <<<<<<<<<<<<<<
 *             return loc, result.group()
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_end); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2716, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (__pyx_t_9) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2716, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2716, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2716, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_loc = __pyx_t_6;

    /* "cPyparsing.pyx":2717
 * 
 *             loc = result.end()
 *             return loc, result.group()             # <<<<<<<<<<<<<<
 * 
 *         if not(instring[loc] in self.initChars):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2717, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_group); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2717, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
      }
    }
    if (__pyx_t_3) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2717, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2717, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2717, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_4);
    __pyx_t_1 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_9;
    __pyx_t_9 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":2711
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if self.re:             # <<<<<<<<<<<<<<
 *             result = self.re.match(instring, loc)
 *             if not result:
 */
  }

  /* "cPyparsing.pyx":2719
 *             return loc, result.group()
 * 
 *         if not(instring[loc] in self.initChars):             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  __pyx_t_9 = __Pyx_GetItemInt(__pyx_v_instring, __pyx_v_loc, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_initChars); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_t_9, __pyx_t_4, Py_NE)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 2719, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = (__pyx_t_8 != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":2720
 * 
 *         if not(instring[loc] in self.initChars):
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *         start = loc
 */
    __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2720, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2720, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2720, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
        __pyx_t_6 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[5] = {__pyx_t_7, __pyx_v_instring, __pyx_t_1, __pyx_t_3, __pyx_v_self};
      __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_6, 4+__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2720, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[5] = {__pyx_t_7, __pyx_v_instring, __pyx_t_1, __pyx_t_3, __pyx_v_self};
      __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_6, 4+__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2720, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(4+__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2720, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__pyx_t_7) {
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7); __pyx_t_7 = NULL;
      }
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_6, __pyx_v_instring);
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_6, __pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_5, 2+__pyx_t_6, __pyx_t_3);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_5, 3+__pyx_t_6, __pyx_v_self);
      __pyx_t_1 = 0;
      __pyx_t_3 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_5, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2720, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 2720, __pyx_L1_error)

    /* "cPyparsing.pyx":2719
 *             return loc, result.group()
 * 
 *         if not(instring[loc] in self.initChars):             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  }

  /* "cPyparsing.pyx":2722
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *         start = loc             # <<<<<<<<<<<<<<
 *         loc += 1
 *         instrlen = len(instring)
 */
  __pyx_v_start = __pyx_v_loc;

  /* "cPyparsing.pyx":2723
 * 
 *         start = loc
 *         loc += 1             # <<<<<<<<<<<<<<
 *         instrlen = len(instring)
 *         bodychars = self.bodyChars
 */
  __pyx_t_6 = 0;
  __pyx_t_10 = __Pyx_add_const_long_checking_overflow(__pyx_v_loc, 1, &__pyx_t_6);
  if (unlikely(__pyx_t_6)) {
    PyErr_SetString(PyExc_OverflowError, "value too large");
    __PYX_ERR(0, 2723, __pyx_L1_error)
  }
  __pyx_v_loc = __pyx_t_10;

  /* "cPyparsing.pyx":2724
 *         start = loc
 *         loc += 1
 *         instrlen = len(instring)             # <<<<<<<<<<<<<<
 *         bodychars = self.bodyChars
 *         maxloc = start + self.maxLen
 */
  __pyx_t_11 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_11 == -1)) __PYX_ERR(0, 2724, __pyx_L1_error)
  __pyx_v_instrlen = __pyx_t_11;

  /* "cPyparsing.pyx":2725
 *         loc += 1
 *         instrlen = len(instring)
 *         bodychars = self.bodyChars             # <<<<<<<<<<<<<<
 *         maxloc = start + self.maxLen
 *         maxloc = min(maxloc, instrlen)
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_bodyChars); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_bodychars = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":2726
 *         instrlen = len(instring)
 *         bodychars = self.bodyChars
 *         maxloc = start + self.maxLen             # <<<<<<<<<<<<<<
 *         maxloc = min(maxloc, instrlen)
 *         while loc < maxloc and instring[loc] in bodychars:
 */
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_start); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_maxLen); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_5 = PyNumber_Add(__pyx_t_4, __pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_v_maxloc = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "cPyparsing.pyx":2727
 *         bodychars = self.bodyChars
 *         maxloc = start + self.maxLen
 *         maxloc = min(maxloc, instrlen)             # <<<<<<<<<<<<<<
 *         while loc < maxloc and instring[loc] in bodychars:
 *             loc += 1
 */
  __pyx_t_11 = __pyx_v_instrlen;
  __Pyx_INCREF(__pyx_v_maxloc);
  __pyx_t_5 = __pyx_v_maxloc;
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_t_11); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_4, __pyx_t_5, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2727, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2727, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {
    __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_11); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2727, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_9 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_9 = __pyx_t_5;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_t_9;
  __Pyx_INCREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF_SET(__pyx_v_maxloc, __pyx_t_5);
  __pyx_t_5 = 0;

  /* "cPyparsing.pyx":2728
 *         maxloc = start + self.maxLen
 *         maxloc = min(maxloc, instrlen)
 *         while loc < maxloc and instring[loc] in bodychars:             # <<<<<<<<<<<<<<
 *             loc += 1
 * 
 */
  while (1) {
    __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2728, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_9 = PyObject_RichCompare(__pyx_t_5, __pyx_v_maxloc, Py_LT); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2728, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 2728, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (__pyx_t_8) {
    } else {
      __pyx_t_2 = __pyx_t_8;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_t_9 = __Pyx_GetItemInt(__pyx_v_instring, __pyx_v_loc, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2728, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_t_9, __pyx_v_bodychars, Py_EQ)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 2728, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_12 = (__pyx_t_8 != 0);
    __pyx_t_2 = __pyx_t_12;
    __pyx_L8_bool_binop_done:;
    if (!__pyx_t_2) break;

    /* "cPyparsing.pyx":2729
 *         maxloc = min(maxloc, instrlen)
 *         while loc < maxloc and instring[loc] in bodychars:
 *             loc += 1             # <<<<<<<<<<<<<<
 * 
 *         throwException = False
 */
    __pyx_t_6 = 0;
    __pyx_t_10 = __Pyx_add_const_long_checking_overflow(__pyx_v_loc, 1, &__pyx_t_6);
    if (unlikely(__pyx_t_6)) {
      PyErr_SetString(PyExc_OverflowError, "value too large");
      __PYX_ERR(0, 2729, __pyx_L1_error)
    }
    __pyx_v_loc = __pyx_t_10;
  }

  /* "cPyparsing.pyx":2731
 *             loc += 1
 * 
 *         throwException = False             # <<<<<<<<<<<<<<
 *         if loc - start < self.minLen:
 *             throwException = True
 */
  __pyx_v_throwException = 0;

  /* "cPyparsing.pyx":2732
 * 
 *         throwException = False
 *         if loc - start < self.minLen:             # <<<<<<<<<<<<<<
 *             throwException = True
 *         if self.maxSpecified and loc < instrlen and instring[loc] in bodychars:
 */
  __pyx_t_6 = 0;
  __pyx_t_13 = __Pyx_sub_int_checking_overflow(__pyx_v_loc, __pyx_v_start, &__pyx_t_6);
  if (unlikely(__pyx_t_6)) {
    PyErr_SetString(PyExc_OverflowError, "value too large");
    __PYX_ERR(0, 2732, __pyx_L1_error)
  }
  __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_t_13); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_minLen); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_9, __pyx_t_5, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2732, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2732, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":2733
 *         throwException = False
 *         if loc - start < self.minLen:
 *             throwException = True             # <<<<<<<<<<<<<<
 *         if self.maxSpecified and loc < instrlen and instring[loc] in bodychars:
 *             throwException = True
 */
    __pyx_v_throwException = 1;

    /* "cPyparsing.pyx":2732
 * 
 *         throwException = False
 *         if loc - start < self.minLen:             # <<<<<<<<<<<<<<
 *             throwException = True
 *         if self.maxSpecified and loc < instrlen and instring[loc] in bodychars:
 */
  }

  /* "cPyparsing.pyx":2734
 *         if loc - start < self.minLen:
 *             throwException = True
 *         if self.maxSpecified and loc < instrlen and instring[loc] in bodychars:             # <<<<<<<<<<<<<<
 *             throwException = True
 *         if self.asKeyword:
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_maxSpecified); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 2734, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_12) {
  } else {
    __pyx_t_2 = __pyx_t_12;
    goto __pyx_L12_bool_binop_done;
  }
  __pyx_t_12 = ((__pyx_v_loc < __pyx_v_instrlen) != 0);
  if (__pyx_t_12) {
  } else {
    __pyx_t_2 = __pyx_t_12;
    goto __pyx_L12_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_instring, __pyx_v_loc, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_12 = (__Pyx_PySequence_ContainsTF(__pyx_t_3, __pyx_v_bodychars, Py_EQ)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 2734, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_8 = (__pyx_t_12 != 0);
  __pyx_t_2 = __pyx_t_8;
  __pyx_L12_bool_binop_done:;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":2735
 *             throwException = True
 *         if self.maxSpecified and loc < instrlen and instring[loc] in bodychars:
 *             throwException = True             # <<<<<<<<<<<<<<
 *         if self.asKeyword:
 *             if (start > 0 and instring[start - 1] in bodychars) or (loc < instrlen and instring[loc] in bodychars):
 */
    __pyx_v_throwException = 1;

    /* "cPyparsing.pyx":2734
 *         if loc - start < self.minLen:
 *             throwException = True
 *         if self.maxSpecified and loc < instrlen and instring[loc] in bodychars:             # <<<<<<<<<<<<<<
 *             throwException = True
 *         if self.asKeyword:
 */
  }

  /* "cPyparsing.pyx":2736
 *         if self.maxSpecified and loc < instrlen and instring[loc] in bodychars:
 *             throwException = True
 *         if self.asKeyword:             # <<<<<<<<<<<<<<
 *             if (start > 0 and instring[start - 1] in bodychars) or (loc < instrlen and instring[loc] in bodychars):
 *                 throwException = True
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_asKeyword); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 2736, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":2737
 *             throwException = True
 *         if self.asKeyword:
 *             if (start > 0 and instring[start - 1] in bodychars) or (loc < instrlen and instring[loc] in bodychars):             # <<<<<<<<<<<<<<
 *                 throwException = True
 * 
 */
    __pyx_t_8 = ((__pyx_v_start > 0) != 0);
    if (!__pyx_t_8) {
      goto __pyx_L18_next_or;
    } else {
    }
    __pyx_t_13 = 0;
    __pyx_t_10 = __Pyx_sub_const_long_checking_overflow(__pyx_v_start, 1, &__pyx_t_13);
    if (unlikely(__pyx_t_13)) {
      PyErr_SetString(PyExc_OverflowError, "value too large");
      __PYX_ERR(0, 2737, __pyx_L1_error)
    }
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_instring, __pyx_t_10, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2737, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_t_3, __pyx_v_bodychars, Py_EQ)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 2737, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_12 = (__pyx_t_8 != 0);
    if (!__pyx_t_12) {
    } else {
      __pyx_t_2 = __pyx_t_12;
      goto __pyx_L17_bool_binop_done;
    }
    __pyx_L18_next_or:;
    __pyx_t_12 = ((__pyx_v_loc < __pyx_v_instrlen) != 0);
    if (__pyx_t_12) {
    } else {
      __pyx_t_2 = __pyx_t_12;
      goto __pyx_L17_bool_binop_done;
    }
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_instring, __pyx_v_loc, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2737, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_12 = (__Pyx_PySequence_ContainsTF(__pyx_t_3, __pyx_v_bodychars, Py_EQ)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 2737, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_8 = (__pyx_t_12 != 0);
    __pyx_t_2 = __pyx_t_8;
    __pyx_L17_bool_binop_done:;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":2738
 *         if self.asKeyword:
 *             if (start > 0 and instring[start - 1] in bodychars) or (loc < instrlen and instring[loc] in bodychars):
 *                 throwException = True             # <<<<<<<<<<<<<<
 * 
 *         if throwException:
 */
      __pyx_v_throwException = 1;

      /* "cPyparsing.pyx":2737
 *             throwException = True
 *         if self.asKeyword:
 *             if (start > 0 and instring[start - 1] in bodychars) or (loc < instrlen and instring[loc] in bodychars):             # <<<<<<<<<<<<<<
 *                 throwException = True
 * 
 */
    }

    /* "cPyparsing.pyx":2736
 *         if self.maxSpecified and loc < instrlen and instring[loc] in bodychars:
 *             throwException = True
 *         if self.asKeyword:             # <<<<<<<<<<<<<<
 *             if (start > 0 and instring[start - 1] in bodychars) or (loc < instrlen and instring[loc] in bodychars):
 *                 throwException = True
 */
  }

  /* "cPyparsing.pyx":2740
 *                 throwException = True
 * 
 *         if throwException:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  __pyx_t_2 = (__pyx_v_throwException != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":2741
 * 
 *         if throwException:
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *         return loc, instring[start:loc]
 */
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2741, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2741, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2741, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = NULL;
    __pyx_t_13 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_13 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[5] = {__pyx_t_1, __pyx_v_instring, __pyx_t_9, __pyx_t_4, __pyx_v_self};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_13, 4+__pyx_t_13); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2741, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[5] = {__pyx_t_1, __pyx_v_instring, __pyx_t_9, __pyx_t_4, __pyx_v_self};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_13, 4+__pyx_t_13); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2741, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(4+__pyx_t_13); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2741, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__pyx_t_1) {
        __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_1); __pyx_t_1 = NULL;
      }
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_13, __pyx_v_instring);
      __Pyx_GIVEREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_13, __pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_13, __pyx_t_4);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_7, 3+__pyx_t_13, __pyx_v_self);
      __pyx_t_9 = 0;
      __pyx_t_4 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2741, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 2741, __pyx_L1_error)

    /* "cPyparsing.pyx":2740
 *                 throwException = True
 * 
 *         if throwException:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  }

  /* "cPyparsing.pyx":2743
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *         return loc, instring[start:loc]             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_v_instring, __pyx_v_start, __pyx_v_loc, NULL, NULL, NULL, 1, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_5);
  __pyx_t_3 = 0;
  __pyx_t_5 = 0;
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2710
 *                 self.re = None
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.re:
 *             result = self.re.match(instring, loc)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.Word.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_bodychars);
  __Pyx_XDECREF(__pyx_v_maxloc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2745
 *         return loc, instring[start:loc]
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(Word, self).__str__()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_4Word_5__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_4Word_5__str__ = {"__str__", (PyCFunction)__pyx_pw_10cPyparsing_4Word_5__str__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_4Word_5__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_4Word_4__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2753
 *         if self.strRepr is None:
 * 
 *             def charsAsStr(s):             # <<<<<<<<<<<<<<
 *                 if len(s) > 4:
 *                     return s[:4] + "..."
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_4Word_7__str___1charsAsStr(PyObject *__pyx_self, PyObject *__pyx_v_s); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_4Word_7__str___1charsAsStr = {"charsAsStr", (PyCFunction)__pyx_pw_10cPyparsing_4Word_7__str___1charsAsStr, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_4Word_7__str___1charsAsStr(PyObject *__pyx_self, PyObject *__pyx_v_s) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("charsAsStr (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_4Word_7__str___charsAsStr(__pyx_self, ((PyObject *)__pyx_v_s));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_4Word_7__str___charsAsStr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("charsAsStr", 0);

  /* "cPyparsing.pyx":2754
 * 
 *             def charsAsStr(s):
 *                 if len(s) > 4:             # <<<<<<<<<<<<<<
 *                     return s[:4] + "..."
 *                 else:
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_s); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 2754, __pyx_L1_error)
  __pyx_t_2 = ((__pyx_t_1 > 4) != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":2755
 *             def charsAsStr(s):
 *                 if len(s) > 4:
 *                     return s[:4] + "..."             # <<<<<<<<<<<<<<
 *                 else:
 *                     return s
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_s, 0, 4, NULL, NULL, &__pyx_slice__87, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2755, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyNumber_Add(__pyx_t_3, __pyx_kp_u__88); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2755, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":2754
 * 
 *             def charsAsStr(s):
 *                 if len(s) > 4:             # <<<<<<<<<<<<<<
 *                     return s[:4] + "..."
 *                 else:
 */
  }

  /* "cPyparsing.pyx":2757
 *                     return s[:4] + "..."
 *                 else:
 *                     return s             # <<<<<<<<<<<<<<
 * 
 *             if (self.initCharsOrig != self.bodyCharsOrig):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_s);
    __pyx_r = __pyx_v_s;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":2753
 *         if self.strRepr is None:
 * 
 *             def charsAsStr(s):             # <<<<<<<<<<<<<<
 *                 if len(s) > 4:
 *                     return s[:4] + "..."
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.Word.__str__.charsAsStr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2745
 *         return loc, instring[start:loc]
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(Word, self).__str__()
 */

static PyObject *__pyx_pf_10cPyparsing_4Word_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_charsAsStr = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "cPyparsing.pyx":2746
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(Word, self).__str__()
 *         except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":2747
 *     def __str__(self):
 *         try:
 *             return super(Word, self).__str__()             # <<<<<<<<<<<<<<
 *         except Exception:
 *             pass
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_Word); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2747, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2747, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_self);
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2747, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_str_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2747, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      if (__pyx_t_5) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2747, __pyx_L3_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else {
        __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2747, __pyx_L3_error)
      }
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":2746
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(Word, self).__str__()
 *         except Exception:
 */
    }
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":2748
 *         try:
 *             return super(Word, self).__str__()
 *         except Exception:             # <<<<<<<<<<<<<<
 *             pass
 * 
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_7) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cPyparsing.pyx":2746
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(Word, self).__str__()
 *         except Exception:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L4_exception_handled:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
  }

  /* "cPyparsing.pyx":2751
 *             pass
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 * 
 *             def charsAsStr(s):
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_8 = (__pyx_t_4 == Py_None);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_9 = (__pyx_t_8 != 0);
  if (__pyx_t_9) {

    /* "cPyparsing.pyx":2753
 *         if self.strRepr is None:
 * 
 *             def charsAsStr(s):             # <<<<<<<<<<<<<<
 *                 if len(s) > 4:
 *                     return s[:4] + "..."
 */
    __pyx_t_4 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_4Word_7__str___1charsAsStr, 0, __pyx_n_s_Word___str___locals_charsAsStr, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__90)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2753, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_charsAsStr = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":2759
 *                     return s
 * 
 *             if (self.initCharsOrig != self.bodyCharsOrig):             # <<<<<<<<<<<<<<
 *                 self.strRepr = "W:(%s,%s)" % (charsAsStr(self.initCharsOrig), charsAsStr(self.bodyCharsOrig))
 *             else:
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_initCharsOrig); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2759, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_bodyCharsOrig); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2759, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_4, __pyx_t_6, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2759, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 2759, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_9) {

      /* "cPyparsing.pyx":2760
 * 
 *             if (self.initCharsOrig != self.bodyCharsOrig):
 *                 self.strRepr = "W:(%s,%s)" % (charsAsStr(self.initCharsOrig), charsAsStr(self.bodyCharsOrig))             # <<<<<<<<<<<<<<
 *             else:
 *                 self.strRepr = "W:(%s)" % charsAsStr(self.initCharsOrig)
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_initCharsOrig); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2760, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __pyx_pf_10cPyparsing_4Word_7__str___charsAsStr(__pyx_v_charsAsStr, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2760, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_bodyCharsOrig); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2760, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = __pyx_pf_10cPyparsing_4Word_7__str___charsAsStr(__pyx_v_charsAsStr, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2760, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2760, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_4);
      __pyx_t_6 = 0;
      __pyx_t_4 = 0;
      __pyx_t_4 = PyUnicode_Format(__pyx_kp_u_W_s_s, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2760, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_4) < 0) __PYX_ERR(0, 2760, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "cPyparsing.pyx":2759
 *                     return s
 * 
 *             if (self.initCharsOrig != self.bodyCharsOrig):             # <<<<<<<<<<<<<<
 *                 self.strRepr = "W:(%s,%s)" % (charsAsStr(self.initCharsOrig), charsAsStr(self.bodyCharsOrig))
 *             else:
 */
      goto __pyx_L12;
    }

    /* "cPyparsing.pyx":2762
 *                 self.strRepr = "W:(%s,%s)" % (charsAsStr(self.initCharsOrig), charsAsStr(self.bodyCharsOrig))
 *             else:
 *                 self.strRepr = "W:(%s)" % charsAsStr(self.initCharsOrig)             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
    /*else*/ {
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_initCharsOrig); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2762, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __pyx_pf_10cPyparsing_4Word_7__str___charsAsStr(__pyx_v_charsAsStr, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2762, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyUnicode_Format(__pyx_kp_u_W_s, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2762, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_4) < 0) __PYX_ERR(0, 2762, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_L12:;

    /* "cPyparsing.pyx":2751
 *             pass
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 * 
 *             def charsAsStr(s):
 */
  }

  /* "cPyparsing.pyx":2764
 *                 self.strRepr = "W:(%s)" % charsAsStr(self.initCharsOrig)
 * 
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2745
 *         return loc, instring[start:loc]
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(Word, self).__str__()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.Word.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_charsAsStr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2782
 *     compiledREtype = type(re.compile("[A-Z]"))
 * 
 *     def __init__(self, pattern, flags=0):             # <<<<<<<<<<<<<<
 *         """The parameters C{pattern} and C{flags} are passed to the C{re.compile()} function as-is. See the Python C{re} module for an explanation of the acceptable patterns and flags."""
 *         super(Regex, self).__init__()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5Regex_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_5Regex___init__[] = "The parameters C{pattern} and C{flags} are passed to the C{re.compile()} function as-is. See the Python C{re} module for an explanation of the acceptable patterns and flags.";
static PyMethodDef __pyx_mdef_10cPyparsing_5Regex_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_5Regex_1__init__, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_5Regex___init__};
static PyObject *__pyx_pw_10cPyparsing_5Regex_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_pattern = 0;
  PyObject *__pyx_v_flags = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_pattern,&__pyx_n_s_flags,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)__pyx_int_0));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_pattern)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 2782, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_flags);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 2782, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_pattern = values[1];
    __pyx_v_flags = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2782, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Regex.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_5Regex___init__(__pyx_self, __pyx_v_self, __pyx_v_pattern, __pyx_v_flags);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_5Regex___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_pattern, PyObject *__pyx_v_flags) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":2784
 *     def __init__(self, pattern, flags=0):
 *         """The parameters C{pattern} and C{flags} are passed to the C{re.compile()} function as-is. See the Python C{re} module for an explanation of the acceptable patterns and flags."""
 *         super(Regex, self).__init__()             # <<<<<<<<<<<<<<
 * 
 *         if isinstance(pattern, basestring):
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2784, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2784, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2784, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2784, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2784, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2784, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2786
 *         super(Regex, self).__init__()
 * 
 *         if isinstance(pattern, basestring):             # <<<<<<<<<<<<<<
 *             if not pattern:
 *                 warnings.warn("null string passed to Regex; use Empty() instead",
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2786, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = PyObject_IsInstance(__pyx_v_pattern, __pyx_t_1); if (unlikely(__pyx_t_4 == -1)) __PYX_ERR(0, 2786, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (__pyx_t_4 != 0);
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":2787
 * 
 *         if isinstance(pattern, basestring):
 *             if not pattern:             # <<<<<<<<<<<<<<
 *                 warnings.warn("null string passed to Regex; use Empty() instead",
 *                               SyntaxWarning, stacklevel=2)
 */
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_pattern); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 2787, __pyx_L1_error)
    __pyx_t_4 = ((!__pyx_t_5) != 0);
    if (__pyx_t_4) {

      /* "cPyparsing.pyx":2788
 *         if isinstance(pattern, basestring):
 *             if not pattern:
 *                 warnings.warn("null string passed to Regex; use Empty() instead",             # <<<<<<<<<<<<<<
 *                               SyntaxWarning, stacklevel=2)
 * 
 */
      __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2788, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2788, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":2789
 *             if not pattern:
 *                 warnings.warn("null string passed to Regex; use Empty() instead",
 *                               SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 * 
 *             self.pattern = pattern
 */
      __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2788, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_kp_u_null_string_passed_to_Regex_use);
      __Pyx_GIVEREF(__pyx_kp_u_null_string_passed_to_Regex_use);
      PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u_null_string_passed_to_Regex_use);
      __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
      __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
      PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_builtin_SyntaxWarning);
      __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2789, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 2789, __pyx_L1_error)

      /* "cPyparsing.pyx":2788
 *         if isinstance(pattern, basestring):
 *             if not pattern:
 *                 warnings.warn("null string passed to Regex; use Empty() instead",             # <<<<<<<<<<<<<<
 *                               SyntaxWarning, stacklevel=2)
 * 
 */
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2788, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "cPyparsing.pyx":2787
 * 
 *         if isinstance(pattern, basestring):
 *             if not pattern:             # <<<<<<<<<<<<<<
 *                 warnings.warn("null string passed to Regex; use Empty() instead",
 *                               SyntaxWarning, stacklevel=2)
 */
    }

    /* "cPyparsing.pyx":2791
 *                               SyntaxWarning, stacklevel=2)
 * 
 *             self.pattern = pattern             # <<<<<<<<<<<<<<
 *             self.flags = flags
 * 
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_pattern, __pyx_v_pattern) < 0) __PYX_ERR(0, 2791, __pyx_L1_error)

    /* "cPyparsing.pyx":2792
 * 
 *             self.pattern = pattern
 *             self.flags = flags             # <<<<<<<<<<<<<<
 * 
 *             try:
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_flags, __pyx_v_flags) < 0) __PYX_ERR(0, 2792, __pyx_L1_error)

    /* "cPyparsing.pyx":2794
 *             self.flags = flags
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 self.re = re.compile(self.pattern, self.flags)
 *                 self.reString = self.pattern
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      /*try:*/ {

        /* "cPyparsing.pyx":2795
 * 
 *             try:
 *                 self.re = re.compile(self.pattern, self.flags)             # <<<<<<<<<<<<<<
 *                 self.reString = self.pattern
 *             except sre_constants.error:
 */
        __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2795, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_compile); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2795, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_pattern); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2795, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_flags); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2795, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_10 = NULL;
        __pyx_t_11 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_1);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_1, function);
            __pyx_t_11 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_1)) {
          PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_t_2, __pyx_t_3};
          __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2795, __pyx_L5_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
          PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_t_2, __pyx_t_3};
          __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2795, __pyx_L5_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        {
          __pyx_t_12 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2795, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_12);
          if (__pyx_t_10) {
            __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_10); __pyx_t_10 = NULL;
          }
          __Pyx_GIVEREF(__pyx_t_2);
          PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_t_2);
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_t_3);
          __pyx_t_2 = 0;
          __pyx_t_3 = 0;
          __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_12, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2795, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_re, __pyx_t_6) < 0) __PYX_ERR(0, 2795, __pyx_L5_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "cPyparsing.pyx":2796
 *             try:
 *                 self.re = re.compile(self.pattern, self.flags)
 *                 self.reString = self.pattern             # <<<<<<<<<<<<<<
 *             except sre_constants.error:
 *                 warnings.warn("invalid pattern (%s) passed to Regex" % pattern,
 */
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_pattern); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2796, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_6);
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_reString, __pyx_t_6) < 0) __PYX_ERR(0, 2796, __pyx_L5_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "cPyparsing.pyx":2794
 *             self.flags = flags
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 self.re = re.compile(self.pattern, self.flags)
 *                 self.reString = self.pattern
 */
      }
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L12_try_end;
      __pyx_L5_error:;
      __Pyx_PyThreadState_assign
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "cPyparsing.pyx":2797
 *                 self.re = re.compile(self.pattern, self.flags)
 *                 self.reString = self.pattern
 *             except sre_constants.error:             # <<<<<<<<<<<<<<
 *                 warnings.warn("invalid pattern (%s) passed to Regex" % pattern,
 *                               SyntaxWarning, stacklevel=2)
 */
      __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_sre_constants); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2797, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_error); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2797, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_11 = __Pyx_PyErr_ExceptionMatches(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_11) {
        __Pyx_AddTraceback("cPyparsing.Regex.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_6, &__pyx_t_12) < 0) __PYX_ERR(0, 2797, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GOTREF(__pyx_t_12);

        /* "cPyparsing.pyx":2798
 *                 self.reString = self.pattern
 *             except sre_constants.error:
 *                 warnings.warn("invalid pattern (%s) passed to Regex" % pattern,             # <<<<<<<<<<<<<<
 *                               SyntaxWarning, stacklevel=2)
 *                 raise
 */
        __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_warnings); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2798, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_warn); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2798, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = PyUnicode_Format(__pyx_kp_u_invalid_pattern_s_passed_to_Rege, __pyx_v_pattern); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2798, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_3);

        /* "cPyparsing.pyx":2799
 *             except sre_constants.error:
 *                 warnings.warn("invalid pattern (%s) passed to Regex" % pattern,
 *                               SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *                 raise
 * 
 */
        __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2798, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_3);
        PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_3);
        __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
        __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
        PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_builtin_SyntaxWarning);
        __pyx_t_3 = 0;
        __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2799, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 2799, __pyx_L7_except_error)

        /* "cPyparsing.pyx":2798
 *                 self.reString = self.pattern
 *             except sre_constants.error:
 *                 warnings.warn("invalid pattern (%s) passed to Regex" % pattern,             # <<<<<<<<<<<<<<
 *                               SyntaxWarning, stacklevel=2)
 *                 raise
 */
        __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_10, __pyx_t_3); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2798, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

        /* "cPyparsing.pyx":2800
 *                 warnings.warn("invalid pattern (%s) passed to Regex" % pattern,
 *                               SyntaxWarning, stacklevel=2)
 *                 raise             # <<<<<<<<<<<<<<
 * 
 *         elif isinstance(pattern, Regex.compiledREtype):
 */
        __Pyx_GIVEREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_ErrRestoreWithState(__pyx_t_1, __pyx_t_6, __pyx_t_12);
        __pyx_t_1 = 0; __pyx_t_6 = 0; __pyx_t_12 = 0; 
        __PYX_ERR(0, 2800, __pyx_L7_except_error)
      }
      goto __pyx_L7_except_error;
      __pyx_L7_except_error:;

      /* "cPyparsing.pyx":2794
 *             self.flags = flags
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 self.re = re.compile(self.pattern, self.flags)
 *                 self.reString = self.pattern
 */
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      goto __pyx_L1_error;
      __pyx_L12_try_end:;
    }

    /* "cPyparsing.pyx":2786
 *         super(Regex, self).__init__()
 * 
 *         if isinstance(pattern, basestring):             # <<<<<<<<<<<<<<
 *             if not pattern:
 *                 warnings.warn("null string passed to Regex; use Empty() instead",
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":2802
 *                 raise
 * 
 *         elif isinstance(pattern, Regex.compiledREtype):             # <<<<<<<<<<<<<<
 *             self.re = pattern
 *             self.pattern = \
 */
  __pyx_t_12 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_compiledREtype); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_4 = PyObject_IsInstance(__pyx_v_pattern, __pyx_t_6); if (unlikely(__pyx_t_4 == -1)) __PYX_ERR(0, 2802, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_5 = (__pyx_t_4 != 0);
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":2803
 * 
 *         elif isinstance(pattern, Regex.compiledREtype):
 *             self.re = pattern             # <<<<<<<<<<<<<<
 *             self.pattern = \
 *                 self.reString = str(pattern)
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_re, __pyx_v_pattern) < 0) __PYX_ERR(0, 2803, __pyx_L1_error)

    /* "cPyparsing.pyx":2805
 *             self.re = pattern
 *             self.pattern = \
 *                 self.reString = str(pattern)             # <<<<<<<<<<<<<<
 *             self.flags = flags
 * 
 */
    __pyx_t_12 = __Pyx_GetModuleGlobalName(__pyx_n_s_str); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2805, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_12);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_12, function);
      }
    }
    if (!__pyx_t_1) {
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_v_pattern); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2805, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_12)) {
        PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_v_pattern};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2805, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
        PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_v_pattern};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2805, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2805, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_1); __pyx_t_1 = NULL;
        __Pyx_INCREF(__pyx_v_pattern);
        __Pyx_GIVEREF(__pyx_v_pattern);
        PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_v_pattern);
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_13, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2805, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

    /* "cPyparsing.pyx":2804
 *         elif isinstance(pattern, Regex.compiledREtype):
 *             self.re = pattern
 *             self.pattern = \             # <<<<<<<<<<<<<<
 *                 self.reString = str(pattern)
 *             self.flags = flags
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_pattern, __pyx_t_6) < 0) __PYX_ERR(0, 2804, __pyx_L1_error)

    /* "cPyparsing.pyx":2805
 *             self.re = pattern
 *             self.pattern = \
 *                 self.reString = str(pattern)             # <<<<<<<<<<<<<<
 *             self.flags = flags
 * 
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_reString, __pyx_t_6) < 0) __PYX_ERR(0, 2805, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":2806
 *             self.pattern = \
 *                 self.reString = str(pattern)
 *             self.flags = flags             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_flags, __pyx_v_flags) < 0) __PYX_ERR(0, 2806, __pyx_L1_error)

    /* "cPyparsing.pyx":2802
 *                 raise
 * 
 *         elif isinstance(pattern, Regex.compiledREtype):             # <<<<<<<<<<<<<<
 *             self.re = pattern
 *             self.pattern = \
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":2809
 * 
 *         else:
 *             raise ValueError("Regex may only be constructed with a string or a compiled RE object")             # <<<<<<<<<<<<<<
 * 
 *         self.name = _ustr(self)
 */
  /*else*/ {
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__91, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2809, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(0, 2809, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":2811
 *             raise ValueError("Regex may only be constructed with a string or a compiled RE object")
 * 
 *         self.name = _ustr(self)             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected " + self.name
 *         self.mayIndexError = False
 */
  __pyx_t_12 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  if (!__pyx_t_13) {
    __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_v_self); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_12)) {
      PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_v_self};
      __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2811, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_t_6);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
      PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_v_self};
      __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2811, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_t_6);
    } else
    #endif
    {
      __pyx_t_1 = PyTuple_New(1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2811, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_13); __pyx_t_13 = NULL;
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_1, 0+1, __pyx_v_self);
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_1, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2811, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name, __pyx_t_6) < 0) __PYX_ERR(0, 2811, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "cPyparsing.pyx":2812
 * 
 *         self.name = _ustr(self)
 *         self.errmsg = "Expected " + self.name             # <<<<<<<<<<<<<<
 *         self.mayIndexError = False
 *         self.mayReturnEmpty = True
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_12 = PyNumber_Add(__pyx_kp_u_Expected, __pyx_t_6); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_12) < 0) __PYX_ERR(0, 2812, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

  /* "cPyparsing.pyx":2813
 *         self.name = _ustr(self)
 *         self.errmsg = "Expected " + self.name
 *         self.mayIndexError = False             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, Py_False) < 0) __PYX_ERR(0, 2813, __pyx_L1_error)

  /* "cPyparsing.pyx":2814
 *         self.errmsg = "Expected " + self.name
 *         self.mayIndexError = False
 *         self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 2814, __pyx_L1_error)

  /* "cPyparsing.pyx":2782
 *     compiledREtype = type(re.compile("[A-Z]"))
 * 
 *     def __init__(self, pattern, flags=0):             # <<<<<<<<<<<<<<
 *         """The parameters C{pattern} and C{flags} are passed to the C{re.compile()} function as-is. See the Python C{re} module for an explanation of the acceptable patterns and flags."""
 *         super(Regex, self).__init__()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("cPyparsing.Regex.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2816
 *         self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = self.re.match(instring, loc)
 *         if not result:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5Regex_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_5Regex_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_5Regex_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_5Regex_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 2816, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 2816, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 2816, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2816, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2816, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Regex.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_5Regex_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_5Regex_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_d = NULL;
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  Py_ssize_t __pyx_t_10;
  PyObject *(*__pyx_t_11)(PyObject *);
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":2817
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         result = self.re.match(instring, loc)             # <<<<<<<<<<<<<<
 *         if not result:
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_match); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_instring, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2817, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_instring, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2817, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  {
    __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2817, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_INCREF(__pyx_v_instring);
    __Pyx_GIVEREF(__pyx_v_instring);
    PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_v_instring);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2817, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2818
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         result = self.re.match(instring, loc)
 *         if not result:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_v_result); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 2818, __pyx_L1_error)
  __pyx_t_8 = ((!__pyx_t_7) != 0);
  if (__pyx_t_8) {

    /* "cPyparsing.pyx":2819
 *         result = self.re.match(instring, loc)
 *         if not result:
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *         loc = result.end()
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2819, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2819, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2819, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[5] = {__pyx_t_4, __pyx_v_instring, __pyx_t_6, __pyx_t_2, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 4+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2819, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[5] = {__pyx_t_4, __pyx_v_instring, __pyx_t_6, __pyx_t_2, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 4+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2819, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(4+__pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2819, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (__pyx_t_4) {
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_4); __pyx_t_4 = NULL;
      }
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_5, __pyx_v_instring);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_5, __pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_5, __pyx_t_2);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_9, 3+__pyx_t_5, __pyx_v_self);
      __pyx_t_6 = 0;
      __pyx_t_2 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2819, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 2819, __pyx_L1_error)

    /* "cPyparsing.pyx":2818
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         result = self.re.match(instring, loc)
 *         if not result:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  }

  /* "cPyparsing.pyx":2821
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *         loc = result.end()             # <<<<<<<<<<<<<<
 *         d = result.groupdict()
 *         ret = ParseResults(result.group())
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_end); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_9) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2821, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2821, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2821, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_loc = __pyx_t_5;

  /* "cPyparsing.pyx":2822
 * 
 *         loc = result.end()
 *         d = result.groupdict()             # <<<<<<<<<<<<<<
 *         ret = ParseResults(result.group())
 *         if d:
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_groupdict); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_9) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2822, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2822, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_d = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2823
 *         loc = result.end()
 *         d = result.groupdict()
 *         ret = ParseResults(result.group())             # <<<<<<<<<<<<<<
 *         if d:
 *             for k in d:
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_group); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_6) {
    __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2823, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else {
    __pyx_t_9 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2823, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2823, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_9};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2823, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_9};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2823, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2823, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_GIVEREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_9);
      __pyx_t_9 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2823, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_ret = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2824
 *         d = result.groupdict()
 *         ret = ParseResults(result.group())
 *         if d:             # <<<<<<<<<<<<<<
 *             for k in d:
 *                 ret[k] = d[k]
 */
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_d); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 2824, __pyx_L1_error)
  if (__pyx_t_8) {

    /* "cPyparsing.pyx":2825
 *         ret = ParseResults(result.group())
 *         if d:
 *             for k in d:             # <<<<<<<<<<<<<<
 *                 ret[k] = d[k]
 *         return loc, ret
 */
    if (likely(PyList_CheckExact(__pyx_v_d)) || PyTuple_CheckExact(__pyx_v_d)) {
      __pyx_t_1 = __pyx_v_d; __Pyx_INCREF(__pyx_t_1); __pyx_t_10 = 0;
      __pyx_t_11 = NULL;
    } else {
      __pyx_t_10 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_d); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2825, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_11 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2825, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_11)) {
        if (likely(PyList_CheckExact(__pyx_t_1))) {
          if (__pyx_t_10 >= PyList_GET_SIZE(__pyx_t_1)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_10); __Pyx_INCREF(__pyx_t_3); __pyx_t_10++; if (unlikely(0 < 0)) __PYX_ERR(0, 2825, __pyx_L1_error)
          #else
          __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_10); __pyx_t_10++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2825, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        } else {
          if (__pyx_t_10 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_10); __Pyx_INCREF(__pyx_t_3); __pyx_t_10++; if (unlikely(0 < 0)) __PYX_ERR(0, 2825, __pyx_L1_error)
          #else
          __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_10); __pyx_t_10++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2825, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        }
      } else {
        __pyx_t_3 = __pyx_t_11(__pyx_t_1);
        if (unlikely(!__pyx_t_3)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 2825, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_XDECREF_SET(__pyx_v_k, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":2826
 *         if d:
 *             for k in d:
 *                 ret[k] = d[k]             # <<<<<<<<<<<<<<
 *         return loc, ret
 * 
 */
      __pyx_t_3 = PyObject_GetItem(__pyx_v_d, __pyx_v_k); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2826, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (unlikely(PyObject_SetItem(__pyx_v_ret, __pyx_v_k, __pyx_t_3) < 0)) __PYX_ERR(0, 2826, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "cPyparsing.pyx":2825
 *         ret = ParseResults(result.group())
 *         if d:
 *             for k in d:             # <<<<<<<<<<<<<<
 *                 ret[k] = d[k]
 *         return loc, ret
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2824
 *         d = result.groupdict()
 *         ret = ParseResults(result.group())
 *         if d:             # <<<<<<<<<<<<<<
 *             for k in d:
 *                 ret[k] = d[k]
 */
  }

  /* "cPyparsing.pyx":2827
 *             for k in d:
 *                 ret[k] = d[k]
 *         return loc, ret             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __Pyx_INCREF(__pyx_v_ret);
  __Pyx_GIVEREF(__pyx_v_ret);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_ret);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2816
 *         self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = self.re.match(instring, loc)
 *         if not result:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.Regex.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_d);
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2829
 *         return loc, ret
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(Regex, self).__str__()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5Regex_5__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_5Regex_5__str__ = {"__str__", (PyCFunction)__pyx_pw_10cPyparsing_5Regex_5__str__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_5Regex_5__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_5Regex_4__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_5Regex_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "cPyparsing.pyx":2830
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(Regex, self).__str__()
 *         except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":2831
 *     def __str__(self):
 *         try:
 *             return super(Regex, self).__str__()             # <<<<<<<<<<<<<<
 *         except Exception:
 *             pass
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2831, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2831, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_self);
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2831, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_str_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2831, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      if (__pyx_t_5) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2831, __pyx_L3_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else {
        __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2831, __pyx_L3_error)
      }
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":2830
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(Regex, self).__str__()
 *         except Exception:
 */
    }
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":2832
 *         try:
 *             return super(Regex, self).__str__()
 *         except Exception:             # <<<<<<<<<<<<<<
 *             pass
 * 
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_7) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cPyparsing.pyx":2830
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(Regex, self).__str__()
 *         except Exception:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L4_exception_handled:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
  }

  /* "cPyparsing.pyx":2835
 *             pass
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "Re:(%s)" % repr(self.pattern)
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_8 = (__pyx_t_4 == Py_None);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_9 = (__pyx_t_8 != 0);
  if (__pyx_t_9) {

    /* "cPyparsing.pyx":2836
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "Re:(%s)" % repr(self.pattern)             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
    __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_repr_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2836, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_pattern); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2836, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_10 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    if (!__pyx_t_10) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2836, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2836, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2836, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2836, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_10); __pyx_t_10 = NULL;
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_11, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2836, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyUnicode_Format(__pyx_kp_u_Re_s, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2836, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_6) < 0) __PYX_ERR(0, 2836, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":2835
 *             pass
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "Re:(%s)" % repr(self.pattern)
 * 
 */
  }

  /* "cPyparsing.pyx":2838
 *             self.strRepr = "Re:(%s)" % repr(self.pattern)
 * 
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2829
 *         return loc, ret
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(Regex, self).__str__()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("cPyparsing.Regex.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2867
 *     """
 * 
 *     def __init__(self, quoteChar, escChar=None, escQuote=None, multiline=False, unquoteResults=True, endQuoteChar=None, convertWhitespaceEscapes=True):             # <<<<<<<<<<<<<<
 *         super(QuotedString, self).__init__()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12QuotedString_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12QuotedString_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_12QuotedString_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_12QuotedString_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_quoteChar = 0;
  PyObject *__pyx_v_escChar = 0;
  PyObject *__pyx_v_escQuote = 0;
  PyObject *__pyx_v_multiline = 0;
  PyObject *__pyx_v_unquoteResults = 0;
  PyObject *__pyx_v_endQuoteChar = 0;
  PyObject *__pyx_v_convertWhitespaceEscapes = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_quoteChar,&__pyx_n_s_escChar,&__pyx_n_s_escQuote,&__pyx_n_s_multiline,&__pyx_n_s_unquoteResults,&__pyx_n_s_endQuoteChar,&__pyx_n_s_convertWhitespaceEscapes,0};
    PyObject* values[8] = {0,0,0,0,0,0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_None));
    values[3] = ((PyObject *)((PyObject *)Py_None));
    values[4] = ((PyObject *)((PyObject *)Py_False));
    values[5] = ((PyObject *)((PyObject *)Py_True));
    values[6] = ((PyObject *)((PyObject *)Py_None));
    values[7] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_quoteChar)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 8, 1); __PYX_ERR(0, 2867, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_escChar);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_escQuote);
          if (value) { values[3] = value; kw_args--; }
        }
        case  4:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_multiline);
          if (value) { values[4] = value; kw_args--; }
        }
        case  5:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_unquoteResults);
          if (value) { values[5] = value; kw_args--; }
        }
        case  6:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_endQuoteChar);
          if (value) { values[6] = value; kw_args--; }
        }
        case  7:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_convertWhitespaceEscapes);
          if (value) { values[7] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 2867, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_quoteChar = values[1];
    __pyx_v_escChar = values[2];
    __pyx_v_escQuote = values[3];
    __pyx_v_multiline = values[4];
    __pyx_v_unquoteResults = values[5];
    __pyx_v_endQuoteChar = values[6];
    __pyx_v_convertWhitespaceEscapes = values[7];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 8, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2867, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.QuotedString.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12QuotedString___init__(__pyx_self, __pyx_v_self, __pyx_v_quoteChar, __pyx_v_escChar, __pyx_v_escQuote, __pyx_v_multiline, __pyx_v_unquoteResults, __pyx_v_endQuoteChar, __pyx_v_convertWhitespaceEscapes);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_12QuotedString_8__init___2generator14(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":2908
 *         if len(self.endQuoteChar) > 1:
 *             self.pattern += (
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),             # <<<<<<<<<<<<<<
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')'
 */

static PyObject *__pyx_pf_10cPyparsing_12QuotedString_8__init___genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_30_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_30_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_30_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_30_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_30_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 2908, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_29___init__ *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_12QuotedString_8__init___2generator14, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_QuotedString___init___locals_gen, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 2908, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.QuotedString.__init__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_12QuotedString_8__init___2generator14(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_30_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_30_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 2908, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 2908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);

  /* "cPyparsing.pyx":2910
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')'             # <<<<<<<<<<<<<<
 *             )
 *         if escQuote:
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_range); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2910, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = 0;
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 2910, __pyx_L1_error) }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_n_s_endQuoteChar); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2910, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_Length(__pyx_t_4); if (unlikely(__pyx_t_5 == -1)) __PYX_ERR(0, 2910, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = __Pyx_sub_const_Py_ssize_t_checking_overflow(__pyx_t_5, 1, &__pyx_t_3);
  if (unlikely(__pyx_t_3)) {
    PyErr_SetString(PyExc_OverflowError, "value too large");
    __PYX_ERR(0, 2910, __pyx_L1_error)
  }
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2910, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = NULL;
  __pyx_t_3 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_3 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_t_4, __pyx_int_0, __pyx_int_neg_1};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_3, 3+__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2910, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_t_4, __pyx_int_0, __pyx_int_neg_1};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_3, 3+__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2910, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else
  #endif
  {
    __pyx_t_8 = PyTuple_New(3+__pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__pyx_t_7) {
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_7); __pyx_t_7 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_3, __pyx_t_4);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_3, __pyx_int_0);
    __Pyx_INCREF(__pyx_int_neg_1);
    __Pyx_GIVEREF(__pyx_int_neg_1);
    PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_3, __pyx_int_neg_1);
    __pyx_t_4 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_6 = 0;
    __pyx_t_9 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_9 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2910, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_9)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 2910, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2910, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 2910, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2910, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_9(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 2910, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_i);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_i, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2908
 *         if len(self.endQuoteChar) > 1:
 *             self.pattern += (
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),             # <<<<<<<<<<<<<<
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')'
 */
    __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_re); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2908, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_escape); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2908, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 2908, __pyx_L1_error) }
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_n_s_endQuoteChar); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2908, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_7 = __Pyx_PyObject_GetSlice(__pyx_t_8, 0, 0, NULL, &__pyx_cur_scope->__pyx_v_i, NULL, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2908, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_8) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2908, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2908, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2908, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2908, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_10, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2908, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":2909
 *             self.pattern += (
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))             # <<<<<<<<<<<<<<
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')'
 *             )
 */
    __pyx_t_10 = __Pyx_GetModuleGlobalName(__pyx_n_s_escapeRegexRangeChars); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2909, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 2909, __pyx_L1_error) }
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_n_s_endQuoteChar); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2909, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = PyObject_GetItem(__pyx_t_7, __pyx_cur_scope->__pyx_v_i); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2909, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
      }
    }
    if (!__pyx_t_7) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2909, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_8};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2909, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_8};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2909, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2909, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_7); __pyx_t_7 = NULL;
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_11, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2909, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "cPyparsing.pyx":2908
 *         if len(self.endQuoteChar) > 1:
 *             self.pattern += (
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),             # <<<<<<<<<<<<<<
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')'
 */
    __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2908, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_4);
    __pyx_t_1 = 0;
    __pyx_t_4 = 0;
    __pyx_t_4 = PyUnicode_Format(__pyx_kp_u_s_s_4, __pyx_t_10); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2908, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_4))) __PYX_ERR(0, 2908, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":2910
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')'             # <<<<<<<<<<<<<<
 *             )
 *         if escQuote:
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "cPyparsing.pyx":2908
 *         if len(self.endQuoteChar) > 1:
 *             self.pattern += (
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),             # <<<<<<<<<<<<<<
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')'
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2867
 *     """
 * 
 *     def __init__(self, quoteChar, escChar=None, escQuote=None, multiline=False, unquoteResults=True, endQuoteChar=None, convertWhitespaceEscapes=True):             # <<<<<<<<<<<<<<
 *         super(QuotedString, self).__init__()
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_12QuotedString___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_quoteChar, PyObject *__pyx_v_escChar, PyObject *__pyx_v_escQuote, PyObject *__pyx_v_multiline, PyObject *__pyx_v_unquoteResults, PyObject *__pyx_v_endQuoteChar, PyObject *__pyx_v_convertWhitespaceEscapes) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_29___init__ *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  __Pyx_RefNannySetupContext("__init__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_29___init__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_29___init__(__pyx_ptype_10cPyparsing___pyx_scope_struct_29___init__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_29___init__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 2867, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_INCREF(__pyx_v_quoteChar);
  __Pyx_INCREF(__pyx_v_endQuoteChar);

  /* "cPyparsing.pyx":2868
 * 
 *     def __init__(self, quoteChar, escChar=None, escQuote=None, multiline=False, unquoteResults=True, endQuoteChar=None, convertWhitespaceEscapes=True):
 *         super(QuotedString, self).__init__()             # <<<<<<<<<<<<<<
 * 
 *         # remove white space from quote chars - wont work anyway
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_QuotedString); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_cur_scope->__pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2868, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2868, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2871
 * 
 *         # remove white space from quote chars - wont work anyway
 *         quoteChar = quoteChar.strip()             # <<<<<<<<<<<<<<
 *         if not quoteChar:
 *             warnings.warn("quoteChar cannot be the empty string", SyntaxWarning, stacklevel=2)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_quoteChar, __pyx_n_s_strip); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2871, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2871, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF_SET(__pyx_v_quoteChar, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2872
 *         # remove white space from quote chars - wont work anyway
 *         quoteChar = quoteChar.strip()
 *         if not quoteChar:             # <<<<<<<<<<<<<<
 *             warnings.warn("quoteChar cannot be the empty string", SyntaxWarning, stacklevel=2)
 *             raise SyntaxError()
 */
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_quoteChar); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 2872, __pyx_L1_error)
  __pyx_t_5 = ((!__pyx_t_4) != 0);
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":2873
 *         quoteChar = quoteChar.strip()
 *         if not quoteChar:
 *             warnings.warn("quoteChar cannot be the empty string", SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             raise SyntaxError()
 * 
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_warnings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_kp_u_quoteChar_cannot_be_the_empty_st);
    __Pyx_GIVEREF(__pyx_kp_u_quoteChar_cannot_be_the_empty_st);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u_quoteChar_cannot_be_the_empty_st);
    __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
    __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_builtin_SyntaxWarning);
    __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 2873, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":2874
 *         if not quoteChar:
 *             warnings.warn("quoteChar cannot be the empty string", SyntaxWarning, stacklevel=2)
 *             raise SyntaxError()             # <<<<<<<<<<<<<<
 * 
 *         if endQuoteChar is None:
 */
    __pyx_t_6 = __Pyx_PyObject_CallNoArg(__pyx_builtin_SyntaxError); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2874, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(0, 2874, __pyx_L1_error)

    /* "cPyparsing.pyx":2872
 *         # remove white space from quote chars - wont work anyway
 *         quoteChar = quoteChar.strip()
 *         if not quoteChar:             # <<<<<<<<<<<<<<
 *             warnings.warn("quoteChar cannot be the empty string", SyntaxWarning, stacklevel=2)
 *             raise SyntaxError()
 */
  }

  /* "cPyparsing.pyx":2876
 *             raise SyntaxError()
 * 
 *         if endQuoteChar is None:             # <<<<<<<<<<<<<<
 *             endQuoteChar = quoteChar
 *         else:
 */
  __pyx_t_5 = (__pyx_v_endQuoteChar == Py_None);
  __pyx_t_4 = (__pyx_t_5 != 0);
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":2877
 * 
 *         if endQuoteChar is None:
 *             endQuoteChar = quoteChar             # <<<<<<<<<<<<<<
 *         else:
 *             endQuoteChar = endQuoteChar.strip()
 */
    __Pyx_INCREF(__pyx_v_quoteChar);
    __Pyx_DECREF_SET(__pyx_v_endQuoteChar, __pyx_v_quoteChar);

    /* "cPyparsing.pyx":2876
 *             raise SyntaxError()
 * 
 *         if endQuoteChar is None:             # <<<<<<<<<<<<<<
 *             endQuoteChar = quoteChar
 *         else:
 */
    goto __pyx_L4;
  }

  /* "cPyparsing.pyx":2879
 *             endQuoteChar = quoteChar
 *         else:
 *             endQuoteChar = endQuoteChar.strip()             # <<<<<<<<<<<<<<
 *             if not endQuoteChar:
 *                 warnings.warn("endQuoteChar cannot be the empty string", SyntaxWarning, stacklevel=2)
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_endQuoteChar, __pyx_n_s_strip); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2879, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (__pyx_t_1) {
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2879, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      __pyx_t_6 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2879, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_endQuoteChar, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "cPyparsing.pyx":2880
 *         else:
 *             endQuoteChar = endQuoteChar.strip()
 *             if not endQuoteChar:             # <<<<<<<<<<<<<<
 *                 warnings.warn("endQuoteChar cannot be the empty string", SyntaxWarning, stacklevel=2)
 *                 raise SyntaxError()
 */
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_endQuoteChar); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 2880, __pyx_L1_error)
    __pyx_t_5 = ((!__pyx_t_4) != 0);
    if (__pyx_t_5) {

      /* "cPyparsing.pyx":2881
 *             endQuoteChar = endQuoteChar.strip()
 *             if not endQuoteChar:
 *                 warnings.warn("endQuoteChar cannot be the empty string", SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *                 raise SyntaxError()
 * 
 */
      __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_warnings); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2881, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_warn); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2881, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2881, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_kp_u_endQuoteChar_cannot_be_the_empty);
      __Pyx_GIVEREF(__pyx_kp_u_endQuoteChar_cannot_be_the_empty);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_kp_u_endQuoteChar_cannot_be_the_empty);
      __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
      __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
      PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_builtin_SyntaxWarning);
      __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2881, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 2881, __pyx_L1_error)
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2881, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "cPyparsing.pyx":2882
 *             if not endQuoteChar:
 *                 warnings.warn("endQuoteChar cannot be the empty string", SyntaxWarning, stacklevel=2)
 *                 raise SyntaxError()             # <<<<<<<<<<<<<<
 * 
 *         self.quoteChar = quoteChar
 */
      __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_builtin_SyntaxError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2882, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 2882, __pyx_L1_error)

      /* "cPyparsing.pyx":2880
 *         else:
 *             endQuoteChar = endQuoteChar.strip()
 *             if not endQuoteChar:             # <<<<<<<<<<<<<<
 *                 warnings.warn("endQuoteChar cannot be the empty string", SyntaxWarning, stacklevel=2)
 *                 raise SyntaxError()
 */
    }
  }
  __pyx_L4:;

  /* "cPyparsing.pyx":2884
 *                 raise SyntaxError()
 * 
 *         self.quoteChar = quoteChar             # <<<<<<<<<<<<<<
 *         self.quoteCharLen = len(quoteChar)
 *         self.firstQuoteChar = quoteChar[0]
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_quoteChar, __pyx_v_quoteChar) < 0) __PYX_ERR(0, 2884, __pyx_L1_error)

  /* "cPyparsing.pyx":2885
 * 
 *         self.quoteChar = quoteChar
 *         self.quoteCharLen = len(quoteChar)             # <<<<<<<<<<<<<<
 *         self.firstQuoteChar = quoteChar[0]
 *         self.endQuoteChar = endQuoteChar
 */
  __pyx_t_7 = PyObject_Length(__pyx_v_quoteChar); if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 2885, __pyx_L1_error)
  __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_quoteCharLen, __pyx_t_3) < 0) __PYX_ERR(0, 2885, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":2886
 *         self.quoteChar = quoteChar
 *         self.quoteCharLen = len(quoteChar)
 *         self.firstQuoteChar = quoteChar[0]             # <<<<<<<<<<<<<<
 *         self.endQuoteChar = endQuoteChar
 *         self.endQuoteCharLen = len(endQuoteChar)
 */
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_quoteChar, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_firstQuoteChar, __pyx_t_3) < 0) __PYX_ERR(0, 2886, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":2887
 *         self.quoteCharLen = len(quoteChar)
 *         self.firstQuoteChar = quoteChar[0]
 *         self.endQuoteChar = endQuoteChar             # <<<<<<<<<<<<<<
 *         self.endQuoteCharLen = len(endQuoteChar)
 *         self.escChar = escChar
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_endQuoteChar, __pyx_v_endQuoteChar) < 0) __PYX_ERR(0, 2887, __pyx_L1_error)

  /* "cPyparsing.pyx":2888
 *         self.firstQuoteChar = quoteChar[0]
 *         self.endQuoteChar = endQuoteChar
 *         self.endQuoteCharLen = len(endQuoteChar)             # <<<<<<<<<<<<<<
 *         self.escChar = escChar
 *         self.escQuote = escQuote
 */
  __pyx_t_7 = PyObject_Length(__pyx_v_endQuoteChar); if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 2888, __pyx_L1_error)
  __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_endQuoteCharLen, __pyx_t_3) < 0) __PYX_ERR(0, 2888, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":2889
 *         self.endQuoteChar = endQuoteChar
 *         self.endQuoteCharLen = len(endQuoteChar)
 *         self.escChar = escChar             # <<<<<<<<<<<<<<
 *         self.escQuote = escQuote
 *         self.unquoteResults = unquoteResults
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_escChar, __pyx_v_escChar) < 0) __PYX_ERR(0, 2889, __pyx_L1_error)

  /* "cPyparsing.pyx":2890
 *         self.endQuoteCharLen = len(endQuoteChar)
 *         self.escChar = escChar
 *         self.escQuote = escQuote             # <<<<<<<<<<<<<<
 *         self.unquoteResults = unquoteResults
 *         self.convertWhitespaceEscapes = convertWhitespaceEscapes
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_escQuote, __pyx_v_escQuote) < 0) __PYX_ERR(0, 2890, __pyx_L1_error)

  /* "cPyparsing.pyx":2891
 *         self.escChar = escChar
 *         self.escQuote = escQuote
 *         self.unquoteResults = unquoteResults             # <<<<<<<<<<<<<<
 *         self.convertWhitespaceEscapes = convertWhitespaceEscapes
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_unquoteResults, __pyx_v_unquoteResults) < 0) __PYX_ERR(0, 2891, __pyx_L1_error)

  /* "cPyparsing.pyx":2892
 *         self.escQuote = escQuote
 *         self.unquoteResults = unquoteResults
 *         self.convertWhitespaceEscapes = convertWhitespaceEscapes             # <<<<<<<<<<<<<<
 * 
 *         if multiline:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_convertWhitespaceEscapes, __pyx_v_convertWhitespaceEscapes) < 0) __PYX_ERR(0, 2892, __pyx_L1_error)

  /* "cPyparsing.pyx":2894
 *         self.convertWhitespaceEscapes = convertWhitespaceEscapes
 * 
 *         if multiline:             # <<<<<<<<<<<<<<
 *             self.flags = re.MULTILINE | re.DOTALL
 *             self.pattern = r'%s(?:[^%s%s]' % \
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_multiline); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 2894, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":2895
 * 
 *         if multiline:
 *             self.flags = re.MULTILINE | re.DOTALL             # <<<<<<<<<<<<<<
 *             self.pattern = r'%s(?:[^%s%s]' % \
 *                 (re.escape(self.quoteChar),
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_re); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2895, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_MULTILINE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2895, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_re); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2895, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_DOTALL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2895, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Or(__pyx_t_1, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2895, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_flags, __pyx_t_3) < 0) __PYX_ERR(0, 2895, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":2897
 *             self.flags = re.MULTILINE | re.DOTALL
 *             self.pattern = r'%s(?:[^%s%s]' % \
 *                 (re.escape(self.quoteChar),             # <<<<<<<<<<<<<<
 *                  _escapeRegexRangeChars(self.endQuoteChar[0]),
 *                  (escChar is not None and _escapeRegexRangeChars(escChar) or ''))
 */
    __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2897, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_escape); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2897, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_quoteChar); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2897, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (!__pyx_t_2) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2897, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_6};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2897, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_6};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2897, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2897, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_2); __pyx_t_2 = NULL;
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_8, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2897, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2898
 *             self.pattern = r'%s(?:[^%s%s]' % \
 *                 (re.escape(self.quoteChar),
 *                  _escapeRegexRangeChars(self.endQuoteChar[0]),             # <<<<<<<<<<<<<<
 *                  (escChar is not None and _escapeRegexRangeChars(escChar) or ''))
 *         else:
 */
    __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_escapeRegexRangeChars); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2898, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_endQuoteChar); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2898, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_6, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2898, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2898, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_2};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2898, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_2};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2898, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2898, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_GIVEREF(__pyx_t_2);
        PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_2);
        __pyx_t_2 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2898, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":2899
 *                 (re.escape(self.quoteChar),
 *                  _escapeRegexRangeChars(self.endQuoteChar[0]),
 *                  (escChar is not None and _escapeRegexRangeChars(escChar) or ''))             # <<<<<<<<<<<<<<
 *         else:
 *             self.flags = 0
 */
    __pyx_t_5 = (__pyx_v_escChar != Py_None);
    if (!__pyx_t_5) {
      goto __pyx_L8_next_or;
    } else {
    }
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_escapeRegexRangeChars); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2899, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_escChar); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2899, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_escChar};
        __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2899, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_9);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_escChar};
        __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2899, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_9);
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2899, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_v_escChar);
        __Pyx_GIVEREF(__pyx_v_escChar);
        PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_v_escChar);
        __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_10, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2899, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 2899, __pyx_L1_error)
    if (!__pyx_t_5) {
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else {
      __Pyx_INCREF(__pyx_t_9);
      __pyx_t_8 = __pyx_t_9;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_L8_next_or:;
    __Pyx_INCREF(__pyx_kp_u__9);
    __pyx_t_8 = __pyx_kp_u__9;
    __pyx_L7_bool_binop_done:;

    /* "cPyparsing.pyx":2897
 *             self.flags = re.MULTILINE | re.DOTALL
 *             self.pattern = r'%s(?:[^%s%s]' % \
 *                 (re.escape(self.quoteChar),             # <<<<<<<<<<<<<<
 *                  _escapeRegexRangeChars(self.endQuoteChar[0]),
 *                  (escChar is not None and _escapeRegexRangeChars(escChar) or ''))
 */
    __pyx_t_9 = PyTuple_New(3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2897, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_t_8);
    __pyx_t_3 = 0;
    __pyx_t_1 = 0;
    __pyx_t_8 = 0;

    /* "cPyparsing.pyx":2896
 *         if multiline:
 *             self.flags = re.MULTILINE | re.DOTALL
 *             self.pattern = r'%s(?:[^%s%s]' % \             # <<<<<<<<<<<<<<
 *                 (re.escape(self.quoteChar),
 *                  _escapeRegexRangeChars(self.endQuoteChar[0]),
 */
    __pyx_t_8 = PyUnicode_Format(__pyx_kp_u_s_s_s_2, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2896, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern, __pyx_t_8) < 0) __PYX_ERR(0, 2896, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":2894
 *         self.convertWhitespaceEscapes = convertWhitespaceEscapes
 * 
 *         if multiline:             # <<<<<<<<<<<<<<
 *             self.flags = re.MULTILINE | re.DOTALL
 *             self.pattern = r'%s(?:[^%s%s]' % \
 */
    goto __pyx_L6;
  }

  /* "cPyparsing.pyx":2901
 *                  (escChar is not None and _escapeRegexRangeChars(escChar) or ''))
 *         else:
 *             self.flags = 0             # <<<<<<<<<<<<<<
 *             self.pattern = r'%s(?:[^%s\n\r%s]' % \
 *                 (re.escape(self.quoteChar),
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_flags, __pyx_int_0) < 0) __PYX_ERR(0, 2901, __pyx_L1_error)

    /* "cPyparsing.pyx":2903
 *             self.flags = 0
 *             self.pattern = r'%s(?:[^%s\n\r%s]' % \
 *                 (re.escape(self.quoteChar),             # <<<<<<<<<<<<<<
 *                  _escapeRegexRangeChars(self.endQuoteChar[0]),
 *                  (escChar is not None and _escapeRegexRangeChars(escChar) or ''))
 */
    __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_re); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2903, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_escape); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2903, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_quoteChar); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2903, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (!__pyx_t_3) {
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2903, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_8);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2903, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2903, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_2 = PyTuple_New(1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2903, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3); __pyx_t_3 = NULL;
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_2, 0+1, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2903, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2904
 *             self.pattern = r'%s(?:[^%s\n\r%s]' % \
 *                 (re.escape(self.quoteChar),
 *                  _escapeRegexRangeChars(self.endQuoteChar[0]),             # <<<<<<<<<<<<<<
 *                  (escChar is not None and _escapeRegexRangeChars(escChar) or ''))
 *         if len(self.endQuoteChar) > 1:
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_escapeRegexRangeChars); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2904, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_endQuoteChar); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2904, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_9, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2904, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (!__pyx_t_9) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2904, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_3};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2904, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_3};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2904, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2904, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_9); __pyx_t_9 = NULL;
        __Pyx_GIVEREF(__pyx_t_3);
        PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_3);
        __pyx_t_3 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_10, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2904, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":2905
 *                 (re.escape(self.quoteChar),
 *                  _escapeRegexRangeChars(self.endQuoteChar[0]),
 *                  (escChar is not None and _escapeRegexRangeChars(escChar) or ''))             # <<<<<<<<<<<<<<
 *         if len(self.endQuoteChar) > 1:
 *             self.pattern += (
 */
    __pyx_t_5 = (__pyx_v_escChar != Py_None);
    if (!__pyx_t_5) {
      goto __pyx_L11_next_or;
    } else {
    }
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_escapeRegexRangeChars); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2905, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (!__pyx_t_9) {
      __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_escChar); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2905, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_v_escChar};
        __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2905, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_10);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_v_escChar};
        __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2905, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_10);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2905, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_9); __pyx_t_9 = NULL;
        __Pyx_INCREF(__pyx_v_escChar);
        __Pyx_GIVEREF(__pyx_v_escChar);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_escChar);
        __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2905, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 2905, __pyx_L1_error)
    if (!__pyx_t_5) {
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    } else {
      __Pyx_INCREF(__pyx_t_10);
      __pyx_t_2 = __pyx_t_10;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_L11_next_or:;
    __Pyx_INCREF(__pyx_kp_u__9);
    __pyx_t_2 = __pyx_kp_u__9;
    __pyx_L10_bool_binop_done:;

    /* "cPyparsing.pyx":2903
 *             self.flags = 0
 *             self.pattern = r'%s(?:[^%s\n\r%s]' % \
 *                 (re.escape(self.quoteChar),             # <<<<<<<<<<<<<<
 *                  _escapeRegexRangeChars(self.endQuoteChar[0]),
 *                  (escChar is not None and _escapeRegexRangeChars(escChar) or ''))
 */
    __pyx_t_10 = PyTuple_New(3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2903, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_10, 2, __pyx_t_2);
    __pyx_t_8 = 0;
    __pyx_t_1 = 0;
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":2902
 *         else:
 *             self.flags = 0
 *             self.pattern = r'%s(?:[^%s\n\r%s]' % \             # <<<<<<<<<<<<<<
 *                 (re.escape(self.quoteChar),
 *                  _escapeRegexRangeChars(self.endQuoteChar[0]),
 */
    __pyx_t_2 = PyUnicode_Format(__pyx_kp_u_s_s_n_r_s, __pyx_t_10); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2902, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern, __pyx_t_2) < 0) __PYX_ERR(0, 2902, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L6:;

  /* "cPyparsing.pyx":2906
 *                  _escapeRegexRangeChars(self.endQuoteChar[0]),
 *                  (escChar is not None and _escapeRegexRangeChars(escChar) or ''))
 *         if len(self.endQuoteChar) > 1:             # <<<<<<<<<<<<<<
 *             self.pattern += (
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_endQuoteChar); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2906, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = PyObject_Length(__pyx_t_2); if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 2906, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = ((__pyx_t_7 > 1) != 0);
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":2907
 *                  (escChar is not None and _escapeRegexRangeChars(escChar) or ''))
 *         if len(self.endQuoteChar) > 1:
 *             self.pattern += (             # <<<<<<<<<<<<<<
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2907, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "cPyparsing.pyx":2908
 *         if len(self.endQuoteChar) > 1:
 *             self.pattern += (
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),             # <<<<<<<<<<<<<<
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')'
 */
    __pyx_t_10 = __pyx_pf_10cPyparsing_12QuotedString_8__init___genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2908, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_1 = __Pyx_Generator_Next(__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2908, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = PyUnicode_Join(__pyx_kp_u__93, __pyx_t_1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2908, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_kp_u__92, __pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2908, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "cPyparsing.pyx":2910
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')'             # <<<<<<<<<<<<<<
 *             )
 *         if escQuote:
 */
    __pyx_t_10 = __Pyx_PyUnicode_Concat(__pyx_t_1, __pyx_kp_u__94); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2907
 *                  (escChar is not None and _escapeRegexRangeChars(escChar) or ''))
 *         if len(self.endQuoteChar) > 1:
 *             self.pattern += (             # <<<<<<<<<<<<<<
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),
 *                                                    _escapeRegexRangeChars(self.endQuoteChar[i]))
 */
    __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_t_2, __pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2907, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern, __pyx_t_1) < 0) __PYX_ERR(0, 2907, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":2906
 *                  _escapeRegexRangeChars(self.endQuoteChar[0]),
 *                  (escChar is not None and _escapeRegexRangeChars(escChar) or ''))
 *         if len(self.endQuoteChar) > 1:             # <<<<<<<<<<<<<<
 *             self.pattern += (
 *                 '|(?:' + ')|(?:'.join("%s[^%s]" % (re.escape(self.endQuoteChar[:i]),
 */
  }

  /* "cPyparsing.pyx":2912
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')'
 *             )
 *         if escQuote:             # <<<<<<<<<<<<<<
 *             self.pattern += (r'|(?:%s)' % re.escape(escQuote))
 *         if escChar:
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_escQuote); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 2912, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":2913
 *             )
 *         if escQuote:
 *             self.pattern += (r'|(?:%s)' % re.escape(escQuote))             # <<<<<<<<<<<<<<
 *         if escChar:
 *             self.pattern += (r'|(?:%s.)' % re.escape(escChar))
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2913, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2913, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_escape); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2913, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    if (!__pyx_t_2) {
      __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_v_escQuote); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2913, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_escQuote};
        __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2913, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_GOTREF(__pyx_t_10);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_escQuote};
        __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2913, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_GOTREF(__pyx_t_10);
      } else
      #endif
      {
        __pyx_t_3 = PyTuple_New(1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2913, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2); __pyx_t_2 = NULL;
        __Pyx_INCREF(__pyx_v_escQuote);
        __Pyx_GIVEREF(__pyx_v_escQuote);
        PyTuple_SET_ITEM(__pyx_t_3, 0+1, __pyx_v_escQuote);
        __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_3, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2913, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = PyUnicode_Format(__pyx_kp_u_s_5, __pyx_t_10); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2913, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = PyNumber_InPlaceAdd(__pyx_t_1, __pyx_t_8); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2913, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern, __pyx_t_10) < 0) __PYX_ERR(0, 2913, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "cPyparsing.pyx":2912
 *                                       for i in range(len(self.endQuoteChar) - 1, 0, -1)) + ')'
 *             )
 *         if escQuote:             # <<<<<<<<<<<<<<
 *             self.pattern += (r'|(?:%s)' % re.escape(escQuote))
 *         if escChar:
 */
  }

  /* "cPyparsing.pyx":2914
 *         if escQuote:
 *             self.pattern += (r'|(?:%s)' % re.escape(escQuote))
 *         if escChar:             # <<<<<<<<<<<<<<
 *             self.pattern += (r'|(?:%s.)' % re.escape(escChar))
 *             self.escCharReplacePattern = re.escape(self.escChar) + "(.)"
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_escChar); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 2914, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":2915
 *             self.pattern += (r'|(?:%s)' % re.escape(escQuote))
 *         if escChar:
 *             self.pattern += (r'|(?:%s.)' % re.escape(escChar))             # <<<<<<<<<<<<<<
 *             self.escCharReplacePattern = re.escape(self.escChar) + "(.)"
 *         self.pattern += (r')*%s' % re.escape(self.endQuoteChar))
 */
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2915, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_re); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2915, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_escape); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2915, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (!__pyx_t_1) {
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_escChar); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2915, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_v_escChar};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2915, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_8);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_v_escChar};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2915, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_8);
      } else
      #endif
      {
        __pyx_t_2 = PyTuple_New(1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2915, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1); __pyx_t_1 = NULL;
        __Pyx_INCREF(__pyx_v_escChar);
        __Pyx_GIVEREF(__pyx_v_escChar);
        PyTuple_SET_ITEM(__pyx_t_2, 0+1, __pyx_v_escChar);
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_2, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2915, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyUnicode_Format(__pyx_kp_u_s_6, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2915, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = PyNumber_InPlaceAdd(__pyx_t_10, __pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2915, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern, __pyx_t_8) < 0) __PYX_ERR(0, 2915, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":2916
 *         if escChar:
 *             self.pattern += (r'|(?:%s.)' % re.escape(escChar))
 *             self.escCharReplacePattern = re.escape(self.escChar) + "(.)"             # <<<<<<<<<<<<<<
 *         self.pattern += (r')*%s' % re.escape(self.endQuoteChar))
 * 
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_re); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2916, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_escape); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2916, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_escChar); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2916, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
      }
    }
    if (!__pyx_t_2) {
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2916, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_8);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_3};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2916, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_3};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2916, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else
      #endif
      {
        __pyx_t_1 = PyTuple_New(1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2916, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2); __pyx_t_2 = NULL;
        __Pyx_GIVEREF(__pyx_t_3);
        PyTuple_SET_ITEM(__pyx_t_1, 0+1, __pyx_t_3);
        __pyx_t_3 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_1, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2916, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = PyNumber_Add(__pyx_t_8, __pyx_kp_u__95); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2916, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_escCharReplacePattern, __pyx_t_10) < 0) __PYX_ERR(0, 2916, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "cPyparsing.pyx":2914
 *         if escQuote:
 *             self.pattern += (r'|(?:%s)' % re.escape(escQuote))
 *         if escChar:             # <<<<<<<<<<<<<<
 *             self.pattern += (r'|(?:%s.)' % re.escape(escChar))
 *             self.escCharReplacePattern = re.escape(self.escChar) + "(.)"
 */
  }

  /* "cPyparsing.pyx":2917
 *             self.pattern += (r'|(?:%s.)' % re.escape(escChar))
 *             self.escCharReplacePattern = re.escape(self.escChar) + "(.)"
 *         self.pattern += (r')*%s' % re.escape(self.endQuoteChar))             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2917, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_re); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2917, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_escape); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2917, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_endQuoteChar); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2917, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2917, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GOTREF(__pyx_t_8);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_1};
      __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2917, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_1};
      __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2917, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2917, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2917, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyUnicode_Format(__pyx_kp_u_s_7, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2917, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = PyNumber_InPlaceAdd(__pyx_t_10, __pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2917, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern, __pyx_t_8) < 0) __PYX_ERR(0, 2917, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":2919
 *         self.pattern += (r')*%s' % re.escape(self.endQuoteChar))
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             self.re = re.compile(self.pattern, self.flags)
 *             self.reString = self.pattern
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
    __Pyx_XGOTREF(__pyx_t_11);
    __Pyx_XGOTREF(__pyx_t_12);
    __Pyx_XGOTREF(__pyx_t_13);
    /*try:*/ {

      /* "cPyparsing.pyx":2920
 * 
 *         try:
 *             self.re = re.compile(self.pattern, self.flags)             # <<<<<<<<<<<<<<
 *             self.reString = self.pattern
 *         except sre_constants.error:
 */
      __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_re); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2920, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_compile); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2920, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2920, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_flags); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2920, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_1 = NULL;
      __pyx_t_14 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_14 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_t_3, __pyx_t_6};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2920, __pyx_L16_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_t_3, __pyx_t_6};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2920, __pyx_L16_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_2 = PyTuple_New(2+__pyx_t_14); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2920, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (__pyx_t_1) {
          __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1); __pyx_t_1 = NULL;
        }
        __Pyx_GIVEREF(__pyx_t_3);
        PyTuple_SET_ITEM(__pyx_t_2, 0+__pyx_t_14, __pyx_t_3);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_2, 1+__pyx_t_14, __pyx_t_6);
        __pyx_t_3 = 0;
        __pyx_t_6 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_2, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2920, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_re, __pyx_t_8) < 0) __PYX_ERR(0, 2920, __pyx_L16_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "cPyparsing.pyx":2921
 *         try:
 *             self.re = re.compile(self.pattern, self.flags)
 *             self.reString = self.pattern             # <<<<<<<<<<<<<<
 *         except sre_constants.error:
 *             warnings.warn("invalid pattern (%s) passed to Regex" % self.pattern,
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2921, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_reString, __pyx_t_8) < 0) __PYX_ERR(0, 2921, __pyx_L16_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "cPyparsing.pyx":2919
 *         self.pattern += (r')*%s' % re.escape(self.endQuoteChar))
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             self.re = re.compile(self.pattern, self.flags)
 *             self.reString = self.pattern
 */
    }
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    goto __pyx_L23_try_end;
    __pyx_L16_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":2922
 *             self.re = re.compile(self.pattern, self.flags)
 *             self.reString = self.pattern
 *         except sre_constants.error:             # <<<<<<<<<<<<<<
 *             warnings.warn("invalid pattern (%s) passed to Regex" % self.pattern,
 *                           SyntaxWarning, stacklevel=2)
 */
    __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_sre_constants); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2922, __pyx_L18_except_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_error); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2922, __pyx_L18_except_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_14 = __Pyx_PyErr_ExceptionMatches(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (__pyx_t_14) {
      __Pyx_AddTraceback("cPyparsing.QuotedString.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_10, &__pyx_t_8, &__pyx_t_2) < 0) __PYX_ERR(0, 2922, __pyx_L18_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_2);

      /* "cPyparsing.pyx":2923
 *             self.reString = self.pattern
 *         except sre_constants.error:
 *             warnings.warn("invalid pattern (%s) passed to Regex" % self.pattern,             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             raise
 */
      __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_warnings); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2923, __pyx_L18_except_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_warn); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2923, __pyx_L18_except_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_pattern); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2923, __pyx_L18_except_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_1 = PyUnicode_Format(__pyx_kp_u_invalid_pattern_s_passed_to_Rege, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2923, __pyx_L18_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "cPyparsing.pyx":2924
 *         except sre_constants.error:
 *             warnings.warn("invalid pattern (%s) passed to Regex" % self.pattern,
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *             raise
 * 
 */
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2923, __pyx_L18_except_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
      __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
      __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
      PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_builtin_SyntaxWarning);
      __pyx_t_1 = 0;
      __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2924, __pyx_L18_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 2924, __pyx_L18_except_error)

      /* "cPyparsing.pyx":2923
 *             self.reString = self.pattern
 *         except sre_constants.error:
 *             warnings.warn("invalid pattern (%s) passed to Regex" % self.pattern,             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 *             raise
 */
      __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, __pyx_t_1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2923, __pyx_L18_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "cPyparsing.pyx":2925
 *             warnings.warn("invalid pattern (%s) passed to Regex" % self.pattern,
 *                           SyntaxWarning, stacklevel=2)
 *             raise             # <<<<<<<<<<<<<<
 * 
 *         self.name = _ustr(self)
 */
      __Pyx_GIVEREF(__pyx_t_10);
      __Pyx_GIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_ErrRestoreWithState(__pyx_t_10, __pyx_t_8, __pyx_t_2);
      __pyx_t_10 = 0; __pyx_t_8 = 0; __pyx_t_2 = 0; 
      __PYX_ERR(0, 2925, __pyx_L18_except_error)
    }
    goto __pyx_L18_except_error;
    __pyx_L18_except_error:;

    /* "cPyparsing.pyx":2919
 *         self.pattern += (r')*%s' % re.escape(self.endQuoteChar))
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             self.re = re.compile(self.pattern, self.flags)
 *             self.reString = self.pattern
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_11);
    __Pyx_XGIVEREF(__pyx_t_12);
    __Pyx_XGIVEREF(__pyx_t_13);
    __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
    goto __pyx_L1_error;
    __pyx_L23_try_end:;
  }

  /* "cPyparsing.pyx":2927
 *             raise
 * 
 *         self.name = _ustr(self)             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected " + self.name
 *         self.mayIndexError = False
 */
  __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2927, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  if (!__pyx_t_10) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_cur_scope->__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2927, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_8)) {
      PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_cur_scope->__pyx_v_self};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2927, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
      PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_cur_scope->__pyx_v_self};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2927, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2927, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_10); __pyx_t_10 = NULL;
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_cur_scope->__pyx_v_self);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_9, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2927, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_name, __pyx_t_2) < 0) __PYX_ERR(0, 2927, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2928
 * 
 *         self.name = _ustr(self)
 *         self.errmsg = "Expected " + self.name             # <<<<<<<<<<<<<<
 *         self.mayIndexError = False
 *         self.mayReturnEmpty = True
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = PyNumber_Add(__pyx_kp_u_Expected, __pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_8) < 0) __PYX_ERR(0, 2928, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":2929
 *         self.name = _ustr(self)
 *         self.errmsg = "Expected " + self.name
 *         self.mayIndexError = False             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_mayIndexError, Py_False) < 0) __PYX_ERR(0, 2929, __pyx_L1_error)

  /* "cPyparsing.pyx":2930
 *         self.errmsg = "Expected " + self.name
 *         self.mayIndexError = False
 *         self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 2930, __pyx_L1_error)

  /* "cPyparsing.pyx":2867
 *     """
 * 
 *     def __init__(self, quoteChar, escChar=None, escQuote=None, multiline=False, unquoteResults=True, endQuoteChar=None, convertWhitespaceEscapes=True):             # <<<<<<<<<<<<<<
 *         super(QuotedString, self).__init__()
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("cPyparsing.QuotedString.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_quoteChar);
  __Pyx_XDECREF(__pyx_v_endQuoteChar);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2932
 *         self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = instring[loc] == self.firstQuoteChar and self.re.match(instring, loc) or None
 *         if not result:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12QuotedString_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12QuotedString_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_12QuotedString_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_12QuotedString_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 2932, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 2932, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 2932, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2932, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2932, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.QuotedString.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12QuotedString_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12QuotedString_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_v_ws_map = NULL;
  PyObject *__pyx_v_wslit = NULL;
  PyObject *__pyx_v_wschar = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  int __pyx_t_13;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":2933
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         result = instring[loc] == self.firstQuoteChar and self.re.match(instring, loc) or None             # <<<<<<<<<<<<<<
 *         if not result:
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_instring, __pyx_v_loc, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_firstQuoteChar); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_2, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2933, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 2933, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (!__pyx_t_5) {
    goto __pyx_L4_next_or;
  } else {
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_re); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_match); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_v_instring, __pyx_t_3};
    __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2933, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_v_instring, __pyx_t_3};
    __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2933, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  {
    __pyx_t_8 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2933, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__pyx_t_6) {
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6); __pyx_t_6 = NULL;
    }
    __Pyx_INCREF(__pyx_v_instring);
    __Pyx_GIVEREF(__pyx_v_instring);
    PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_v_instring);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_8, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2933, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 2933, __pyx_L1_error)
  if (!__pyx_t_5) {
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_1 = __pyx_t_4;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_L4_next_or:;
  __Pyx_INCREF(Py_None);
  __pyx_t_1 = Py_None;
  __pyx_L3_bool_binop_done:;
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2934
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         result = instring[loc] == self.firstQuoteChar and self.re.match(instring, loc) or None
 *         if not result:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_result); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 2934, __pyx_L1_error)
  __pyx_t_9 = ((!__pyx_t_5) != 0);
  if (__pyx_t_9) {

    /* "cPyparsing.pyx":2935
 *         result = instring[loc] == self.firstQuoteChar and self.re.match(instring, loc) or None
 *         if not result:
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *         loc = result.end()
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2935, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2935, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2935, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_3 = NULL;
    __pyx_t_7 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[5] = {__pyx_t_3, __pyx_v_instring, __pyx_t_2, __pyx_t_8, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_7, 4+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2935, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[5] = {__pyx_t_3, __pyx_v_instring, __pyx_t_2, __pyx_t_8, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_7, 4+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2935, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(4+__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2935, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__pyx_t_3) {
        __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_3); __pyx_t_3 = NULL;
      }
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_7, __pyx_v_instring);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_7, __pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_8);
      PyTuple_SET_ITEM(__pyx_t_6, 2+__pyx_t_7, __pyx_t_8);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_6, 3+__pyx_t_7, __pyx_v_self);
      __pyx_t_2 = 0;
      __pyx_t_8 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2935, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 2935, __pyx_L1_error)

    /* "cPyparsing.pyx":2934
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         result = instring[loc] == self.firstQuoteChar and self.re.match(instring, loc) or None
 *         if not result:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  }

  /* "cPyparsing.pyx":2937
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *         loc = result.end()             # <<<<<<<<<<<<<<
 *         ret = result.group()
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_end); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2937, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_6) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2937, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2937, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2937, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_loc = __pyx_t_7;

  /* "cPyparsing.pyx":2938
 * 
 *         loc = result.end()
 *         ret = result.group()             # <<<<<<<<<<<<<<
 * 
 *         if self.unquoteResults:
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_group); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_6) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2938, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2938, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_ret = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2940
 *         ret = result.group()
 * 
 *         if self.unquoteResults:             # <<<<<<<<<<<<<<
 * 
 *             # strip off quotes
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_unquoteResults); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2940, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 2940, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_9) {

    /* "cPyparsing.pyx":2943
 * 
 *             # strip off quotes
 *             ret = ret[self.quoteCharLen:-self.endQuoteCharLen]             # <<<<<<<<<<<<<<
 * 
 *             if isinstance(ret, basestring):
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_quoteCharLen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2943, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_endQuoteCharLen); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2943, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = PyNumber_Negative(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2943, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_v_ret, 0, 0, &__pyx_t_1, &__pyx_t_6, NULL, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2943, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF_SET(__pyx_v_ret, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":2945
 *             ret = ret[self.quoteCharLen:-self.endQuoteCharLen]
 * 
 *             if isinstance(ret, basestring):             # <<<<<<<<<<<<<<
 *                 # replace escaped whitespace
 *                 if '\\' in ret and self.convertWhitespaceEscapes:
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2945, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_9 = PyObject_IsInstance(__pyx_v_ret, __pyx_t_4); if (unlikely(__pyx_t_9 == -1)) __PYX_ERR(0, 2945, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = (__pyx_t_9 != 0);
    if (__pyx_t_5) {

      /* "cPyparsing.pyx":2947
 *             if isinstance(ret, basestring):
 *                 # replace escaped whitespace
 *                 if '\\' in ret and self.convertWhitespaceEscapes:             # <<<<<<<<<<<<<<
 *                     ws_map = {
 *                         r'\t': '\t',
 */
      __pyx_t_9 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u__96, __pyx_v_ret, Py_EQ)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 2947, __pyx_L1_error)
      __pyx_t_10 = (__pyx_t_9 != 0);
      if (__pyx_t_10) {
      } else {
        __pyx_t_5 = __pyx_t_10;
        goto __pyx_L10_bool_binop_done;
      }
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_convertWhitespaceEscapes); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2947, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(0, 2947, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_5 = __pyx_t_10;
      __pyx_L10_bool_binop_done:;
      if (__pyx_t_5) {

        /* "cPyparsing.pyx":2949
 *                 if '\\' in ret and self.convertWhitespaceEscapes:
 *                     ws_map = {
 *                         r'\t': '\t',             # <<<<<<<<<<<<<<
 *                         r'\n': '\n',
 *                         r'\f': '\f',
 */
        __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2949, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        if (PyDict_SetItem(__pyx_t_4, __pyx_kp_u_t_2, __pyx_kp_u__97) < 0) __PYX_ERR(0, 2949, __pyx_L1_error)
        if (PyDict_SetItem(__pyx_t_4, __pyx_kp_u_n_2, __pyx_kp_u__21) < 0) __PYX_ERR(0, 2949, __pyx_L1_error)
        if (PyDict_SetItem(__pyx_t_4, __pyx_kp_u_f, __pyx_kp_u__98) < 0) __PYX_ERR(0, 2949, __pyx_L1_error)
        if (PyDict_SetItem(__pyx_t_4, __pyx_kp_u_r_2, __pyx_kp_u__99) < 0) __PYX_ERR(0, 2949, __pyx_L1_error)
        __pyx_v_ws_map = ((PyObject*)__pyx_t_4);
        __pyx_t_4 = 0;

        /* "cPyparsing.pyx":2954
 *                         r'\r': '\r',
 *                     }
 *                     for wslit, wschar in ws_map.items():             # <<<<<<<<<<<<<<
 *                         ret = ret.replace(wslit, wschar)
 * 
 */
        __pyx_t_11 = 0;
        __pyx_t_6 = __Pyx_dict_iterator(__pyx_v_ws_map, 1, __pyx_n_s_items, (&__pyx_t_12), (&__pyx_t_7)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2954, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_4);
        __pyx_t_4 = __pyx_t_6;
        __pyx_t_6 = 0;
        while (1) {
          __pyx_t_13 = __Pyx_dict_iter_next(__pyx_t_4, __pyx_t_12, &__pyx_t_11, &__pyx_t_6, &__pyx_t_1, NULL, __pyx_t_7);
          if (unlikely(__pyx_t_13 == 0)) break;
          if (unlikely(__pyx_t_13 == -1)) __PYX_ERR(0, 2954, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_XDECREF_SET(__pyx_v_wslit, __pyx_t_6);
          __pyx_t_6 = 0;
          __Pyx_XDECREF_SET(__pyx_v_wschar, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "cPyparsing.pyx":2955
 *                     }
 *                     for wslit, wschar in ws_map.items():
 *                         ret = ret.replace(wslit, wschar)             # <<<<<<<<<<<<<<
 * 
 *                 # replace escaped characters
 */
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ret, __pyx_n_s_replace); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2955, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_8 = NULL;
          __pyx_t_13 = 0;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
            if (likely(__pyx_t_8)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
              __Pyx_INCREF(__pyx_t_8);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_6, function);
              __pyx_t_13 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_6)) {
            PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_wslit, __pyx_v_wschar};
            __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_13, 2+__pyx_t_13); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2955, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_GOTREF(__pyx_t_1);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
            PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_wslit, __pyx_v_wschar};
            __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_13, 2+__pyx_t_13); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2955, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_GOTREF(__pyx_t_1);
          } else
          #endif
          {
            __pyx_t_2 = PyTuple_New(2+__pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2955, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            if (__pyx_t_8) {
              __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_8); __pyx_t_8 = NULL;
            }
            __Pyx_INCREF(__pyx_v_wslit);
            __Pyx_GIVEREF(__pyx_v_wslit);
            PyTuple_SET_ITEM(__pyx_t_2, 0+__pyx_t_13, __pyx_v_wslit);
            __Pyx_INCREF(__pyx_v_wschar);
            __Pyx_GIVEREF(__pyx_v_wschar);
            PyTuple_SET_ITEM(__pyx_t_2, 1+__pyx_t_13, __pyx_v_wschar);
            __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2955, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          }
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF_SET(__pyx_v_ret, __pyx_t_1);
          __pyx_t_1 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "cPyparsing.pyx":2947
 *             if isinstance(ret, basestring):
 *                 # replace escaped whitespace
 *                 if '\\' in ret and self.convertWhitespaceEscapes:             # <<<<<<<<<<<<<<
 *                     ws_map = {
 *                         r'\t': '\t',
 */
      }

      /* "cPyparsing.pyx":2958
 * 
 *                 # replace escaped characters
 *                 if self.escChar:             # <<<<<<<<<<<<<<
 *                     ret = re.sub(self.escCharReplacePattern, r"\g<1>", ret)
 * 
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_escChar); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2958, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 2958, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_5) {

        /* "cPyparsing.pyx":2959
 *                 # replace escaped characters
 *                 if self.escChar:
 *                     ret = re.sub(self.escCharReplacePattern, r"\g<1>", ret)             # <<<<<<<<<<<<<<
 * 
 *                 # replace escaped quotes
 */
        __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_re); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2959, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_sub); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2959, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_escCharReplacePattern); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2959, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = NULL;
        __pyx_t_7 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_2)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_2);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
            __pyx_t_7 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[4] = {__pyx_t_2, __pyx_t_1, __pyx_kp_u_g_1, __pyx_v_ret};
          __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2959, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[4] = {__pyx_t_2, __pyx_t_1, __pyx_kp_u_g_1, __pyx_v_ret};
          __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2959, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        } else
        #endif
        {
          __pyx_t_8 = PyTuple_New(3+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2959, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          if (__pyx_t_2) {
            __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_2); __pyx_t_2 = NULL;
          }
          __Pyx_GIVEREF(__pyx_t_1);
          PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_t_1);
          __Pyx_INCREF(__pyx_kp_u_g_1);
          __Pyx_GIVEREF(__pyx_kp_u_g_1);
          PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_kp_u_g_1);
          __Pyx_INCREF(__pyx_v_ret);
          __Pyx_GIVEREF(__pyx_v_ret);
          PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_7, __pyx_v_ret);
          __pyx_t_1 = 0;
          __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_8, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2959, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF_SET(__pyx_v_ret, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "cPyparsing.pyx":2958
 * 
 *                 # replace escaped characters
 *                 if self.escChar:             # <<<<<<<<<<<<<<
 *                     ret = re.sub(self.escCharReplacePattern, r"\g<1>", ret)
 * 
 */
      }

      /* "cPyparsing.pyx":2962
 * 
 *                 # replace escaped quotes
 *                 if self.escQuote:             # <<<<<<<<<<<<<<
 *                     ret = ret.replace(self.escQuote, self.endQuoteChar)
 * 
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_escQuote); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2962, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 2962, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_5) {

        /* "cPyparsing.pyx":2963
 *                 # replace escaped quotes
 *                 if self.escQuote:
 *                     ret = ret.replace(self.escQuote, self.endQuoteChar)             # <<<<<<<<<<<<<<
 * 
 *         return loc, ret
 */
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_ret, __pyx_n_s_replace); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2963, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_escQuote); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2963, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_endQuoteChar); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2963, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = NULL;
        __pyx_t_7 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_2)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_2);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
            __pyx_t_7 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_t_8, __pyx_t_1};
          __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2963, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_t_8, __pyx_t_1};
          __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2963, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        } else
        #endif
        {
          __pyx_t_3 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2963, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          if (__pyx_t_2) {
            __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2); __pyx_t_2 = NULL;
          }
          __Pyx_GIVEREF(__pyx_t_8);
          PyTuple_SET_ITEM(__pyx_t_3, 0+__pyx_t_7, __pyx_t_8);
          __Pyx_GIVEREF(__pyx_t_1);
          PyTuple_SET_ITEM(__pyx_t_3, 1+__pyx_t_7, __pyx_t_1);
          __pyx_t_8 = 0;
          __pyx_t_1 = 0;
          __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2963, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF_SET(__pyx_v_ret, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "cPyparsing.pyx":2962
 * 
 *                 # replace escaped quotes
 *                 if self.escQuote:             # <<<<<<<<<<<<<<
 *                     ret = ret.replace(self.escQuote, self.endQuoteChar)
 * 
 */
      }

      /* "cPyparsing.pyx":2945
 *             ret = ret[self.quoteCharLen:-self.endQuoteCharLen]
 * 
 *             if isinstance(ret, basestring):             # <<<<<<<<<<<<<<
 *                 # replace escaped whitespace
 *                 if '\\' in ret and self.convertWhitespaceEscapes:
 */
    }

    /* "cPyparsing.pyx":2940
 *         ret = result.group()
 * 
 *         if self.unquoteResults:             # <<<<<<<<<<<<<<
 * 
 *             # strip off quotes
 */
  }

  /* "cPyparsing.pyx":2965
 *                     ret = ret.replace(self.escQuote, self.endQuoteChar)
 * 
 *         return loc, ret             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4);
  __Pyx_INCREF(__pyx_v_ret);
  __Pyx_GIVEREF(__pyx_v_ret);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_ret);
  __pyx_t_4 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2932
 *         self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = instring[loc] == self.firstQuoteChar and self.re.match(instring, loc) or None
 *         if not result:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing.QuotedString.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_ws_map);
  __Pyx_XDECREF(__pyx_v_wslit);
  __Pyx_XDECREF(__pyx_v_wschar);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2967
 *         return loc, ret
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(QuotedString, self).__str__()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12QuotedString_5__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12QuotedString_5__str__ = {"__str__", (PyCFunction)__pyx_pw_10cPyparsing_12QuotedString_5__str__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_12QuotedString_5__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_12QuotedString_4__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12QuotedString_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "cPyparsing.pyx":2968
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(QuotedString, self).__str__()
 *         except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":2969
 *     def __str__(self):
 *         try:
 *             return super(QuotedString, self).__str__()             # <<<<<<<<<<<<<<
 *         except Exception:
 *             pass
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_QuotedString); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2969, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2969, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_self);
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2969, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_str_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2969, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      if (__pyx_t_5) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2969, __pyx_L3_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else {
        __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2969, __pyx_L3_error)
      }
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":2968
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(QuotedString, self).__str__()
 *         except Exception:
 */
    }
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":2970
 *         try:
 *             return super(QuotedString, self).__str__()
 *         except Exception:             # <<<<<<<<<<<<<<
 *             pass
 * 
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_7) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cPyparsing.pyx":2968
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(QuotedString, self).__str__()
 *         except Exception:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L4_exception_handled:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
  }

  /* "cPyparsing.pyx":2973
 *             pass
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "quoted string, starting with %s ending with %s" % (self.quoteChar, self.endQuoteChar)
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_8 = (__pyx_t_4 == Py_None);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_9 = (__pyx_t_8 != 0);
  if (__pyx_t_9) {

    /* "cPyparsing.pyx":2974
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "quoted string, starting with %s ending with %s" % (self.quoteChar, self.endQuoteChar)             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_quoteChar); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2974, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_endQuoteChar); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2974, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2974, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_6);
    __pyx_t_4 = 0;
    __pyx_t_6 = 0;
    __pyx_t_6 = PyUnicode_Format(__pyx_kp_u_quoted_string_starting_with_s_en, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2974, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_6) < 0) __PYX_ERR(0, 2974, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":2973
 *             pass
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "quoted string, starting with %s ending with %s" % (self.quoteChar, self.endQuoteChar)
 * 
 */
  }

  /* "cPyparsing.pyx":2976
 *             self.strRepr = "quoted string, starting with %s ending with %s" % (self.quoteChar, self.endQuoteChar)
 * 
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":2967
 *         return loc, ret
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(QuotedString, self).__str__()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.QuotedString.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":2996
 *     """
 * 
 *     def __init__(self, notChars, min=1, max=0, exact=0):             # <<<<<<<<<<<<<<
 *         super(CharsNotIn, self).__init__()
 *         self.skipWhitespace = False
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10CharsNotIn_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10CharsNotIn_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_10CharsNotIn_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10CharsNotIn_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_notChars = 0;
  PyObject *__pyx_v_min = 0;
  PyObject *__pyx_v_max = 0;
  PyObject *__pyx_v_exact = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_notChars,&__pyx_n_s_min,&__pyx_n_s_max,&__pyx_n_s_exact,0};
    PyObject* values[5] = {0,0,0,0,0};
    values[2] = ((PyObject *)((PyObject *)__pyx_int_1));
    values[3] = ((PyObject *)((PyObject *)__pyx_int_0));
    values[4] = ((PyObject *)((PyObject *)__pyx_int_0));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_notChars)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 5, 1); __PYX_ERR(0, 2996, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_min);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_max);
          if (value) { values[3] = value; kw_args--; }
        }
        case  4:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_exact);
          if (value) { values[4] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 2996, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_notChars = values[1];
    __pyx_v_min = values[2];
    __pyx_v_max = values[3];
    __pyx_v_exact = values[4];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 5, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 2996, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.CharsNotIn.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10CharsNotIn___init__(__pyx_self, __pyx_v_self, __pyx_v_notChars, __pyx_v_min, __pyx_v_max, __pyx_v_exact);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10CharsNotIn___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_notChars, PyObject *__pyx_v_min, PyObject *__pyx_v_max, PyObject *__pyx_v_exact) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":2997
 * 
 *     def __init__(self, notChars, min=1, max=0, exact=0):
 *         super(CharsNotIn, self).__init__()             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = False
 *         self.notChars = notChars
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_CharsNotIn); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2997, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2997, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2998
 *     def __init__(self, notChars, min=1, max=0, exact=0):
 *         super(CharsNotIn, self).__init__()
 *         self.skipWhitespace = False             # <<<<<<<<<<<<<<
 *         self.notChars = notChars
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, Py_False) < 0) __PYX_ERR(0, 2998, __pyx_L1_error)

  /* "cPyparsing.pyx":2999
 *         super(CharsNotIn, self).__init__()
 *         self.skipWhitespace = False
 *         self.notChars = notChars             # <<<<<<<<<<<<<<
 * 
 *         if min < 1:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_notChars, __pyx_v_notChars) < 0) __PYX_ERR(0, 2999, __pyx_L1_error)

  /* "cPyparsing.pyx":3001
 *         self.notChars = notChars
 * 
 *         if min < 1:             # <<<<<<<<<<<<<<
 *             raise ValueError("cannot specify a minimum length < 1; use Optional(CharsNotIn()) if zero-length char group is permitted")
 * 
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_min, __pyx_int_1, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3001, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 3001, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":3002
 * 
 *         if min < 1:
 *             raise ValueError("cannot specify a minimum length < 1; use Optional(CharsNotIn()) if zero-length char group is permitted")             # <<<<<<<<<<<<<<
 * 
 *         self.minLen = min
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__100, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3002, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 3002, __pyx_L1_error)

    /* "cPyparsing.pyx":3001
 *         self.notChars = notChars
 * 
 *         if min < 1:             # <<<<<<<<<<<<<<
 *             raise ValueError("cannot specify a minimum length < 1; use Optional(CharsNotIn()) if zero-length char group is permitted")
 * 
 */
  }

  /* "cPyparsing.pyx":3004
 *             raise ValueError("cannot specify a minimum length < 1; use Optional(CharsNotIn()) if zero-length char group is permitted")
 * 
 *         self.minLen = min             # <<<<<<<<<<<<<<
 * 
 *         if max > 0:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_minLen, __pyx_v_min) < 0) __PYX_ERR(0, 3004, __pyx_L1_error)

  /* "cPyparsing.pyx":3006
 *         self.minLen = min
 * 
 *         if max > 0:             # <<<<<<<<<<<<<<
 *             self.maxLen = max
 *         else:
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_max, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3006, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 3006, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":3007
 * 
 *         if max > 0:
 *             self.maxLen = max             # <<<<<<<<<<<<<<
 *         else:
 *             self.maxLen = _MAX_INT
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_maxLen, __pyx_v_max) < 0) __PYX_ERR(0, 3007, __pyx_L1_error)

    /* "cPyparsing.pyx":3006
 *         self.minLen = min
 * 
 *         if max > 0:             # <<<<<<<<<<<<<<
 *             self.maxLen = max
 *         else:
 */
    goto __pyx_L4;
  }

  /* "cPyparsing.pyx":3009
 *             self.maxLen = max
 *         else:
 *             self.maxLen = _MAX_INT             # <<<<<<<<<<<<<<
 * 
 *         if exact > 0:
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_MAX_INT); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3009, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_maxLen, __pyx_t_1) < 0) __PYX_ERR(0, 3009, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L4:;

  /* "cPyparsing.pyx":3011
 *             self.maxLen = _MAX_INT
 * 
 *         if exact > 0:             # <<<<<<<<<<<<<<
 *             self.maxLen = exact
 *             self.minLen = exact
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_exact, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3011, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 3011, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":3012
 * 
 *         if exact > 0:
 *             self.maxLen = exact             # <<<<<<<<<<<<<<
 *             self.minLen = exact
 * 
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_maxLen, __pyx_v_exact) < 0) __PYX_ERR(0, 3012, __pyx_L1_error)

    /* "cPyparsing.pyx":3013
 *         if exact > 0:
 *             self.maxLen = exact
 *             self.minLen = exact             # <<<<<<<<<<<<<<
 * 
 *         self.name = _ustr(self)
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_minLen, __pyx_v_exact) < 0) __PYX_ERR(0, 3013, __pyx_L1_error)

    /* "cPyparsing.pyx":3011
 *             self.maxLen = _MAX_INT
 * 
 *         if exact > 0:             # <<<<<<<<<<<<<<
 *             self.maxLen = exact
 *             self.minLen = exact
 */
  }

  /* "cPyparsing.pyx":3015
 *             self.minLen = exact
 * 
 *         self.name = _ustr(self)             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected " + self.name
 *         self.mayReturnEmpty = (self.minLen == 0)
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3015, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3015, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3015, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_self);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3015, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name, __pyx_t_1) < 0) __PYX_ERR(0, 3015, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3016
 * 
 *         self.name = _ustr(self)
 *         self.errmsg = "Expected " + self.name             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = (self.minLen == 0)
 *         self.mayIndexError = False
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3016, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyNumber_Add(__pyx_kp_u_Expected, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3016, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_3) < 0) __PYX_ERR(0, 3016, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3017
 *         self.name = _ustr(self)
 *         self.errmsg = "Expected " + self.name
 *         self.mayReturnEmpty = (self.minLen == 0)             # <<<<<<<<<<<<<<
 *         self.mayIndexError = False
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_minLen); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_t_3, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_1) < 0) __PYX_ERR(0, 3017, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3018
 *         self.errmsg = "Expected " + self.name
 *         self.mayReturnEmpty = (self.minLen == 0)
 *         self.mayIndexError = False             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, Py_False) < 0) __PYX_ERR(0, 3018, __pyx_L1_error)

  /* "cPyparsing.pyx":2996
 *     """
 * 
 *     def __init__(self, notChars, min=1, max=0, exact=0):             # <<<<<<<<<<<<<<
 *         super(CharsNotIn, self).__init__()
 *         self.skipWhitespace = False
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.CharsNotIn.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3020
 *         self.mayIndexError = False
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc] in self.notChars:
 *             raise ParseException(instring, loc, self.errmsg, self)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10CharsNotIn_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10CharsNotIn_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_10CharsNotIn_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10CharsNotIn_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3020, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3020, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3020, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3020, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3020, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.CharsNotIn.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10CharsNotIn_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10CharsNotIn_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  int __pyx_v_start;
  PyObject *__pyx_v_notchars = NULL;
  PyObject *__pyx_v_maxlen = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  long __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":3021
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if instring[loc] in self.notChars:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_instring, __pyx_v_loc, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3021, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_notChars); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3021, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_t_2, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 3021, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":3022
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if instring[loc] in self.notChars:
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *         start = loc
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3022, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3022, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3022, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_8 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[5] = {__pyx_t_7, __pyx_v_instring, __pyx_t_5, __pyx_t_6, __pyx_v_self};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_8, 4+__pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3022, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[5] = {__pyx_t_7, __pyx_v_instring, __pyx_t_5, __pyx_t_6, __pyx_v_self};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_8, 4+__pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3022, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(4+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3022, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (__pyx_t_7) {
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
      }
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_v_instring);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_8, __pyx_t_6);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_9, 3+__pyx_t_8, __pyx_v_self);
      __pyx_t_5 = 0;
      __pyx_t_6 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_9, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3022, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 3022, __pyx_L1_error)

    /* "cPyparsing.pyx":3021
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if instring[loc] in self.notChars:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  }

  /* "cPyparsing.pyx":3024
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *         start = loc             # <<<<<<<<<<<<<<
 *         loc += 1
 *         notchars = self.notChars
 */
  __pyx_v_start = __pyx_v_loc;

  /* "cPyparsing.pyx":3025
 * 
 *         start = loc
 *         loc += 1             # <<<<<<<<<<<<<<
 *         notchars = self.notChars
 *         maxlen = min(start + self.maxLen, len(instring))
 */
  __pyx_t_8 = 0;
  __pyx_t_10 = __Pyx_add_const_long_checking_overflow(__pyx_v_loc, 1, &__pyx_t_8);
  if (unlikely(__pyx_t_8)) {
    PyErr_SetString(PyExc_OverflowError, "value too large");
    __PYX_ERR(0, 3025, __pyx_L1_error)
  }
  __pyx_v_loc = __pyx_t_10;

  /* "cPyparsing.pyx":3026
 *         start = loc
 *         loc += 1
 *         notchars = self.notChars             # <<<<<<<<<<<<<<
 *         maxlen = min(start + self.maxLen, len(instring))
 *         while loc < maxlen and \
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_notChars); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_notchars = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3027
 *         loc += 1
 *         notchars = self.notChars
 *         maxlen = min(start + self.maxLen, len(instring))             # <<<<<<<<<<<<<<
 *         while loc < maxlen and \
 *                 (instring[loc] not in notchars):
 */
  __pyx_t_11 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_11 == -1)) __PYX_ERR(0, 3027, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_start); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3027, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_maxLen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3027, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_9 = PyNumber_Add(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3027, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_11); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3027, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = PyObject_RichCompare(__pyx_t_2, __pyx_t_9, Py_LT); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3027, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 3027, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__pyx_t_4) {
    __pyx_t_6 = PyInt_FromSsize_t(__pyx_t_11); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3027, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = __pyx_t_6;
    __pyx_t_6 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_9);
    __pyx_t_1 = __pyx_t_9;
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __pyx_t_1;
  __Pyx_INCREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_maxlen = __pyx_t_9;
  __pyx_t_9 = 0;

  /* "cPyparsing.pyx":3028
 *         notchars = self.notChars
 *         maxlen = min(start + self.maxLen, len(instring))
 *         while loc < maxlen and \             # <<<<<<<<<<<<<<
 *                 (instring[loc] not in notchars):
 *             loc += 1
 */
  while (1) {
    __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3028, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_1 = PyObject_RichCompare(__pyx_t_9, __pyx_v_maxlen, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3028, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 3028, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_3) {
    } else {
      __pyx_t_4 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }

    /* "cPyparsing.pyx":3029
 *         maxlen = min(start + self.maxLen, len(instring))
 *         while loc < maxlen and \
 *                 (instring[loc] not in notchars):             # <<<<<<<<<<<<<<
 *             loc += 1
 * 
 */
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_instring, __pyx_v_loc, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3029, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_v_notchars, Py_NE)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 3029, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_12 = (__pyx_t_3 != 0);
    __pyx_t_4 = __pyx_t_12;
    __pyx_L6_bool_binop_done:;
    if (!__pyx_t_4) break;

    /* "cPyparsing.pyx":3030
 *         while loc < maxlen and \
 *                 (instring[loc] not in notchars):
 *             loc += 1             # <<<<<<<<<<<<<<
 * 
 *         if loc - start < self.minLen:
 */
    __pyx_t_8 = 0;
    __pyx_t_10 = __Pyx_add_const_long_checking_overflow(__pyx_v_loc, 1, &__pyx_t_8);
    if (unlikely(__pyx_t_8)) {
      PyErr_SetString(PyExc_OverflowError, "value too large");
      __PYX_ERR(0, 3030, __pyx_L1_error)
    }
    __pyx_v_loc = __pyx_t_10;
  }

  /* "cPyparsing.pyx":3032
 *             loc += 1
 * 
 *         if loc - start < self.minLen:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  __pyx_t_8 = 0;
  __pyx_t_13 = __Pyx_sub_int_checking_overflow(__pyx_v_loc, __pyx_v_start, &__pyx_t_8);
  if (unlikely(__pyx_t_8)) {
    PyErr_SetString(PyExc_OverflowError, "value too large");
    __PYX_ERR(0, 3032, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_t_13); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3032, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_minLen); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3032, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_6 = PyObject_RichCompare(__pyx_t_1, __pyx_t_9, Py_LT); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3032, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 3032, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":3033
 * 
 *         if loc - start < self.minLen:
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *         return loc, instring[start:loc]
 */
    __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3033, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3033, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3033, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = NULL;
    __pyx_t_13 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
        __pyx_t_13 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[5] = {__pyx_t_5, __pyx_v_instring, __pyx_t_1, __pyx_t_2, __pyx_v_self};
      __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_13, 4+__pyx_t_13); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3033, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[5] = {__pyx_t_5, __pyx_v_instring, __pyx_t_1, __pyx_t_2, __pyx_v_self};
      __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_13, 4+__pyx_t_13); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3033, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(4+__pyx_t_13); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3033, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__pyx_t_5) {
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
      }
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_13, __pyx_v_instring);
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_13, __pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_13, __pyx_t_2);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_7, 3+__pyx_t_13, __pyx_v_self);
      __pyx_t_1 = 0;
      __pyx_t_2 = 0;
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_7, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3033, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(0, 3033, __pyx_L1_error)

    /* "cPyparsing.pyx":3032
 *             loc += 1
 * 
 *         if loc - start < self.minLen:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  }

  /* "cPyparsing.pyx":3035
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *         return loc, instring[start:loc]             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_9 = __Pyx_PyObject_GetSlice(__pyx_v_instring, __pyx_v_start, __pyx_v_loc, NULL, NULL, NULL, 1, 1, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_9);
  PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_9);
  __pyx_t_6 = 0;
  __pyx_t_9 = 0;
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3020
 *         self.mayIndexError = False
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc] in self.notChars:
 *             raise ParseException(instring, loc, self.errmsg, self)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.CharsNotIn.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_notchars);
  __Pyx_XDECREF(__pyx_v_maxlen);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3037
 *         return loc, instring[start:loc]
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(CharsNotIn, self).__str__()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10CharsNotIn_5__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10CharsNotIn_5__str__ = {"__str__", (PyCFunction)__pyx_pw_10cPyparsing_10CharsNotIn_5__str__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_10CharsNotIn_5__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_10CharsNotIn_4__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10CharsNotIn_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "cPyparsing.pyx":3038
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(CharsNotIn, self).__str__()
 *         except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":3039
 *     def __str__(self):
 *         try:
 *             return super(CharsNotIn, self).__str__()             # <<<<<<<<<<<<<<
 *         except Exception:
 *             pass
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_CharsNotIn); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3039, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3039, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_self);
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3039, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_str_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3039, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      if (__pyx_t_5) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3039, __pyx_L3_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else {
        __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3039, __pyx_L3_error)
      }
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":3038
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(CharsNotIn, self).__str__()
 *         except Exception:
 */
    }
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":3040
 *         try:
 *             return super(CharsNotIn, self).__str__()
 *         except Exception:             # <<<<<<<<<<<<<<
 *             pass
 * 
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_7) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cPyparsing.pyx":3038
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(CharsNotIn, self).__str__()
 *         except Exception:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L4_exception_handled:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
  }

  /* "cPyparsing.pyx":3043
 *             pass
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             if len(self.notChars) > 4:
 *                 self.strRepr = "!W:(%s...)" % self.notChars[:4]
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_8 = (__pyx_t_4 == Py_None);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_9 = (__pyx_t_8 != 0);
  if (__pyx_t_9) {

    /* "cPyparsing.pyx":3044
 * 
 *         if self.strRepr is None:
 *             if len(self.notChars) > 4:             # <<<<<<<<<<<<<<
 *                 self.strRepr = "!W:(%s...)" % self.notChars[:4]
 *             else:
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_notChars); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3044, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_10 = PyObject_Length(__pyx_t_4); if (unlikely(__pyx_t_10 == -1)) __PYX_ERR(0, 3044, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_9 = ((__pyx_t_10 > 4) != 0);
    if (__pyx_t_9) {

      /* "cPyparsing.pyx":3045
 *         if self.strRepr is None:
 *             if len(self.notChars) > 4:
 *                 self.strRepr = "!W:(%s...)" % self.notChars[:4]             # <<<<<<<<<<<<<<
 *             else:
 *                 self.strRepr = "!W:(%s)" % self.notChars
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_notChars); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3045, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = __Pyx_PyObject_GetSlice(__pyx_t_4, 0, 4, NULL, NULL, &__pyx_slice__101, 0, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3045, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyUnicode_Format(__pyx_kp_u_W_s_2, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3045, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_4) < 0) __PYX_ERR(0, 3045, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "cPyparsing.pyx":3044
 * 
 *         if self.strRepr is None:
 *             if len(self.notChars) > 4:             # <<<<<<<<<<<<<<
 *                 self.strRepr = "!W:(%s...)" % self.notChars[:4]
 *             else:
 */
      goto __pyx_L12;
    }

    /* "cPyparsing.pyx":3047
 *                 self.strRepr = "!W:(%s...)" % self.notChars[:4]
 *             else:
 *                 self.strRepr = "!W:(%s)" % self.notChars             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
    /*else*/ {
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_notChars); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3047, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = PyUnicode_Format(__pyx_kp_u_W_s_3, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3047, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_6) < 0) __PYX_ERR(0, 3047, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_L12:;

    /* "cPyparsing.pyx":3043
 *             pass
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             if len(self.notChars) > 4:
 *                 self.strRepr = "!W:(%s...)" % self.notChars[:4]
 */
  }

  /* "cPyparsing.pyx":3049
 *                 self.strRepr = "!W:(%s)" % self.notChars
 * 
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3037
 *         return loc, instring[start:loc]
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(CharsNotIn, self).__str__()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.CharsNotIn.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3068
 *     }
 * 
 *     def __init__(self, ws=" \t\r\n", min=1, max=0, exact=0):             # <<<<<<<<<<<<<<
 *         super(White, self).__init__()
 *         self.matchWhite = ws
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5White_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_5White_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_5White_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_5White_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_ws = 0;
  PyObject *__pyx_v_min = 0;
  PyObject *__pyx_v_max = 0;
  PyObject *__pyx_v_exact = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_ws,&__pyx_n_s_min,&__pyx_n_s_max,&__pyx_n_s_exact,0};
    PyObject* values[5] = {0,0,0,0,0};
    values[1] = ((PyObject *)((PyObject*)__pyx_kp_u__102));
    values[2] = ((PyObject *)((PyObject *)__pyx_int_1));
    values[3] = ((PyObject *)((PyObject *)__pyx_int_0));
    values[4] = ((PyObject *)((PyObject *)__pyx_int_0));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_ws);
          if (value) { values[1] = value; kw_args--; }
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_min);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_max);
          if (value) { values[3] = value; kw_args--; }
        }
        case  4:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_exact);
          if (value) { values[4] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 3068, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_ws = values[1];
    __pyx_v_min = values[2];
    __pyx_v_max = values[3];
    __pyx_v_exact = values[4];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 5, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3068, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.White.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_5White___init__(__pyx_self, __pyx_v_self, __pyx_v_ws, __pyx_v_min, __pyx_v_max, __pyx_v_exact);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_5White_8__init___2generator15(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":3071
 *         super(White, self).__init__()
 *         self.matchWhite = ws
 *         self.setWhitespaceChars("".join(c for c in self.whiteChars if c not in self.matchWhite))             # <<<<<<<<<<<<<<
 *         #~ self.leaveWhitespace()
 *         self.name = ("".join(White.whiteStrs[c] for c in self.matchWhite))
 */

static PyObject *__pyx_pf_10cPyparsing_5White_8__init___genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_32_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_32_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3071, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_31___init__ *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_5White_8__init___2generator15, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_White___init___locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 3071, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.White.__init__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_5White_8__init___2generator15(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  int __pyx_t_5;
  int __pyx_t_6;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 3071, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 3071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 3071, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_n_s_whiteChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3071, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3071, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3071, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3071, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3071, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3071, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3071, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_c);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_c, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 3071, __pyx_L1_error) }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_n_s_matchWhite); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3071, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_cur_scope->__pyx_v_c, __pyx_t_1, Py_NE)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 3071, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {
      if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_cur_scope->__pyx_v_c))) __PYX_ERR(0, 3071, __pyx_L1_error)
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_5White_8__init___5generator16(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":3073
 *         self.setWhitespaceChars("".join(c for c in self.whiteChars if c not in self.matchWhite))
 *         #~ self.leaveWhitespace()
 *         self.name = ("".join(White.whiteStrs[c] for c in self.matchWhite))             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 *         self.errmsg = "Expected " + self.name
 */

static PyObject *__pyx_pf_10cPyparsing_5White_8__init___3genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_33_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_33_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_33_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_33_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_33_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3073, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_31___init__ *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_5White_8__init___5generator16, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_White___init___locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 3073, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.White.__init__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_5White_8__init___5generator16(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_33_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_33_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 3073, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 3073, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 3073, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_n_s_matchWhite); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3073, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3073, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3073, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3073, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3073, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3073, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3073, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3073, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_c);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_c, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_White); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3073, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_whiteStrs); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3073, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyObject_GetItem(__pyx_t_5, __pyx_cur_scope->__pyx_v_c); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3073, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_1))) __PYX_ERR(0, 3073, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3068
 *     }
 * 
 *     def __init__(self, ws=" \t\r\n", min=1, max=0, exact=0):             # <<<<<<<<<<<<<<
 *         super(White, self).__init__()
 *         self.matchWhite = ws
 */

static PyObject *__pyx_pf_10cPyparsing_5White___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_ws, PyObject *__pyx_v_min, PyObject *__pyx_v_max, PyObject *__pyx_v_exact) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_31___init__ *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  __Pyx_RefNannySetupContext("__init__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_31___init__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_31___init__(__pyx_ptype_10cPyparsing___pyx_scope_struct_31___init__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_31___init__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3068, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);

  /* "cPyparsing.pyx":3069
 * 
 *     def __init__(self, ws=" \t\r\n", min=1, max=0, exact=0):
 *         super(White, self).__init__()             # <<<<<<<<<<<<<<
 *         self.matchWhite = ws
 *         self.setWhitespaceChars("".join(c for c in self.whiteChars if c not in self.matchWhite))
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_White); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_cur_scope->__pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3069, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3069, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3070
 *     def __init__(self, ws=" \t\r\n", min=1, max=0, exact=0):
 *         super(White, self).__init__()
 *         self.matchWhite = ws             # <<<<<<<<<<<<<<
 *         self.setWhitespaceChars("".join(c for c in self.whiteChars if c not in self.matchWhite))
 *         #~ self.leaveWhitespace()
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_matchWhite, __pyx_v_ws) < 0) __PYX_ERR(0, 3070, __pyx_L1_error)

  /* "cPyparsing.pyx":3071
 *         super(White, self).__init__()
 *         self.matchWhite = ws
 *         self.setWhitespaceChars("".join(c for c in self.whiteChars if c not in self.matchWhite))             # <<<<<<<<<<<<<<
 *         #~ self.leaveWhitespace()
 *         self.name = ("".join(White.whiteStrs[c] for c in self.matchWhite))
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_setWhitespaceChars); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __pyx_pf_10cPyparsing_5White_8__init___genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_Generator_Next(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyUnicode_Join(__pyx_kp_u__9, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3071, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3071, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3071, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3071, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3071, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3073
 *         self.setWhitespaceChars("".join(c for c in self.whiteChars if c not in self.matchWhite))
 *         #~ self.leaveWhitespace()
 *         self.name = ("".join(White.whiteStrs[c] for c in self.matchWhite))             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 *         self.errmsg = "Expected " + self.name
 */
  __pyx_t_1 = __pyx_pf_10cPyparsing_5White_8__init___3genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3073, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3073, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__9, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3073, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_name, __pyx_t_1) < 0) __PYX_ERR(0, 3073, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3074
 *         #~ self.leaveWhitespace()
 *         self.name = ("".join(White.whiteStrs[c] for c in self.matchWhite))
 *         self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected " + self.name
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 3074, __pyx_L1_error)

  /* "cPyparsing.pyx":3075
 *         self.name = ("".join(White.whiteStrs[c] for c in self.matchWhite))
 *         self.mayReturnEmpty = True
 *         self.errmsg = "Expected " + self.name             # <<<<<<<<<<<<<<
 * 
 *         self.minLen = min
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3075, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyNumber_Add(__pyx_kp_u_Expected, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3075, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_3) < 0) __PYX_ERR(0, 3075, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3077
 *         self.errmsg = "Expected " + self.name
 * 
 *         self.minLen = min             # <<<<<<<<<<<<<<
 * 
 *         if max > 0:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_minLen, __pyx_v_min) < 0) __PYX_ERR(0, 3077, __pyx_L1_error)

  /* "cPyparsing.pyx":3079
 *         self.minLen = min
 * 
 *         if max > 0:             # <<<<<<<<<<<<<<
 *             self.maxLen = max
 *         else:
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_max, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3079, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 3079, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":3080
 * 
 *         if max > 0:
 *             self.maxLen = max             # <<<<<<<<<<<<<<
 *         else:
 *             self.maxLen = _MAX_INT
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_maxLen, __pyx_v_max) < 0) __PYX_ERR(0, 3080, __pyx_L1_error)

    /* "cPyparsing.pyx":3079
 *         self.minLen = min
 * 
 *         if max > 0:             # <<<<<<<<<<<<<<
 *             self.maxLen = max
 *         else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":3082
 *             self.maxLen = max
 *         else:
 *             self.maxLen = _MAX_INT             # <<<<<<<<<<<<<<
 * 
 *         if exact > 0:
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_MAX_INT); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3082, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_maxLen, __pyx_t_3) < 0) __PYX_ERR(0, 3082, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":3084
 *             self.maxLen = _MAX_INT
 * 
 *         if exact > 0:             # <<<<<<<<<<<<<<
 *             self.maxLen = exact
 *             self.minLen = exact
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_exact, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3084, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 3084, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":3085
 * 
 *         if exact > 0:
 *             self.maxLen = exact             # <<<<<<<<<<<<<<
 *             self.minLen = exact
 * 
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_maxLen, __pyx_v_exact) < 0) __PYX_ERR(0, 3085, __pyx_L1_error)

    /* "cPyparsing.pyx":3086
 *         if exact > 0:
 *             self.maxLen = exact
 *             self.minLen = exact             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_minLen, __pyx_v_exact) < 0) __PYX_ERR(0, 3086, __pyx_L1_error)

    /* "cPyparsing.pyx":3084
 *             self.maxLen = _MAX_INT
 * 
 *         if exact > 0:             # <<<<<<<<<<<<<<
 *             self.maxLen = exact
 *             self.minLen = exact
 */
  }

  /* "cPyparsing.pyx":3068
 *     }
 * 
 *     def __init__(self, ws=" \t\r\n", min=1, max=0, exact=0):             # <<<<<<<<<<<<<<
 *         super(White, self).__init__()
 *         self.matchWhite = ws
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.White.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3088
 *             self.minLen = exact
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if not(instring[loc] in self.matchWhite):
 *             raise ParseException(instring, loc, self.errmsg, self)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5White_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_5White_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_5White_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_5White_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3088, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3088, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3088, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3088, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3088, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.White.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_5White_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_5White_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  int __pyx_v_start;
  PyObject *__pyx_v_maxloc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  long __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":3089
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if not(instring[loc] in self.matchWhite):             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 *         start = loc
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_instring, __pyx_v_loc, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3089, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchWhite); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3089, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_t_2, Py_NE)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 3089, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":3090
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if not(instring[loc] in self.matchWhite):
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 *         start = loc
 *         loc += 1
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3090, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3090, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3090, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_8 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[5] = {__pyx_t_7, __pyx_v_instring, __pyx_t_5, __pyx_t_6, __pyx_v_self};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_8, 4+__pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3090, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[5] = {__pyx_t_7, __pyx_v_instring, __pyx_t_5, __pyx_t_6, __pyx_v_self};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_8, 4+__pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3090, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(4+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3090, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (__pyx_t_7) {
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
      }
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_v_instring);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_8, __pyx_t_6);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_9, 3+__pyx_t_8, __pyx_v_self);
      __pyx_t_5 = 0;
      __pyx_t_6 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_9, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3090, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 3090, __pyx_L1_error)

    /* "cPyparsing.pyx":3089
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if not(instring[loc] in self.matchWhite):             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 *         start = loc
 */
  }

  /* "cPyparsing.pyx":3091
 *         if not(instring[loc] in self.matchWhite):
 *             raise ParseException(instring, loc, self.errmsg, self)
 *         start = loc             # <<<<<<<<<<<<<<
 *         loc += 1
 *         maxloc = start + self.maxLen
 */
  __pyx_v_start = __pyx_v_loc;

  /* "cPyparsing.pyx":3092
 *             raise ParseException(instring, loc, self.errmsg, self)
 *         start = loc
 *         loc += 1             # <<<<<<<<<<<<<<
 *         maxloc = start + self.maxLen
 *         maxloc = min(maxloc, len(instring))
 */
  __pyx_t_8 = 0;
  __pyx_t_10 = __Pyx_add_const_long_checking_overflow(__pyx_v_loc, 1, &__pyx_t_8);
  if (unlikely(__pyx_t_8)) {
    PyErr_SetString(PyExc_OverflowError, "value too large");
    __PYX_ERR(0, 3092, __pyx_L1_error)
  }
  __pyx_v_loc = __pyx_t_10;

  /* "cPyparsing.pyx":3093
 *         start = loc
 *         loc += 1
 *         maxloc = start + self.maxLen             # <<<<<<<<<<<<<<
 *         maxloc = min(maxloc, len(instring))
 *         while loc < maxloc and instring[loc] in self.matchWhite:
 */
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_start); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_maxLen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_9 = PyNumber_Add(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_maxloc = __pyx_t_9;
  __pyx_t_9 = 0;

  /* "cPyparsing.pyx":3094
 *         loc += 1
 *         maxloc = start + self.maxLen
 *         maxloc = min(maxloc, len(instring))             # <<<<<<<<<<<<<<
 *         while loc < maxloc and instring[loc] in self.matchWhite:
 *             loc += 1
 */
  __pyx_t_11 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_11 == -1)) __PYX_ERR(0, 3094, __pyx_L1_error)
  __Pyx_INCREF(__pyx_v_maxloc);
  __pyx_t_9 = __pyx_v_maxloc;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_11); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = PyObject_RichCompare(__pyx_t_2, __pyx_t_9, Py_LT); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3094, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 3094, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__pyx_t_4) {
    __pyx_t_6 = PyInt_FromSsize_t(__pyx_t_11); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3094, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = __pyx_t_6;
    __pyx_t_6 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_9);
    __pyx_t_1 = __pyx_t_9;
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __pyx_t_1;
  __Pyx_INCREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_maxloc, __pyx_t_9);
  __pyx_t_9 = 0;

  /* "cPyparsing.pyx":3095
 *         maxloc = start + self.maxLen
 *         maxloc = min(maxloc, len(instring))
 *         while loc < maxloc and instring[loc] in self.matchWhite:             # <<<<<<<<<<<<<<
 *             loc += 1
 * 
 */
  while (1) {
    __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3095, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_1 = PyObject_RichCompare(__pyx_t_9, __pyx_v_maxloc, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3095, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 3095, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_3) {
    } else {
      __pyx_t_4 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_instring, __pyx_v_loc, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3095, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_matchWhite); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3095, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_t_9, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 3095, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_12 = (__pyx_t_3 != 0);
    __pyx_t_4 = __pyx_t_12;
    __pyx_L6_bool_binop_done:;
    if (!__pyx_t_4) break;

    /* "cPyparsing.pyx":3096
 *         maxloc = min(maxloc, len(instring))
 *         while loc < maxloc and instring[loc] in self.matchWhite:
 *             loc += 1             # <<<<<<<<<<<<<<
 * 
 *         if loc - start < self.minLen:
 */
    __pyx_t_8 = 0;
    __pyx_t_10 = __Pyx_add_const_long_checking_overflow(__pyx_v_loc, 1, &__pyx_t_8);
    if (unlikely(__pyx_t_8)) {
      PyErr_SetString(PyExc_OverflowError, "value too large");
      __PYX_ERR(0, 3096, __pyx_L1_error)
    }
    __pyx_v_loc = __pyx_t_10;
  }

  /* "cPyparsing.pyx":3098
 *             loc += 1
 * 
 *         if loc - start < self.minLen:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  __pyx_t_8 = 0;
  __pyx_t_13 = __Pyx_sub_int_checking_overflow(__pyx_v_loc, __pyx_v_start, &__pyx_t_8);
  if (unlikely(__pyx_t_8)) {
    PyErr_SetString(PyExc_OverflowError, "value too large");
    __PYX_ERR(0, 3098, __pyx_L1_error)
  }
  __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_t_13); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_minLen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyObject_RichCompare(__pyx_t_9, __pyx_t_1, Py_LT); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3098, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 3098, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":3099
 * 
 *         if loc - start < self.minLen:
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *         return loc, instring[start:loc]
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3099, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3099, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3099, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = NULL;
    __pyx_t_13 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_13 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[5] = {__pyx_t_5, __pyx_v_instring, __pyx_t_9, __pyx_t_2, __pyx_v_self};
      __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_13, 4+__pyx_t_13); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3099, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[5] = {__pyx_t_5, __pyx_v_instring, __pyx_t_9, __pyx_t_2, __pyx_v_self};
      __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_13, 4+__pyx_t_13); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3099, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(4+__pyx_t_13); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3099, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__pyx_t_5) {
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
      }
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_13, __pyx_v_instring);
      __Pyx_GIVEREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_13, __pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_13, __pyx_t_2);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_7, 3+__pyx_t_13, __pyx_v_self);
      __pyx_t_9 = 0;
      __pyx_t_2 = 0;
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_7, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3099, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(0, 3099, __pyx_L1_error)

    /* "cPyparsing.pyx":3098
 *             loc += 1
 * 
 *         if loc - start < self.minLen:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  }

  /* "cPyparsing.pyx":3101
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *         return loc, instring[start:loc]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_instring, __pyx_v_start, __pyx_v_loc, NULL, NULL, NULL, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_1);
  __pyx_t_6 = 0;
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3088
 *             self.minLen = exact
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if not(instring[loc] in self.matchWhite):
 *             raise ParseException(instring, loc, self.errmsg, self)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.White.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_maxloc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3105
 * 
 * class _PositionToken(Token):
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(_PositionToken, self).__init__()
 *         self.name = self.__class__.__name__
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_14_PositionToken_1__init__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_14_PositionToken_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_14_PositionToken_1__init__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_14_PositionToken_1__init__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_14_PositionToken___init__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_14_PositionToken___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":3106
 * class _PositionToken(Token):
 *     def __init__(self):
 *         super(_PositionToken, self).__init__()             # <<<<<<<<<<<<<<
 *         self.name = self.__class__.__name__
 *         self.mayReturnEmpty = True
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_PositionToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3106, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3106, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3107
 *     def __init__(self):
 *         super(_PositionToken, self).__init__()
 *         self.name = self.__class__.__name__             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 *         self.mayIndexError = False
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_name_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name, __pyx_t_3) < 0) __PYX_ERR(0, 3107, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3108
 *         super(_PositionToken, self).__init__()
 *         self.name = self.__class__.__name__
 *         self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 *         self.mayIndexError = False
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 3108, __pyx_L1_error)

  /* "cPyparsing.pyx":3109
 *         self.name = self.__class__.__name__
 *         self.mayReturnEmpty = True
 *         self.mayIndexError = False             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, Py_False) < 0) __PYX_ERR(0, 3109, __pyx_L1_error)

  /* "cPyparsing.pyx":3105
 * 
 * class _PositionToken(Token):
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(_PositionToken, self).__init__()
 *         self.name = self.__class__.__name__
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing._PositionToken.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3117
 *     """
 * 
 *     def __init__(self, colno):             # <<<<<<<<<<<<<<
 *         super(GoToColumn, self).__init__()
 *         self.col = colno
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10GoToColumn_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10GoToColumn_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_10GoToColumn_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10GoToColumn_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_colno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_colno,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_colno)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 3117, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 3117, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_colno = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3117, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.GoToColumn.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10GoToColumn___init__(__pyx_self, __pyx_v_self, __pyx_v_colno);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10GoToColumn___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_colno) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":3118
 * 
 *     def __init__(self, colno):
 *         super(GoToColumn, self).__init__()             # <<<<<<<<<<<<<<
 *         self.col = colno
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_GoToColumn); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3118, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3118, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3119
 *     def __init__(self, colno):
 *         super(GoToColumn, self).__init__()
 *         self.col = colno             # <<<<<<<<<<<<<<
 * 
 *     def preParse(self, instring, int loc):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_col, __pyx_v_colno) < 0) __PYX_ERR(0, 3119, __pyx_L1_error)

  /* "cPyparsing.pyx":3117
 *     """
 * 
 *     def __init__(self, colno):             # <<<<<<<<<<<<<<
 *         super(GoToColumn, self).__init__()
 *         self.col = colno
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.GoToColumn.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3121
 *         self.col = colno
 * 
 *     def preParse(self, instring, int loc):             # <<<<<<<<<<<<<<
 *         if col(loc, instring) != self.col:
 *             instrlen = len(instring)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10GoToColumn_3preParse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10GoToColumn_3preParse = {"preParse", (PyCFunction)__pyx_pw_10cPyparsing_10GoToColumn_3preParse, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10GoToColumn_3preParse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("preParse (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("preParse", 1, 3, 3, 1); __PYX_ERR(0, 3121, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("preParse", 1, 3, 3, 2); __PYX_ERR(0, 3121, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "preParse") < 0)) __PYX_ERR(0, 3121, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3121, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("preParse", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3121, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.GoToColumn.preParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10GoToColumn_2preParse(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10GoToColumn_2preParse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc) {
  Py_ssize_t __pyx_v_instrlen;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  long __pyx_t_10;
  __Pyx_RefNannySetupContext("preParse", 0);

  /* "cPyparsing.pyx":3122
 * 
 *     def preParse(self, instring, int loc):
 *         if col(loc, instring) != self.col:             # <<<<<<<<<<<<<<
 *             instrlen = len(instring)
 *             if self.ignoreExprs:
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_col); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_t_3, __pyx_v_instring};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3122, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_t_3, __pyx_v_instring};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3122, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  {
    __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3122, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_t_3);
    __Pyx_INCREF(__pyx_v_instring);
    __Pyx_GIVEREF(__pyx_v_instring);
    PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_v_instring);
    __pyx_t_3 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3122, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_col); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = PyObject_RichCompare(__pyx_t_1, __pyx_t_2, Py_NE); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3122, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 3122, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__pyx_t_7) {

    /* "cPyparsing.pyx":3123
 *     def preParse(self, instring, int loc):
 *         if col(loc, instring) != self.col:
 *             instrlen = len(instring)             # <<<<<<<<<<<<<<
 *             if self.ignoreExprs:
 *                 loc = self._skipIgnorables(instring, loc)
 */
    __pyx_t_8 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_8 == -1)) __PYX_ERR(0, 3123, __pyx_L1_error)
    __pyx_v_instrlen = __pyx_t_8;

    /* "cPyparsing.pyx":3124
 *         if col(loc, instring) != self.col:
 *             instrlen = len(instring)
 *             if self.ignoreExprs:             # <<<<<<<<<<<<<<
 *                 loc = self._skipIgnorables(instring, loc)
 *             while loc < instrlen and instring[loc].isspace() and col(loc, instring) != self.col:
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3124, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 3124, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (__pyx_t_7) {

      /* "cPyparsing.pyx":3125
 *             instrlen = len(instring)
 *             if self.ignoreExprs:
 *                 loc = self._skipIgnorables(instring, loc)             # <<<<<<<<<<<<<<
 *             while loc < instrlen and instring[loc].isspace() and col(loc, instring) != self.col:
 *                 loc += 1
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_skipIgnorables); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3125, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3125, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = NULL;
      __pyx_t_5 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_5 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_instring, __pyx_t_1};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3125, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_instring, __pyx_t_1};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3125, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else
      #endif
      {
        __pyx_t_4 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3125, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        if (__pyx_t_3) {
          __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
        }
        __Pyx_INCREF(__pyx_v_instring);
        __Pyx_GIVEREF(__pyx_v_instring);
        PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_5, __pyx_v_instring);
        __Pyx_GIVEREF(__pyx_t_1);
        PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_5, __pyx_t_1);
        __pyx_t_1 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3125, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_6); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3125, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_loc = __pyx_t_5;

      /* "cPyparsing.pyx":3124
 *         if col(loc, instring) != self.col:
 *             instrlen = len(instring)
 *             if self.ignoreExprs:             # <<<<<<<<<<<<<<
 *                 loc = self._skipIgnorables(instring, loc)
 *             while loc < instrlen and instring[loc].isspace() and col(loc, instring) != self.col:
 */
    }

    /* "cPyparsing.pyx":3126
 *             if self.ignoreExprs:
 *                 loc = self._skipIgnorables(instring, loc)
 *             while loc < instrlen and instring[loc].isspace() and col(loc, instring) != self.col:             # <<<<<<<<<<<<<<
 *                 loc += 1
 *         return loc
 */
    while (1) {
      __pyx_t_9 = ((__pyx_v_loc < __pyx_v_instrlen) != 0);
      if (__pyx_t_9) {
      } else {
        __pyx_t_7 = __pyx_t_9;
        goto __pyx_L7_bool_binop_done;
      }
      __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_instring, __pyx_v_loc, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3126, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_isspace); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3126, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      if (__pyx_t_2) {
        __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3126, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else {
        __pyx_t_6 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3126, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 3126, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (__pyx_t_9) {
      } else {
        __pyx_t_7 = __pyx_t_9;
        goto __pyx_L7_bool_binop_done;
      }
      __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_col); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3126, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3126, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = NULL;
      __pyx_t_5 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_5 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_t_2, __pyx_v_instring};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3126, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_t_2, __pyx_v_instring};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3126, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else
      #endif
      {
        __pyx_t_3 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3126, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (__pyx_t_1) {
          __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1); __pyx_t_1 = NULL;
        }
        __Pyx_GIVEREF(__pyx_t_2);
        PyTuple_SET_ITEM(__pyx_t_3, 0+__pyx_t_5, __pyx_t_2);
        __Pyx_INCREF(__pyx_v_instring);
        __Pyx_GIVEREF(__pyx_v_instring);
        PyTuple_SET_ITEM(__pyx_t_3, 1+__pyx_t_5, __pyx_v_instring);
        __pyx_t_2 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3126, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_col); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3126, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_t_6, __pyx_t_4, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3126, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 3126, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __pyx_t_9;
      __pyx_L7_bool_binop_done:;
      if (!__pyx_t_7) break;

      /* "cPyparsing.pyx":3127
 *                 loc = self._skipIgnorables(instring, loc)
 *             while loc < instrlen and instring[loc].isspace() and col(loc, instring) != self.col:
 *                 loc += 1             # <<<<<<<<<<<<<<
 *         return loc
 * 
 */
      __pyx_t_5 = 0;
      __pyx_t_10 = __Pyx_add_const_long_checking_overflow(__pyx_v_loc, 1, &__pyx_t_5);
      if (unlikely(__pyx_t_5)) {
        PyErr_SetString(PyExc_OverflowError, "value too large");
        __PYX_ERR(0, 3127, __pyx_L1_error)
      }
      __pyx_v_loc = __pyx_t_10;
    }

    /* "cPyparsing.pyx":3122
 * 
 *     def preParse(self, instring, int loc):
 *         if col(loc, instring) != self.col:             # <<<<<<<<<<<<<<
 *             instrlen = len(instring)
 *             if self.ignoreExprs:
 */
  }

  /* "cPyparsing.pyx":3128
 *             while loc < instrlen and instring[loc].isspace() and col(loc, instring) != self.col:
 *                 loc += 1
 *         return loc             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3121
 *         self.col = colno
 * 
 *     def preParse(self, instring, int loc):             # <<<<<<<<<<<<<<
 *         if col(loc, instring) != self.col:
 *             instrlen = len(instring)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.GoToColumn.preParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3130
 *         return loc
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         thiscol = col(loc, instring)
 *         if thiscol > self.col:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10GoToColumn_5parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10GoToColumn_5parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_10GoToColumn_5parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10GoToColumn_5parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3130, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3130, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3130, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3130, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3130, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.GoToColumn.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10GoToColumn_4parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10GoToColumn_4parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_thiscol = NULL;
  PyObject *__pyx_v_newloc = NULL;
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":3131
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         thiscol = col(loc, instring)             # <<<<<<<<<<<<<<
 *         if thiscol > self.col:
 *             raise ParseException(instring, loc, "Text not in expected column", self)
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_col); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_t_3, __pyx_v_instring};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3131, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_t_3, __pyx_v_instring};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3131, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  {
    __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_t_3);
    __Pyx_INCREF(__pyx_v_instring);
    __Pyx_GIVEREF(__pyx_v_instring);
    PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_v_instring);
    __pyx_t_3 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_thiscol = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3132
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         thiscol = col(loc, instring)
 *         if thiscol > self.col:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, "Text not in expected column", self)
 *         newloc = loc + self.col - thiscol
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_col); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_thiscol, __pyx_t_1, Py_GT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3132, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 3132, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_7) {

    /* "cPyparsing.pyx":3133
 *         thiscol = col(loc, instring)
 *         if thiscol > self.col:
 *             raise ParseException(instring, loc, "Text not in expected column", self)             # <<<<<<<<<<<<<<
 *         newloc = loc + self.col - thiscol
 *         ret = instring[loc: newloc]
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_5 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[5] = {__pyx_t_3, __pyx_v_instring, __pyx_t_6, __pyx_kp_u_Text_not_in_expected_column, __pyx_v_self};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_5, 4+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3133, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[5] = {__pyx_t_3, __pyx_v_instring, __pyx_t_6, __pyx_kp_u_Text_not_in_expected_column, __pyx_v_self};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_5, 4+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3133, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(4+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3133, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (__pyx_t_3) {
        __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
      }
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_5, __pyx_v_instring);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_5, __pyx_t_6);
      __Pyx_INCREF(__pyx_kp_u_Text_not_in_expected_column);
      __Pyx_GIVEREF(__pyx_kp_u_Text_not_in_expected_column);
      PyTuple_SET_ITEM(__pyx_t_4, 2+__pyx_t_5, __pyx_kp_u_Text_not_in_expected_column);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_4, 3+__pyx_t_5, __pyx_v_self);
      __pyx_t_6 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3133, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 3133, __pyx_L1_error)

    /* "cPyparsing.pyx":3132
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         thiscol = col(loc, instring)
 *         if thiscol > self.col:             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, "Text not in expected column", self)
 *         newloc = loc + self.col - thiscol
 */
  }

  /* "cPyparsing.pyx":3134
 *         if thiscol > self.col:
 *             raise ParseException(instring, loc, "Text not in expected column", self)
 *         newloc = loc + self.col - thiscol             # <<<<<<<<<<<<<<
 *         ret = instring[loc: newloc]
 *         return newloc, ret
 */
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_col); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = PyNumber_Add(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Subtract(__pyx_t_4, __pyx_v_thiscol); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_newloc = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3135
 *             raise ParseException(instring, loc, "Text not in expected column", self)
 *         newloc = loc + self.col - thiscol
 *         ret = instring[loc: newloc]             # <<<<<<<<<<<<<<
 *         return newloc, ret
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_instring, __pyx_v_loc, 0, NULL, &__pyx_v_newloc, NULL, 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_ret = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3136
 *         newloc = loc + self.col - thiscol
 *         ret = instring[loc: newloc]
 *         return newloc, ret             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_newloc);
  __Pyx_GIVEREF(__pyx_v_newloc);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_newloc);
  __Pyx_INCREF(__pyx_v_ret);
  __Pyx_GIVEREF(__pyx_v_ret);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_ret);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3130
 *         return loc
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         thiscol = col(loc, instring)
 *         if thiscol > self.col:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.GoToColumn.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_thiscol);
  __Pyx_XDECREF(__pyx_v_newloc);
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3161
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(LineStart, self).__init__()
 *         self.errmsg = "Expected start of line"
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_9LineStart_1__init__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_9LineStart_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_9LineStart_1__init__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_9LineStart_1__init__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_9LineStart___init__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_9LineStart___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":3162
 * 
 *     def __init__(self):
 *         super(LineStart, self).__init__()             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected start of line"
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_LineStart); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3162, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3162, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3163
 *     def __init__(self):
 *         super(LineStart, self).__init__()
 *         self.errmsg = "Expected start of line"             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_kp_u_Expected_start_of_line) < 0) __PYX_ERR(0, 3163, __pyx_L1_error)

  /* "cPyparsing.pyx":3161
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(LineStart, self).__init__()
 *         self.errmsg = "Expected start of line"
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.LineStart.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3165
 *         self.errmsg = "Expected start of line"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if col(loc, instring) == 1:
 *             return loc, []
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_9LineStart_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_9LineStart_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_9LineStart_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_9LineStart_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3165, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3165, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3165, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3165, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3165, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.LineStart.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_9LineStart_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_9LineStart_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":3166
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if col(loc, instring) == 1:             # <<<<<<<<<<<<<<
 *             return loc, []
 *         raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_col); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_t_3, __pyx_v_instring};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3166, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_t_3, __pyx_v_instring};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3166, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  {
    __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3166, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_t_3);
    __Pyx_INCREF(__pyx_v_instring);
    __Pyx_GIVEREF(__pyx_v_instring);
    PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_v_instring);
    __pyx_t_3 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3166, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_EqObjC(__pyx_t_1, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 3166, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_7) {

    /* "cPyparsing.pyx":3167
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if col(loc, instring) == 1:
 *             return loc, []             # <<<<<<<<<<<<<<
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3167, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3167, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3167, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":3166
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if col(loc, instring) == 1:             # <<<<<<<<<<<<<<
 *             return loc, []
 *         raise ParseException(instring, loc, self.errmsg, self)
 */
  }

  /* "cPyparsing.pyx":3168
 *         if col(loc, instring) == 1:
 *             return loc, []
 *         raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_1)) {
    PyObject *__pyx_temp[5] = {__pyx_t_4, __pyx_v_instring, __pyx_t_2, __pyx_t_3, __pyx_v_self};
    __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_5, 4+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3168, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
    PyObject *__pyx_temp[5] = {__pyx_t_4, __pyx_v_instring, __pyx_t_2, __pyx_t_3, __pyx_v_self};
    __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_5, 4+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3168, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  {
    __pyx_t_8 = PyTuple_New(4+__pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3168, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_INCREF(__pyx_v_instring);
    __Pyx_GIVEREF(__pyx_v_instring);
    PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_5, __pyx_v_instring);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_5, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_5, __pyx_t_3);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_8, 3+__pyx_t_5, __pyx_v_self);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_8, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3168, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_Raise(__pyx_t_6, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __PYX_ERR(0, 3168, __pyx_L1_error)

  /* "cPyparsing.pyx":3165
 *         self.errmsg = "Expected start of line"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if col(loc, instring) == 1:
 *             return loc, []
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing.LineStart.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3176
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(LineEnd, self).__init__()
 *         self.setWhitespaceChars(ParserElement.DEFAULT_WHITE_CHARS.replace("\n", ""))
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7LineEnd_1__init__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_7LineEnd_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_7LineEnd_1__init__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_7LineEnd_1__init__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_7LineEnd___init__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7LineEnd___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":3177
 * 
 *     def __init__(self):
 *         super(LineEnd, self).__init__()             # <<<<<<<<<<<<<<
 *         self.setWhitespaceChars(ParserElement.DEFAULT_WHITE_CHARS.replace("\n", ""))
 *         self.errmsg = "Expected end of line"
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_LineEnd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3177, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3177, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3178
 *     def __init__(self):
 *         super(LineEnd, self).__init__()
 *         self.setWhitespaceChars(ParserElement.DEFAULT_WHITE_CHARS.replace("\n", ""))             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected end of line"
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_setWhitespaceChars); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DEFAULT_WHITE_CHARS); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_replace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__103, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3178, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3178, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3178, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3178, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3178, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3179
 *         super(LineEnd, self).__init__()
 *         self.setWhitespaceChars(ParserElement.DEFAULT_WHITE_CHARS.replace("\n", ""))
 *         self.errmsg = "Expected end of line"             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_kp_u_Expected_end_of_line) < 0) __PYX_ERR(0, 3179, __pyx_L1_error)

  /* "cPyparsing.pyx":3176
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(LineEnd, self).__init__()
 *         self.setWhitespaceChars(ParserElement.DEFAULT_WHITE_CHARS.replace("\n", ""))
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.LineEnd.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3181
 *         self.errmsg = "Expected end of line"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc < len(instring):
 *             if instring[loc] == "\n":
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7LineEnd_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_7LineEnd_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_7LineEnd_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_7LineEnd_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3181, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3181, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3181, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3181, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3181, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.LineEnd.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7LineEnd_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7LineEnd_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  long __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":3182
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if loc < len(instring):             # <<<<<<<<<<<<<<
 *             if instring[loc] == "\n":
 *                 return loc + 1, "\n"
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 3182, __pyx_L1_error)
  __pyx_t_2 = ((__pyx_v_loc < __pyx_t_1) != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":3183
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if loc < len(instring):
 *             if instring[loc] == "\n":             # <<<<<<<<<<<<<<
 *                 return loc + 1, "\n"
 *             else:
 */
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_instring, __pyx_v_loc, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3183, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_kp_u__21, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 3183, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":3184
 *         if loc < len(instring):
 *             if instring[loc] == "\n":
 *                 return loc + 1, "\n"             # <<<<<<<<<<<<<<
 *             else:
 *                 raise ParseException(instring, loc, self.errmsg, self)
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = 0;
      __pyx_t_5 = __Pyx_add_const_long_checking_overflow(__pyx_v_loc, 1, &__pyx_t_4);
      if (unlikely(__pyx_t_4)) {
        PyErr_SetString(PyExc_OverflowError, "value too large");
        __PYX_ERR(0, 3184, __pyx_L1_error)
      }
      __pyx_t_3 = __Pyx_PyInt_From_long(__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3184, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3184, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_3);
      __Pyx_INCREF(__pyx_kp_u__21);
      __Pyx_GIVEREF(__pyx_kp_u__21);
      PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_kp_u__21);
      __pyx_t_3 = 0;
      __pyx_r = __pyx_t_6;
      __pyx_t_6 = 0;
      goto __pyx_L0;

      /* "cPyparsing.pyx":3183
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if loc < len(instring):
 *             if instring[loc] == "\n":             # <<<<<<<<<<<<<<
 *                 return loc + 1, "\n"
 *             else:
 */
    }

    /* "cPyparsing.pyx":3186
 *                 return loc + 1, "\n"
 *             else:
 *                 raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 *         elif loc == len(instring):
 *             return loc + 1, []
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3186, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3186, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3186, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = NULL;
      __pyx_t_4 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_4 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[5] = {__pyx_t_9, __pyx_v_instring, __pyx_t_7, __pyx_t_8, __pyx_v_self};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 4+__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3186, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[5] = {__pyx_t_9, __pyx_v_instring, __pyx_t_7, __pyx_t_8, __pyx_v_self};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 4+__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3186, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(4+__pyx_t_4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3186, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_v_instring);
        __Pyx_GIVEREF(__pyx_v_instring);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_4, __pyx_v_instring);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_4, __pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_10, 2+__pyx_t_4, __pyx_t_8);
        __Pyx_INCREF(__pyx_v_self);
        __Pyx_GIVEREF(__pyx_v_self);
        PyTuple_SET_ITEM(__pyx_t_10, 3+__pyx_t_4, __pyx_v_self);
        __pyx_t_7 = 0;
        __pyx_t_8 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_10, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3186, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(0, 3186, __pyx_L1_error)
    }

    /* "cPyparsing.pyx":3182
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if loc < len(instring):             # <<<<<<<<<<<<<<
 *             if instring[loc] == "\n":
 *                 return loc + 1, "\n"
 */
  }

  /* "cPyparsing.pyx":3187
 *             else:
 *                 raise ParseException(instring, loc, self.errmsg, self)
 *         elif loc == len(instring):             # <<<<<<<<<<<<<<
 *             return loc + 1, []
 *         else:
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 3187, __pyx_L1_error)
  __pyx_t_2 = ((__pyx_v_loc == __pyx_t_1) != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":3188
 *                 raise ParseException(instring, loc, self.errmsg, self)
 *         elif loc == len(instring):
 *             return loc + 1, []             # <<<<<<<<<<<<<<
 *         else:
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_add_const_long_checking_overflow(__pyx_v_loc, 1, &__pyx_t_4);
    if (unlikely(__pyx_t_4)) {
      PyErr_SetString(PyExc_OverflowError, "value too large");
      __PYX_ERR(0, 3188, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_PyInt_From_long(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3188, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3188, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3188, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_3);
    __pyx_t_6 = 0;
    __pyx_t_3 = 0;
    __pyx_r = __pyx_t_10;
    __pyx_t_10 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":3187
 *             else:
 *                 raise ParseException(instring, loc, self.errmsg, self)
 *         elif loc == len(instring):             # <<<<<<<<<<<<<<
 *             return loc + 1, []
 *         else:
 */
  }

  /* "cPyparsing.pyx":3190
 *             return loc + 1, []
 *         else:
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_4 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[5] = {__pyx_t_7, __pyx_v_instring, __pyx_t_6, __pyx_t_8, __pyx_v_self};
      __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 4+__pyx_t_4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3190, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[5] = {__pyx_t_7, __pyx_v_instring, __pyx_t_6, __pyx_t_8, __pyx_v_self};
      __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 4+__pyx_t_4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3190, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(4+__pyx_t_4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3190, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (__pyx_t_7) {
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
      }
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_4, __pyx_v_instring);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_4, __pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_8);
      PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_4, __pyx_t_8);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_9, 3+__pyx_t_4, __pyx_v_self);
      __pyx_t_6 = 0;
      __pyx_t_8 = 0;
      __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_9, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3190, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_10, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __PYX_ERR(0, 3190, __pyx_L1_error)
  }

  /* "cPyparsing.pyx":3181
 *         self.errmsg = "Expected end of line"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc < len(instring):
 *             if instring[loc] == "\n":
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("cPyparsing.LineEnd.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3198
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(StringStart, self).__init__()
 *         self.errmsg = "Expected start of text"
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_11StringStart_1__init__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_11StringStart_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_11StringStart_1__init__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_11StringStart_1__init__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_11StringStart___init__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_11StringStart___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":3199
 * 
 *     def __init__(self):
 *         super(StringStart, self).__init__()             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected start of text"
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_StringStart); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3199, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3199, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3200
 *     def __init__(self):
 *         super(StringStart, self).__init__()
 *         self.errmsg = "Expected start of text"             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_kp_u_Expected_start_of_text) < 0) __PYX_ERR(0, 3200, __pyx_L1_error)

  /* "cPyparsing.pyx":3198
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(StringStart, self).__init__()
 *         self.errmsg = "Expected start of text"
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.StringStart.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3202
 *         self.errmsg = "Expected start of text"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc != 0:
 *             # see if entire string up to here is just whitespace and ignoreables
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_11StringStart_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_11StringStart_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_11StringStart_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_11StringStart_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3202, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3202, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3202, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3202, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3202, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.StringStart.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_11StringStart_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_11StringStart_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":3203
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if loc != 0:             # <<<<<<<<<<<<<<
 *             # see if entire string up to here is just whitespace and ignoreables
 *             if loc != self.preParse(instring, 0):
 */
  __pyx_t_1 = ((__pyx_v_loc != 0) != 0);
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":3205
 *         if loc != 0:
 *             # see if entire string up to here is just whitespace and ignoreables
 *             if loc != self.preParse(instring, 0):             # <<<<<<<<<<<<<<
 *                 raise ParseException(instring, loc, self.errmsg, self)
 *         return loc, []
 */
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3205, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_preParse); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3205, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_instring, __pyx_int_0};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3205, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_instring, __pyx_int_0};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3205, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3205, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__pyx_t_5) {
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
      }
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_instring);
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_GIVEREF(__pyx_int_0);
      PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_int_0);
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3205, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_2, __pyx_t_3, Py_NE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3205, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 3205, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_1) {

      /* "cPyparsing.pyx":3206
 *             # see if entire string up to here is just whitespace and ignoreables
 *             if loc != self.preParse(instring, 0):
 *                 raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 *         return loc, []
 * 
 */
      __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3206, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3206, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3206, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_6 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[5] = {__pyx_t_5, __pyx_v_instring, __pyx_t_2, __pyx_t_7, __pyx_v_self};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 4+__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3206, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[5] = {__pyx_t_5, __pyx_v_instring, __pyx_t_2, __pyx_t_7, __pyx_v_self};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 4+__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3206, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(4+__pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3206, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_5) {
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_5); __pyx_t_5 = NULL;
        }
        __Pyx_INCREF(__pyx_v_instring);
        __Pyx_GIVEREF(__pyx_v_instring);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_6, __pyx_v_instring);
        __Pyx_GIVEREF(__pyx_t_2);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_6, __pyx_t_2);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_6, __pyx_t_7);
        __Pyx_INCREF(__pyx_v_self);
        __Pyx_GIVEREF(__pyx_v_self);
        PyTuple_SET_ITEM(__pyx_t_8, 3+__pyx_t_6, __pyx_v_self);
        __pyx_t_2 = 0;
        __pyx_t_7 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_8, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3206, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(0, 3206, __pyx_L1_error)

      /* "cPyparsing.pyx":3205
 *         if loc != 0:
 *             # see if entire string up to here is just whitespace and ignoreables
 *             if loc != self.preParse(instring, 0):             # <<<<<<<<<<<<<<
 *                 raise ParseException(instring, loc, self.errmsg, self)
 *         return loc, []
 */
    }

    /* "cPyparsing.pyx":3203
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if loc != 0:             # <<<<<<<<<<<<<<
 *             # see if entire string up to here is just whitespace and ignoreables
 *             if loc != self.preParse(instring, 0):
 */
  }

  /* "cPyparsing.pyx":3207
 *             if loc != self.preParse(instring, 0):
 *                 raise ParseException(instring, loc, self.errmsg, self)
 *         return loc, []             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_3);
  __pyx_t_4 = 0;
  __pyx_t_3 = 0;
  __pyx_r = __pyx_t_8;
  __pyx_t_8 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3202
 *         self.errmsg = "Expected start of text"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc != 0:
 *             # see if entire string up to here is just whitespace and ignoreables
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing.StringStart.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3215
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(StringEnd, self).__init__()
 *         self.errmsg = "Expected end of text"
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_9StringEnd_1__init__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_9StringEnd_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_9StringEnd_1__init__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_9StringEnd_1__init__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_9StringEnd___init__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_9StringEnd___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":3216
 * 
 *     def __init__(self):
 *         super(StringEnd, self).__init__()             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected end of text"
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_StringEnd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3216, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3216, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3217
 *     def __init__(self):
 *         super(StringEnd, self).__init__()
 *         self.errmsg = "Expected end of text"             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_kp_u_Expected_end_of_text) < 0) __PYX_ERR(0, 3217, __pyx_L1_error)

  /* "cPyparsing.pyx":3215
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(StringEnd, self).__init__()
 *         self.errmsg = "Expected end of text"
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.StringEnd.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3219
 *         self.errmsg = "Expected end of text"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc < len(instring):
 *             raise ParseException(instring, loc, self.errmsg, self)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_9StringEnd_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_9StringEnd_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_9StringEnd_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_9StringEnd_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3219, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3219, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3219, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3219, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3219, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.StringEnd.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_9StringEnd_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_9StringEnd_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  long __pyx_t_10;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":3220
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if loc < len(instring):             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 *         elif loc == len(instring):
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 3220, __pyx_L1_error)
  __pyx_t_2 = ((__pyx_v_loc < __pyx_t_1) != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":3221
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if loc < len(instring):
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 *         elif loc == len(instring):
 *             return loc + 1, []
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_8 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[5] = {__pyx_t_7, __pyx_v_instring, __pyx_t_5, __pyx_t_6, __pyx_v_self};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_8, 4+__pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3221, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[5] = {__pyx_t_7, __pyx_v_instring, __pyx_t_5, __pyx_t_6, __pyx_v_self};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_8, 4+__pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3221, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(4+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3221, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (__pyx_t_7) {
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
      }
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_v_instring);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_8, __pyx_t_6);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_9, 3+__pyx_t_8, __pyx_v_self);
      __pyx_t_5 = 0;
      __pyx_t_6 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_9, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3221, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 3221, __pyx_L1_error)

    /* "cPyparsing.pyx":3220
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if loc < len(instring):             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 *         elif loc == len(instring):
 */
  }

  /* "cPyparsing.pyx":3222
 *         if loc < len(instring):
 *             raise ParseException(instring, loc, self.errmsg, self)
 *         elif loc == len(instring):             # <<<<<<<<<<<<<<
 *             return loc + 1, []
 *         elif loc > len(instring):
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 3222, __pyx_L1_error)
  __pyx_t_2 = ((__pyx_v_loc == __pyx_t_1) != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":3223
 *             raise ParseException(instring, loc, self.errmsg, self)
 *         elif loc == len(instring):
 *             return loc + 1, []             # <<<<<<<<<<<<<<
 *         elif loc > len(instring):
 *             return loc, []
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_8 = 0;
    __pyx_t_10 = __Pyx_add_const_long_checking_overflow(__pyx_v_loc, 1, &__pyx_t_8);
    if (unlikely(__pyx_t_8)) {
      PyErr_SetString(PyExc_OverflowError, "value too large");
      __PYX_ERR(0, 3223, __pyx_L1_error)
    }
    __pyx_t_3 = __Pyx_PyInt_From_long(__pyx_t_10); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3223, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3223, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3223, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_4);
    __pyx_t_3 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_9;
    __pyx_t_9 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":3222
 *         if loc < len(instring):
 *             raise ParseException(instring, loc, self.errmsg, self)
 *         elif loc == len(instring):             # <<<<<<<<<<<<<<
 *             return loc + 1, []
 *         elif loc > len(instring):
 */
  }

  /* "cPyparsing.pyx":3224
 *         elif loc == len(instring):
 *             return loc + 1, []
 *         elif loc > len(instring):             # <<<<<<<<<<<<<<
 *             return loc, []
 *         else:
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 3224, __pyx_L1_error)
  __pyx_t_2 = ((__pyx_v_loc > __pyx_t_1) != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":3225
 *             return loc + 1, []
 *         elif loc > len(instring):
 *             return loc, []             # <<<<<<<<<<<<<<
 *         else:
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3225, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3225, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3225, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_9);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_9);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_4);
    __pyx_t_9 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":3224
 *         elif loc == len(instring):
 *             return loc + 1, []
 *         elif loc > len(instring):             # <<<<<<<<<<<<<<
 *             return loc, []
 *         else:
 */
  }

  /* "cPyparsing.pyx":3227
 *             return loc, []
 *         else:
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3227, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3227, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3227, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = NULL;
    __pyx_t_8 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_8 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[5] = {__pyx_t_5, __pyx_v_instring, __pyx_t_9, __pyx_t_6, __pyx_v_self};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_8, 4+__pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3227, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[5] = {__pyx_t_5, __pyx_v_instring, __pyx_t_9, __pyx_t_6, __pyx_v_self};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_8, 4+__pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3227, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(4+__pyx_t_8); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3227, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__pyx_t_5) {
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
      }
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_8, __pyx_v_instring);
      __Pyx_GIVEREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_8, __pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_8, __pyx_t_6);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_7, 3+__pyx_t_8, __pyx_v_self);
      __pyx_t_9 = 0;
      __pyx_t_6 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3227, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 3227, __pyx_L1_error)
  }

  /* "cPyparsing.pyx":3219
 *         self.errmsg = "Expected end of text"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc < len(instring):
 *             raise ParseException(instring, loc, self.errmsg, self)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.StringEnd.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3239
 *     """
 * 
 *     def __init__(self, wordChars=printables):             # <<<<<<<<<<<<<<
 *         super(WordStart, self).__init__()
 *         self.wordChars = set(wordChars)
 */

static PyObject *__pyx_pf_10cPyparsing_95__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults6, __pyx_self)->__pyx_arg_wordChars);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults6, __pyx_self)->__pyx_arg_wordChars);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults6, __pyx_self)->__pyx_arg_wordChars);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_9WordStart_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_9WordStart_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_9WordStart_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_9WordStart_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_wordChars = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_wordChars,0};
    PyObject* values[2] = {0,0};
    __pyx_defaults6 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults6, __pyx_self);
    values[1] = __pyx_dynamic_args->__pyx_arg_wordChars;
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_wordChars);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 3239, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_wordChars = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3239, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.WordStart.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_9WordStart___init__(__pyx_self, __pyx_v_self, __pyx_v_wordChars);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_9WordStart___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_wordChars) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":3240
 * 
 *     def __init__(self, wordChars=printables):
 *         super(WordStart, self).__init__()             # <<<<<<<<<<<<<<
 *         self.wordChars = set(wordChars)
 *         self.errmsg = "Not at the start of a word"
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_WordStart); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3240, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3240, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3241
 *     def __init__(self, wordChars=printables):
 *         super(WordStart, self).__init__()
 *         self.wordChars = set(wordChars)             # <<<<<<<<<<<<<<
 *         self.errmsg = "Not at the start of a word"
 * 
 */
  __pyx_t_1 = PySet_New(__pyx_v_wordChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_wordChars, __pyx_t_1) < 0) __PYX_ERR(0, 3241, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3242
 *         super(WordStart, self).__init__()
 *         self.wordChars = set(wordChars)
 *         self.errmsg = "Not at the start of a word"             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_kp_u_Not_at_the_start_of_a_word) < 0) __PYX_ERR(0, 3242, __pyx_L1_error)

  /* "cPyparsing.pyx":3239
 *     """
 * 
 *     def __init__(self, wordChars=printables):             # <<<<<<<<<<<<<<
 *         super(WordStart, self).__init__()
 *         self.wordChars = set(wordChars)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.WordStart.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3244
 *         self.errmsg = "Not at the start of a word"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc != 0:
 *             if (instring[loc - 1] in self.wordChars or
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_9WordStart_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_9WordStart_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_9WordStart_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_9WordStart_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3244, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3244, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3244, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3244, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3244, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.WordStart.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_9WordStart_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_9WordStart_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  long __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":3245
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if loc != 0:             # <<<<<<<<<<<<<<
 *             if (instring[loc - 1] in self.wordChars or
 *                     instring[loc] not in self.wordChars):
 */
  __pyx_t_1 = ((__pyx_v_loc != 0) != 0);
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":3246
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if loc != 0:
 *             if (instring[loc - 1] in self.wordChars or             # <<<<<<<<<<<<<<
 *                     instring[loc] not in self.wordChars):
 *                 raise ParseException(instring, loc, self.errmsg, self)
 */
    __pyx_t_2 = 0;
    __pyx_t_3 = __Pyx_sub_const_long_checking_overflow(__pyx_v_loc, 1, &__pyx_t_2);
    if (unlikely(__pyx_t_2)) {
      PyErr_SetString(PyExc_OverflowError, "value too large");
      __PYX_ERR(0, 3246, __pyx_L1_error)
    }
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_instring, __pyx_t_3, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3246, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_wordChars); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3246, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_t_4, __pyx_t_5, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 3246, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_7 = (__pyx_t_6 != 0);
    if (!__pyx_t_7) {
    } else {
      __pyx_t_1 = __pyx_t_7;
      goto __pyx_L5_bool_binop_done;
    }

    /* "cPyparsing.pyx":3247
 *         if loc != 0:
 *             if (instring[loc - 1] in self.wordChars or
 *                     instring[loc] not in self.wordChars):             # <<<<<<<<<<<<<<
 *                 raise ParseException(instring, loc, self.errmsg, self)
 *         return loc, []
 */
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_instring, __pyx_v_loc, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_wordChars); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = (__Pyx_PySequence_ContainsTF(__pyx_t_5, __pyx_t_4, Py_NE)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 3247, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = (__pyx_t_7 != 0);
    __pyx_t_1 = __pyx_t_6;
    __pyx_L5_bool_binop_done:;

    /* "cPyparsing.pyx":3246
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if loc != 0:
 *             if (instring[loc - 1] in self.wordChars or             # <<<<<<<<<<<<<<
 *                     instring[loc] not in self.wordChars):
 *                 raise ParseException(instring, loc, self.errmsg, self)
 */
    if (__pyx_t_1) {

      /* "cPyparsing.pyx":3248
 *             if (instring[loc - 1] in self.wordChars or
 *                     instring[loc] not in self.wordChars):
 *                 raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 *         return loc, []
 * 
 */
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3248, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3248, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3248, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = NULL;
      __pyx_t_2 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_2 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[5] = {__pyx_t_10, __pyx_v_instring, __pyx_t_8, __pyx_t_9, __pyx_v_self};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_2, 4+__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3248, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[5] = {__pyx_t_10, __pyx_v_instring, __pyx_t_8, __pyx_t_9, __pyx_v_self};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_2, 4+__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3248, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(4+__pyx_t_2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3248, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_v_instring);
        __Pyx_GIVEREF(__pyx_v_instring);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_2, __pyx_v_instring);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_2, __pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_11, 2+__pyx_t_2, __pyx_t_9);
        __Pyx_INCREF(__pyx_v_self);
        __Pyx_GIVEREF(__pyx_v_self);
        PyTuple_SET_ITEM(__pyx_t_11, 3+__pyx_t_2, __pyx_v_self);
        __pyx_t_8 = 0;
        __pyx_t_9 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_11, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3248, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(0, 3248, __pyx_L1_error)

      /* "cPyparsing.pyx":3246
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if loc != 0:
 *             if (instring[loc - 1] in self.wordChars or             # <<<<<<<<<<<<<<
 *                     instring[loc] not in self.wordChars):
 *                 raise ParseException(instring, loc, self.errmsg, self)
 */
    }

    /* "cPyparsing.pyx":3245
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if loc != 0:             # <<<<<<<<<<<<<<
 *             if (instring[loc - 1] in self.wordChars or
 *                     instring[loc] not in self.wordChars):
 */
  }

  /* "cPyparsing.pyx":3249
 *                     instring[loc] not in self.wordChars):
 *                 raise ParseException(instring, loc, self.errmsg, self)
 *         return loc, []             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_11 = PyTuple_New(2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_t_5);
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_r = __pyx_t_11;
  __pyx_t_11 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3244
 *         self.errmsg = "Not at the start of a word"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc != 0:
 *             if (instring[loc - 1] in self.wordChars or
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("cPyparsing.WordStart.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3261
 *     """
 * 
 *     def __init__(self, wordChars=printables):             # <<<<<<<<<<<<<<
 *         super(WordEnd, self).__init__()
 *         self.wordChars = set(wordChars)
 */

static PyObject *__pyx_pf_10cPyparsing_97__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults7, __pyx_self)->__pyx_arg_wordChars);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults7, __pyx_self)->__pyx_arg_wordChars);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults7, __pyx_self)->__pyx_arg_wordChars);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7WordEnd_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_7WordEnd_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_7WordEnd_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_7WordEnd_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_wordChars = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_wordChars,0};
    PyObject* values[2] = {0,0};
    __pyx_defaults7 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults7, __pyx_self);
    values[1] = __pyx_dynamic_args->__pyx_arg_wordChars;
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_wordChars);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 3261, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_wordChars = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3261, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.WordEnd.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7WordEnd___init__(__pyx_self, __pyx_v_self, __pyx_v_wordChars);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7WordEnd___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_wordChars) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":3262
 * 
 *     def __init__(self, wordChars=printables):
 *         super(WordEnd, self).__init__()             # <<<<<<<<<<<<<<
 *         self.wordChars = set(wordChars)
 *         self.skipWhitespace = False
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_WordEnd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3262, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3262, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3263
 *     def __init__(self, wordChars=printables):
 *         super(WordEnd, self).__init__()
 *         self.wordChars = set(wordChars)             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = False
 *         self.errmsg = "Not at the end of a word"
 */
  __pyx_t_1 = PySet_New(__pyx_v_wordChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3263, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_wordChars, __pyx_t_1) < 0) __PYX_ERR(0, 3263, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3264
 *         super(WordEnd, self).__init__()
 *         self.wordChars = set(wordChars)
 *         self.skipWhitespace = False             # <<<<<<<<<<<<<<
 *         self.errmsg = "Not at the end of a word"
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, Py_False) < 0) __PYX_ERR(0, 3264, __pyx_L1_error)

  /* "cPyparsing.pyx":3265
 *         self.wordChars = set(wordChars)
 *         self.skipWhitespace = False
 *         self.errmsg = "Not at the end of a word"             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_kp_u_Not_at_the_end_of_a_word) < 0) __PYX_ERR(0, 3265, __pyx_L1_error)

  /* "cPyparsing.pyx":3261
 *     """
 * 
 *     def __init__(self, wordChars=printables):             # <<<<<<<<<<<<<<
 *         super(WordEnd, self).__init__()
 *         self.wordChars = set(wordChars)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.WordEnd.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3267
 *         self.errmsg = "Not at the end of a word"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         instrlen = len(instring)
 *         if instrlen > 0 and loc < instrlen:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7WordEnd_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_7WordEnd_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_7WordEnd_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_7WordEnd_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3267, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3267, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3267, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3267, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3267, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.WordEnd.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7WordEnd_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7WordEnd_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  Py_ssize_t __pyx_v_instrlen;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  long __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":3268
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         instrlen = len(instring)             # <<<<<<<<<<<<<<
 *         if instrlen > 0 and loc < instrlen:
 *             if (instring[loc] in self.wordChars or
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 3268, __pyx_L1_error)
  __pyx_v_instrlen = __pyx_t_1;

  /* "cPyparsing.pyx":3269
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         instrlen = len(instring)
 *         if instrlen > 0 and loc < instrlen:             # <<<<<<<<<<<<<<
 *             if (instring[loc] in self.wordChars or
 *                     instring[loc - 1] not in self.wordChars):
 */
  __pyx_t_3 = ((__pyx_v_instrlen > 0) != 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = ((__pyx_v_loc < __pyx_v_instrlen) != 0);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":3270
 *         instrlen = len(instring)
 *         if instrlen > 0 and loc < instrlen:
 *             if (instring[loc] in self.wordChars or             # <<<<<<<<<<<<<<
 *                     instring[loc - 1] not in self.wordChars):
 *                 raise ParseException(instring, loc, self.errmsg, self)
 */
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_instring, __pyx_v_loc, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3270, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_wordChars); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3270, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_t_4, __pyx_t_5, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 3270, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = (__pyx_t_3 != 0);
    if (!__pyx_t_6) {
    } else {
      __pyx_t_2 = __pyx_t_6;
      goto __pyx_L7_bool_binop_done;
    }

    /* "cPyparsing.pyx":3271
 *         if instrlen > 0 and loc < instrlen:
 *             if (instring[loc] in self.wordChars or
 *                     instring[loc - 1] not in self.wordChars):             # <<<<<<<<<<<<<<
 *                 raise ParseException(instring, loc, self.errmsg, self)
 *         return loc, []
 */
    __pyx_t_7 = 0;
    __pyx_t_8 = __Pyx_sub_const_long_checking_overflow(__pyx_v_loc, 1, &__pyx_t_7);
    if (unlikely(__pyx_t_7)) {
      PyErr_SetString(PyExc_OverflowError, "value too large");
      __PYX_ERR(0, 3271, __pyx_L1_error)
    }
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_instring, __pyx_t_8, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3271, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_wordChars); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3271, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_t_5, __pyx_t_4, Py_NE)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 3271, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_3 = (__pyx_t_6 != 0);
    __pyx_t_2 = __pyx_t_3;
    __pyx_L7_bool_binop_done:;

    /* "cPyparsing.pyx":3270
 *         instrlen = len(instring)
 *         if instrlen > 0 and loc < instrlen:
 *             if (instring[loc] in self.wordChars or             # <<<<<<<<<<<<<<
 *                     instring[loc - 1] not in self.wordChars):
 *                 raise ParseException(instring, loc, self.errmsg, self)
 */
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":3272
 *             if (instring[loc] in self.wordChars or
 *                     instring[loc - 1] not in self.wordChars):
 *                 raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 *         return loc, []
 * 
 */
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3272, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3272, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3272, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_11 = NULL;
      __pyx_t_7 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_7 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[5] = {__pyx_t_11, __pyx_v_instring, __pyx_t_9, __pyx_t_10, __pyx_v_self};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_7, 4+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3272, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[5] = {__pyx_t_11, __pyx_v_instring, __pyx_t_9, __pyx_t_10, __pyx_v_self};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_7, 4+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3272, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(4+__pyx_t_7); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 3272, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_v_instring);
        __Pyx_GIVEREF(__pyx_v_instring);
        PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_7, __pyx_v_instring);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_7, __pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_10);
        PyTuple_SET_ITEM(__pyx_t_12, 2+__pyx_t_7, __pyx_t_10);
        __Pyx_INCREF(__pyx_v_self);
        __Pyx_GIVEREF(__pyx_v_self);
        PyTuple_SET_ITEM(__pyx_t_12, 3+__pyx_t_7, __pyx_v_self);
        __pyx_t_9 = 0;
        __pyx_t_10 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_12, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3272, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(0, 3272, __pyx_L1_error)

      /* "cPyparsing.pyx":3270
 *         instrlen = len(instring)
 *         if instrlen > 0 and loc < instrlen:
 *             if (instring[loc] in self.wordChars or             # <<<<<<<<<<<<<<
 *                     instring[loc - 1] not in self.wordChars):
 *                 raise ParseException(instring, loc, self.errmsg, self)
 */
    }

    /* "cPyparsing.pyx":3269
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         instrlen = len(instring)
 *         if instrlen > 0 and loc < instrlen:             # <<<<<<<<<<<<<<
 *             if (instring[loc] in self.wordChars or
 *                     instring[loc - 1] not in self.wordChars):
 */
  }

  /* "cPyparsing.pyx":3273
 *                     instring[loc - 1] not in self.wordChars):
 *                 raise ParseException(instring, loc, self.errmsg, self)
 *         return loc, []             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_12 = PyTuple_New(2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 3273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_12, 1, __pyx_t_5);
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_r = __pyx_t_12;
  __pyx_t_12 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3267
 *         self.errmsg = "Not at the end of a word"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         instrlen = len(instring)
 *         if instrlen > 0 and loc < instrlen:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("cPyparsing.WordEnd.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3281
 *     """
 * 
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(ParseExpression, self).__init__(savelist)
 *         if isinstance(exprs, _generatorType):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15ParseExpression_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_15ParseExpression_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_exprs = 0;
  PyObject *__pyx_v_savelist = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_exprs,&__pyx_n_s_savelist,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_False));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_exprs)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 3281, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_savelist);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 3281, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_exprs = values[1];
    __pyx_v_savelist = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3281, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseExpression.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15ParseExpression___init__(__pyx_self, __pyx_v_self, __pyx_v_exprs, __pyx_v_savelist);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_15ParseExpression_8__init___2generator17(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":3291
 *             exprs = list(exprs)
 *             # if sequence of strings provided, wrap with Literal
 *             if all(isinstance(expr, basestring) for expr in exprs):             # <<<<<<<<<<<<<<
 *                 exprs = map(ParserElement._literalStringClass, exprs)
 *             self.exprs = list(exprs)
 */

static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_8__init___genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_35_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_35_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3291, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_34___init__ *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_15ParseExpression_8__init___2generator17, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_ParseExpression___init___locals, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 3291, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.ParseExpression.__init__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_15ParseExpression_8__init___2generator17(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 3291, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_exprs)) { __Pyx_RaiseClosureNameError("exprs"); __PYX_ERR(0, 3291, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_exprs)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_exprs)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_outer_scope->__pyx_v_exprs; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3291, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3291, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 3291, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3291, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 3291, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3291, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3291, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_expr);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_expr, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3291, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyObject_IsInstance(__pyx_cur_scope->__pyx_v_expr, __pyx_t_4); if (unlikely(__pyx_t_5 == -1)) __PYX_ERR(0, 3291, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = ((!(__pyx_t_5 != 0)) != 0);
    if (__pyx_t_6) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3281
 *     """
 * 
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(ParseExpression, self).__init__(savelist)
 *         if isinstance(exprs, _generatorType):
 */

static PyObject *__pyx_pf_10cPyparsing_15ParseExpression___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exprs, PyObject *__pyx_v_savelist) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_34___init__ *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  __Pyx_RefNannySetupContext("__init__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_34___init__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_34___init__(__pyx_ptype_10cPyparsing___pyx_scope_struct_34___init__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_34___init__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3281, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_exprs = __pyx_v_exprs;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_exprs);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_exprs);

  /* "cPyparsing.pyx":3282
 * 
 *     def __init__(self, exprs, savelist=False):
 *         super(ParseExpression, self).__init__(savelist)             # <<<<<<<<<<<<<<
 *         if isinstance(exprs, _generatorType):
 *             exprs = list(exprs)
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseExpression); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_savelist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3282, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_savelist};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3282, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_savelist};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3282, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3282, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_savelist);
      __Pyx_GIVEREF(__pyx_v_savelist);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_savelist);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3282, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3283
 *     def __init__(self, exprs, savelist=False):
 *         super(ParseExpression, self).__init__(savelist)
 *         if isinstance(exprs, _generatorType):             # <<<<<<<<<<<<<<
 *             exprs = list(exprs)
 * 
 */
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_exprs;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_generatorType); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = PyObject_IsInstance(__pyx_t_1, __pyx_t_3); if (unlikely(__pyx_t_5 == -1)) __PYX_ERR(0, 3283, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":3284
 *         super(ParseExpression, self).__init__(savelist)
 *         if isinstance(exprs, _generatorType):
 *             exprs = list(exprs)             # <<<<<<<<<<<<<<
 * 
 *         if isinstance(exprs, basestring):
 */
    __pyx_t_3 = PySequence_List(__pyx_cur_scope->__pyx_v_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3284, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_exprs);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_exprs, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3283
 *     def __init__(self, exprs, savelist=False):
 *         super(ParseExpression, self).__init__(savelist)
 *         if isinstance(exprs, _generatorType):             # <<<<<<<<<<<<<<
 *             exprs = list(exprs)
 * 
 */
  }

  /* "cPyparsing.pyx":3286
 *             exprs = list(exprs)
 * 
 *         if isinstance(exprs, basestring):             # <<<<<<<<<<<<<<
 *             self.exprs = [ParserElement._literalStringClass(exprs)]
 *         elif isinstance(exprs, collections.Iterable):
 */
  __pyx_t_3 = __pyx_cur_scope->__pyx_v_exprs;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyObject_IsInstance(__pyx_t_3, __pyx_t_1); if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 3286, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (__pyx_t_6 != 0);
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":3287
 * 
 *         if isinstance(exprs, basestring):
 *             self.exprs = [ParserElement._literalStringClass(exprs)]             # <<<<<<<<<<<<<<
 *         elif isinstance(exprs, collections.Iterable):
 *             exprs = list(exprs)
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3287, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3287, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_3) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_cur_scope->__pyx_v_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3287, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_cur_scope->__pyx_v_exprs};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3287, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_cur_scope->__pyx_v_exprs};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3287, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_2 = PyTuple_New(1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3287, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3); __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_exprs);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_exprs);
        PyTuple_SET_ITEM(__pyx_t_2, 0+1, __pyx_cur_scope->__pyx_v_exprs);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3287, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3287, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    PyList_SET_ITEM(__pyx_t_4, 0, __pyx_t_1);
    __pyx_t_1 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_exprs, __pyx_t_4) < 0) __PYX_ERR(0, 3287, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":3286
 *             exprs = list(exprs)
 * 
 *         if isinstance(exprs, basestring):             # <<<<<<<<<<<<<<
 *             self.exprs = [ParserElement._literalStringClass(exprs)]
 *         elif isinstance(exprs, collections.Iterable):
 */
    goto __pyx_L4;
  }

  /* "cPyparsing.pyx":3288
 *         if isinstance(exprs, basestring):
 *             self.exprs = [ParserElement._literalStringClass(exprs)]
 *         elif isinstance(exprs, collections.Iterable):             # <<<<<<<<<<<<<<
 *             exprs = list(exprs)
 *             # if sequence of strings provided, wrap with Literal
 */
  __pyx_t_4 = __pyx_cur_scope->__pyx_v_exprs;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_collections); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_Iterable); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = PyObject_IsInstance(__pyx_t_4, __pyx_t_2); if (unlikely(__pyx_t_5 == -1)) __PYX_ERR(0, 3288, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":3289
 *             self.exprs = [ParserElement._literalStringClass(exprs)]
 *         elif isinstance(exprs, collections.Iterable):
 *             exprs = list(exprs)             # <<<<<<<<<<<<<<
 *             # if sequence of strings provided, wrap with Literal
 *             if all(isinstance(expr, basestring) for expr in exprs):
 */
    __pyx_t_2 = PySequence_List(__pyx_cur_scope->__pyx_v_exprs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3289, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_exprs);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_exprs, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":3291
 *             exprs = list(exprs)
 *             # if sequence of strings provided, wrap with Literal
 *             if all(isinstance(expr, basestring) for expr in exprs):             # <<<<<<<<<<<<<<
 *                 exprs = map(ParserElement._literalStringClass, exprs)
 *             self.exprs = list(exprs)
 */
    __pyx_t_2 = __pyx_pf_10cPyparsing_15ParseExpression_8__init___genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3291, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_Generator_Next(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3291, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 3291, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_6) {

      /* "cPyparsing.pyx":3292
 *             # if sequence of strings provided, wrap with Literal
 *             if all(isinstance(expr, basestring) for expr in exprs):
 *                 exprs = map(ParserElement._literalStringClass, exprs)             # <<<<<<<<<<<<<<
 *             self.exprs = list(exprs)
 *         else:
 */
      __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3292, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3292, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3292, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2);
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_exprs);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_exprs);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_cur_scope->__pyx_v_exprs);
      __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_map, __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3292, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_exprs);
      __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_exprs, __pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_2);
      __pyx_t_2 = 0;

      /* "cPyparsing.pyx":3291
 *             exprs = list(exprs)
 *             # if sequence of strings provided, wrap with Literal
 *             if all(isinstance(expr, basestring) for expr in exprs):             # <<<<<<<<<<<<<<
 *                 exprs = map(ParserElement._literalStringClass, exprs)
 *             self.exprs = list(exprs)
 */
    }

    /* "cPyparsing.pyx":3293
 *             if all(isinstance(expr, basestring) for expr in exprs):
 *                 exprs = map(ParserElement._literalStringClass, exprs)
 *             self.exprs = list(exprs)             # <<<<<<<<<<<<<<
 *         else:
 *             try:
 */
    __pyx_t_2 = PySequence_List(__pyx_cur_scope->__pyx_v_exprs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3293, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_exprs, __pyx_t_2) < 0) __PYX_ERR(0, 3293, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":3288
 *         if isinstance(exprs, basestring):
 *             self.exprs = [ParserElement._literalStringClass(exprs)]
 *         elif isinstance(exprs, collections.Iterable):             # <<<<<<<<<<<<<<
 *             exprs = list(exprs)
 *             # if sequence of strings provided, wrap with Literal
 */
    goto __pyx_L4;
  }

  /* "cPyparsing.pyx":3295
 *             self.exprs = list(exprs)
 *         else:
 *             try:             # <<<<<<<<<<<<<<
 *                 self.exprs = list(exprs)
 *             except TypeError:
 */
  /*else*/ {
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      /*try:*/ {

        /* "cPyparsing.pyx":3296
 *         else:
 *             try:
 *                 self.exprs = list(exprs)             # <<<<<<<<<<<<<<
 *             except TypeError:
 *                 self.exprs = [exprs]
 */
        __pyx_t_2 = PySequence_List(__pyx_cur_scope->__pyx_v_exprs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3296, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_exprs, __pyx_t_2) < 0) __PYX_ERR(0, 3296, __pyx_L6_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "cPyparsing.pyx":3295
 *             self.exprs = list(exprs)
 *         else:
 *             try:             # <<<<<<<<<<<<<<
 *                 self.exprs = list(exprs)
 *             except TypeError:
 */
      }
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L13_try_end;
      __pyx_L6_error:;
      __Pyx_PyThreadState_assign
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "cPyparsing.pyx":3297
 *             try:
 *                 self.exprs = list(exprs)
 *             except TypeError:             # <<<<<<<<<<<<<<
 *                 self.exprs = [exprs]
 *         self.callPreparse = False
 */
      __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_TypeError);
      if (__pyx_t_10) {
        __Pyx_AddTraceback("cPyparsing.ParseExpression.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_4, &__pyx_t_1) < 0) __PYX_ERR(0, 3297, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GOTREF(__pyx_t_1);

        /* "cPyparsing.pyx":3298
 *                 self.exprs = list(exprs)
 *             except TypeError:
 *                 self.exprs = [exprs]             # <<<<<<<<<<<<<<
 *         self.callPreparse = False
 * 
 */
        __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3298, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_exprs);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_exprs);
        PyList_SET_ITEM(__pyx_t_3, 0, __pyx_cur_scope->__pyx_v_exprs);
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_exprs, __pyx_t_3) < 0) __PYX_ERR(0, 3298, __pyx_L8_except_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L7_exception_handled;
      }
      goto __pyx_L8_except_error;
      __pyx_L8_except_error:;

      /* "cPyparsing.pyx":3295
 *             self.exprs = list(exprs)
 *         else:
 *             try:             # <<<<<<<<<<<<<<
 *                 self.exprs = list(exprs)
 *             except TypeError:
 */
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      goto __pyx_L1_error;
      __pyx_L7_exception_handled:;
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      __pyx_L13_try_end:;
    }
  }
  __pyx_L4:;

  /* "cPyparsing.pyx":3299
 *             except TypeError:
 *                 self.exprs = [exprs]
 *         self.callPreparse = False             # <<<<<<<<<<<<<<
 * 
 *     def __getitem__(self, i):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_callPreparse, Py_False) < 0) __PYX_ERR(0, 3299, __pyx_L1_error)

  /* "cPyparsing.pyx":3281
 *     """
 * 
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(ParseExpression, self).__init__(savelist)
 *         if isinstance(exprs, _generatorType):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ParseExpression.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3301
 *         self.callPreparse = False
 * 
 *     def __getitem__(self, i):             # <<<<<<<<<<<<<<
 *         return self.exprs[i]
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_3__getitem__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15ParseExpression_3__getitem__ = {"__getitem__", (PyCFunction)__pyx_pw_10cPyparsing_15ParseExpression_3__getitem__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_3__getitem__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_i = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_i,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_i)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__getitem__", 1, 2, 2, 1); __PYX_ERR(0, 3301, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__getitem__") < 0)) __PYX_ERR(0, 3301, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_i = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__getitem__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3301, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseExpression.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15ParseExpression_2__getitem__(__pyx_self, __pyx_v_self, __pyx_v_i);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_2__getitem__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_i) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "cPyparsing.pyx":3302
 * 
 *     def __getitem__(self, i):
 *         return self.exprs[i]             # <<<<<<<<<<<<<<
 * 
 *     def append(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetItem(__pyx_t_1, __pyx_v_i); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3301
 *         self.callPreparse = False
 * 
 *     def __getitem__(self, i):             # <<<<<<<<<<<<<<
 *         return self.exprs[i]
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.ParseExpression.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3304
 *         return self.exprs[i]
 * 
 *     def append(self, other):             # <<<<<<<<<<<<<<
 *         self.exprs.append(other)
 *         self.strRepr = None
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_5append(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15ParseExpression_5append = {"append", (PyCFunction)__pyx_pw_10cPyparsing_15ParseExpression_5append, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_5append(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("append (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("append", 1, 2, 2, 1); __PYX_ERR(0, 3304, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "append") < 0)) __PYX_ERR(0, 3304, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("append", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3304, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseExpression.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15ParseExpression_4append(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_4append(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("append", 0);

  /* "cPyparsing.pyx":3305
 * 
 *     def append(self, other):
 *         self.exprs.append(other)             # <<<<<<<<<<<<<<
 *         self.strRepr = None
 *         return self
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_v_other); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 3305, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3306
 *     def append(self, other):
 *         self.exprs.append(other)
 *         self.strRepr = None             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, Py_None) < 0) __PYX_ERR(0, 3306, __pyx_L1_error)

  /* "cPyparsing.pyx":3307
 *         self.exprs.append(other)
 *         self.strRepr = None
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def leaveWhitespace(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3304
 *         return self.exprs[i]
 * 
 *     def append(self, other):             # <<<<<<<<<<<<<<
 *         self.exprs.append(other)
 *         self.strRepr = None
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ParseExpression.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3309
 *         return self
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         """Extends C{leaveWhitespace} defined in base class, and also invokes C{leaveWhitespace} on
 *            all contained expressions."""
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_7leaveWhitespace(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_10cPyparsing_15ParseExpression_6leaveWhitespace[] = "Extends C{leaveWhitespace} defined in base class, and also invokes C{leaveWhitespace} on\n           all contained expressions.";
static PyMethodDef __pyx_mdef_10cPyparsing_15ParseExpression_7leaveWhitespace = {"leaveWhitespace", (PyCFunction)__pyx_pw_10cPyparsing_15ParseExpression_7leaveWhitespace, METH_O, __pyx_doc_10cPyparsing_15ParseExpression_6leaveWhitespace};
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_7leaveWhitespace(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("leaveWhitespace (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_15ParseExpression_6leaveWhitespace(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_6leaveWhitespace(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("leaveWhitespace", 0);

  /* "cPyparsing.pyx":3312
 *         """Extends C{leaveWhitespace} defined in base class, and also invokes C{leaveWhitespace} on
 *            all contained expressions."""
 *         self.skipWhitespace = False             # <<<<<<<<<<<<<<
 *         self.exprs = [e.copy() for e in self.exprs]
 *         for e in self.exprs:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, Py_False) < 0) __PYX_ERR(0, 3312, __pyx_L1_error)

  /* "cPyparsing.pyx":3313
 *            all contained expressions."""
 *         self.skipWhitespace = False
 *         self.exprs = [e.copy() for e in self.exprs]             # <<<<<<<<<<<<<<
 *         for e in self.exprs:
 *             e.leaveWhitespace()
 */
  { /* enter inner scope */
    PyObject *__pyx_9genexpr22__pyx_v_e = NULL;
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3313, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3313, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
      __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
      __pyx_t_5 = NULL;
    } else {
      __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3313, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3313, __pyx_L5_error)
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (likely(!__pyx_t_5)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_3)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 3313, __pyx_L5_error)
          #else
          __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3313, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 3313, __pyx_L5_error)
          #else
          __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3313, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        }
      } else {
        __pyx_t_2 = __pyx_t_5(__pyx_t_3);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 3313, __pyx_L5_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_9genexpr22__pyx_v_e, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_9genexpr22__pyx_v_e, __pyx_n_s_copy); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3313, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      if (__pyx_t_7) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3313, __pyx_L5_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else {
        __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3313, __pyx_L5_error)
      }
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_2))) __PYX_ERR(0, 3313, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_9genexpr22__pyx_v_e);
    goto __pyx_L8_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_9genexpr22__pyx_v_e);
    goto __pyx_L1_error;
    __pyx_L8_exit_scope:;
  } /* exit inner scope */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_exprs, __pyx_t_1) < 0) __PYX_ERR(0, 3313, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3314
 *         self.skipWhitespace = False
 *         self.exprs = [e.copy() for e in self.exprs]
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.leaveWhitespace()
 *         return self
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_3 = __pyx_t_1; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3314, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3314, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 3314, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3314, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 3314, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3314, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_5(__pyx_t_3);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3314, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3315
 *         self.exprs = [e.copy() for e in self.exprs]
 *         for e in self.exprs:
 *             e.leaveWhitespace()             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_leaveWhitespace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3315, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (__pyx_t_6) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3315, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3315, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3314
 *         self.skipWhitespace = False
 *         self.exprs = [e.copy() for e in self.exprs]
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.leaveWhitespace()
 *         return self
 */
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3316
 *         for e in self.exprs:
 *             e.leaveWhitespace()
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def ignore(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3309
 *         return self
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         """Extends C{leaveWhitespace} defined in base class, and also invokes C{leaveWhitespace} on
 *            all contained expressions."""
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParseExpression.leaveWhitespace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3318
 *         return self
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_9ignore(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15ParseExpression_9ignore = {"ignore", (PyCFunction)__pyx_pw_10cPyparsing_15ParseExpression_9ignore, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_9ignore(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ignore (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ignore", 1, 2, 2, 1); __PYX_ERR(0, 3318, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "ignore") < 0)) __PYX_ERR(0, 3318, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("ignore", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3318, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseExpression.ignore", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15ParseExpression_8ignore(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_8ignore(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  __Pyx_RefNannySetupContext("ignore", 0);

  /* "cPyparsing.pyx":3319
 * 
 *     def ignore(self, other):
 *         if isinstance(other, Suppress):             # <<<<<<<<<<<<<<
 *             if other not in self.ignoreExprs:
 *                 super(ParseExpression, self).ignore(other)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Suppress); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 3319, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":3320
 *     def ignore(self, other):
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:             # <<<<<<<<<<<<<<
 *                 super(ParseExpression, self).ignore(other)
 *                 for e in self.exprs:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3320, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_v_other, __pyx_t_1, Py_NE)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 3320, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = (__pyx_t_3 != 0);
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":3321
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:
 *                 super(ParseExpression, self).ignore(other)             # <<<<<<<<<<<<<<
 *                 for e in self.exprs:
 *                     e.ignore(self.ignoreExprs[-1])
 */
      __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseExpression); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3321, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3321, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_self);
      __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_5, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3321, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_ignore); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3321, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (!__pyx_t_4) {
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3321, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
          __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3321, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_1);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
          __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3321, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_1);
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3321, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
          __Pyx_INCREF(__pyx_v_other);
          __Pyx_GIVEREF(__pyx_v_other);
          PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_other);
          __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3321, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":3322
 *             if other not in self.ignoreExprs:
 *                 super(ParseExpression, self).ignore(other)
 *                 for e in self.exprs:             # <<<<<<<<<<<<<<
 *                     e.ignore(self.ignoreExprs[-1])
 *         else:
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3322, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
        __pyx_t_5 = __pyx_t_1; __Pyx_INCREF(__pyx_t_5); __pyx_t_7 = 0;
        __pyx_t_8 = NULL;
      } else {
        __pyx_t_7 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3322, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_8 = Py_TYPE(__pyx_t_5)->tp_iternext; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3322, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      for (;;) {
        if (likely(!__pyx_t_8)) {
          if (likely(PyList_CheckExact(__pyx_t_5))) {
            if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_5)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_7); __Pyx_INCREF(__pyx_t_1); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 3322, __pyx_L1_error)
            #else
            __pyx_t_1 = PySequence_ITEM(__pyx_t_5, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3322, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          } else {
            if (__pyx_t_7 >= PyTuple_GET_SIZE(__pyx_t_5)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_7); __Pyx_INCREF(__pyx_t_1); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 3322, __pyx_L1_error)
            #else
            __pyx_t_1 = PySequence_ITEM(__pyx_t_5, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3322, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          }
        } else {
          __pyx_t_1 = __pyx_t_8(__pyx_t_5);
          if (unlikely(!__pyx_t_1)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 3322, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "cPyparsing.pyx":3323
 *                 super(ParseExpression, self).ignore(other)
 *                 for e in self.exprs:
 *                     e.ignore(self.ignoreExprs[-1])             # <<<<<<<<<<<<<<
 *         else:
 *             super(ParseExpression, self).ignore(other)
 */
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_ignore); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3323, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3323, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_9 = __Pyx_GetItemInt(__pyx_t_4, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3323, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
          }
        }
        if (!__pyx_t_4) {
          __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3323, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_GOTREF(__pyx_t_1);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_6)) {
            PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_9};
            __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3323, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
            PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_9};
            __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3323, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          } else
          #endif
          {
            __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3323, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_4); __pyx_t_4 = NULL;
            __Pyx_GIVEREF(__pyx_t_9);
            PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_9);
            __pyx_t_9 = 0;
            __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_10, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3323, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "cPyparsing.pyx":3322
 *             if other not in self.ignoreExprs:
 *                 super(ParseExpression, self).ignore(other)
 *                 for e in self.exprs:             # <<<<<<<<<<<<<<
 *                     e.ignore(self.ignoreExprs[-1])
 *         else:
 */
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "cPyparsing.pyx":3320
 *     def ignore(self, other):
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:             # <<<<<<<<<<<<<<
 *                 super(ParseExpression, self).ignore(other)
 *                 for e in self.exprs:
 */
    }

    /* "cPyparsing.pyx":3319
 * 
 *     def ignore(self, other):
 *         if isinstance(other, Suppress):             # <<<<<<<<<<<<<<
 *             if other not in self.ignoreExprs:
 *                 super(ParseExpression, self).ignore(other)
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":3325
 *                     e.ignore(self.ignoreExprs[-1])
 *         else:
 *             super(ParseExpression, self).ignore(other)             # <<<<<<<<<<<<<<
 *             for e in self.exprs:
 *                 e.ignore(self.ignoreExprs[-1])
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseExpression); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3325, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3325, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_self);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3325, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_ignore); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3325, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    if (!__pyx_t_1) {
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_other); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3325, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_v_other};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3325, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_5);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_v_other};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3325, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_5);
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3325, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_1); __pyx_t_1 = NULL;
        __Pyx_INCREF(__pyx_v_other);
        __Pyx_GIVEREF(__pyx_v_other);
        PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_v_other);
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_10, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3325, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "cPyparsing.pyx":3326
 *         else:
 *             super(ParseExpression, self).ignore(other)
 *             for e in self.exprs:             # <<<<<<<<<<<<<<
 *                 e.ignore(self.ignoreExprs[-1])
 *         return self
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3326, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (likely(PyList_CheckExact(__pyx_t_5)) || PyTuple_CheckExact(__pyx_t_5)) {
      __pyx_t_6 = __pyx_t_5; __Pyx_INCREF(__pyx_t_6); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
    } else {
      __pyx_t_7 = -1; __pyx_t_6 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3326, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_8 = Py_TYPE(__pyx_t_6)->tp_iternext; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3326, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    for (;;) {
      if (likely(!__pyx_t_8)) {
        if (likely(PyList_CheckExact(__pyx_t_6))) {
          if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_6)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_7); __Pyx_INCREF(__pyx_t_5); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 3326, __pyx_L1_error)
          #else
          __pyx_t_5 = PySequence_ITEM(__pyx_t_6, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3326, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        } else {
          if (__pyx_t_7 >= PyTuple_GET_SIZE(__pyx_t_6)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_6, __pyx_t_7); __Pyx_INCREF(__pyx_t_5); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 3326, __pyx_L1_error)
          #else
          __pyx_t_5 = PySequence_ITEM(__pyx_t_6, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3326, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        }
      } else {
        __pyx_t_5 = __pyx_t_8(__pyx_t_6);
        if (unlikely(!__pyx_t_5)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 3326, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "cPyparsing.pyx":3327
 *             super(ParseExpression, self).ignore(other)
 *             for e in self.exprs:
 *                 e.ignore(self.ignoreExprs[-1])             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_ignore); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3327, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3327, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = __Pyx_GetItemInt(__pyx_t_1, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3327, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      if (!__pyx_t_1) {
        __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3327, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_5);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_10)) {
          PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_9};
          __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3327, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
          PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_9};
          __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3327, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        } else
        #endif
        {
          __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3327, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1); __pyx_t_1 = NULL;
          __Pyx_GIVEREF(__pyx_t_9);
          PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_t_9);
          __pyx_t_9 = 0;
          __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_4, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3327, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "cPyparsing.pyx":3326
 *         else:
 *             super(ParseExpression, self).ignore(other)
 *             for e in self.exprs:             # <<<<<<<<<<<<<<
 *                 e.ignore(self.ignoreExprs[-1])
 *         return self
 */
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":3328
 *             for e in self.exprs:
 *                 e.ignore(self.ignoreExprs[-1])
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3318
 *         return self
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("cPyparsing.ParseExpression.ignore", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3330
 *         return self
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(ParseExpression, self).__str__()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_11__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15ParseExpression_11__str__ = {"__str__", (PyCFunction)__pyx_pw_10cPyparsing_15ParseExpression_11__str__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_11__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_15ParseExpression_10__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_10__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "cPyparsing.pyx":3331
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(ParseExpression, self).__str__()
 *         except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":3332
 *     def __str__(self):
 *         try:
 *             return super(ParseExpression, self).__str__()             # <<<<<<<<<<<<<<
 *         except Exception:
 *             pass
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseExpression); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3332, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3332, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_self);
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3332, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_str_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3332, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      if (__pyx_t_5) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3332, __pyx_L3_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else {
        __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3332, __pyx_L3_error)
      }
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":3331
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(ParseExpression, self).__str__()
 *         except Exception:
 */
    }
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":3333
 *         try:
 *             return super(ParseExpression, self).__str__()
 *         except Exception:             # <<<<<<<<<<<<<<
 *             pass
 * 
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_7) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cPyparsing.pyx":3331
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(ParseExpression, self).__str__()
 *         except Exception:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L4_exception_handled:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
  }

  /* "cPyparsing.pyx":3336
 *             pass
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "%s:(%s)" % (self.__class__.__name__, _ustr(self.exprs))
 *         return self.strRepr
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_8 = (__pyx_t_4 == Py_None);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_9 = (__pyx_t_8 != 0);
  if (__pyx_t_9) {

    /* "cPyparsing.pyx":3337
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "%s:(%s)" % (self.__class__.__name__, _ustr(self.exprs))             # <<<<<<<<<<<<<<
 *         return self.strRepr
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3337, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_name_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3337, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3337, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3337, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_11 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_11) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_10); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3337, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_t_10};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3337, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_t_10};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3337, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 3337, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_11); __pyx_t_11 = NULL;
        __Pyx_GIVEREF(__pyx_t_10);
        PyTuple_SET_ITEM(__pyx_t_12, 0+1, __pyx_t_10);
        __pyx_t_10 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_12, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3337, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3337, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_4);
    __pyx_t_6 = 0;
    __pyx_t_4 = 0;
    __pyx_t_4 = PyUnicode_Format(__pyx_kp_u_s_s_5, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3337, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_4) < 0) __PYX_ERR(0, 3337, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":3336
 *             pass
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "%s:(%s)" % (self.__class__.__name__, _ustr(self.exprs))
 *         return self.strRepr
 */
  }

  /* "cPyparsing.pyx":3338
 *         if self.strRepr is None:
 *             self.strRepr = "%s:(%s)" % (self.__class__.__name__, _ustr(self.exprs))
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 *     def streamline(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3330
 *         return self
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(ParseExpression, self).__str__()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("cPyparsing.ParseExpression.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3340
 *         return self.strRepr
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(ParseExpression, self).streamline()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_13streamline(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15ParseExpression_13streamline = {"streamline", (PyCFunction)__pyx_pw_10cPyparsing_15ParseExpression_13streamline, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_13streamline(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("streamline (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_15ParseExpression_12streamline(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_12streamline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_v_other = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("streamline", 0);

  /* "cPyparsing.pyx":3341
 * 
 *     def streamline(self):
 *         super(ParseExpression, self).streamline()             # <<<<<<<<<<<<<<
 * 
 *         for e in self.exprs:
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseExpression); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_streamline); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3341, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3341, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3343
 *         super(ParseExpression, self).streamline()
 * 
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.streamline()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_3 = __pyx_t_1; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3343, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3343, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 3343, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3343, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 3343, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3343, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_5(__pyx_t_3);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3343, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3344
 * 
 *         for e in self.exprs:
 *             e.streamline()             # <<<<<<<<<<<<<<
 * 
 *         # collapse nested And's of the form And( And( And( a,b), c), d) to And( a,b,c,d )
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_streamline); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3344, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (__pyx_t_6) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3344, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3344, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3343
 *         super(ParseExpression, self).streamline()
 * 
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.streamline()
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3349
 *         # but only if there are no parse actions or resultsNames on the nested And's
 *         # (likewise for Or's and MatchFirst's)
 *         if (len(self.exprs) == 2):             # <<<<<<<<<<<<<<
 *             other = self.exprs[0]
 *             if (isinstance(other, self.__class__) and
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_4 == -1)) __PYX_ERR(0, 3349, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_7 = ((__pyx_t_4 == 2) != 0);
  if (__pyx_t_7) {

    /* "cPyparsing.pyx":3350
 *         # (likewise for Or's and MatchFirst's)
 *         if (len(self.exprs) == 2):
 *             other = self.exprs[0]             # <<<<<<<<<<<<<<
 *             if (isinstance(other, self.__class__) and
 *                 not(other.parseAction) and
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3350, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_3, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3350, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_other = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3351
 *         if (len(self.exprs) == 2):
 *             other = self.exprs[0]
 *             if (isinstance(other, self.__class__) and             # <<<<<<<<<<<<<<
 *                 not(other.parseAction) and
 *                 other.resultsName is None and
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3351, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_8 == -1)) __PYX_ERR(0, 3351, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_9 = (__pyx_t_8 != 0);
    if (__pyx_t_9) {
    } else {
      __pyx_t_7 = __pyx_t_9;
      goto __pyx_L7_bool_binop_done;
    }

    /* "cPyparsing.pyx":3352
 *             other = self.exprs[0]
 *             if (isinstance(other, self.__class__) and
 *                 not(other.parseAction) and             # <<<<<<<<<<<<<<
 *                 other.resultsName is None and
 *                     not other.debug):
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3352, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 3352, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_8 = ((!__pyx_t_9) != 0);
    if (__pyx_t_8) {
    } else {
      __pyx_t_7 = __pyx_t_8;
      goto __pyx_L7_bool_binop_done;
    }

    /* "cPyparsing.pyx":3353
 *             if (isinstance(other, self.__class__) and
 *                 not(other.parseAction) and
 *                 other.resultsName is None and             # <<<<<<<<<<<<<<
 *                     not other.debug):
 *                 self.exprs = other.exprs[:] + [self.exprs[1]]
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3353, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = (__pyx_t_1 == Py_None);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_9 = (__pyx_t_8 != 0);
    if (__pyx_t_9) {
    } else {
      __pyx_t_7 = __pyx_t_9;
      goto __pyx_L7_bool_binop_done;
    }

    /* "cPyparsing.pyx":3354
 *                 not(other.parseAction) and
 *                 other.resultsName is None and
 *                     not other.debug):             # <<<<<<<<<<<<<<
 *                 self.exprs = other.exprs[:] + [self.exprs[1]]
 *                 self.strRepr = None
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_debug); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3354, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 3354, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_8 = ((!__pyx_t_9) != 0);
    __pyx_t_7 = __pyx_t_8;
    __pyx_L7_bool_binop_done:;

    /* "cPyparsing.pyx":3351
 *         if (len(self.exprs) == 2):
 *             other = self.exprs[0]
 *             if (isinstance(other, self.__class__) and             # <<<<<<<<<<<<<<
 *                 not(other.parseAction) and
 *                 other.resultsName is None and
 */
    if (__pyx_t_7) {

      /* "cPyparsing.pyx":3355
 *                 other.resultsName is None and
 *                     not other.debug):
 *                 self.exprs = other.exprs[:] + [self.exprs[1]]             # <<<<<<<<<<<<<<
 *                 self.strRepr = None
 *                 self.mayReturnEmpty |= other.mayReturnEmpty
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3355, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_1, 0, 0, NULL, NULL, &__pyx_slice__104, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3355, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3355, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3355, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3355, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_2);
      PyList_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3355, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_exprs, __pyx_t_2) < 0) __PYX_ERR(0, 3355, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "cPyparsing.pyx":3356
 *                     not other.debug):
 *                 self.exprs = other.exprs[:] + [self.exprs[1]]
 *                 self.strRepr = None             # <<<<<<<<<<<<<<
 *                 self.mayReturnEmpty |= other.mayReturnEmpty
 *                 self.mayIndexError |= other.mayIndexError
 */
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, Py_None) < 0) __PYX_ERR(0, 3356, __pyx_L1_error)

      /* "cPyparsing.pyx":3357
 *                 self.exprs = other.exprs[:] + [self.exprs[1]]
 *                 self.strRepr = None
 *                 self.mayReturnEmpty |= other.mayReturnEmpty             # <<<<<<<<<<<<<<
 *                 self.mayIndexError |= other.mayIndexError
 * 
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3357, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3357, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = PyNumber_InPlaceOr(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3357, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_3) < 0) __PYX_ERR(0, 3357, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "cPyparsing.pyx":3358
 *                 self.strRepr = None
 *                 self.mayReturnEmpty |= other.mayReturnEmpty
 *                 self.mayIndexError |= other.mayIndexError             # <<<<<<<<<<<<<<
 * 
 *             other = self.exprs[-1]
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3358, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_mayIndexError); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3358, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = PyNumber_InPlaceOr(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3358, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, __pyx_t_2) < 0) __PYX_ERR(0, 3358, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "cPyparsing.pyx":3351
 *         if (len(self.exprs) == 2):
 *             other = self.exprs[0]
 *             if (isinstance(other, self.__class__) and             # <<<<<<<<<<<<<<
 *                 not(other.parseAction) and
 *                 other.resultsName is None and
 */
    }

    /* "cPyparsing.pyx":3360
 *                 self.mayIndexError |= other.mayIndexError
 * 
 *             other = self.exprs[-1]             # <<<<<<<<<<<<<<
 *             if (isinstance(other, self.__class__) and
 *                 not(other.parseAction) and
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3360, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_2, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3360, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3361
 * 
 *             other = self.exprs[-1]
 *             if (isinstance(other, self.__class__) and             # <<<<<<<<<<<<<<
 *                 not(other.parseAction) and
 *                 other.resultsName is None and
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3361, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_8 == -1)) __PYX_ERR(0, 3361, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_9 = (__pyx_t_8 != 0);
    if (__pyx_t_9) {
    } else {
      __pyx_t_7 = __pyx_t_9;
      goto __pyx_L12_bool_binop_done;
    }

    /* "cPyparsing.pyx":3362
 *             other = self.exprs[-1]
 *             if (isinstance(other, self.__class__) and
 *                 not(other.parseAction) and             # <<<<<<<<<<<<<<
 *                 other.resultsName is None and
 *                     not other.debug):
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_parseAction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3362, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 3362, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_8 = ((!__pyx_t_9) != 0);
    if (__pyx_t_8) {
    } else {
      __pyx_t_7 = __pyx_t_8;
      goto __pyx_L12_bool_binop_done;
    }

    /* "cPyparsing.pyx":3363
 *             if (isinstance(other, self.__class__) and
 *                 not(other.parseAction) and
 *                 other.resultsName is None and             # <<<<<<<<<<<<<<
 *                     not other.debug):
 *                 self.exprs = self.exprs[:-1] + other.exprs[:]
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3363, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = (__pyx_t_1 == Py_None);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_9 = (__pyx_t_8 != 0);
    if (__pyx_t_9) {
    } else {
      __pyx_t_7 = __pyx_t_9;
      goto __pyx_L12_bool_binop_done;
    }

    /* "cPyparsing.pyx":3364
 *                 not(other.parseAction) and
 *                 other.resultsName is None and
 *                     not other.debug):             # <<<<<<<<<<<<<<
 *                 self.exprs = self.exprs[:-1] + other.exprs[:]
 *                 self.strRepr = None
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_debug); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3364, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 3364, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_8 = ((!__pyx_t_9) != 0);
    __pyx_t_7 = __pyx_t_8;
    __pyx_L12_bool_binop_done:;

    /* "cPyparsing.pyx":3361
 * 
 *             other = self.exprs[-1]
 *             if (isinstance(other, self.__class__) and             # <<<<<<<<<<<<<<
 *                 not(other.parseAction) and
 *                 other.resultsName is None and
 */
    if (__pyx_t_7) {

      /* "cPyparsing.pyx":3365
 *                 other.resultsName is None and
 *                     not other.debug):
 *                 self.exprs = self.exprs[:-1] + other.exprs[:]             # <<<<<<<<<<<<<<
 *                 self.strRepr = None
 *                 self.mayReturnEmpty |= other.mayReturnEmpty
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3365, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_t_1, 0, -1L, NULL, NULL, &__pyx_slice__105, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3365, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3365, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_1, 0, 0, NULL, NULL, &__pyx_slice__106, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3365, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3365, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_exprs, __pyx_t_1) < 0) __PYX_ERR(0, 3365, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":3366
 *                     not other.debug):
 *                 self.exprs = self.exprs[:-1] + other.exprs[:]
 *                 self.strRepr = None             # <<<<<<<<<<<<<<
 *                 self.mayReturnEmpty |= other.mayReturnEmpty
 *                 self.mayIndexError |= other.mayIndexError
 */
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, Py_None) < 0) __PYX_ERR(0, 3366, __pyx_L1_error)

      /* "cPyparsing.pyx":3367
 *                 self.exprs = self.exprs[:-1] + other.exprs[:]
 *                 self.strRepr = None
 *                 self.mayReturnEmpty |= other.mayReturnEmpty             # <<<<<<<<<<<<<<
 *                 self.mayIndexError |= other.mayIndexError
 * 
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3367, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3367, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = PyNumber_InPlaceOr(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3367, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_2) < 0) __PYX_ERR(0, 3367, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "cPyparsing.pyx":3368
 *                 self.strRepr = None
 *                 self.mayReturnEmpty |= other.mayReturnEmpty
 *                 self.mayIndexError |= other.mayIndexError             # <<<<<<<<<<<<<<
 * 
 *         self.errmsg = "Expected " + _ustr(self)
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3368, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_mayIndexError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3368, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = PyNumber_InPlaceOr(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3368, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, __pyx_t_1) < 0) __PYX_ERR(0, 3368, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":3361
 * 
 *             other = self.exprs[-1]
 *             if (isinstance(other, self.__class__) and             # <<<<<<<<<<<<<<
 *                 not(other.parseAction) and
 *                 other.resultsName is None and
 */
    }

    /* "cPyparsing.pyx":3349
 *         # but only if there are no parse actions or resultsNames on the nested And's
 *         # (likewise for Or's and MatchFirst's)
 *         if (len(self.exprs) == 2):             # <<<<<<<<<<<<<<
 *             other = self.exprs[0]
 *             if (isinstance(other, self.__class__) and
 */
  }

  /* "cPyparsing.pyx":3370
 *                 self.mayIndexError |= other.mayIndexError
 * 
 *         self.errmsg = "Expected " + _ustr(self)             # <<<<<<<<<<<<<<
 * 
 *         return self
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3370, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3370, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3370, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3370, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_self);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3370, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Add(__pyx_kp_u_Expected, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_3) < 0) __PYX_ERR(0, 3370, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3372
 *         self.errmsg = "Expected " + _ustr(self)
 * 
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def setResultsName(self, name, listAllMatches=False):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3340
 *         return self.strRepr
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(ParseExpression, self).streamline()
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.ParseExpression.streamline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3374
 *         return self
 * 
 *     def setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         ret = super(ParseExpression, self).setResultsName(name, listAllMatches)
 *         return ret
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_15setResultsName(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15ParseExpression_15setResultsName = {"setResultsName", (PyCFunction)__pyx_pw_10cPyparsing_15ParseExpression_15setResultsName, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_15setResultsName(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_listAllMatches = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setResultsName (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_name,&__pyx_n_s_listAllMatches,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_False));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("setResultsName", 0, 2, 3, 1); __PYX_ERR(0, 3374, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_listAllMatches);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "setResultsName") < 0)) __PYX_ERR(0, 3374, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_name = values[1];
    __pyx_v_listAllMatches = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("setResultsName", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3374, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseExpression.setResultsName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15ParseExpression_14setResultsName(__pyx_self, __pyx_v_self, __pyx_v_name, __pyx_v_listAllMatches);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_14setResultsName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_listAllMatches) {
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("setResultsName", 0);

  /* "cPyparsing.pyx":3375
 * 
 *     def setResultsName(self, name, listAllMatches=False):
 *         ret = super(ParseExpression, self).setResultsName(name, listAllMatches)             # <<<<<<<<<<<<<<
 *         return ret
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseExpression); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setResultsName); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_name, __pyx_v_listAllMatches};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3375, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_name, __pyx_v_listAllMatches};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3375, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3375, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_2) {
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2); __pyx_t_2 = NULL;
    }
    __Pyx_INCREF(__pyx_v_name);
    __Pyx_GIVEREF(__pyx_v_name);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_name);
    __Pyx_INCREF(__pyx_v_listAllMatches);
    __Pyx_GIVEREF(__pyx_v_listAllMatches);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_listAllMatches);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3375, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_ret = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3376
 *     def setResultsName(self, name, listAllMatches=False):
 *         ret = super(ParseExpression, self).setResultsName(name, listAllMatches)
 *         return ret             # <<<<<<<<<<<<<<
 * 
 *     def validate(self, validateTrace=[]):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ret);
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3374
 *         return self
 * 
 *     def setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         ret = super(ParseExpression, self).setResultsName(name, listAllMatches)
 *         return ret
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ParseExpression.setResultsName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3378
 *         return ret
 * 
 *     def validate(self, validateTrace=[]):             # <<<<<<<<<<<<<<
 *         tmp = validateTrace[:] + [self]
 *         for e in self.exprs:
 */

static PyObject *__pyx_pf_10cPyparsing_99__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults8, __pyx_self)->__pyx_arg_validateTrace);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults8, __pyx_self)->__pyx_arg_validateTrace);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults8, __pyx_self)->__pyx_arg_validateTrace);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_17validate(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15ParseExpression_17validate = {"validate", (PyCFunction)__pyx_pw_10cPyparsing_15ParseExpression_17validate, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_17validate(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_validateTrace = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("validate (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_validateTrace,0};
    PyObject* values[2] = {0,0};
    __pyx_defaults8 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults8, __pyx_self);
    values[1] = __pyx_dynamic_args->__pyx_arg_validateTrace;
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_validateTrace);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "validate") < 0)) __PYX_ERR(0, 3378, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_validateTrace = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("validate", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3378, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseExpression.validate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15ParseExpression_16validate(__pyx_self, __pyx_v_self, __pyx_v_validateTrace);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_16validate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_validateTrace) {
  PyObject *__pyx_v_tmp = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("validate", 0);

  /* "cPyparsing.pyx":3379
 * 
 *     def validate(self, validateTrace=[]):
 *         tmp = validateTrace[:] + [self]             # <<<<<<<<<<<<<<
 *         for e in self.exprs:
 *             e.validate(tmp)
 */
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_validateTrace, 0, 0, NULL, NULL, &__pyx_slice__107, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_self);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_tmp = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3380
 *     def validate(self, validateTrace=[]):
 *         tmp = validateTrace[:] + [self]
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.validate(tmp)
 *         self.checkRecursion([])
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
    __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3380, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3380, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 3380, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3380, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 3380, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3380, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3380, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3381
 *         tmp = validateTrace[:] + [self]
 *         for e in self.exprs:
 *             e.validate(tmp)             # <<<<<<<<<<<<<<
 *         self.checkRecursion([])
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_validate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3381, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_tmp); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3381, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_tmp};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3381, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_tmp};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3381, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3381, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_v_tmp);
        __Pyx_GIVEREF(__pyx_v_tmp);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_tmp);
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3381, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3380
 *     def validate(self, validateTrace=[]):
 *         tmp = validateTrace[:] + [self]
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.validate(tmp)
 *         self.checkRecursion([])
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3382
 *         for e in self.exprs:
 *             e.validate(tmp)
 *         self.checkRecursion([])             # <<<<<<<<<<<<<<
 * 
 *     def copy(self):
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_checkRecursion); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_7) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3382, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_1};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3382, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_1};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3382, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3382, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_7); __pyx_t_7 = NULL;
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3382, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3378
 *         return ret
 * 
 *     def validate(self, validateTrace=[]):             # <<<<<<<<<<<<<<
 *         tmp = validateTrace[:] + [self]
 *         for e in self.exprs:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParseExpression.validate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tmp);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3384
 *         self.checkRecursion([])
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         ret = super(ParseExpression, self).copy()
 *         ret.exprs = [e.copy() for e in self.exprs]
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_19copy(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15ParseExpression_19copy = {"copy", (PyCFunction)__pyx_pw_10cPyparsing_15ParseExpression_19copy, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_15ParseExpression_19copy(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_15ParseExpression_18copy(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15ParseExpression_18copy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("copy", 0);

  /* "cPyparsing.pyx":3385
 * 
 *     def copy(self):
 *         ret = super(ParseExpression, self).copy()             # <<<<<<<<<<<<<<
 *         ret.exprs = [e.copy() for e in self.exprs]
 *         return ret
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseExpression); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3385, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3385, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3385, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_copy); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3385, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3385, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3385, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_ret = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3386
 *     def copy(self):
 *         ret = super(ParseExpression, self).copy()
 *         ret.exprs = [e.copy() for e in self.exprs]             # <<<<<<<<<<<<<<
 *         return ret
 * 
 */
  { /* enter inner scope */
    PyObject *__pyx_9genexpr23__pyx_v_e = NULL;
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3386, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3386, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
      __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
      __pyx_t_5 = NULL;
    } else {
      __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3386, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3386, __pyx_L5_error)
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    for (;;) {
      if (likely(!__pyx_t_5)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 3386, __pyx_L5_error)
          #else
          __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3386, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        } else {
          if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 3386, __pyx_L5_error)
          #else
          __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3386, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        }
      } else {
        __pyx_t_3 = __pyx_t_5(__pyx_t_2);
        if (unlikely(!__pyx_t_3)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 3386, __pyx_L5_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_XDECREF_SET(__pyx_9genexpr23__pyx_v_e, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_9genexpr23__pyx_v_e, __pyx_n_s_copy); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3386, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      if (__pyx_t_7) {
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3386, __pyx_L5_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else {
        __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3386, __pyx_L5_error)
      }
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_3))) __PYX_ERR(0, 3386, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_9genexpr23__pyx_v_e);
    goto __pyx_L8_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_9genexpr23__pyx_v_e);
    goto __pyx_L1_error;
    __pyx_L8_exit_scope:;
  } /* exit inner scope */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_ret, __pyx_n_s_exprs, __pyx_t_1) < 0) __PYX_ERR(0, 3386, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3387
 *         ret = super(ParseExpression, self).copy()
 *         ret.exprs = [e.copy() for e in self.exprs]
 *         return ret             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ret);
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3384
 *         self.checkRecursion([])
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         ret = super(ParseExpression, self).copy()
 *         ret.exprs = [e.copy() for e in self.exprs]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParseExpression.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3407
 * 
 *     class _ErrorStop(Empty):
 *         def __init__(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *             super(And._ErrorStop, self).__init__(*args, **kwargs)
 *             self.name = '-'
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_ErrorStop_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10_ErrorStop_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_10_ErrorStop_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10_ErrorStop_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  if (PyTuple_GET_SIZE(__pyx_args) > 1) {
    __pyx_v_args = PyTuple_GetSlice(__pyx_args, 1, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v_args)) {
      __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
      __Pyx_RefNannyFinishContext();
      return NULL;
    }
    __Pyx_GOTREF(__pyx_v_args);
  } else {
    __pyx_v_args = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 1) ? pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, __pyx_v_kwargs, values, used_pos_args, "__init__") < 0)) __PYX_ERR(0, 3407, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3407, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("cPyparsing._ErrorStop.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10_ErrorStop___init__(__pyx_self, __pyx_v_self, __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_ErrorStop___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":3408
 *     class _ErrorStop(Empty):
 *         def __init__(self, *args, **kwargs):
 *             super(And._ErrorStop, self).__init__(*args, **kwargs)             # <<<<<<<<<<<<<<
 *             self.name = '-'
 *             self.leaveWhitespace()
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_And); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_ErrorStop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_v_args, __pyx_v_kwargs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3409
 *         def __init__(self, *args, **kwargs):
 *             super(And._ErrorStop, self).__init__(*args, **kwargs)
 *             self.name = '-'             # <<<<<<<<<<<<<<
 *             self.leaveWhitespace()
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_name, __pyx_kp_u__108) < 0) __PYX_ERR(0, 3409, __pyx_L1_error)

  /* "cPyparsing.pyx":3410
 *             super(And._ErrorStop, self).__init__(*args, **kwargs)
 *             self.name = '-'
 *             self.leaveWhitespace()             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, exprs, savelist=True):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_leaveWhitespace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3410, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3410, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3410, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3407
 * 
 *     class _ErrorStop(Empty):
 *         def __init__(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *             super(And._ErrorStop, self).__init__(*args, **kwargs)
 *             self.name = '-'
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing._ErrorStop.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3412
 *             self.leaveWhitespace()
 * 
 *     def __init__(self, exprs, savelist=True):             # <<<<<<<<<<<<<<
 *         super(And, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_3And_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_3And_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_3And_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_3And_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_exprs = 0;
  PyObject *__pyx_v_savelist = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_exprs,&__pyx_n_s_savelist,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_exprs)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 3412, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_savelist);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 3412, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_exprs = values[1];
    __pyx_v_savelist = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3412, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.And.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_3And___init__(__pyx_self, __pyx_v_self, __pyx_v_exprs, __pyx_v_savelist);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_3And_8__init___2generator18(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":3414
 *     def __init__(self, exprs, savelist=True):
 *         super(And, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         self.setWhitespaceChars(self.exprs[0].whiteChars)
 *         self.skipWhitespace = self.exprs[0].skipWhitespace
 */

static PyObject *__pyx_pf_10cPyparsing_3And_8__init___genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_37_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_37_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3414, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_36___init__ *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_3And_8__init___2generator18, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_And___init___locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 3414, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.And.__init__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_3And_8__init___2generator18(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  int __pyx_t_5;
  int __pyx_t_6;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 3414, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 3414, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3414, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3414, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3414, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3414, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3414, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3414, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3414, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_e, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3414, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 3414, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = ((!__pyx_t_5) != 0);
    if (__pyx_t_6) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L0;
    }
  }
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3412
 *             self.leaveWhitespace()
 * 
 *     def __init__(self, exprs, savelist=True):             # <<<<<<<<<<<<<<
 *         super(And, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 */

static PyObject *__pyx_pf_10cPyparsing_3And___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exprs, PyObject *__pyx_v_savelist) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_36___init__ *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_36___init__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_36___init__(__pyx_ptype_10cPyparsing___pyx_scope_struct_36___init__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_36___init__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3412, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);

  /* "cPyparsing.pyx":3413
 * 
 *     def __init__(self, exprs, savelist=True):
 *         super(And, self).__init__(exprs, savelist)             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 *         self.setWhitespaceChars(self.exprs[0].whiteChars)
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_And); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_cur_scope->__pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_exprs, __pyx_v_savelist};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3413, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_exprs, __pyx_v_savelist};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3413, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3413, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_2) {
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2); __pyx_t_2 = NULL;
    }
    __Pyx_INCREF(__pyx_v_exprs);
    __Pyx_GIVEREF(__pyx_v_exprs);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_exprs);
    __Pyx_INCREF(__pyx_v_savelist);
    __Pyx_GIVEREF(__pyx_v_savelist);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_savelist);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3413, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3414
 *     def __init__(self, exprs, savelist=True):
 *         super(And, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         self.setWhitespaceChars(self.exprs[0].whiteChars)
 *         self.skipWhitespace = self.exprs[0].skipWhitespace
 */
  __pyx_t_1 = __pyx_pf_10cPyparsing_3And_8__init___genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_3) < 0) __PYX_ERR(0, 3414, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3415
 *         super(And, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 *         self.setWhitespaceChars(self.exprs[0].whiteChars)             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = self.exprs[0].skipWhitespace
 *         self.callPreparse = True
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_setWhitespaceChars); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_5, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_whiteChars); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3415, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3415, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3415, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_5);
      __pyx_t_5 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3416
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 *         self.setWhitespaceChars(self.exprs[0].whiteChars)
 *         self.skipWhitespace = self.exprs[0].skipWhitespace             # <<<<<<<<<<<<<<
 *         self.callPreparse = True
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_3, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_skipWhitespace); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_skipWhitespace, __pyx_t_3) < 0) __PYX_ERR(0, 3416, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3417
 *         self.setWhitespaceChars(self.exprs[0].whiteChars)
 *         self.skipWhitespace = self.exprs[0].skipWhitespace
 *         self.callPreparse = True             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_callPreparse, Py_True) < 0) __PYX_ERR(0, 3417, __pyx_L1_error)

  /* "cPyparsing.pyx":3412
 *             self.leaveWhitespace()
 * 
 *     def __init__(self, exprs, savelist=True):             # <<<<<<<<<<<<<<
 *         super(And, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.And.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3419
 *         self.callPreparse = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         # pass False as last arg to _parse for first element, since we already
 *         # pre-parsed the string as part of our And pre-parsing
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_3And_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_3And_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_3And_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_3And_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3419, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3419, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3419, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3419, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3419, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.And.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_3And_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_3And_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_resultlist = NULL;
  int __pyx_v_errorStop;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_v_exprtokens = NULL;
  PyObject *__pyx_v_pe = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  int __pyx_t_18;
  char const *__pyx_t_19;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  Py_ssize_t __pyx_t_26;
  PyObject *__pyx_t_27 = NULL;
  PyObject *__pyx_t_28 = NULL;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":3422
 *         # pass False as last arg to _parse for first element, since we already
 *         # pre-parsed the string as part of our And pre-parsing
 *         loc, resultlist = self.exprs[0]._parse(instring, loc, doActions, callPreParse=False)             # <<<<<<<<<<<<<<
 *         errorStop = False
 *         for e in self.exprs[1:]:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_parse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_instring);
  __Pyx_GIVEREF(__pyx_v_instring);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_instring);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_doActions);
  __Pyx_GIVEREF(__pyx_v_doActions);
  PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_doActions);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_callPreParse, Py_False) < 0) __PYX_ERR(0, 3422, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
    PyObject* sequence = __pyx_t_4;
    #if !CYTHON_COMPILING_IN_PYPY
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 3422, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3422, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3422, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3422, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = Py_TYPE(__pyx_t_1)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_1), 2) < 0) __PYX_ERR(0, 3422, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 3422, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3422, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_loc = __pyx_t_6;
  __pyx_v_resultlist = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3423
 *         # pre-parsed the string as part of our And pre-parsing
 *         loc, resultlist = self.exprs[0]._parse(instring, loc, doActions, callPreParse=False)
 *         errorStop = False             # <<<<<<<<<<<<<<
 *         for e in self.exprs[1:]:
 *             if isinstance(e, And._ErrorStop):
 */
  __pyx_v_errorStop = 0;

  /* "cPyparsing.pyx":3424
 *         loc, resultlist = self.exprs[0]._parse(instring, loc, doActions, callPreParse=False)
 *         errorStop = False
 *         for e in self.exprs[1:]:             # <<<<<<<<<<<<<<
 *             if isinstance(e, And._ErrorStop):
 *                 errorStop = True
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_4, 1, 0, NULL, NULL, &__pyx_slice__109, 1, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
    __pyx_t_4 = __pyx_t_3; __Pyx_INCREF(__pyx_t_4); __pyx_t_7 = 0;
    __pyx_t_8 = NULL;
  } else {
    __pyx_t_7 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3424, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3424, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  for (;;) {
    if (likely(!__pyx_t_8)) {
      if (likely(PyList_CheckExact(__pyx_t_4))) {
        if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_7); __Pyx_INCREF(__pyx_t_3); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 3424, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_4, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3424, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        if (__pyx_t_7 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_7); __Pyx_INCREF(__pyx_t_3); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 3424, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_4, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3424, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_8(__pyx_t_4);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3424, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3425
 *         errorStop = False
 *         for e in self.exprs[1:]:
 *             if isinstance(e, And._ErrorStop):             # <<<<<<<<<<<<<<
 *                 errorStop = True
 *                 continue
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_And); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3425, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ErrorStop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3425, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_9 = PyObject_IsInstance(__pyx_v_e, __pyx_t_2); if (unlikely(__pyx_t_9 == -1)) __PYX_ERR(0, 3425, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_10 = (__pyx_t_9 != 0);
    if (__pyx_t_10) {

      /* "cPyparsing.pyx":3426
 *         for e in self.exprs[1:]:
 *             if isinstance(e, And._ErrorStop):
 *                 errorStop = True             # <<<<<<<<<<<<<<
 *                 continue
 *             if errorStop:
 */
      __pyx_v_errorStop = 1;

      /* "cPyparsing.pyx":3427
 *             if isinstance(e, And._ErrorStop):
 *                 errorStop = True
 *                 continue             # <<<<<<<<<<<<<<
 *             if errorStop:
 *                 try:
 */
      goto __pyx_L5_continue;

      /* "cPyparsing.pyx":3425
 *         errorStop = False
 *         for e in self.exprs[1:]:
 *             if isinstance(e, And._ErrorStop):             # <<<<<<<<<<<<<<
 *                 errorStop = True
 *                 continue
 */
    }

    /* "cPyparsing.pyx":3428
 *                 errorStop = True
 *                 continue
 *             if errorStop:             # <<<<<<<<<<<<<<
 *                 try:
 *                     loc, exprtokens = e._parse(instring, loc, doActions)
 */
    __pyx_t_10 = (__pyx_v_errorStop != 0);
    if (__pyx_t_10) {

      /* "cPyparsing.pyx":3429
 *                 continue
 *             if errorStop:
 *                 try:             # <<<<<<<<<<<<<<
 *                     loc, exprtokens = e._parse(instring, loc, doActions)
 *                 except ParseSyntaxException:
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
        __Pyx_XGOTREF(__pyx_t_11);
        __Pyx_XGOTREF(__pyx_t_12);
        __Pyx_XGOTREF(__pyx_t_13);
        /*try:*/ {

          /* "cPyparsing.pyx":3430
 *             if errorStop:
 *                 try:
 *                     loc, exprtokens = e._parse(instring, loc, doActions)             # <<<<<<<<<<<<<<
 *                 except ParseSyntaxException:
 *                     raise
 */
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_parse); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3430, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3430, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_14 = NULL;
          __pyx_t_6 = 0;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
            __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_3);
            if (likely(__pyx_t_14)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
              __Pyx_INCREF(__pyx_t_14);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_3, function);
              __pyx_t_6 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_3)) {
            PyObject *__pyx_temp[4] = {__pyx_t_14, __pyx_v_instring, __pyx_t_1, __pyx_v_doActions};
            __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3430, __pyx_L9_error)
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
            PyObject *__pyx_temp[4] = {__pyx_t_14, __pyx_v_instring, __pyx_t_1, __pyx_v_doActions};
            __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3430, __pyx_L9_error)
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          } else
          #endif
          {
            __pyx_t_15 = PyTuple_New(3+__pyx_t_6); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3430, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_15);
            if (__pyx_t_14) {
              __Pyx_GIVEREF(__pyx_t_14); PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_14); __pyx_t_14 = NULL;
            }
            __Pyx_INCREF(__pyx_v_instring);
            __Pyx_GIVEREF(__pyx_v_instring);
            PyTuple_SET_ITEM(__pyx_t_15, 0+__pyx_t_6, __pyx_v_instring);
            __Pyx_GIVEREF(__pyx_t_1);
            PyTuple_SET_ITEM(__pyx_t_15, 1+__pyx_t_6, __pyx_t_1);
            __Pyx_INCREF(__pyx_v_doActions);
            __Pyx_GIVEREF(__pyx_v_doActions);
            PyTuple_SET_ITEM(__pyx_t_15, 2+__pyx_t_6, __pyx_v_doActions);
            __pyx_t_1 = 0;
            __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_15, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3430, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
          }
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
            PyObject* sequence = __pyx_t_2;
            #if !CYTHON_COMPILING_IN_PYPY
            Py_ssize_t size = Py_SIZE(sequence);
            #else
            Py_ssize_t size = PySequence_Size(sequence);
            #endif
            if (unlikely(size != 2)) {
              if (size > 2) __Pyx_RaiseTooManyValuesError(2);
              else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
              __PYX_ERR(0, 3430, __pyx_L9_error)
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            if (likely(PyTuple_CheckExact(sequence))) {
              __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
              __pyx_t_15 = PyTuple_GET_ITEM(sequence, 1); 
            } else {
              __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
              __pyx_t_15 = PyList_GET_ITEM(sequence, 1); 
            }
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_15);
            #else
            __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3430, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_t_15 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3430, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_15);
            #endif
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          } else {
            Py_ssize_t index = -1;
            __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3430, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __pyx_t_5 = Py_TYPE(__pyx_t_1)->tp_iternext;
            index = 0; __pyx_t_3 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_3)) goto __pyx_L17_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_3);
            index = 1; __pyx_t_15 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_15)) goto __pyx_L17_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_15);
            if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_1), 2) < 0) __PYX_ERR(0, 3430, __pyx_L9_error)
            __pyx_t_5 = NULL;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            goto __pyx_L18_unpacking_done;
            __pyx_L17_unpacking_failed:;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_5 = NULL;
            if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
            __PYX_ERR(0, 3430, __pyx_L9_error)
            __pyx_L18_unpacking_done:;
          }
          __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_t_3); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3430, __pyx_L9_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_v_loc = __pyx_t_6;
          __Pyx_XDECREF_SET(__pyx_v_exprtokens, __pyx_t_15);
          __pyx_t_15 = 0;

          /* "cPyparsing.pyx":3429
 *                 continue
 *             if errorStop:
 *                 try:             # <<<<<<<<<<<<<<
 *                     loc, exprtokens = e._parse(instring, loc, doActions)
 *                 except ParseSyntaxException:
 */
        }
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        goto __pyx_L16_try_end;
        __pyx_L9_error:;
        __Pyx_PyThreadState_assign
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "cPyparsing.pyx":3431
 *                 try:
 *                     loc, exprtokens = e._parse(instring, loc, doActions)
 *                 except ParseSyntaxException:             # <<<<<<<<<<<<<<
 *                     raise
 *                 except ParseBaseException as pe:
 */
        __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseSyntaxException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3431, __pyx_L11_except_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (__pyx_t_6) {
          __Pyx_AddTraceback("cPyparsing.And.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_15, &__pyx_t_3) < 0) __PYX_ERR(0, 3431, __pyx_L11_except_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_GOTREF(__pyx_t_15);
          __Pyx_GOTREF(__pyx_t_3);

          /* "cPyparsing.pyx":3432
 *                     loc, exprtokens = e._parse(instring, loc, doActions)
 *                 except ParseSyntaxException:
 *                     raise             # <<<<<<<<<<<<<<
 *                 except ParseBaseException as pe:
 *                     pe.__traceback__ = None
 */
          __Pyx_GIVEREF(__pyx_t_2);
          __Pyx_GIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_3);
          __Pyx_ErrRestoreWithState(__pyx_t_2, __pyx_t_15, __pyx_t_3);
          __pyx_t_2 = 0; __pyx_t_15 = 0; __pyx_t_3 = 0; 
          __PYX_ERR(0, 3432, __pyx_L11_except_error)
        }

        /* "cPyparsing.pyx":3433
 *                 except ParseSyntaxException:
 *                     raise
 *                 except ParseBaseException as pe:             # <<<<<<<<<<<<<<
 *                     pe.__traceback__ = None
 *                     raise ParseSyntaxException._from_exception(pe)
 */
        __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3433, __pyx_L11_except_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (__pyx_t_6) {
          __Pyx_AddTraceback("cPyparsing.And.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_15, &__pyx_t_2) < 0) __PYX_ERR(0, 3433, __pyx_L11_except_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_GOTREF(__pyx_t_15);
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_15);
          __pyx_v_pe = __pyx_t_15;
          /*try:*/ {

            /* "cPyparsing.pyx":3434
 *                     raise
 *                 except ParseBaseException as pe:
 *                     pe.__traceback__ = None             # <<<<<<<<<<<<<<
 *                     raise ParseSyntaxException._from_exception(pe)
 *                 except IndexError:
 */
            if (__Pyx_PyObject_SetAttrStr(__pyx_v_pe, __pyx_n_s_traceback_2, Py_None) < 0) __PYX_ERR(0, 3434, __pyx_L26_error)

            /* "cPyparsing.pyx":3435
 *                 except ParseBaseException as pe:
 *                     pe.__traceback__ = None
 *                     raise ParseSyntaxException._from_exception(pe)             # <<<<<<<<<<<<<<
 *                 except IndexError:
 *                     raise ParseSyntaxException(instring, len(instring), self.errmsg, self)
 */
            __pyx_t_14 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseSyntaxException); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3435, __pyx_L26_error)
            __Pyx_GOTREF(__pyx_t_14);
            __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_from_exception); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3435, __pyx_L26_error)
            __Pyx_GOTREF(__pyx_t_16);
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            __pyx_t_14 = NULL;
            if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_16))) {
              __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_16);
              if (likely(__pyx_t_14)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
                __Pyx_INCREF(__pyx_t_14);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_16, function);
              }
            }
            if (!__pyx_t_14) {
              __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_v_pe); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3435, __pyx_L26_error)
              __Pyx_GOTREF(__pyx_t_1);
            } else {
              #if CYTHON_FAST_PYCALL
              if (PyFunction_Check(__pyx_t_16)) {
                PyObject *__pyx_temp[2] = {__pyx_t_14, __pyx_v_pe};
                __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_16, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3435, __pyx_L26_error)
                __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
                __Pyx_GOTREF(__pyx_t_1);
              } else
              #endif
              #if CYTHON_FAST_PYCCALL
              if (__Pyx_PyFastCFunction_Check(__pyx_t_16)) {
                PyObject *__pyx_temp[2] = {__pyx_t_14, __pyx_v_pe};
                __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_16, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3435, __pyx_L26_error)
                __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
                __Pyx_GOTREF(__pyx_t_1);
              } else
              #endif
              {
                __pyx_t_17 = PyTuple_New(1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 3435, __pyx_L26_error)
                __Pyx_GOTREF(__pyx_t_17);
                __Pyx_GIVEREF(__pyx_t_14); PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_t_14); __pyx_t_14 = NULL;
                __Pyx_INCREF(__pyx_v_pe);
                __Pyx_GIVEREF(__pyx_v_pe);
                PyTuple_SET_ITEM(__pyx_t_17, 0+1, __pyx_v_pe);
                __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_16, __pyx_t_17, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3435, __pyx_L26_error)
                __Pyx_GOTREF(__pyx_t_1);
                __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
              }
            }
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            __Pyx_Raise(__pyx_t_1, 0, 0, 0);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __PYX_ERR(0, 3435, __pyx_L26_error)
          }

          /* "cPyparsing.pyx":3433
 *                 except ParseSyntaxException:
 *                     raise
 *                 except ParseBaseException as pe:             # <<<<<<<<<<<<<<
 *                     pe.__traceback__ = None
 *                     raise ParseSyntaxException._from_exception(pe)
 */
          /*finally:*/ {
            /*exception exit:*/{
              __Pyx_PyThreadState_declare
              __pyx_L26_error:;
              __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0;
              __Pyx_PyThreadState_assign
              __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
              __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_23, &__pyx_t_24, &__pyx_t_25);
              if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22) < 0)) __Pyx_ErrFetch(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22);
              __Pyx_XGOTREF(__pyx_t_20);
              __Pyx_XGOTREF(__pyx_t_21);
              __Pyx_XGOTREF(__pyx_t_22);
              __Pyx_XGOTREF(__pyx_t_23);
              __Pyx_XGOTREF(__pyx_t_24);
              __Pyx_XGOTREF(__pyx_t_25);
              __pyx_t_6 = __pyx_lineno; __pyx_t_18 = __pyx_clineno; __pyx_t_19 = __pyx_filename;
              {
                __Pyx_DECREF(__pyx_v_pe);
                __pyx_v_pe = NULL;
              }
              __Pyx_PyThreadState_assign
              if (PY_MAJOR_VERSION >= 3) {
                __Pyx_XGIVEREF(__pyx_t_23);
                __Pyx_XGIVEREF(__pyx_t_24);
                __Pyx_XGIVEREF(__pyx_t_25);
                __Pyx_ExceptionReset(__pyx_t_23, __pyx_t_24, __pyx_t_25);
              }
              __Pyx_XGIVEREF(__pyx_t_20);
              __Pyx_XGIVEREF(__pyx_t_21);
              __Pyx_XGIVEREF(__pyx_t_22);
              __Pyx_ErrRestore(__pyx_t_20, __pyx_t_21, __pyx_t_22);
              __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0;
              __pyx_lineno = __pyx_t_6; __pyx_clineno = __pyx_t_18; __pyx_filename = __pyx_t_19;
              goto __pyx_L11_except_error;
            }
          }
        }

        /* "cPyparsing.pyx":3436
 *                     pe.__traceback__ = None
 *                     raise ParseSyntaxException._from_exception(pe)
 *                 except IndexError:             # <<<<<<<<<<<<<<
 *                     raise ParseSyntaxException(instring, len(instring), self.errmsg, self)
 *             else:
 */
        __pyx_t_18 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
        if (__pyx_t_18) {
          __Pyx_AddTraceback("cPyparsing.And.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_15, &__pyx_t_3) < 0) __PYX_ERR(0, 3436, __pyx_L11_except_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_GOTREF(__pyx_t_15);
          __Pyx_GOTREF(__pyx_t_3);

          /* "cPyparsing.pyx":3437
 *                     raise ParseSyntaxException._from_exception(pe)
 *                 except IndexError:
 *                     raise ParseSyntaxException(instring, len(instring), self.errmsg, self)             # <<<<<<<<<<<<<<
 *             else:
 *                 loc, exprtokens = e._parse(instring, loc, doActions)
 */
          __pyx_t_16 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseSyntaxException); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3437, __pyx_L11_except_error)
          __Pyx_GOTREF(__pyx_t_16);
          __pyx_t_26 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_26 == -1)) __PYX_ERR(0, 3437, __pyx_L11_except_error)
          __pyx_t_17 = PyInt_FromSsize_t(__pyx_t_26); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 3437, __pyx_L11_except_error)
          __Pyx_GOTREF(__pyx_t_17);
          __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 3437, __pyx_L11_except_error)
          __Pyx_GOTREF(__pyx_t_14);
          __pyx_t_27 = NULL;
          __pyx_t_18 = 0;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_16))) {
            __pyx_t_27 = PyMethod_GET_SELF(__pyx_t_16);
            if (likely(__pyx_t_27)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
              __Pyx_INCREF(__pyx_t_27);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_16, function);
              __pyx_t_18 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_16)) {
            PyObject *__pyx_temp[5] = {__pyx_t_27, __pyx_v_instring, __pyx_t_17, __pyx_t_14, __pyx_v_self};
            __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_16, __pyx_temp+1-__pyx_t_18, 4+__pyx_t_18); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3437, __pyx_L11_except_error)
            __Pyx_XDECREF(__pyx_t_27); __pyx_t_27 = 0;
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_16)) {
            PyObject *__pyx_temp[5] = {__pyx_t_27, __pyx_v_instring, __pyx_t_17, __pyx_t_14, __pyx_v_self};
            __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_16, __pyx_temp+1-__pyx_t_18, 4+__pyx_t_18); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3437, __pyx_L11_except_error)
            __Pyx_XDECREF(__pyx_t_27); __pyx_t_27 = 0;
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          } else
          #endif
          {
            __pyx_t_28 = PyTuple_New(4+__pyx_t_18); if (unlikely(!__pyx_t_28)) __PYX_ERR(0, 3437, __pyx_L11_except_error)
            __Pyx_GOTREF(__pyx_t_28);
            if (__pyx_t_27) {
              __Pyx_GIVEREF(__pyx_t_27); PyTuple_SET_ITEM(__pyx_t_28, 0, __pyx_t_27); __pyx_t_27 = NULL;
            }
            __Pyx_INCREF(__pyx_v_instring);
            __Pyx_GIVEREF(__pyx_v_instring);
            PyTuple_SET_ITEM(__pyx_t_28, 0+__pyx_t_18, __pyx_v_instring);
            __Pyx_GIVEREF(__pyx_t_17);
            PyTuple_SET_ITEM(__pyx_t_28, 1+__pyx_t_18, __pyx_t_17);
            __Pyx_GIVEREF(__pyx_t_14);
            PyTuple_SET_ITEM(__pyx_t_28, 2+__pyx_t_18, __pyx_t_14);
            __Pyx_INCREF(__pyx_v_self);
            __Pyx_GIVEREF(__pyx_v_self);
            PyTuple_SET_ITEM(__pyx_t_28, 3+__pyx_t_18, __pyx_v_self);
            __pyx_t_17 = 0;
            __pyx_t_14 = 0;
            __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_16, __pyx_t_28, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3437, __pyx_L11_except_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_28); __pyx_t_28 = 0;
          }
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __Pyx_Raise(__pyx_t_1, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __PYX_ERR(0, 3437, __pyx_L11_except_error)
        }
        goto __pyx_L11_except_error;
        __pyx_L11_except_error:;

        /* "cPyparsing.pyx":3429
 *                 continue
 *             if errorStop:
 *                 try:             # <<<<<<<<<<<<<<
 *                     loc, exprtokens = e._parse(instring, loc, doActions)
 *                 except ParseSyntaxException:
 */
        __Pyx_PyThreadState_assign
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
        goto __pyx_L1_error;
        __pyx_L16_try_end:;
      }

      /* "cPyparsing.pyx":3428
 *                 errorStop = True
 *                 continue
 *             if errorStop:             # <<<<<<<<<<<<<<
 *                 try:
 *                     loc, exprtokens = e._parse(instring, loc, doActions)
 */
      goto __pyx_L8;
    }

    /* "cPyparsing.pyx":3439
 *                     raise ParseSyntaxException(instring, len(instring), self.errmsg, self)
 *             else:
 *                 loc, exprtokens = e._parse(instring, loc, doActions)             # <<<<<<<<<<<<<<
 *             if exprtokens or exprtokens.haskeys():
 *                 resultlist += exprtokens
 */
    /*else*/ {
      __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_parse); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3439, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3439, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = NULL;
      __pyx_t_18 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_15);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_15, function);
          __pyx_t_18 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_15)) {
        PyObject *__pyx_temp[4] = {__pyx_t_1, __pyx_v_instring, __pyx_t_2, __pyx_v_doActions};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_15, __pyx_temp+1-__pyx_t_18, 3+__pyx_t_18); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3439, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_15)) {
        PyObject *__pyx_temp[4] = {__pyx_t_1, __pyx_v_instring, __pyx_t_2, __pyx_v_doActions};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_15, __pyx_temp+1-__pyx_t_18, 3+__pyx_t_18); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3439, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else
      #endif
      {
        __pyx_t_16 = PyTuple_New(3+__pyx_t_18); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3439, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        if (__pyx_t_1) {
          __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_t_1); __pyx_t_1 = NULL;
        }
        __Pyx_INCREF(__pyx_v_instring);
        __Pyx_GIVEREF(__pyx_v_instring);
        PyTuple_SET_ITEM(__pyx_t_16, 0+__pyx_t_18, __pyx_v_instring);
        __Pyx_GIVEREF(__pyx_t_2);
        PyTuple_SET_ITEM(__pyx_t_16, 1+__pyx_t_18, __pyx_t_2);
        __Pyx_INCREF(__pyx_v_doActions);
        __Pyx_GIVEREF(__pyx_v_doActions);
        PyTuple_SET_ITEM(__pyx_t_16, 2+__pyx_t_18, __pyx_v_doActions);
        __pyx_t_2 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_15, __pyx_t_16, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3439, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      }
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
        PyObject* sequence = __pyx_t_3;
        #if !CYTHON_COMPILING_IN_PYPY
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 3439, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_15 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_16 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_15 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_16 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_15);
        __Pyx_INCREF(__pyx_t_16);
        #else
        __pyx_t_15 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3439, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __pyx_t_16 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3439, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        #endif
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3439, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext;
        index = 0; __pyx_t_15 = __pyx_t_5(__pyx_t_2); if (unlikely(!__pyx_t_15)) goto __pyx_L34_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_15);
        index = 1; __pyx_t_16 = __pyx_t_5(__pyx_t_2); if (unlikely(!__pyx_t_16)) goto __pyx_L34_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_16);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_2), 2) < 0) __PYX_ERR(0, 3439, __pyx_L1_error)
        __pyx_t_5 = NULL;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        goto __pyx_L35_unpacking_done;
        __pyx_L34_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_5 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 3439, __pyx_L1_error)
        __pyx_L35_unpacking_done:;
      }
      __pyx_t_18 = __Pyx_PyInt_As_int(__pyx_t_15); if (unlikely((__pyx_t_18 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3439, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_v_loc = __pyx_t_18;
      __Pyx_XDECREF_SET(__pyx_v_exprtokens, __pyx_t_16);
      __pyx_t_16 = 0;
    }
    __pyx_L8:;

    /* "cPyparsing.pyx":3440
 *             else:
 *                 loc, exprtokens = e._parse(instring, loc, doActions)
 *             if exprtokens or exprtokens.haskeys():             # <<<<<<<<<<<<<<
 *                 resultlist += exprtokens
 *         return loc, resultlist
 */
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_v_exprtokens); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 3440, __pyx_L1_error)
    if (!__pyx_t_9) {
    } else {
      __pyx_t_10 = __pyx_t_9;
      goto __pyx_L37_bool_binop_done;
    }
    __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_v_exprtokens, __pyx_n_s_haskeys); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 3440, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __pyx_t_15 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_16))) {
      __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_16);
      if (likely(__pyx_t_15)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
        __Pyx_INCREF(__pyx_t_15);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_16, function);
      }
    }
    if (__pyx_t_15) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_t_15); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3440, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    } else {
      __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_16); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3440, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 3440, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_10 = __pyx_t_9;
    __pyx_L37_bool_binop_done:;
    if (__pyx_t_10) {

      /* "cPyparsing.pyx":3441
 *                 loc, exprtokens = e._parse(instring, loc, doActions)
 *             if exprtokens or exprtokens.haskeys():
 *                 resultlist += exprtokens             # <<<<<<<<<<<<<<
 *         return loc, resultlist
 * 
 */
      __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_v_resultlist, __pyx_v_exprtokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3441, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF_SET(__pyx_v_resultlist, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "cPyparsing.pyx":3440
 *             else:
 *                 loc, exprtokens = e._parse(instring, loc, doActions)
 *             if exprtokens or exprtokens.haskeys():             # <<<<<<<<<<<<<<
 *                 resultlist += exprtokens
 *         return loc, resultlist
 */
    }

    /* "cPyparsing.pyx":3424
 *         loc, resultlist = self.exprs[0]._parse(instring, loc, doActions, callPreParse=False)
 *         errorStop = False
 *         for e in self.exprs[1:]:             # <<<<<<<<<<<<<<
 *             if isinstance(e, And._ErrorStop):
 *                 errorStop = True
 */
    __pyx_L5_continue:;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":3442
 *             if exprtokens or exprtokens.haskeys():
 *                 resultlist += exprtokens
 *         return loc, resultlist             # <<<<<<<<<<<<<<
 * 
 *     def __iadd__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4);
  __Pyx_INCREF(__pyx_v_resultlist);
  __Pyx_GIVEREF(__pyx_v_resultlist);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_resultlist);
  __pyx_t_4 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3419
 *         self.callPreparse = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         # pass False as last arg to _parse for first element, since we already
 *         # pre-parsed the string as part of our And pre-parsing
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_27);
  __Pyx_XDECREF(__pyx_t_28);
  __Pyx_AddTraceback("cPyparsing.And.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_resultlist);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_exprtokens);
  __Pyx_XDECREF(__pyx_v_pe);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3444
 *         return loc, resultlist
 * 
 *     def __iadd__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_3And_5__iadd__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_3And_5__iadd__ = {"__iadd__", (PyCFunction)__pyx_pw_10cPyparsing_3And_5__iadd__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_3And_5__iadd__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iadd__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__iadd__", 1, 2, 2, 1); __PYX_ERR(0, 3444, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__iadd__") < 0)) __PYX_ERR(0, 3444, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__iadd__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3444, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.And.__iadd__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_3And_4__iadd__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_3And_4__iadd__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("__iadd__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":3445
 * 
 *     def __iadd__(self, other):
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         return self.append(other)  # And( [ self, other ] )
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 3445, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":3446
 *     def __iadd__(self, other):
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         return self.append(other)  # And( [ self, other ] )
 * 
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3446, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3446, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3446, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3446, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3446, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3446, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_other);
        __Pyx_GIVEREF(__pyx_v_other);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_other);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3446, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3445
 * 
 *     def __iadd__(self, other):
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         return self.append(other)  # And( [ self, other ] )
 */
  }

  /* "cPyparsing.pyx":3447
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 *         return self.append(other)  # And( [ self, other ] )             # <<<<<<<<<<<<<<
 * 
 *     def checkRecursion(self, parseElementList):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_append); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (!__pyx_t_6) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3447, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3447, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3447, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3447, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6); __pyx_t_6 = NULL;
      __Pyx_INCREF(__pyx_v_other);
      __Pyx_GIVEREF(__pyx_v_other);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_other);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3447, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3444
 *         return loc, resultlist
 * 
 *     def __iadd__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.And.__iadd__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3449
 *         return self.append(other)  # And( [ self, other ] )
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_3And_7checkRecursion(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_3And_7checkRecursion = {"checkRecursion", (PyCFunction)__pyx_pw_10cPyparsing_3And_7checkRecursion, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_3And_7checkRecursion(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_parseElementList = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("checkRecursion (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_parseElementList,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_parseElementList)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("checkRecursion", 1, 2, 2, 1); __PYX_ERR(0, 3449, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "checkRecursion") < 0)) __PYX_ERR(0, 3449, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_parseElementList = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("checkRecursion", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3449, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.And.checkRecursion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_3And_6checkRecursion(__pyx_self, __pyx_v_self, __pyx_v_parseElementList);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_3And_6checkRecursion(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parseElementList) {
  PyObject *__pyx_v_subRecCheckList = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("checkRecursion", 0);

  /* "cPyparsing.pyx":3450
 * 
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]             # <<<<<<<<<<<<<<
 *         for e in self.exprs:
 *             e.checkRecursion(subRecCheckList)
 */
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_parseElementList, 0, 0, NULL, NULL, &__pyx_slice__110, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_self);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_subRecCheckList = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3451
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.checkRecursion(subRecCheckList)
 *             if not e.mayReturnEmpty:
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
    __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3451, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3451, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 3451, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3451, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 3451, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3451, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3451, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3452
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 *             e.checkRecursion(subRecCheckList)             # <<<<<<<<<<<<<<
 *             if not e.mayReturnEmpty:
 *                 break
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_checkRecursion); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3452, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_subRecCheckList); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3452, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_subRecCheckList};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3452, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_subRecCheckList};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3452, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3452, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_v_subRecCheckList);
        __Pyx_GIVEREF(__pyx_v_subRecCheckList);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_subRecCheckList);
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3452, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3453
 *         for e in self.exprs:
 *             e.checkRecursion(subRecCheckList)
 *             if not e.mayReturnEmpty:             # <<<<<<<<<<<<<<
 *                 break
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3453, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 3453, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_9 = ((!__pyx_t_8) != 0);
    if (__pyx_t_9) {

      /* "cPyparsing.pyx":3454
 *             e.checkRecursion(subRecCheckList)
 *             if not e.mayReturnEmpty:
 *                 break             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
      goto __pyx_L4_break;

      /* "cPyparsing.pyx":3453
 *         for e in self.exprs:
 *             e.checkRecursion(subRecCheckList)
 *             if not e.mayReturnEmpty:             # <<<<<<<<<<<<<<
 *                 break
 * 
 */
    }

    /* "cPyparsing.pyx":3451
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.checkRecursion(subRecCheckList)
 *             if not e.mayReturnEmpty:
 */
  }
  __pyx_L4_break:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3449
 *         return self.append(other)  # And( [ self, other ] )
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.And.checkRecursion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_subRecCheckList);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3456
 *                 break
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_3And_9__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_3And_9__str__ = {"__str__", (PyCFunction)__pyx_pw_10cPyparsing_3And_9__str__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_3And_9__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_3And_8__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_3And_7__str___2generator19(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":3461
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + " ".join(_ustr(e) for e in self.exprs) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */

static PyObject *__pyx_pf_10cPyparsing_3And_7__str___genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_39_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_39_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3461, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_38___str__ *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_3And_7__str___2generator19, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_And___str___locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 3461, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.And.__str__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_3And_7__str___2generator19(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 3461, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 3461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 3461, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3461, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3461, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3461, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3461, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3461, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3461, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_cur_scope->__pyx_v_e); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3461, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_e};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3461, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_e};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3461, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3461, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_e);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_e);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_cur_scope->__pyx_v_e);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3461, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_1))) __PYX_ERR(0, 3461, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3456
 *                 break
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

static PyObject *__pyx_pf_10cPyparsing_3And_8__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_38___str__ *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("__str__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_38___str__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_38___str__(__pyx_ptype_10cPyparsing___pyx_scope_struct_38___str__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_38___str__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3456, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);

  /* "cPyparsing.pyx":3457
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_self;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = PyObject_HasAttr(__pyx_t_1, __pyx_n_u_name); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 3457, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":3458
 *     def __str__(self):
 *         if hasattr(self, "name"):
 *             return self.name             # <<<<<<<<<<<<<<
 * 
 *         if self.strRepr is None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3458, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":3457
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  }

  /* "cPyparsing.pyx":3460
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "{" + " ".join(_ustr(e) for e in self.exprs) + "}"
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = (__pyx_t_1 == Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":3461
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + " ".join(_ustr(e) for e in self.exprs) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
    __pyx_t_1 = __pyx_pf_10cPyparsing_3And_7__str___genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__84, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_kp_u__111, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_t_4, __pyx_kp_u__112); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_1) < 0) __PYX_ERR(0, 3461, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3460
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "{" + " ".join(_ustr(e) for e in self.exprs) + "}"
 * 
 */
  }

  /* "cPyparsing.pyx":3463
 *             self.strRepr = "{" + " ".join(_ustr(e) for e in self.exprs) + "}"
 * 
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3456
 *                 break
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.And.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3481
 *     """
 * 
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(Or, self).__init__(exprs, savelist)
 *         if self.exprs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_2Or_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_2Or_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_2Or_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_2Or_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_exprs = 0;
  PyObject *__pyx_v_savelist = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_exprs,&__pyx_n_s_savelist,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_False));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_exprs)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 3481, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_savelist);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 3481, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_exprs = values[1];
    __pyx_v_savelist = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3481, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Or.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_2Or___init__(__pyx_self, __pyx_v_self, __pyx_v_exprs, __pyx_v_savelist);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_2Or_8__init___2generator20(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":3484
 *         super(Or, self).__init__(exprs, savelist)
 *         if self.exprs:
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         else:
 *             self.mayReturnEmpty = True
 */

static PyObject *__pyx_pf_10cPyparsing_2Or_8__init___genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_41_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_41_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3484, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_40___init__ *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_2Or_8__init___2generator20, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_Or___init___locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 3484, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.Or.__init__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_2Or_8__init___2generator20(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  int __pyx_t_5;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 3484, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 3484, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3484, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3484, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3484, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3484, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3484, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3484, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3484, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_e, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3484, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 3484, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_5) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L0;
    }
  }
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3481
 *     """
 * 
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(Or, self).__init__(exprs, savelist)
 *         if self.exprs:
 */

static PyObject *__pyx_pf_10cPyparsing_2Or___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exprs, PyObject *__pyx_v_savelist) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_40___init__ *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  __Pyx_RefNannySetupContext("__init__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_40___init__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_40___init__(__pyx_ptype_10cPyparsing___pyx_scope_struct_40___init__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_40___init__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3481, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);

  /* "cPyparsing.pyx":3482
 * 
 *     def __init__(self, exprs, savelist=False):
 *         super(Or, self).__init__(exprs, savelist)             # <<<<<<<<<<<<<<
 *         if self.exprs:
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Or); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_cur_scope->__pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_exprs, __pyx_v_savelist};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3482, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_exprs, __pyx_v_savelist};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3482, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3482, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_2) {
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2); __pyx_t_2 = NULL;
    }
    __Pyx_INCREF(__pyx_v_exprs);
    __Pyx_GIVEREF(__pyx_v_exprs);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_exprs);
    __Pyx_INCREF(__pyx_v_savelist);
    __Pyx_GIVEREF(__pyx_v_savelist);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_savelist);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3482, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3483
 *     def __init__(self, exprs, savelist=False):
 *         super(Or, self).__init__(exprs, savelist)
 *         if self.exprs:             # <<<<<<<<<<<<<<
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 3483, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":3484
 *         super(Or, self).__init__(exprs, savelist)
 *         if self.exprs:
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         else:
 *             self.mayReturnEmpty = True
 */
    __pyx_t_1 = __pyx_pf_10cPyparsing_2Or_8__init___genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3484, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3484, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_3) < 0) __PYX_ERR(0, 3484, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3483
 *     def __init__(self, exprs, savelist=False):
 *         super(Or, self).__init__(exprs, savelist)
 *         if self.exprs:             # <<<<<<<<<<<<<<
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":3486
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)
 *         else:
 *             self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 3486, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":3481
 *     """
 * 
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(Or, self).__init__(exprs, savelist)
 *         if self.exprs:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.Or.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3488
 *             self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         maxExcLoc = -1
 *         maxException = None
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_2Or_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_2Or_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_2Or_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_2Or_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3488, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3488, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3488, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3488, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3488, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Or.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_2Or_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3509
 * 
 *         if matches:
 *             matches.sort(key=lambda x: -x[0])             # <<<<<<<<<<<<<<
 *             for _, e in matches:
 *                 try:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_2Or_9parseImpl_lambda20(PyObject *__pyx_self, PyObject *__pyx_v_x); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_2Or_9parseImpl_lambda20 = {"lambda20", (PyCFunction)__pyx_pw_10cPyparsing_2Or_9parseImpl_lambda20, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_2Or_9parseImpl_lambda20(PyObject *__pyx_self, PyObject *__pyx_v_x) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda20 (wrapper)", 0);
  __pyx_r = __pyx_lambda_funcdef_lambda20(__pyx_self, ((PyObject *)__pyx_v_x));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda20(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_x) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("lambda20", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_x, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Negative(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.Or.parseImpl.lambda20", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3488
 *             self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         maxExcLoc = -1
 *         maxException = None
 */

static PyObject *__pyx_pf_10cPyparsing_2Or_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_maxExcLoc = NULL;
  PyObject *__pyx_v_maxException = NULL;
  PyObject *__pyx_v_matches = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_v_loc2 = NULL;
  PyObject *__pyx_v_err = NULL;
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  int __pyx_t_14;
  int __pyx_t_15;
  char const *__pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  Py_ssize_t __pyx_t_23;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  PyObject *__pyx_t_27 = NULL;
  PyObject *(*__pyx_t_28)(PyObject *);
  char const *__pyx_t_29;
  int __pyx_t_30;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":3489
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         maxExcLoc = -1             # <<<<<<<<<<<<<<
 *         maxException = None
 *         matches = []
 */
  __Pyx_INCREF(__pyx_int_neg_1);
  __pyx_v_maxExcLoc = __pyx_int_neg_1;

  /* "cPyparsing.pyx":3490
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         maxExcLoc = -1
 *         maxException = None             # <<<<<<<<<<<<<<
 *         matches = []
 *         for e in self.exprs:
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_maxException = Py_None;

  /* "cPyparsing.pyx":3491
 *         maxExcLoc = -1
 *         maxException = None
 *         matches = []             # <<<<<<<<<<<<<<
 *         for e in self.exprs:
 *             try:
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_matches = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3492
 *         maxException = None
 *         matches = []
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             try:
 *                 loc2 = e.tryParse(instring, loc)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3492, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3492, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3492, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3492, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3492, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3492, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3492, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3493
 *         matches = []
 *         for e in self.exprs:
 *             try:             # <<<<<<<<<<<<<<
 *                 loc2 = e.tryParse(instring, loc)
 *             except ParseException as err:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      /*try:*/ {

        /* "cPyparsing.pyx":3494
 *         for e in self.exprs:
 *             try:
 *                 loc2 = e.tryParse(instring, loc)             # <<<<<<<<<<<<<<
 *             except ParseException as err:
 *                 err.__traceback__ = None
 */
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_tryParse); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3494, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3494, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_10 = NULL;
        __pyx_t_11 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
            __pyx_t_11 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_8)) {
          PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_v_instring, __pyx_t_9};
          __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3494, __pyx_L5_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
          PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_v_instring, __pyx_t_9};
          __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3494, __pyx_L5_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        } else
        #endif
        {
          __pyx_t_12 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 3494, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_12);
          if (__pyx_t_10) {
            __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_10); __pyx_t_10 = NULL;
          }
          __Pyx_INCREF(__pyx_v_instring);
          __Pyx_GIVEREF(__pyx_v_instring);
          PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_v_instring);
          __Pyx_GIVEREF(__pyx_t_9);
          PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_t_9);
          __pyx_t_9 = 0;
          __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_12, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3494, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF_SET(__pyx_v_loc2, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "cPyparsing.pyx":3493
 *         matches = []
 *         for e in self.exprs:
 *             try:             # <<<<<<<<<<<<<<
 *                 loc2 = e.tryParse(instring, loc)
 *             except ParseException as err:
 */
      }

      /* "cPyparsing.pyx":3506
 *             else:
 *                 # save match among all matches, to retry longest to shortest
 *                 matches.append((loc2, e))             # <<<<<<<<<<<<<<
 * 
 *         if matches:
 */
      /*else:*/ {
        __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3506, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_v_loc2);
        __Pyx_GIVEREF(__pyx_v_loc2);
        PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_loc2);
        __Pyx_INCREF(__pyx_v_e);
        __Pyx_GIVEREF(__pyx_v_e);
        PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_e);
        __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_matches, __pyx_t_1); if (unlikely(__pyx_t_13 == -1)) __PYX_ERR(0, 3506, __pyx_L7_except_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L12_try_end;
      __pyx_L5_error:;
      __Pyx_PyThreadState_assign
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":3495
 *             try:
 *                 loc2 = e.tryParse(instring, loc)
 *             except ParseException as err:             # <<<<<<<<<<<<<<
 *                 err.__traceback__ = None
 *                 if err.loc > maxExcLoc:
 */
      __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3495, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_11 = __Pyx_PyErr_ExceptionMatches(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_11) {
        __Pyx_AddTraceback("cPyparsing.Or.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_8, &__pyx_t_12) < 0) __PYX_ERR(0, 3495, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_INCREF(__pyx_t_8);
        __pyx_v_err = __pyx_t_8;
        /*try:*/ {

          /* "cPyparsing.pyx":3496
 *                 loc2 = e.tryParse(instring, loc)
 *             except ParseException as err:
 *                 err.__traceback__ = None             # <<<<<<<<<<<<<<
 *                 if err.loc > maxExcLoc:
 *                     maxException = err
 */
          if (__Pyx_PyObject_SetAttrStr(__pyx_v_err, __pyx_n_s_traceback_2, Py_None) < 0) __PYX_ERR(0, 3496, __pyx_L18_error)

          /* "cPyparsing.pyx":3497
 *             except ParseException as err:
 *                 err.__traceback__ = None
 *                 if err.loc > maxExcLoc:             # <<<<<<<<<<<<<<
 *                     maxException = err
 *                     maxExcLoc = err.loc
 */
          __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_err, __pyx_n_s_loc); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3497, __pyx_L18_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_10 = PyObject_RichCompare(__pyx_t_9, __pyx_v_maxExcLoc, Py_GT); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3497, __pyx_L18_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 3497, __pyx_L18_error)
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (__pyx_t_14) {

            /* "cPyparsing.pyx":3498
 *                 err.__traceback__ = None
 *                 if err.loc > maxExcLoc:
 *                     maxException = err             # <<<<<<<<<<<<<<
 *                     maxExcLoc = err.loc
 *             except IndexError:
 */
            __Pyx_INCREF(__pyx_v_err);
            __Pyx_DECREF_SET(__pyx_v_maxException, __pyx_v_err);

            /* "cPyparsing.pyx":3499
 *                 if err.loc > maxExcLoc:
 *                     maxException = err
 *                     maxExcLoc = err.loc             # <<<<<<<<<<<<<<
 *             except IndexError:
 *                 if len(instring) > maxExcLoc:
 */
            __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_err, __pyx_n_s_loc); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3499, __pyx_L18_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF_SET(__pyx_v_maxExcLoc, __pyx_t_10);
            __pyx_t_10 = 0;

            /* "cPyparsing.pyx":3497
 *             except ParseException as err:
 *                 err.__traceback__ = None
 *                 if err.loc > maxExcLoc:             # <<<<<<<<<<<<<<
 *                     maxException = err
 *                     maxExcLoc = err.loc
 */
          }
        }

        /* "cPyparsing.pyx":3495
 *             try:
 *                 loc2 = e.tryParse(instring, loc)
 *             except ParseException as err:             # <<<<<<<<<<<<<<
 *                 err.__traceback__ = None
 *                 if err.loc > maxExcLoc:
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_err);
            __pyx_v_err = NULL;
            goto __pyx_L19;
          }
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __pyx_L18_error:;
            __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
            __Pyx_PyThreadState_assign
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19) < 0)) __Pyx_ErrFetch(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_20);
            __Pyx_XGOTREF(__pyx_t_21);
            __Pyx_XGOTREF(__pyx_t_22);
            __pyx_t_11 = __pyx_lineno; __pyx_t_15 = __pyx_clineno; __pyx_t_16 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_err);
              __pyx_v_err = NULL;
            }
            __Pyx_PyThreadState_assign
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_20);
              __Pyx_XGIVEREF(__pyx_t_21);
              __Pyx_XGIVEREF(__pyx_t_22);
              __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_21, __pyx_t_22);
            }
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_ErrRestore(__pyx_t_17, __pyx_t_18, __pyx_t_19);
            __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
            __pyx_lineno = __pyx_t_11; __pyx_clineno = __pyx_t_15; __pyx_filename = __pyx_t_16;
            goto __pyx_L7_except_error;
          }
          __pyx_L19:;
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        goto __pyx_L6_exception_handled;
      }

      /* "cPyparsing.pyx":3500
 *                     maxException = err
 *                     maxExcLoc = err.loc
 *             except IndexError:             # <<<<<<<<<<<<<<
 *                 if len(instring) > maxExcLoc:
 *                     maxException = ParseException(instring, len(instring), e.errmsg, self)
 */
      __pyx_t_15 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
      if (__pyx_t_15) {
        __Pyx_AddTraceback("cPyparsing.Or.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_12, &__pyx_t_8, &__pyx_t_1) < 0) __PYX_ERR(0, 3500, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GOTREF(__pyx_t_1);

        /* "cPyparsing.pyx":3501
 *                     maxExcLoc = err.loc
 *             except IndexError:
 *                 if len(instring) > maxExcLoc:             # <<<<<<<<<<<<<<
 *                     maxException = ParseException(instring, len(instring), e.errmsg, self)
 *                     maxExcLoc = len(instring)
 */
        __pyx_t_23 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_23 == -1)) __PYX_ERR(0, 3501, __pyx_L7_except_error)
        __pyx_t_10 = PyInt_FromSsize_t(__pyx_t_23); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3501, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_9 = PyObject_RichCompare(__pyx_t_10, __pyx_v_maxExcLoc, Py_GT); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3501, __pyx_L7_except_error)
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 3501, __pyx_L7_except_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (__pyx_t_14) {

          /* "cPyparsing.pyx":3502
 *             except IndexError:
 *                 if len(instring) > maxExcLoc:
 *                     maxException = ParseException(instring, len(instring), e.errmsg, self)             # <<<<<<<<<<<<<<
 *                     maxExcLoc = len(instring)
 *             else:
 */
          __pyx_t_10 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3502, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_23 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_23 == -1)) __PYX_ERR(0, 3502, __pyx_L7_except_error)
          __pyx_t_24 = PyInt_FromSsize_t(__pyx_t_23); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 3502, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_24);
          __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 3502, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_25);
          __pyx_t_26 = NULL;
          __pyx_t_15 = 0;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
            __pyx_t_26 = PyMethod_GET_SELF(__pyx_t_10);
            if (likely(__pyx_t_26)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
              __Pyx_INCREF(__pyx_t_26);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_10, function);
              __pyx_t_15 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_10)) {
            PyObject *__pyx_temp[5] = {__pyx_t_26, __pyx_v_instring, __pyx_t_24, __pyx_t_25, __pyx_v_self};
            __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_15, 4+__pyx_t_15); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3502, __pyx_L7_except_error)
            __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
            __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
            PyObject *__pyx_temp[5] = {__pyx_t_26, __pyx_v_instring, __pyx_t_24, __pyx_t_25, __pyx_v_self};
            __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_15, 4+__pyx_t_15); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3502, __pyx_L7_except_error)
            __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
            __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
          } else
          #endif
          {
            __pyx_t_27 = PyTuple_New(4+__pyx_t_15); if (unlikely(!__pyx_t_27)) __PYX_ERR(0, 3502, __pyx_L7_except_error)
            __Pyx_GOTREF(__pyx_t_27);
            if (__pyx_t_26) {
              __Pyx_GIVEREF(__pyx_t_26); PyTuple_SET_ITEM(__pyx_t_27, 0, __pyx_t_26); __pyx_t_26 = NULL;
            }
            __Pyx_INCREF(__pyx_v_instring);
            __Pyx_GIVEREF(__pyx_v_instring);
            PyTuple_SET_ITEM(__pyx_t_27, 0+__pyx_t_15, __pyx_v_instring);
            __Pyx_GIVEREF(__pyx_t_24);
            PyTuple_SET_ITEM(__pyx_t_27, 1+__pyx_t_15, __pyx_t_24);
            __Pyx_GIVEREF(__pyx_t_25);
            PyTuple_SET_ITEM(__pyx_t_27, 2+__pyx_t_15, __pyx_t_25);
            __Pyx_INCREF(__pyx_v_self);
            __Pyx_GIVEREF(__pyx_v_self);
            PyTuple_SET_ITEM(__pyx_t_27, 3+__pyx_t_15, __pyx_v_self);
            __pyx_t_24 = 0;
            __pyx_t_25 = 0;
            __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_27, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3502, __pyx_L7_except_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_27); __pyx_t_27 = 0;
          }
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF_SET(__pyx_v_maxException, __pyx_t_9);
          __pyx_t_9 = 0;

          /* "cPyparsing.pyx":3503
 *                 if len(instring) > maxExcLoc:
 *                     maxException = ParseException(instring, len(instring), e.errmsg, self)
 *                     maxExcLoc = len(instring)             # <<<<<<<<<<<<<<
 *             else:
 *                 # save match among all matches, to retry longest to shortest
 */
          __pyx_t_23 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_23 == -1)) __PYX_ERR(0, 3503, __pyx_L7_except_error)
          __pyx_t_9 = PyInt_FromSsize_t(__pyx_t_23); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3503, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF_SET(__pyx_v_maxExcLoc, __pyx_t_9);
          __pyx_t_9 = 0;

          /* "cPyparsing.pyx":3501
 *                     maxExcLoc = err.loc
 *             except IndexError:
 *                 if len(instring) > maxExcLoc:             # <<<<<<<<<<<<<<
 *                     maxException = ParseException(instring, len(instring), e.errmsg, self)
 *                     maxExcLoc = len(instring)
 */
        }
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L6_exception_handled;
      }
      goto __pyx_L7_except_error;
      __pyx_L7_except_error:;

      /* "cPyparsing.pyx":3493
 *         matches = []
 *         for e in self.exprs:
 *             try:             # <<<<<<<<<<<<<<
 *                 loc2 = e.tryParse(instring, loc)
 *             except ParseException as err:
 */
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
      goto __pyx_L1_error;
      __pyx_L6_exception_handled:;
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
      __pyx_L12_try_end:;
    }

    /* "cPyparsing.pyx":3492
 *         maxException = None
 *         matches = []
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             try:
 *                 loc2 = e.tryParse(instring, loc)
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3508
 *                 matches.append((loc2, e))
 * 
 *         if matches:             # <<<<<<<<<<<<<<
 *             matches.sort(key=lambda x: -x[0])
 *             for _, e in matches:
 */
  __pyx_t_14 = (__pyx_v_matches != Py_None) && (PyList_GET_SIZE(__pyx_v_matches) != 0);
  if (__pyx_t_14) {

    /* "cPyparsing.pyx":3509
 * 
 *         if matches:
 *             matches.sort(key=lambda x: -x[0])             # <<<<<<<<<<<<<<
 *             for _, e in matches:
 *                 try:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_matches, __pyx_n_s_sort); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3509, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3509, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_2Or_9parseImpl_lambda20, 0, __pyx_n_s_Or_parseImpl_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3509, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_key, __pyx_t_8) < 0) __PYX_ERR(0, 3509, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3509, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":3510
 *         if matches:
 *             matches.sort(key=lambda x: -x[0])
 *             for _, e in matches:             # <<<<<<<<<<<<<<
 *                 try:
 *                     return e._parse(instring, loc, doActions)
 */
    __pyx_t_8 = __pyx_v_matches; __Pyx_INCREF(__pyx_t_8); __pyx_t_3 = 0;
    for (;;) {
      if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_8)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_1 = PyList_GET_ITEM(__pyx_t_8, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3510, __pyx_L1_error)
      #else
      __pyx_t_1 = PySequence_ITEM(__pyx_t_8, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3510, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      #endif
      if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
        PyObject* sequence = __pyx_t_1;
        #if !CYTHON_COMPILING_IN_PYPY
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 3510, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_12 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_12 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_12);
        #else
        __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3510, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_12 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 3510, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        #endif
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_9 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3510, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_28 = Py_TYPE(__pyx_t_9)->tp_iternext;
        index = 0; __pyx_t_2 = __pyx_t_28(__pyx_t_9); if (unlikely(!__pyx_t_2)) goto __pyx_L31_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_2);
        index = 1; __pyx_t_12 = __pyx_t_28(__pyx_t_9); if (unlikely(!__pyx_t_12)) goto __pyx_L31_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_12);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_28(__pyx_t_9), 2) < 0) __PYX_ERR(0, 3510, __pyx_L1_error)
        __pyx_t_28 = NULL;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L32_unpacking_done;
        __pyx_L31_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_28 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 3510, __pyx_L1_error)
        __pyx_L32_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v__, __pyx_t_2);
      __pyx_t_2 = 0;
      __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_12);
      __pyx_t_12 = 0;

      /* "cPyparsing.pyx":3511
 *             matches.sort(key=lambda x: -x[0])
 *             for _, e in matches:
 *                 try:             # <<<<<<<<<<<<<<
 *                     return e._parse(instring, loc, doActions)
 *                 except ParseException as err:
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_6, &__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_5);
        /*try:*/ {

          /* "cPyparsing.pyx":3512
 *             for _, e in matches:
 *                 try:
 *                     return e._parse(instring, loc, doActions)             # <<<<<<<<<<<<<<
 *                 except ParseException as err:
 *                     err.__traceback__ = None
 */
          __Pyx_XDECREF(__pyx_r);
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_parse); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 3512, __pyx_L33_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3512, __pyx_L33_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_9 = NULL;
          __pyx_t_15 = 0;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
            __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_12);
            if (likely(__pyx_t_9)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
              __Pyx_INCREF(__pyx_t_9);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_12, function);
              __pyx_t_15 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_12)) {
            PyObject *__pyx_temp[4] = {__pyx_t_9, __pyx_v_instring, __pyx_t_2, __pyx_v_doActions};
            __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_15, 3+__pyx_t_15); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3512, __pyx_L33_error)
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
            PyObject *__pyx_temp[4] = {__pyx_t_9, __pyx_v_instring, __pyx_t_2, __pyx_v_doActions};
            __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_15, 3+__pyx_t_15); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3512, __pyx_L33_error)
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          } else
          #endif
          {
            __pyx_t_10 = PyTuple_New(3+__pyx_t_15); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3512, __pyx_L33_error)
            __Pyx_GOTREF(__pyx_t_10);
            if (__pyx_t_9) {
              __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_9); __pyx_t_9 = NULL;
            }
            __Pyx_INCREF(__pyx_v_instring);
            __Pyx_GIVEREF(__pyx_v_instring);
            PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_15, __pyx_v_instring);
            __Pyx_GIVEREF(__pyx_t_2);
            PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_15, __pyx_t_2);
            __Pyx_INCREF(__pyx_v_doActions);
            __Pyx_GIVEREF(__pyx_v_doActions);
            PyTuple_SET_ITEM(__pyx_t_10, 2+__pyx_t_15, __pyx_v_doActions);
            __pyx_t_2 = 0;
            __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_10, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3512, __pyx_L33_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          }
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_r = __pyx_t_1;
          __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          goto __pyx_L37_try_return;

          /* "cPyparsing.pyx":3511
 *             matches.sort(key=lambda x: -x[0])
 *             for _, e in matches:
 *                 try:             # <<<<<<<<<<<<<<
 *                     return e._parse(instring, loc, doActions)
 *                 except ParseException as err:
 */
        }
        __pyx_L33_error:;
        __Pyx_PyThreadState_assign
        __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
        __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
        __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
        __Pyx_XDECREF(__pyx_t_27); __pyx_t_27 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "cPyparsing.pyx":3513
 *                 try:
 *                     return e._parse(instring, loc, doActions)
 *                 except ParseException as err:             # <<<<<<<<<<<<<<
 *                     err.__traceback__ = None
 *                     if err.loc > maxExcLoc:
 */
        __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3513, __pyx_L35_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_15 = __Pyx_PyErr_ExceptionMatches(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_15) {
          __Pyx_AddTraceback("cPyparsing.Or.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_12, &__pyx_t_10) < 0) __PYX_ERR(0, 3513, __pyx_L35_except_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_12);
          __pyx_v_err = __pyx_t_12;
          /*try:*/ {

            /* "cPyparsing.pyx":3514
 *                     return e._parse(instring, loc, doActions)
 *                 except ParseException as err:
 *                     err.__traceback__ = None             # <<<<<<<<<<<<<<
 *                     if err.loc > maxExcLoc:
 *                         maxException = err
 */
            if (__Pyx_PyObject_SetAttrStr(__pyx_v_err, __pyx_n_s_traceback_2, Py_None) < 0) __PYX_ERR(0, 3514, __pyx_L46_error)

            /* "cPyparsing.pyx":3515
 *                 except ParseException as err:
 *                     err.__traceback__ = None
 *                     if err.loc > maxExcLoc:             # <<<<<<<<<<<<<<
 *                         maxException = err
 *                         maxExcLoc = err.loc
 */
            __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_err, __pyx_n_s_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3515, __pyx_L46_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_9 = PyObject_RichCompare(__pyx_t_2, __pyx_v_maxExcLoc, Py_GT); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3515, __pyx_L46_error)
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 3515, __pyx_L46_error)
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            if (__pyx_t_14) {

              /* "cPyparsing.pyx":3516
 *                     err.__traceback__ = None
 *                     if err.loc > maxExcLoc:
 *                         maxException = err             # <<<<<<<<<<<<<<
 *                         maxExcLoc = err.loc
 * 
 */
              __Pyx_INCREF(__pyx_v_err);
              __Pyx_DECREF_SET(__pyx_v_maxException, __pyx_v_err);

              /* "cPyparsing.pyx":3517
 *                     if err.loc > maxExcLoc:
 *                         maxException = err
 *                         maxExcLoc = err.loc             # <<<<<<<<<<<<<<
 * 
 *         if maxException is not None:
 */
              __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_err, __pyx_n_s_loc); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3517, __pyx_L46_error)
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_DECREF_SET(__pyx_v_maxExcLoc, __pyx_t_9);
              __pyx_t_9 = 0;

              /* "cPyparsing.pyx":3515
 *                 except ParseException as err:
 *                     err.__traceback__ = None
 *                     if err.loc > maxExcLoc:             # <<<<<<<<<<<<<<
 *                         maxException = err
 *                         maxExcLoc = err.loc
 */
            }
          }

          /* "cPyparsing.pyx":3513
 *                 try:
 *                     return e._parse(instring, loc, doActions)
 *                 except ParseException as err:             # <<<<<<<<<<<<<<
 *                     err.__traceback__ = None
 *                     if err.loc > maxExcLoc:
 */
          /*finally:*/ {
            /*normal exit:*/{
              __Pyx_DECREF(__pyx_v_err);
              __pyx_v_err = NULL;
              goto __pyx_L47;
            }
            /*exception exit:*/{
              __Pyx_PyThreadState_declare
              __pyx_L46_error:;
              __pyx_t_22 = 0; __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0;
              __Pyx_PyThreadState_assign
              __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
              __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
              __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
              __Pyx_XDECREF(__pyx_t_27); __pyx_t_27 = 0;
              __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_19, &__pyx_t_18, &__pyx_t_17);
              if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_22, &__pyx_t_21, &__pyx_t_20) < 0)) __Pyx_ErrFetch(&__pyx_t_22, &__pyx_t_21, &__pyx_t_20);
              __Pyx_XGOTREF(__pyx_t_22);
              __Pyx_XGOTREF(__pyx_t_21);
              __Pyx_XGOTREF(__pyx_t_20);
              __Pyx_XGOTREF(__pyx_t_19);
              __Pyx_XGOTREF(__pyx_t_18);
              __Pyx_XGOTREF(__pyx_t_17);
              __pyx_t_15 = __pyx_lineno; __pyx_t_11 = __pyx_clineno; __pyx_t_29 = __pyx_filename;
              {
                __Pyx_DECREF(__pyx_v_err);
                __pyx_v_err = NULL;
              }
              __Pyx_PyThreadState_assign
              if (PY_MAJOR_VERSION >= 3) {
                __Pyx_XGIVEREF(__pyx_t_19);
                __Pyx_XGIVEREF(__pyx_t_18);
                __Pyx_XGIVEREF(__pyx_t_17);
                __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_18, __pyx_t_17);
              }
              __Pyx_XGIVEREF(__pyx_t_22);
              __Pyx_XGIVEREF(__pyx_t_21);
              __Pyx_XGIVEREF(__pyx_t_20);
              __Pyx_ErrRestore(__pyx_t_22, __pyx_t_21, __pyx_t_20);
              __pyx_t_22 = 0; __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0;
              __pyx_lineno = __pyx_t_15; __pyx_clineno = __pyx_t_11; __pyx_filename = __pyx_t_29;
              goto __pyx_L35_except_error;
            }
            __pyx_L47:;
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          goto __pyx_L34_exception_handled;
        }
        goto __pyx_L35_except_error;
        __pyx_L35_except_error:;

        /* "cPyparsing.pyx":3511
 *             matches.sort(key=lambda x: -x[0])
 *             for _, e in matches:
 *                 try:             # <<<<<<<<<<<<<<
 *                     return e._parse(instring, loc, doActions)
 *                 except ParseException as err:
 */
        __Pyx_PyThreadState_assign
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_6, __pyx_t_5);
        goto __pyx_L1_error;
        __pyx_L37_try_return:;
        __Pyx_PyThreadState_assign
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_6, __pyx_t_5);
        goto __pyx_L0;
        __pyx_L34_exception_handled:;
        __Pyx_PyThreadState_assign
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_6, __pyx_t_5);
      }

      /* "cPyparsing.pyx":3510
 *         if matches:
 *             matches.sort(key=lambda x: -x[0])
 *             for _, e in matches:             # <<<<<<<<<<<<<<
 *                 try:
 *                     return e._parse(instring, loc, doActions)
 */
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":3508
 *                 matches.append((loc2, e))
 * 
 *         if matches:             # <<<<<<<<<<<<<<
 *             matches.sort(key=lambda x: -x[0])
 *             for _, e in matches:
 */
  }

  /* "cPyparsing.pyx":3519
 *                         maxExcLoc = err.loc
 * 
 *         if maxException is not None:             # <<<<<<<<<<<<<<
 *             maxException.msg = self.errmsg
 *             raise maxException
 */
  __pyx_t_14 = (__pyx_v_maxException != Py_None);
  __pyx_t_30 = (__pyx_t_14 != 0);
  if (__pyx_t_30) {

    /* "cPyparsing.pyx":3520
 * 
 *         if maxException is not None:
 *             maxException.msg = self.errmsg             # <<<<<<<<<<<<<<
 *             raise maxException
 *         else:
 */
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3520, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_maxException, __pyx_n_s_msg, __pyx_t_8) < 0) __PYX_ERR(0, 3520, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":3521
 *         if maxException is not None:
 *             maxException.msg = self.errmsg
 *             raise maxException             # <<<<<<<<<<<<<<
 *         else:
 *             raise ParseException(instring, loc, "no defined alternatives to match", self)
 */
    __Pyx_Raise(__pyx_v_maxException, 0, 0, 0);
    __PYX_ERR(0, 3521, __pyx_L1_error)

    /* "cPyparsing.pyx":3519
 *                         maxExcLoc = err.loc
 * 
 *         if maxException is not None:             # <<<<<<<<<<<<<<
 *             maxException.msg = self.errmsg
 *             raise maxException
 */
  }

  /* "cPyparsing.pyx":3523
 *             raise maxException
 *         else:
 *             raise ParseException(instring, loc, "no defined alternatives to match", self)             # <<<<<<<<<<<<<<
 * 
 *     def __ixor__(self, other):
 */
  /*else*/ {
    __pyx_t_10 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3523, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_12 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 3523, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_1 = NULL;
    __pyx_t_11 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
        __pyx_t_11 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_10)) {
      PyObject *__pyx_temp[5] = {__pyx_t_1, __pyx_v_instring, __pyx_t_12, __pyx_kp_u_no_defined_alternatives_to_match, __pyx_v_self};
      __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_11, 4+__pyx_t_11); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3523, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
      PyObject *__pyx_temp[5] = {__pyx_t_1, __pyx_v_instring, __pyx_t_12, __pyx_kp_u_no_defined_alternatives_to_match, __pyx_v_self};
      __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_11, 4+__pyx_t_11); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3523, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(4+__pyx_t_11); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3523, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (__pyx_t_1) {
        __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_1); __pyx_t_1 = NULL;
      }
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_11, __pyx_v_instring);
      __Pyx_GIVEREF(__pyx_t_12);
      PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_11, __pyx_t_12);
      __Pyx_INCREF(__pyx_kp_u_no_defined_alternatives_to_match);
      __Pyx_GIVEREF(__pyx_kp_u_no_defined_alternatives_to_match);
      PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_11, __pyx_kp_u_no_defined_alternatives_to_match);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_9, 3+__pyx_t_11, __pyx_v_self);
      __pyx_t_12 = 0;
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_9, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3523, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_Raise(__pyx_t_8, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __PYX_ERR(0, 3523, __pyx_L1_error)
  }

  /* "cPyparsing.pyx":3488
 *             self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         maxExcLoc = -1
 *         maxException = None
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_24);
  __Pyx_XDECREF(__pyx_t_25);
  __Pyx_XDECREF(__pyx_t_26);
  __Pyx_XDECREF(__pyx_t_27);
  __Pyx_AddTraceback("cPyparsing.Or.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_maxExcLoc);
  __Pyx_XDECREF(__pyx_v_maxException);
  __Pyx_XDECREF(__pyx_v_matches);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_loc2);
  __Pyx_XDECREF(__pyx_v_err);
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3525
 *             raise ParseException(instring, loc, "no defined alternatives to match", self)
 * 
 *     def __ixor__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_2Or_5__ixor__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_2Or_5__ixor__ = {"__ixor__", (PyCFunction)__pyx_pw_10cPyparsing_2Or_5__ixor__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_2Or_5__ixor__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__ixor__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__ixor__", 1, 2, 2, 1); __PYX_ERR(0, 3525, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__ixor__") < 0)) __PYX_ERR(0, 3525, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__ixor__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3525, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Or.__ixor__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_2Or_4__ixor__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_2Or_4__ixor__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("__ixor__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":3526
 * 
 *     def __ixor__(self, other):
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         return self.append(other)  # Or( [ self, other ] )
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 3526, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":3527
 *     def __ixor__(self, other):
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         return self.append(other)  # Or( [ self, other ] )
 * 
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3527, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3527, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3527, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3527, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3527, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3527, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_other);
        __Pyx_GIVEREF(__pyx_v_other);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_other);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3527, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3526
 * 
 *     def __ixor__(self, other):
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         return self.append(other)  # Or( [ self, other ] )
 */
  }

  /* "cPyparsing.pyx":3528
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 *         return self.append(other)  # Or( [ self, other ] )             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_append); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (!__pyx_t_6) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3528, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3528, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3528, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3528, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6); __pyx_t_6 = NULL;
      __Pyx_INCREF(__pyx_v_other);
      __Pyx_GIVEREF(__pyx_v_other);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_other);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3528, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3525
 *             raise ParseException(instring, loc, "no defined alternatives to match", self)
 * 
 *     def __ixor__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.Or.__ixor__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3530
 *         return self.append(other)  # Or( [ self, other ] )
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_2Or_7__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_2Or_7__str__ = {"__str__", (PyCFunction)__pyx_pw_10cPyparsing_2Or_7__str__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_2Or_7__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_2Or_6__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_2Or_7__str___2generator21(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":3535
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + " ^ ".join(_ustr(e) for e in self.exprs) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */

static PyObject *__pyx_pf_10cPyparsing_2Or_7__str___genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_43_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_43_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3535, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_42___str__ *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_2Or_7__str___2generator21, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_Or___str___locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 3535, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.Or.__str__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_2Or_7__str___2generator21(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 3535, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 3535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 3535, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3535, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3535, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3535, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3535, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3535, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3535, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3535, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3535, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_cur_scope->__pyx_v_e); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3535, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_e};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3535, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_e};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3535, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3535, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_e);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_e);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_cur_scope->__pyx_v_e);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3535, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_1))) __PYX_ERR(0, 3535, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3530
 *         return self.append(other)  # Or( [ self, other ] )
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

static PyObject *__pyx_pf_10cPyparsing_2Or_6__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_42___str__ *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("__str__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_42___str__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_42___str__(__pyx_ptype_10cPyparsing___pyx_scope_struct_42___str__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_42___str__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3530, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);

  /* "cPyparsing.pyx":3531
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_self;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = PyObject_HasAttr(__pyx_t_1, __pyx_n_u_name); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 3531, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":3532
 *     def __str__(self):
 *         if hasattr(self, "name"):
 *             return self.name             # <<<<<<<<<<<<<<
 * 
 *         if self.strRepr is None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3532, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":3531
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  }

  /* "cPyparsing.pyx":3534
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "{" + " ^ ".join(_ustr(e) for e in self.exprs) + "}"
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = (__pyx_t_1 == Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":3535
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + " ^ ".join(_ustr(e) for e in self.exprs) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
    __pyx_t_1 = __pyx_pf_10cPyparsing_2Or_7__str___genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3535, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3535, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__113, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3535, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_kp_u__111, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3535, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_t_4, __pyx_kp_u__112); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3535, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_1) < 0) __PYX_ERR(0, 3535, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3534
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "{" + " ^ ".join(_ustr(e) for e in self.exprs) + "}"
 * 
 */
  }

  /* "cPyparsing.pyx":3537
 *             self.strRepr = "{" + " ^ ".join(_ustr(e) for e in self.exprs) + "}"
 * 
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 *     def checkRecursion(self, parseElementList):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3530
 *         return self.append(other)  # Or( [ self, other ] )
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.Or.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3539
 *         return self.strRepr
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_2Or_9checkRecursion(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_2Or_9checkRecursion = {"checkRecursion", (PyCFunction)__pyx_pw_10cPyparsing_2Or_9checkRecursion, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_2Or_9checkRecursion(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_parseElementList = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("checkRecursion (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_parseElementList,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_parseElementList)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("checkRecursion", 1, 2, 2, 1); __PYX_ERR(0, 3539, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "checkRecursion") < 0)) __PYX_ERR(0, 3539, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_parseElementList = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("checkRecursion", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3539, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Or.checkRecursion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_2Or_8checkRecursion(__pyx_self, __pyx_v_self, __pyx_v_parseElementList);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_2Or_8checkRecursion(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parseElementList) {
  PyObject *__pyx_v_subRecCheckList = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("checkRecursion", 0);

  /* "cPyparsing.pyx":3540
 * 
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]             # <<<<<<<<<<<<<<
 *         for e in self.exprs:
 *             e.checkRecursion(subRecCheckList)
 */
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_parseElementList, 0, 0, NULL, NULL, &__pyx_slice__114, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_self);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_subRecCheckList = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3541
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.checkRecursion(subRecCheckList)
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
    __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3541, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3541, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 3541, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3541, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 3541, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3541, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3541, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3542
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 *             e.checkRecursion(subRecCheckList)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_checkRecursion); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3542, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_subRecCheckList); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3542, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_subRecCheckList};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3542, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_subRecCheckList};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3542, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3542, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_v_subRecCheckList);
        __Pyx_GIVEREF(__pyx_v_subRecCheckList);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_subRecCheckList);
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3542, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3541
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.checkRecursion(subRecCheckList)
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3539
 *         return self.strRepr
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.Or.checkRecursion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_subRecCheckList);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3563
 *     """
 * 
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(MatchFirst, self).__init__(exprs, savelist)
 *         if self.exprs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10MatchFirst_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_10MatchFirst_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_exprs = 0;
  PyObject *__pyx_v_savelist = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_exprs,&__pyx_n_s_savelist,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_False));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_exprs)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 3563, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_savelist);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 3563, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_exprs = values[1];
    __pyx_v_savelist = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3563, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.MatchFirst.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10MatchFirst___init__(__pyx_self, __pyx_v_self, __pyx_v_exprs, __pyx_v_savelist);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_10MatchFirst_8__init___2generator22(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":3566
 *         super(MatchFirst, self).__init__(exprs, savelist)
 *         if self.exprs:
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         else:
 *             self.mayReturnEmpty = True
 */

static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_8__init___genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_45_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_45_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3566, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_44___init__ *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_10MatchFirst_8__init___2generator22, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_MatchFirst___init___locals_genex, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 3566, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.MatchFirst.__init__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_10MatchFirst_8__init___2generator22(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  int __pyx_t_5;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 3566, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 3566, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3566, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3566, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3566, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3566, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3566, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3566, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3566, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_e, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3566, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 3566, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_5) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L0;
    }
  }
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3563
 *     """
 * 
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(MatchFirst, self).__init__(exprs, savelist)
 *         if self.exprs:
 */

static PyObject *__pyx_pf_10cPyparsing_10MatchFirst___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exprs, PyObject *__pyx_v_savelist) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_44___init__ *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  __Pyx_RefNannySetupContext("__init__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_44___init__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_44___init__(__pyx_ptype_10cPyparsing___pyx_scope_struct_44___init__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_44___init__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3563, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);

  /* "cPyparsing.pyx":3564
 * 
 *     def __init__(self, exprs, savelist=False):
 *         super(MatchFirst, self).__init__(exprs, savelist)             # <<<<<<<<<<<<<<
 *         if self.exprs:
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_MatchFirst); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_cur_scope->__pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_exprs, __pyx_v_savelist};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3564, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_exprs, __pyx_v_savelist};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3564, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3564, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_2) {
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2); __pyx_t_2 = NULL;
    }
    __Pyx_INCREF(__pyx_v_exprs);
    __Pyx_GIVEREF(__pyx_v_exprs);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_exprs);
    __Pyx_INCREF(__pyx_v_savelist);
    __Pyx_GIVEREF(__pyx_v_savelist);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_savelist);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3564, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3565
 *     def __init__(self, exprs, savelist=False):
 *         super(MatchFirst, self).__init__(exprs, savelist)
 *         if self.exprs:             # <<<<<<<<<<<<<<
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 3565, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":3566
 *         super(MatchFirst, self).__init__(exprs, savelist)
 *         if self.exprs:
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         else:
 *             self.mayReturnEmpty = True
 */
    __pyx_t_1 = __pyx_pf_10cPyparsing_10MatchFirst_8__init___genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3566, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3566, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_3) < 0) __PYX_ERR(0, 3566, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3565
 *     def __init__(self, exprs, savelist=False):
 *         super(MatchFirst, self).__init__(exprs, savelist)
 *         if self.exprs:             # <<<<<<<<<<<<<<
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":3568
 *             self.mayReturnEmpty = any(e.mayReturnEmpty for e in self.exprs)
 *         else:
 *             self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 3568, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":3563
 *     """
 * 
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(MatchFirst, self).__init__(exprs, savelist)
 *         if self.exprs:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.MatchFirst.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3570
 *             self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         maxExcLoc = -1
 *         maxException = None
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10MatchFirst_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_10MatchFirst_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3570, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3570, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3570, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3570, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3570, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.MatchFirst.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10MatchFirst_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_maxExcLoc = NULL;
  PyObject *__pyx_v_maxException = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_v_err = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  int __pyx_t_14;
  char const *__pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  Py_ssize_t __pyx_t_22;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  int __pyx_t_27;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":3571
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         maxExcLoc = -1             # <<<<<<<<<<<<<<
 *         maxException = None
 *         for e in self.exprs:
 */
  __Pyx_INCREF(__pyx_int_neg_1);
  __pyx_v_maxExcLoc = __pyx_int_neg_1;

  /* "cPyparsing.pyx":3572
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         maxExcLoc = -1
 *         maxException = None             # <<<<<<<<<<<<<<
 *         for e in self.exprs:
 *             try:
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_maxException = Py_None;

  /* "cPyparsing.pyx":3573
 *         maxExcLoc = -1
 *         maxException = None
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             try:
 *                 ret = e._parse(instring, loc, doActions)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3573, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3573, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3573, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3573, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3573, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3573, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3573, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3574
 *         maxException = None
 *         for e in self.exprs:
 *             try:             # <<<<<<<<<<<<<<
 *                 ret = e._parse(instring, loc, doActions)
 *                 return ret
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      /*try:*/ {

        /* "cPyparsing.pyx":3575
 *         for e in self.exprs:
 *             try:
 *                 ret = e._parse(instring, loc, doActions)             # <<<<<<<<<<<<<<
 *                 return ret
 *             except ParseException as err:
 */
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_parse); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3575, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3575, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_10 = NULL;
        __pyx_t_11 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
            __pyx_t_11 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_8)) {
          PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_v_instring, __pyx_t_9, __pyx_v_doActions};
          __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3575, __pyx_L5_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
          PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_v_instring, __pyx_t_9, __pyx_v_doActions};
          __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3575, __pyx_L5_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        } else
        #endif
        {
          __pyx_t_12 = PyTuple_New(3+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 3575, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_12);
          if (__pyx_t_10) {
            __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_10); __pyx_t_10 = NULL;
          }
          __Pyx_INCREF(__pyx_v_instring);
          __Pyx_GIVEREF(__pyx_v_instring);
          PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_v_instring);
          __Pyx_GIVEREF(__pyx_t_9);
          PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_t_9);
          __Pyx_INCREF(__pyx_v_doActions);
          __Pyx_GIVEREF(__pyx_v_doActions);
          PyTuple_SET_ITEM(__pyx_t_12, 2+__pyx_t_11, __pyx_v_doActions);
          __pyx_t_9 = 0;
          __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_12, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3575, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF_SET(__pyx_v_ret, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "cPyparsing.pyx":3576
 *             try:
 *                 ret = e._parse(instring, loc, doActions)
 *                 return ret             # <<<<<<<<<<<<<<
 *             except ParseException as err:
 *                 if err.loc > maxExcLoc:
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_v_ret);
        __pyx_r = __pyx_v_ret;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        goto __pyx_L9_try_return;

        /* "cPyparsing.pyx":3574
 *         maxException = None
 *         for e in self.exprs:
 *             try:             # <<<<<<<<<<<<<<
 *                 ret = e._parse(instring, loc, doActions)
 *                 return ret
 */
      }
      __pyx_L5_error:;
      __Pyx_PyThreadState_assign
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":3577
 *                 ret = e._parse(instring, loc, doActions)
 *                 return ret
 *             except ParseException as err:             # <<<<<<<<<<<<<<
 *                 if err.loc > maxExcLoc:
 *                     maxException = err
 */
      __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3577, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_11 = __Pyx_PyErr_ExceptionMatches(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_11) {
        __Pyx_AddTraceback("cPyparsing.MatchFirst.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_8, &__pyx_t_12) < 0) __PYX_ERR(0, 3577, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_INCREF(__pyx_t_8);
        __pyx_v_err = __pyx_t_8;
        /*try:*/ {

          /* "cPyparsing.pyx":3578
 *                 return ret
 *             except ParseException as err:
 *                 if err.loc > maxExcLoc:             # <<<<<<<<<<<<<<
 *                     maxException = err
 *                     maxExcLoc = err.loc
 */
          __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_err, __pyx_n_s_loc); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3578, __pyx_L18_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_10 = PyObject_RichCompare(__pyx_t_9, __pyx_v_maxExcLoc, Py_GT); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3578, __pyx_L18_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 3578, __pyx_L18_error)
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (__pyx_t_13) {

            /* "cPyparsing.pyx":3579
 *             except ParseException as err:
 *                 if err.loc > maxExcLoc:
 *                     maxException = err             # <<<<<<<<<<<<<<
 *                     maxExcLoc = err.loc
 *             except IndexError:
 */
            __Pyx_INCREF(__pyx_v_err);
            __Pyx_DECREF_SET(__pyx_v_maxException, __pyx_v_err);

            /* "cPyparsing.pyx":3580
 *                 if err.loc > maxExcLoc:
 *                     maxException = err
 *                     maxExcLoc = err.loc             # <<<<<<<<<<<<<<
 *             except IndexError:
 *                 if len(instring) > maxExcLoc:
 */
            __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_err, __pyx_n_s_loc); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3580, __pyx_L18_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF_SET(__pyx_v_maxExcLoc, __pyx_t_10);
            __pyx_t_10 = 0;

            /* "cPyparsing.pyx":3578
 *                 return ret
 *             except ParseException as err:
 *                 if err.loc > maxExcLoc:             # <<<<<<<<<<<<<<
 *                     maxException = err
 *                     maxExcLoc = err.loc
 */
          }
        }

        /* "cPyparsing.pyx":3577
 *                 ret = e._parse(instring, loc, doActions)
 *                 return ret
 *             except ParseException as err:             # <<<<<<<<<<<<<<
 *                 if err.loc > maxExcLoc:
 *                     maxException = err
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_err);
            __pyx_v_err = NULL;
            goto __pyx_L19;
          }
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __pyx_L18_error:;
            __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
            __Pyx_PyThreadState_assign
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18) < 0)) __Pyx_ErrFetch(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_16);
            __Pyx_XGOTREF(__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_20);
            __Pyx_XGOTREF(__pyx_t_21);
            __pyx_t_11 = __pyx_lineno; __pyx_t_14 = __pyx_clineno; __pyx_t_15 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_err);
              __pyx_v_err = NULL;
            }
            __Pyx_PyThreadState_assign
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_19);
              __Pyx_XGIVEREF(__pyx_t_20);
              __Pyx_XGIVEREF(__pyx_t_21);
              __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
            }
            __Pyx_XGIVEREF(__pyx_t_16);
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_ErrRestore(__pyx_t_16, __pyx_t_17, __pyx_t_18);
            __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
            __pyx_lineno = __pyx_t_11; __pyx_clineno = __pyx_t_14; __pyx_filename = __pyx_t_15;
            goto __pyx_L7_except_error;
          }
          __pyx_L19:;
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        goto __pyx_L6_exception_handled;
      }

      /* "cPyparsing.pyx":3581
 *                     maxException = err
 *                     maxExcLoc = err.loc
 *             except IndexError:             # <<<<<<<<<<<<<<
 *                 if len(instring) > maxExcLoc:
 *                     maxException = ParseException(instring, len(instring), e.errmsg, self)
 */
      __pyx_t_14 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
      if (__pyx_t_14) {
        __Pyx_AddTraceback("cPyparsing.MatchFirst.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_12, &__pyx_t_8, &__pyx_t_1) < 0) __PYX_ERR(0, 3581, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GOTREF(__pyx_t_1);

        /* "cPyparsing.pyx":3582
 *                     maxExcLoc = err.loc
 *             except IndexError:
 *                 if len(instring) > maxExcLoc:             # <<<<<<<<<<<<<<
 *                     maxException = ParseException(instring, len(instring), e.errmsg, self)
 *                     maxExcLoc = len(instring)
 */
        __pyx_t_22 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_22 == -1)) __PYX_ERR(0, 3582, __pyx_L7_except_error)
        __pyx_t_10 = PyInt_FromSsize_t(__pyx_t_22); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3582, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_9 = PyObject_RichCompare(__pyx_t_10, __pyx_v_maxExcLoc, Py_GT); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3582, __pyx_L7_except_error)
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 3582, __pyx_L7_except_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (__pyx_t_13) {

          /* "cPyparsing.pyx":3583
 *             except IndexError:
 *                 if len(instring) > maxExcLoc:
 *                     maxException = ParseException(instring, len(instring), e.errmsg, self)             # <<<<<<<<<<<<<<
 *                     maxExcLoc = len(instring)
 * 
 */
          __pyx_t_10 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3583, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_22 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_22 == -1)) __PYX_ERR(0, 3583, __pyx_L7_except_error)
          __pyx_t_23 = PyInt_FromSsize_t(__pyx_t_22); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 3583, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_23);
          __pyx_t_24 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 3583, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_24);
          __pyx_t_25 = NULL;
          __pyx_t_14 = 0;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
            __pyx_t_25 = PyMethod_GET_SELF(__pyx_t_10);
            if (likely(__pyx_t_25)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
              __Pyx_INCREF(__pyx_t_25);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_10, function);
              __pyx_t_14 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_10)) {
            PyObject *__pyx_temp[5] = {__pyx_t_25, __pyx_v_instring, __pyx_t_23, __pyx_t_24, __pyx_v_self};
            __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_14, 4+__pyx_t_14); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3583, __pyx_L7_except_error)
            __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
            __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
            PyObject *__pyx_temp[5] = {__pyx_t_25, __pyx_v_instring, __pyx_t_23, __pyx_t_24, __pyx_v_self};
            __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_14, 4+__pyx_t_14); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3583, __pyx_L7_except_error)
            __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
            __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
          } else
          #endif
          {
            __pyx_t_26 = PyTuple_New(4+__pyx_t_14); if (unlikely(!__pyx_t_26)) __PYX_ERR(0, 3583, __pyx_L7_except_error)
            __Pyx_GOTREF(__pyx_t_26);
            if (__pyx_t_25) {
              __Pyx_GIVEREF(__pyx_t_25); PyTuple_SET_ITEM(__pyx_t_26, 0, __pyx_t_25); __pyx_t_25 = NULL;
            }
            __Pyx_INCREF(__pyx_v_instring);
            __Pyx_GIVEREF(__pyx_v_instring);
            PyTuple_SET_ITEM(__pyx_t_26, 0+__pyx_t_14, __pyx_v_instring);
            __Pyx_GIVEREF(__pyx_t_23);
            PyTuple_SET_ITEM(__pyx_t_26, 1+__pyx_t_14, __pyx_t_23);
            __Pyx_GIVEREF(__pyx_t_24);
            PyTuple_SET_ITEM(__pyx_t_26, 2+__pyx_t_14, __pyx_t_24);
            __Pyx_INCREF(__pyx_v_self);
            __Pyx_GIVEREF(__pyx_v_self);
            PyTuple_SET_ITEM(__pyx_t_26, 3+__pyx_t_14, __pyx_v_self);
            __pyx_t_23 = 0;
            __pyx_t_24 = 0;
            __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_26, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3583, __pyx_L7_except_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_26); __pyx_t_26 = 0;
          }
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF_SET(__pyx_v_maxException, __pyx_t_9);
          __pyx_t_9 = 0;

          /* "cPyparsing.pyx":3584
 *                 if len(instring) > maxExcLoc:
 *                     maxException = ParseException(instring, len(instring), e.errmsg, self)
 *                     maxExcLoc = len(instring)             # <<<<<<<<<<<<<<
 * 
 *         # only got here if no expression matched, raise exception for match that made it the furthest
 */
          __pyx_t_22 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_22 == -1)) __PYX_ERR(0, 3584, __pyx_L7_except_error)
          __pyx_t_9 = PyInt_FromSsize_t(__pyx_t_22); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3584, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF_SET(__pyx_v_maxExcLoc, __pyx_t_9);
          __pyx_t_9 = 0;

          /* "cPyparsing.pyx":3582
 *                     maxExcLoc = err.loc
 *             except IndexError:
 *                 if len(instring) > maxExcLoc:             # <<<<<<<<<<<<<<
 *                     maxException = ParseException(instring, len(instring), e.errmsg, self)
 *                     maxExcLoc = len(instring)
 */
        }
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L6_exception_handled;
      }
      goto __pyx_L7_except_error;
      __pyx_L7_except_error:;

      /* "cPyparsing.pyx":3574
 *         maxException = None
 *         for e in self.exprs:
 *             try:             # <<<<<<<<<<<<<<
 *                 ret = e._parse(instring, loc, doActions)
 *                 return ret
 */
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
      goto __pyx_L1_error;
      __pyx_L9_try_return:;
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
      goto __pyx_L0;
      __pyx_L6_exception_handled:;
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
    }

    /* "cPyparsing.pyx":3573
 *         maxExcLoc = -1
 *         maxException = None
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             try:
 *                 ret = e._parse(instring, loc, doActions)
 */
  }
  /*else*/ {

    /* "cPyparsing.pyx":3588
 *         # only got here if no expression matched, raise exception for match that made it the furthest
 *         else:
 *             if maxException is not None:             # <<<<<<<<<<<<<<
 *                 maxException.msg = self.errmsg
 *                 raise maxException
 */
    __pyx_t_13 = (__pyx_v_maxException != Py_None);
    __pyx_t_27 = (__pyx_t_13 != 0);
    if (__pyx_t_27) {

      /* "cPyparsing.pyx":3589
 *         else:
 *             if maxException is not None:
 *                 maxException.msg = self.errmsg             # <<<<<<<<<<<<<<
 *                 raise maxException
 *             else:
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3589, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_maxException, __pyx_n_s_msg, __pyx_t_1) < 0) __PYX_ERR(0, 3589, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":3590
 *             if maxException is not None:
 *                 maxException.msg = self.errmsg
 *                 raise maxException             # <<<<<<<<<<<<<<
 *             else:
 *                 raise ParseException(instring, loc, "no defined alternatives to match", self)
 */
      __Pyx_Raise(__pyx_v_maxException, 0, 0, 0);
      __PYX_ERR(0, 3590, __pyx_L1_error)

      /* "cPyparsing.pyx":3588
 *         # only got here if no expression matched, raise exception for match that made it the furthest
 *         else:
 *             if maxException is not None:             # <<<<<<<<<<<<<<
 *                 maxException.msg = self.errmsg
 *                 raise maxException
 */
    }

    /* "cPyparsing.pyx":3592
 *                 raise maxException
 *             else:
 *                 raise ParseException(instring, loc, "no defined alternatives to match", self)             # <<<<<<<<<<<<<<
 * 
 *     def __ior__(self, other):
 */
    /*else*/ {
      __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3592, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_12 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 3592, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_9 = NULL;
      __pyx_t_14 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_14 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[5] = {__pyx_t_9, __pyx_v_instring, __pyx_t_12, __pyx_kp_u_no_defined_alternatives_to_match, __pyx_v_self};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_14, 4+__pyx_t_14); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3592, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[5] = {__pyx_t_9, __pyx_v_instring, __pyx_t_12, __pyx_kp_u_no_defined_alternatives_to_match, __pyx_v_self};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_14, 4+__pyx_t_14); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3592, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(4+__pyx_t_14); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3592, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_v_instring);
        __Pyx_GIVEREF(__pyx_v_instring);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_14, __pyx_v_instring);
        __Pyx_GIVEREF(__pyx_t_12);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_14, __pyx_t_12);
        __Pyx_INCREF(__pyx_kp_u_no_defined_alternatives_to_match);
        __Pyx_GIVEREF(__pyx_kp_u_no_defined_alternatives_to_match);
        PyTuple_SET_ITEM(__pyx_t_10, 2+__pyx_t_14, __pyx_kp_u_no_defined_alternatives_to_match);
        __Pyx_INCREF(__pyx_v_self);
        __Pyx_GIVEREF(__pyx_v_self);
        PyTuple_SET_ITEM(__pyx_t_10, 3+__pyx_t_14, __pyx_v_self);
        __pyx_t_12 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_10, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3592, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 3592, __pyx_L1_error)
    }
  }

  /* "cPyparsing.pyx":3573
 *         maxExcLoc = -1
 *         maxException = None
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             try:
 *                 ret = e._parse(instring, loc, doActions)
 */
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3570
 *             self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         maxExcLoc = -1
 *         maxException = None
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_23);
  __Pyx_XDECREF(__pyx_t_24);
  __Pyx_XDECREF(__pyx_t_25);
  __Pyx_XDECREF(__pyx_t_26);
  __Pyx_AddTraceback("cPyparsing.MatchFirst.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_maxExcLoc);
  __Pyx_XDECREF(__pyx_v_maxException);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_err);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3594
 *                 raise ParseException(instring, loc, "no defined alternatives to match", self)
 * 
 *     def __ior__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_5__ior__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10MatchFirst_5__ior__ = {"__ior__", (PyCFunction)__pyx_pw_10cPyparsing_10MatchFirst_5__ior__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_5__ior__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__ior__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__ior__", 1, 2, 2, 1); __PYX_ERR(0, 3594, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__ior__") < 0)) __PYX_ERR(0, 3594, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__ior__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3594, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.MatchFirst.__ior__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10MatchFirst_4__ior__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_4__ior__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("__ior__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":3595
 * 
 *     def __ior__(self, other):
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         return self.append(other)  # MatchFirst( [ self, other ] )
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 3595, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":3596
 *     def __ior__(self, other):
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         return self.append(other)  # MatchFirst( [ self, other ] )
 * 
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3596, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3596, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3596, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3596, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3596, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3596, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_other);
        __Pyx_GIVEREF(__pyx_v_other);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_other);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3596, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3595
 * 
 *     def __ior__(self, other):
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         return self.append(other)  # MatchFirst( [ self, other ] )
 */
  }

  /* "cPyparsing.pyx":3597
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 *         return self.append(other)  # MatchFirst( [ self, other ] )             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_append); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (!__pyx_t_6) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3597, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3597, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3597, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3597, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6); __pyx_t_6 = NULL;
      __Pyx_INCREF(__pyx_v_other);
      __Pyx_GIVEREF(__pyx_v_other);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_other);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3597, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3594
 *                 raise ParseException(instring, loc, "no defined alternatives to match", self)
 * 
 *     def __ior__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.MatchFirst.__ior__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3599
 *         return self.append(other)  # MatchFirst( [ self, other ] )
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_7__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10MatchFirst_7__str__ = {"__str__", (PyCFunction)__pyx_pw_10cPyparsing_10MatchFirst_7__str__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_7__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_10MatchFirst_6__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_10MatchFirst_7__str___2generator23(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":3604
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + " | ".join(_ustr(e) for e in self.exprs) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */

static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_7__str___genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_47_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_47_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3604, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_46___str__ *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_10MatchFirst_7__str___2generator23, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_MatchFirst___str___locals_genexp, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 3604, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.MatchFirst.__str__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_10MatchFirst_7__str___2generator23(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 3604, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 3604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 3604, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3604, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3604, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3604, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3604, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3604, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3604, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_cur_scope->__pyx_v_e); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3604, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_e};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3604, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_e};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3604, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3604, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_e);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_e);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_cur_scope->__pyx_v_e);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3604, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_1))) __PYX_ERR(0, 3604, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3599
 *         return self.append(other)  # MatchFirst( [ self, other ] )
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_6__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_46___str__ *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("__str__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_46___str__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_46___str__(__pyx_ptype_10cPyparsing___pyx_scope_struct_46___str__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_46___str__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3599, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);

  /* "cPyparsing.pyx":3600
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_self;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = PyObject_HasAttr(__pyx_t_1, __pyx_n_u_name); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 3600, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":3601
 *     def __str__(self):
 *         if hasattr(self, "name"):
 *             return self.name             # <<<<<<<<<<<<<<
 * 
 *         if self.strRepr is None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3601, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":3600
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  }

  /* "cPyparsing.pyx":3603
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "{" + " | ".join(_ustr(e) for e in self.exprs) + "}"
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = (__pyx_t_1 == Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":3604
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + " | ".join(_ustr(e) for e in self.exprs) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
    __pyx_t_1 = __pyx_pf_10cPyparsing_10MatchFirst_7__str___genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__115, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_kp_u__111, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_t_4, __pyx_kp_u__112); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_1) < 0) __PYX_ERR(0, 3604, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3603
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "{" + " | ".join(_ustr(e) for e in self.exprs) + "}"
 * 
 */
  }

  /* "cPyparsing.pyx":3606
 *             self.strRepr = "{" + " | ".join(_ustr(e) for e in self.exprs) + "}"
 * 
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 *     def checkRecursion(self, parseElementList):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3599
 *         return self.append(other)  # MatchFirst( [ self, other ] )
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.MatchFirst.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3608
 *         return self.strRepr
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_9checkRecursion(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10MatchFirst_9checkRecursion = {"checkRecursion", (PyCFunction)__pyx_pw_10cPyparsing_10MatchFirst_9checkRecursion, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10MatchFirst_9checkRecursion(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_parseElementList = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("checkRecursion (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_parseElementList,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_parseElementList)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("checkRecursion", 1, 2, 2, 1); __PYX_ERR(0, 3608, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "checkRecursion") < 0)) __PYX_ERR(0, 3608, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_parseElementList = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("checkRecursion", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3608, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.MatchFirst.checkRecursion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10MatchFirst_8checkRecursion(__pyx_self, __pyx_v_self, __pyx_v_parseElementList);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10MatchFirst_8checkRecursion(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parseElementList) {
  PyObject *__pyx_v_subRecCheckList = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("checkRecursion", 0);

  /* "cPyparsing.pyx":3609
 * 
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]             # <<<<<<<<<<<<<<
 *         for e in self.exprs:
 *             e.checkRecursion(subRecCheckList)
 */
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_parseElementList, 0, 0, NULL, NULL, &__pyx_slice__116, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_self);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_subRecCheckList = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3610
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.checkRecursion(subRecCheckList)
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3610, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
    __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3610, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3610, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 3610, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3610, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 3610, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3610, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3610, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3611
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 *             e.checkRecursion(subRecCheckList)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_checkRecursion); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3611, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_subRecCheckList); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3611, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_subRecCheckList};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3611, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_subRecCheckList};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3611, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3611, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_v_subRecCheckList);
        __Pyx_GIVEREF(__pyx_v_subRecCheckList);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_subRecCheckList);
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3611, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3610
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.checkRecursion(subRecCheckList)
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3608
 *         return self.strRepr
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.MatchFirst.checkRecursion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_subRecCheckList);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3669
 *     """
 * 
 *     def __init__(self, exprs, savelist=True):             # <<<<<<<<<<<<<<
 *         super(Each, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_4Each_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_4Each_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_4Each_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_4Each_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_exprs = 0;
  PyObject *__pyx_v_savelist = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_exprs,&__pyx_n_s_savelist,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_exprs)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 3669, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_savelist);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 3669, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_exprs = values[1];
    __pyx_v_savelist = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3669, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Each.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_4Each___init__(__pyx_self, __pyx_v_self, __pyx_v_exprs, __pyx_v_savelist);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_4Each_8__init___2generator24(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":3671
 *     def __init__(self, exprs, savelist=True):
 *         super(Each, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = True
 *         self.initExprGroups = True
 */

static PyObject *__pyx_pf_10cPyparsing_4Each_8__init___genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_49_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_49_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3671, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_48___init__ *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_4Each_8__init___2generator24, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_Each___init___locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 3671, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.Each.__init__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_4Each_8__init___2generator24(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  int __pyx_t_5;
  int __pyx_t_6;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 3671, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 3671, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3671, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3671, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3671, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3671, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3671, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3671, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3671, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_e, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3671, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 3671, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = ((!__pyx_t_5) != 0);
    if (__pyx_t_6) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L0;
    }
  }
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3669
 *     """
 * 
 *     def __init__(self, exprs, savelist=True):             # <<<<<<<<<<<<<<
 *         super(Each, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 */

static PyObject *__pyx_pf_10cPyparsing_4Each___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exprs, PyObject *__pyx_v_savelist) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_48___init__ *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_48___init__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_48___init__(__pyx_ptype_10cPyparsing___pyx_scope_struct_48___init__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_48___init__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3669, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);

  /* "cPyparsing.pyx":3670
 * 
 *     def __init__(self, exprs, savelist=True):
 *         super(Each, self).__init__(exprs, savelist)             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 *         self.skipWhitespace = True
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Each); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_cur_scope->__pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_exprs, __pyx_v_savelist};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3670, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_exprs, __pyx_v_savelist};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3670, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3670, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_2) {
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2); __pyx_t_2 = NULL;
    }
    __Pyx_INCREF(__pyx_v_exprs);
    __Pyx_GIVEREF(__pyx_v_exprs);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_exprs);
    __Pyx_INCREF(__pyx_v_savelist);
    __Pyx_GIVEREF(__pyx_v_savelist);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_savelist);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3670, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3671
 *     def __init__(self, exprs, savelist=True):
 *         super(Each, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = True
 *         self.initExprGroups = True
 */
  __pyx_t_1 = __pyx_pf_10cPyparsing_4Each_8__init___genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_3) < 0) __PYX_ERR(0, 3671, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3672
 *         super(Each, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 *         self.skipWhitespace = True             # <<<<<<<<<<<<<<
 *         self.initExprGroups = True
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_skipWhitespace, Py_True) < 0) __PYX_ERR(0, 3672, __pyx_L1_error)

  /* "cPyparsing.pyx":3673
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 *         self.skipWhitespace = True
 *         self.initExprGroups = True             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_initExprGroups, Py_True) < 0) __PYX_ERR(0, 3673, __pyx_L1_error)

  /* "cPyparsing.pyx":3669
 *     """
 * 
 *     def __init__(self, exprs, savelist=True):             # <<<<<<<<<<<<<<
 *         super(Each, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.Each.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3675
 *         self.initExprGroups = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.initExprGroups:
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_4Each_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_4Each_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_4Each_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_4Each_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3675, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3675, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3675, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3675, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3675, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Each.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_4Each_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_4Each_9parseImpl_2generator25(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":3677
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if self.initExprGroups:
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))             # <<<<<<<<<<<<<<
 *             opt1 = [e.expr for e in self.exprs if isinstance(e, Optional)]
 *             opt2 = [e for e in self.exprs if e.mayReturnEmpty and not isinstance(e, Optional)]
 */

static PyObject *__pyx_pf_10cPyparsing_4Each_9parseImpl_genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_51_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_51_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3677, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_parseImpl *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_4Each_9parseImpl_2generator25, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_Each_parseImpl_locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 3677, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.Each.parseImpl.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_4Each_9parseImpl_2generator25(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 3677, __pyx_L1_error)
  __pyx_r = PyDict_New(); if (unlikely(!__pyx_r)) __PYX_ERR(0, 3677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 3677, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3677, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3677, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3677, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3677, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3677, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3677, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3677, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3677, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyObject_IsInstance(__pyx_cur_scope->__pyx_v_e, __pyx_t_1); if (unlikely(__pyx_t_5 == -1)) __PYX_ERR(0, 3677, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_e, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3677, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3677, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_id, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3677, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(PyDict_SetItem(__pyx_r, (PyObject*)__pyx_t_1, (PyObject*)__pyx_cur_scope->__pyx_v_e))) __PYX_ERR(0, 3677, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_4Each_9parseImpl_5generator26(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":3710
 * 
 *         if tmpReqd:
 *             missing = ", ".join(_ustr(e) for e in tmpReqd)             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, "Missing one or more required elements (%s)" % missing)
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_4Each_9parseImpl_3genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_52_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_52_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3710, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_parseImpl *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_4Each_9parseImpl_5generator26, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_Each_parseImpl_locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 3710, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.Each.parseImpl.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_4Each_9parseImpl_5generator26(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 3710, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 3710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_tmpReqd)) { __Pyx_RaiseClosureNameError("tmpReqd"); __PYX_ERR(0, 3710, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_tmpReqd)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_tmpReqd)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_outer_scope->__pyx_v_tmpReqd; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_tmpReqd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3710, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3710, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 3710, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3710, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 3710, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3710, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3710, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3710, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_cur_scope->__pyx_v_e); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3710, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_e};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3710, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_e};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3710, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3710, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_e);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_e);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_cur_scope->__pyx_v_e);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3710, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_4))) __PYX_ERR(0, 3710, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3675
 *         self.initExprGroups = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.initExprGroups:
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))
 */

static PyObject *__pyx_pf_10cPyparsing_4Each_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, PyObject *__pyx_v_doActions) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_parseImpl *__pyx_cur_scope;
  PyObject *__pyx_v_opt1 = NULL;
  PyObject *__pyx_v_opt2 = NULL;
  PyObject *__pyx_v_tmpLoc = NULL;
  PyObject *__pyx_v_tmpOpt = NULL;
  PyObject *__pyx_v_matchOrder = NULL;
  int __pyx_v_keepMatching;
  PyObject *__pyx_v_tmpExprs = NULL;
  PyObject *__pyx_v_failed = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_v_missing = NULL;
  PyObject *__pyx_v_resultlist = NULL;
  PyObject *__pyx_v_results = NULL;
  PyObject *__pyx_v_finalResults = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  PyObject *(*__pyx_t_18)(PyObject *);
  __Pyx_RefNannySetupContext("parseImpl", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_parseImpl *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_50_parseImpl(__pyx_ptype_10cPyparsing___pyx_scope_struct_50_parseImpl, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_parseImpl *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3675, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);

  /* "cPyparsing.pyx":3676
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if self.initExprGroups:             # <<<<<<<<<<<<<<
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))
 *             opt1 = [e.expr for e in self.exprs if isinstance(e, Optional)]
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_initExprGroups); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 3676, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":3677
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if self.initExprGroups:
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))             # <<<<<<<<<<<<<<
 *             opt1 = [e.expr for e in self.exprs if isinstance(e, Optional)]
 *             opt2 = [e for e in self.exprs if e.mayReturnEmpty and not isinstance(e, Optional)]
 */
    __pyx_t_1 = __pyx_pf_10cPyparsing_4Each_9parseImpl_genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3677, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3677, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_opt1map, __pyx_t_3) < 0) __PYX_ERR(0, 3677, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3678
 *         if self.initExprGroups:
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))
 *             opt1 = [e.expr for e in self.exprs if isinstance(e, Optional)]             # <<<<<<<<<<<<<<
 *             opt2 = [e for e in self.exprs if e.mayReturnEmpty and not isinstance(e, Optional)]
 *             self.optionals = opt1 + opt2
 */
    { /* enter inner scope */
      PyObject *__pyx_9genexpr32__pyx_v_e = NULL;
      __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3678, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3678, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
        __pyx_t_4 = __pyx_t_1; __Pyx_INCREF(__pyx_t_4); __pyx_t_5 = 0;
        __pyx_t_6 = NULL;
      } else {
        __pyx_t_5 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3678, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_6 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3678, __pyx_L6_error)
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      for (;;) {
        if (likely(!__pyx_t_6)) {
          if (likely(PyList_CheckExact(__pyx_t_4))) {
            if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_4)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 3678, __pyx_L6_error)
            #else
            __pyx_t_1 = PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3678, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          } else {
            if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 3678, __pyx_L6_error)
            #else
            __pyx_t_1 = PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3678, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          }
        } else {
          __pyx_t_1 = __pyx_t_6(__pyx_t_4);
          if (unlikely(!__pyx_t_1)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 3678, __pyx_L6_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_XDECREF_SET(__pyx_9genexpr32__pyx_v_e, __pyx_t_1);
        __pyx_t_1 = 0;
        __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3678, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = PyObject_IsInstance(__pyx_9genexpr32__pyx_v_e, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 3678, __pyx_L6_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_7 = (__pyx_t_2 != 0);
        if (__pyx_t_7) {
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_9genexpr32__pyx_v_e, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3678, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_1);
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_3, (PyObject*)__pyx_t_1))) __PYX_ERR(0, 3678, __pyx_L6_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_9genexpr32__pyx_v_e);
      goto __pyx_L10_exit_scope;
      __pyx_L6_error:;
      __Pyx_XDECREF(__pyx_9genexpr32__pyx_v_e);
      goto __pyx_L1_error;
      __pyx_L10_exit_scope:;
    } /* exit inner scope */
    __pyx_v_opt1 = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3679
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))
 *             opt1 = [e.expr for e in self.exprs if isinstance(e, Optional)]
 *             opt2 = [e for e in self.exprs if e.mayReturnEmpty and not isinstance(e, Optional)]             # <<<<<<<<<<<<<<
 *             self.optionals = opt1 + opt2
 *             self.multioptionals = [e.expr for e in self.exprs if isinstance(e, ZeroOrMore)]
 */
    { /* enter inner scope */
      PyObject *__pyx_9genexpr33__pyx_v_e = NULL;
      __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3679, __pyx_L13_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3679, __pyx_L13_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
        __pyx_t_1 = __pyx_t_4; __Pyx_INCREF(__pyx_t_1); __pyx_t_5 = 0;
        __pyx_t_6 = NULL;
      } else {
        __pyx_t_5 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3679, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_6 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3679, __pyx_L13_error)
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      for (;;) {
        if (likely(!__pyx_t_6)) {
          if (likely(PyList_CheckExact(__pyx_t_1))) {
            if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_1)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 3679, __pyx_L13_error)
            #else
            __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3679, __pyx_L13_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          } else {
            if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 3679, __pyx_L13_error)
            #else
            __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3679, __pyx_L13_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          }
        } else {
          __pyx_t_4 = __pyx_t_6(__pyx_t_1);
          if (unlikely(!__pyx_t_4)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 3679, __pyx_L13_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_4);
        }
        __Pyx_XDECREF_SET(__pyx_9genexpr33__pyx_v_e, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_9genexpr33__pyx_v_e, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3679, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 3679, __pyx_L13_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (__pyx_t_2) {
        } else {
          __pyx_t_7 = __pyx_t_2;
          goto __pyx_L17_bool_binop_done;
        }
        __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3679, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_2 = PyObject_IsInstance(__pyx_9genexpr33__pyx_v_e, __pyx_t_4); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 3679, __pyx_L13_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_8 = ((!(__pyx_t_2 != 0)) != 0);
        __pyx_t_7 = __pyx_t_8;
        __pyx_L17_bool_binop_done:;
        if (__pyx_t_7) {
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_3, (PyObject*)__pyx_9genexpr33__pyx_v_e))) __PYX_ERR(0, 3679, __pyx_L13_error)
        }
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_9genexpr33__pyx_v_e);
      goto __pyx_L19_exit_scope;
      __pyx_L13_error:;
      __Pyx_XDECREF(__pyx_9genexpr33__pyx_v_e);
      goto __pyx_L1_error;
      __pyx_L19_exit_scope:;
    } /* exit inner scope */
    __pyx_v_opt2 = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3680
 *             opt1 = [e.expr for e in self.exprs if isinstance(e, Optional)]
 *             opt2 = [e for e in self.exprs if e.mayReturnEmpty and not isinstance(e, Optional)]
 *             self.optionals = opt1 + opt2             # <<<<<<<<<<<<<<
 *             self.multioptionals = [e.expr for e in self.exprs if isinstance(e, ZeroOrMore)]
 *             self.multirequired = [e.expr for e in self.exprs if isinstance(e, OneOrMore)]
 */
    __pyx_t_3 = PyNumber_Add(__pyx_v_opt1, __pyx_v_opt2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3680, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_optionals, __pyx_t_3) < 0) __PYX_ERR(0, 3680, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3681
 *             opt2 = [e for e in self.exprs if e.mayReturnEmpty and not isinstance(e, Optional)]
 *             self.optionals = opt1 + opt2
 *             self.multioptionals = [e.expr for e in self.exprs if isinstance(e, ZeroOrMore)]             # <<<<<<<<<<<<<<
 *             self.multirequired = [e.expr for e in self.exprs if isinstance(e, OneOrMore)]
 *             self.required = [e for e in self.exprs if not isinstance(e, (Optional, ZeroOrMore, OneOrMore))]
 */
    { /* enter inner scope */
      PyObject *__pyx_9genexpr34__pyx_v_e = NULL;
      __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3681, __pyx_L22_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3681, __pyx_L22_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
        __pyx_t_4 = __pyx_t_1; __Pyx_INCREF(__pyx_t_4); __pyx_t_5 = 0;
        __pyx_t_6 = NULL;
      } else {
        __pyx_t_5 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3681, __pyx_L22_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_6 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3681, __pyx_L22_error)
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      for (;;) {
        if (likely(!__pyx_t_6)) {
          if (likely(PyList_CheckExact(__pyx_t_4))) {
            if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_4)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 3681, __pyx_L22_error)
            #else
            __pyx_t_1 = PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3681, __pyx_L22_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          } else {
            if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 3681, __pyx_L22_error)
            #else
            __pyx_t_1 = PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3681, __pyx_L22_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          }
        } else {
          __pyx_t_1 = __pyx_t_6(__pyx_t_4);
          if (unlikely(!__pyx_t_1)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 3681, __pyx_L22_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_XDECREF_SET(__pyx_9genexpr34__pyx_v_e, __pyx_t_1);
        __pyx_t_1 = 0;
        __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3681, __pyx_L22_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = PyObject_IsInstance(__pyx_9genexpr34__pyx_v_e, __pyx_t_1); if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 3681, __pyx_L22_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_8 = (__pyx_t_7 != 0);
        if (__pyx_t_8) {
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_9genexpr34__pyx_v_e, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3681, __pyx_L22_error)
          __Pyx_GOTREF(__pyx_t_1);
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_3, (PyObject*)__pyx_t_1))) __PYX_ERR(0, 3681, __pyx_L22_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_9genexpr34__pyx_v_e);
      goto __pyx_L26_exit_scope;
      __pyx_L22_error:;
      __Pyx_XDECREF(__pyx_9genexpr34__pyx_v_e);
      goto __pyx_L1_error;
      __pyx_L26_exit_scope:;
    } /* exit inner scope */
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_multioptionals, __pyx_t_3) < 0) __PYX_ERR(0, 3681, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3682
 *             self.optionals = opt1 + opt2
 *             self.multioptionals = [e.expr for e in self.exprs if isinstance(e, ZeroOrMore)]
 *             self.multirequired = [e.expr for e in self.exprs if isinstance(e, OneOrMore)]             # <<<<<<<<<<<<<<
 *             self.required = [e for e in self.exprs if not isinstance(e, (Optional, ZeroOrMore, OneOrMore))]
 *             self.required += self.multirequired
 */
    { /* enter inner scope */
      PyObject *__pyx_9genexpr35__pyx_v_e = NULL;
      __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3682, __pyx_L29_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3682, __pyx_L29_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
        __pyx_t_1 = __pyx_t_4; __Pyx_INCREF(__pyx_t_1); __pyx_t_5 = 0;
        __pyx_t_6 = NULL;
      } else {
        __pyx_t_5 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3682, __pyx_L29_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_6 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3682, __pyx_L29_error)
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      for (;;) {
        if (likely(!__pyx_t_6)) {
          if (likely(PyList_CheckExact(__pyx_t_1))) {
            if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_1)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 3682, __pyx_L29_error)
            #else
            __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3682, __pyx_L29_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          } else {
            if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 3682, __pyx_L29_error)
            #else
            __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3682, __pyx_L29_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          }
        } else {
          __pyx_t_4 = __pyx_t_6(__pyx_t_1);
          if (unlikely(!__pyx_t_4)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 3682, __pyx_L29_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_4);
        }
        __Pyx_XDECREF_SET(__pyx_9genexpr35__pyx_v_e, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3682, __pyx_L29_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_8 = PyObject_IsInstance(__pyx_9genexpr35__pyx_v_e, __pyx_t_4); if (unlikely(__pyx_t_8 == -1)) __PYX_ERR(0, 3682, __pyx_L29_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_7 = (__pyx_t_8 != 0);
        if (__pyx_t_7) {
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_9genexpr35__pyx_v_e, __pyx_n_s_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3682, __pyx_L29_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_3, (PyObject*)__pyx_t_4))) __PYX_ERR(0, 3682, __pyx_L29_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_9genexpr35__pyx_v_e);
      goto __pyx_L33_exit_scope;
      __pyx_L29_error:;
      __Pyx_XDECREF(__pyx_9genexpr35__pyx_v_e);
      goto __pyx_L1_error;
      __pyx_L33_exit_scope:;
    } /* exit inner scope */
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_multirequired, __pyx_t_3) < 0) __PYX_ERR(0, 3682, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3683
 *             self.multioptionals = [e.expr for e in self.exprs if isinstance(e, ZeroOrMore)]
 *             self.multirequired = [e.expr for e in self.exprs if isinstance(e, OneOrMore)]
 *             self.required = [e for e in self.exprs if not isinstance(e, (Optional, ZeroOrMore, OneOrMore))]             # <<<<<<<<<<<<<<
 *             self.required += self.multirequired
 *             self.initExprGroups = False
 */
    { /* enter inner scope */
      PyObject *__pyx_9genexpr36__pyx_v_e = NULL;
      __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3683, __pyx_L36_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3683, __pyx_L36_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
        __pyx_t_4 = __pyx_t_1; __Pyx_INCREF(__pyx_t_4); __pyx_t_5 = 0;
        __pyx_t_6 = NULL;
      } else {
        __pyx_t_5 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3683, __pyx_L36_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_6 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3683, __pyx_L36_error)
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      for (;;) {
        if (likely(!__pyx_t_6)) {
          if (likely(PyList_CheckExact(__pyx_t_4))) {
            if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_4)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 3683, __pyx_L36_error)
            #else
            __pyx_t_1 = PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3683, __pyx_L36_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          } else {
            if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 3683, __pyx_L36_error)
            #else
            __pyx_t_1 = PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3683, __pyx_L36_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          }
        } else {
          __pyx_t_1 = __pyx_t_6(__pyx_t_4);
          if (unlikely(!__pyx_t_1)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 3683, __pyx_L36_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_XDECREF_SET(__pyx_9genexpr36__pyx_v_e, __pyx_t_1);
        __pyx_t_1 = 0;
        __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3683, __pyx_L36_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3683, __pyx_L36_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_10 = __Pyx_GetModuleGlobalName(__pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3683, __pyx_L36_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_8 = PyObject_IsInstance(__pyx_9genexpr36__pyx_v_e, __pyx_t_1); 
        __pyx_t_2 = (__pyx_t_8 != 0);
        if (!__pyx_t_2) {
        } else {
          __pyx_t_7 = __pyx_t_2;
          goto __pyx_L40_bool_binop_done;
        }
        __pyx_t_2 = PyObject_IsInstance(__pyx_9genexpr36__pyx_v_e, __pyx_t_9); 
        __pyx_t_8 = (__pyx_t_2 != 0);
        if (!__pyx_t_8) {
        } else {
          __pyx_t_7 = __pyx_t_8;
          goto __pyx_L40_bool_binop_done;
        }
        __pyx_t_8 = PyObject_IsInstance(__pyx_9genexpr36__pyx_v_e, __pyx_t_10); 
        __pyx_t_2 = (__pyx_t_8 != 0);
        __pyx_t_7 = __pyx_t_2;
        __pyx_L40_bool_binop_done:;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_2 = ((!(__pyx_t_7 != 0)) != 0);
        if (__pyx_t_2) {
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_3, (PyObject*)__pyx_9genexpr36__pyx_v_e))) __PYX_ERR(0, 3683, __pyx_L36_error)
        }
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_9genexpr36__pyx_v_e);
      goto __pyx_L43_exit_scope;
      __pyx_L36_error:;
      __Pyx_XDECREF(__pyx_9genexpr36__pyx_v_e);
      goto __pyx_L1_error;
      __pyx_L43_exit_scope:;
    } /* exit inner scope */
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_required, __pyx_t_3) < 0) __PYX_ERR(0, 3683, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3684
 *             self.multirequired = [e.expr for e in self.exprs if isinstance(e, OneOrMore)]
 *             self.required = [e for e in self.exprs if not isinstance(e, (Optional, ZeroOrMore, OneOrMore))]
 *             self.required += self.multirequired             # <<<<<<<<<<<<<<
 *             self.initExprGroups = False
 *         tmpLoc = loc
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_required); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3684, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_multirequired); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3684, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3684, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_required, __pyx_t_1) < 0) __PYX_ERR(0, 3684, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3685
 *             self.required = [e for e in self.exprs if not isinstance(e, (Optional, ZeroOrMore, OneOrMore))]
 *             self.required += self.multirequired
 *             self.initExprGroups = False             # <<<<<<<<<<<<<<
 *         tmpLoc = loc
 *         tmpReqd = self.required[:]
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_initExprGroups, Py_False) < 0) __PYX_ERR(0, 3685, __pyx_L1_error)

    /* "cPyparsing.pyx":3676
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if self.initExprGroups:             # <<<<<<<<<<<<<<
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))
 *             opt1 = [e.expr for e in self.exprs if isinstance(e, Optional)]
 */
  }

  /* "cPyparsing.pyx":3686
 *             self.required += self.multirequired
 *             self.initExprGroups = False
 *         tmpLoc = loc             # <<<<<<<<<<<<<<
 *         tmpReqd = self.required[:]
 *         tmpOpt = self.optionals[:]
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_tmpLoc = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3687
 *             self.initExprGroups = False
 *         tmpLoc = loc
 *         tmpReqd = self.required[:]             # <<<<<<<<<<<<<<
 *         tmpOpt = self.optionals[:]
 *         matchOrder = []
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_required); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_t_1, 0, 0, NULL, NULL, &__pyx_slice__117, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_cur_scope->__pyx_v_tmpReqd = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":3688
 *         tmpLoc = loc
 *         tmpReqd = self.required[:]
 *         tmpOpt = self.optionals[:]             # <<<<<<<<<<<<<<
 *         matchOrder = []
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_optionals); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_t_4, 0, 0, NULL, NULL, &__pyx_slice__118, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_tmpOpt = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3689
 *         tmpReqd = self.required[:]
 *         tmpOpt = self.optionals[:]
 *         matchOrder = []             # <<<<<<<<<<<<<<
 * 
 *         keepMatching = True
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_matchOrder = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3691
 *         matchOrder = []
 * 
 *         keepMatching = True             # <<<<<<<<<<<<<<
 *         while keepMatching:
 *             tmpExprs = tmpReqd + tmpOpt + self.multioptionals + self.multirequired
 */
  __pyx_v_keepMatching = 1;

  /* "cPyparsing.pyx":3692
 * 
 *         keepMatching = True
 *         while keepMatching:             # <<<<<<<<<<<<<<
 *             tmpExprs = tmpReqd + tmpOpt + self.multioptionals + self.multirequired
 *             failed = []
 */
  while (1) {
    __pyx_t_2 = (__pyx_v_keepMatching != 0);
    if (!__pyx_t_2) break;

    /* "cPyparsing.pyx":3693
 *         keepMatching = True
 *         while keepMatching:
 *             tmpExprs = tmpReqd + tmpOpt + self.multioptionals + self.multirequired             # <<<<<<<<<<<<<<
 *             failed = []
 *             for e in tmpExprs:
 */
    __pyx_t_1 = PyNumber_Add(__pyx_cur_scope->__pyx_v_tmpReqd, __pyx_v_tmpOpt); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3693, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_multioptionals); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3693, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3693, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_multirequired); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3693, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyNumber_Add(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3693, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF_SET(__pyx_v_tmpExprs, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3694
 *         while keepMatching:
 *             tmpExprs = tmpReqd + tmpOpt + self.multioptionals + self.multirequired
 *             failed = []             # <<<<<<<<<<<<<<
 *             for e in tmpExprs:
 *                 try:
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3694, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_failed, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3695
 *             tmpExprs = tmpReqd + tmpOpt + self.multioptionals + self.multirequired
 *             failed = []
 *             for e in tmpExprs:             # <<<<<<<<<<<<<<
 *                 try:
 *                     tmpLoc = e.tryParse(instring, tmpLoc)
 */
    if (likely(PyList_CheckExact(__pyx_v_tmpExprs)) || PyTuple_CheckExact(__pyx_v_tmpExprs)) {
      __pyx_t_1 = __pyx_v_tmpExprs; __Pyx_INCREF(__pyx_t_1); __pyx_t_5 = 0;
      __pyx_t_6 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_tmpExprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3695, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3695, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_6)) {
        if (likely(PyList_CheckExact(__pyx_t_1))) {
          if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_1)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 3695, __pyx_L1_error)
          #else
          __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3695, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
        } else {
          if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 3695, __pyx_L1_error)
          #else
          __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3695, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
        }
      } else {
        __pyx_t_4 = __pyx_t_6(__pyx_t_1);
        if (unlikely(!__pyx_t_4)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 3695, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "cPyparsing.pyx":3696
 *             failed = []
 *             for e in tmpExprs:
 *                 try:             # <<<<<<<<<<<<<<
 *                     tmpLoc = e.tryParse(instring, tmpLoc)
 *                 except ParseException:
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
        __Pyx_XGOTREF(__pyx_t_11);
        __Pyx_XGOTREF(__pyx_t_12);
        __Pyx_XGOTREF(__pyx_t_13);
        /*try:*/ {

          /* "cPyparsing.pyx":3697
 *             for e in tmpExprs:
 *                 try:
 *                     tmpLoc = e.tryParse(instring, tmpLoc)             # <<<<<<<<<<<<<<
 *                 except ParseException:
 *                     failed.append(e)
 */
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_tryParse); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3697, __pyx_L48_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_9 = NULL;
          __pyx_t_14 = 0;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
            __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_3);
            if (likely(__pyx_t_9)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
              __Pyx_INCREF(__pyx_t_9);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_3, function);
              __pyx_t_14 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_3)) {
            PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_v_instring, __pyx_v_tmpLoc};
            __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3697, __pyx_L48_error)
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_GOTREF(__pyx_t_4);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
            PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_v_instring, __pyx_v_tmpLoc};
            __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3697, __pyx_L48_error)
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_GOTREF(__pyx_t_4);
          } else
          #endif
          {
            __pyx_t_10 = PyTuple_New(2+__pyx_t_14); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3697, __pyx_L48_error)
            __Pyx_GOTREF(__pyx_t_10);
            if (__pyx_t_9) {
              __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_9); __pyx_t_9 = NULL;
            }
            __Pyx_INCREF(__pyx_v_instring);
            __Pyx_GIVEREF(__pyx_v_instring);
            PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_14, __pyx_v_instring);
            __Pyx_INCREF(__pyx_v_tmpLoc);
            __Pyx_GIVEREF(__pyx_v_tmpLoc);
            PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_14, __pyx_v_tmpLoc);
            __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_10, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3697, __pyx_L48_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          }
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF_SET(__pyx_v_tmpLoc, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "cPyparsing.pyx":3696
 *             failed = []
 *             for e in tmpExprs:
 *                 try:             # <<<<<<<<<<<<<<
 *                     tmpLoc = e.tryParse(instring, tmpLoc)
 *                 except ParseException:
 */
        }

        /* "cPyparsing.pyx":3701
 *                     failed.append(e)
 *                 else:
 *                     matchOrder.append(self.opt1map.get(id(e), e))             # <<<<<<<<<<<<<<
 *                     if e in tmpReqd:
 *                         tmpReqd.remove(e)
 */
        /*else:*/ {
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_opt1map); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3701, __pyx_L50_except_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_get); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3701, __pyx_L50_except_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3701, __pyx_L50_except_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_INCREF(__pyx_v_e);
          __Pyx_GIVEREF(__pyx_v_e);
          PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_e);
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_builtin_id, __pyx_t_3, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3701, __pyx_L50_except_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = NULL;
          __pyx_t_14 = 0;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
            __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_10);
            if (likely(__pyx_t_3)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
              __Pyx_INCREF(__pyx_t_3);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_10, function);
              __pyx_t_14 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_10)) {
            PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_t_9, __pyx_v_e};
            __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3701, __pyx_L50_except_error)
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
            PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_t_9, __pyx_v_e};
            __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3701, __pyx_L50_except_error)
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          } else
          #endif
          {
            __pyx_t_15 = PyTuple_New(2+__pyx_t_14); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3701, __pyx_L50_except_error)
            __Pyx_GOTREF(__pyx_t_15);
            if (__pyx_t_3) {
              __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_3); __pyx_t_3 = NULL;
            }
            __Pyx_GIVEREF(__pyx_t_9);
            PyTuple_SET_ITEM(__pyx_t_15, 0+__pyx_t_14, __pyx_t_9);
            __Pyx_INCREF(__pyx_v_e);
            __Pyx_GIVEREF(__pyx_v_e);
            PyTuple_SET_ITEM(__pyx_t_15, 1+__pyx_t_14, __pyx_v_e);
            __pyx_t_9 = 0;
            __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_15, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3701, __pyx_L50_except_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
          }
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_16 = __Pyx_PyList_Append(__pyx_v_matchOrder, __pyx_t_4); if (unlikely(__pyx_t_16 == -1)) __PYX_ERR(0, 3701, __pyx_L50_except_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

          /* "cPyparsing.pyx":3702
 *                 else:
 *                     matchOrder.append(self.opt1map.get(id(e), e))
 *                     if e in tmpReqd:             # <<<<<<<<<<<<<<
 *                         tmpReqd.remove(e)
 *                     elif e in tmpOpt:
 */
          __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_e, __pyx_cur_scope->__pyx_v_tmpReqd, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 3702, __pyx_L50_except_error)
          __pyx_t_7 = (__pyx_t_2 != 0);
          if (__pyx_t_7) {

            /* "cPyparsing.pyx":3703
 *                     matchOrder.append(self.opt1map.get(id(e), e))
 *                     if e in tmpReqd:
 *                         tmpReqd.remove(e)             # <<<<<<<<<<<<<<
 *                     elif e in tmpOpt:
 *                         tmpOpt.remove(e)
 */
            __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_tmpReqd, __pyx_n_s_remove); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3703, __pyx_L50_except_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_15 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
              __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_10);
              if (likely(__pyx_t_15)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
                __Pyx_INCREF(__pyx_t_15);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_10, function);
              }
            }
            if (!__pyx_t_15) {
              __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_v_e); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3703, __pyx_L50_except_error)
              __Pyx_GOTREF(__pyx_t_4);
            } else {
              #if CYTHON_FAST_PYCALL
              if (PyFunction_Check(__pyx_t_10)) {
                PyObject *__pyx_temp[2] = {__pyx_t_15, __pyx_v_e};
                __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3703, __pyx_L50_except_error)
                __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
                __Pyx_GOTREF(__pyx_t_4);
              } else
              #endif
              #if CYTHON_FAST_PYCCALL
              if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
                PyObject *__pyx_temp[2] = {__pyx_t_15, __pyx_v_e};
                __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3703, __pyx_L50_except_error)
                __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
                __Pyx_GOTREF(__pyx_t_4);
              } else
              #endif
              {
                __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3703, __pyx_L50_except_error)
                __Pyx_GOTREF(__pyx_t_9);
                __Pyx_GIVEREF(__pyx_t_15); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_15); __pyx_t_15 = NULL;
                __Pyx_INCREF(__pyx_v_e);
                __Pyx_GIVEREF(__pyx_v_e);
                PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_v_e);
                __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_9, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3703, __pyx_L50_except_error)
                __Pyx_GOTREF(__pyx_t_4);
                __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
              }
            }
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

            /* "cPyparsing.pyx":3702
 *                 else:
 *                     matchOrder.append(self.opt1map.get(id(e), e))
 *                     if e in tmpReqd:             # <<<<<<<<<<<<<<
 *                         tmpReqd.remove(e)
 *                     elif e in tmpOpt:
 */
            goto __pyx_L56;
          }

          /* "cPyparsing.pyx":3704
 *                     if e in tmpReqd:
 *                         tmpReqd.remove(e)
 *                     elif e in tmpOpt:             # <<<<<<<<<<<<<<
 *                         tmpOpt.remove(e)
 *             if len(failed) == len(tmpExprs):
 */
          __pyx_t_7 = (__Pyx_PySequence_ContainsTF(__pyx_v_e, __pyx_v_tmpOpt, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 3704, __pyx_L50_except_error)
          __pyx_t_2 = (__pyx_t_7 != 0);
          if (__pyx_t_2) {

            /* "cPyparsing.pyx":3705
 *                         tmpReqd.remove(e)
 *                     elif e in tmpOpt:
 *                         tmpOpt.remove(e)             # <<<<<<<<<<<<<<
 *             if len(failed) == len(tmpExprs):
 *                 keepMatching = False
 */
            __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_tmpOpt, __pyx_n_s_remove); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3705, __pyx_L50_except_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_9 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
              __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_10);
              if (likely(__pyx_t_9)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
                __Pyx_INCREF(__pyx_t_9);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_10, function);
              }
            }
            if (!__pyx_t_9) {
              __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_v_e); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3705, __pyx_L50_except_error)
              __Pyx_GOTREF(__pyx_t_4);
            } else {
              #if CYTHON_FAST_PYCALL
              if (PyFunction_Check(__pyx_t_10)) {
                PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_v_e};
                __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3705, __pyx_L50_except_error)
                __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
                __Pyx_GOTREF(__pyx_t_4);
              } else
              #endif
              #if CYTHON_FAST_PYCCALL
              if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
                PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_v_e};
                __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3705, __pyx_L50_except_error)
                __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
                __Pyx_GOTREF(__pyx_t_4);
              } else
              #endif
              {
                __pyx_t_15 = PyTuple_New(1+1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3705, __pyx_L50_except_error)
                __Pyx_GOTREF(__pyx_t_15);
                __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_9); __pyx_t_9 = NULL;
                __Pyx_INCREF(__pyx_v_e);
                __Pyx_GIVEREF(__pyx_v_e);
                PyTuple_SET_ITEM(__pyx_t_15, 0+1, __pyx_v_e);
                __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_15, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3705, __pyx_L50_except_error)
                __Pyx_GOTREF(__pyx_t_4);
                __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
              }
            }
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

            /* "cPyparsing.pyx":3704
 *                     if e in tmpReqd:
 *                         tmpReqd.remove(e)
 *                     elif e in tmpOpt:             # <<<<<<<<<<<<<<
 *                         tmpOpt.remove(e)
 *             if len(failed) == len(tmpExprs):
 */
          }
          __pyx_L56:;
        }
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        goto __pyx_L55_try_end;
        __pyx_L48_error:;
        __Pyx_PyThreadState_assign
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "cPyparsing.pyx":3698
 *                 try:
 *                     tmpLoc = e.tryParse(instring, tmpLoc)
 *                 except ParseException:             # <<<<<<<<<<<<<<
 *                     failed.append(e)
 *                 else:
 */
        __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3698, __pyx_L50_except_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_14 = __Pyx_PyErr_ExceptionMatches(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (__pyx_t_14) {
          __Pyx_AddTraceback("cPyparsing.Each.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_10, &__pyx_t_15) < 0) __PYX_ERR(0, 3698, __pyx_L50_except_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_GOTREF(__pyx_t_15);

          /* "cPyparsing.pyx":3699
 *                     tmpLoc = e.tryParse(instring, tmpLoc)
 *                 except ParseException:
 *                     failed.append(e)             # <<<<<<<<<<<<<<
 *                 else:
 *                     matchOrder.append(self.opt1map.get(id(e), e))
 */
          __pyx_t_16 = __Pyx_PyList_Append(__pyx_v_failed, __pyx_v_e); if (unlikely(__pyx_t_16 == -1)) __PYX_ERR(0, 3699, __pyx_L50_except_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
          goto __pyx_L49_exception_handled;
        }
        goto __pyx_L50_except_error;
        __pyx_L50_except_error:;

        /* "cPyparsing.pyx":3696
 *             failed = []
 *             for e in tmpExprs:
 *                 try:             # <<<<<<<<<<<<<<
 *                     tmpLoc = e.tryParse(instring, tmpLoc)
 *                 except ParseException:
 */
        __Pyx_PyThreadState_assign
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
        goto __pyx_L1_error;
        __pyx_L49_exception_handled:;
        __Pyx_PyThreadState_assign
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
        __pyx_L55_try_end:;
      }

      /* "cPyparsing.pyx":3695
 *             tmpExprs = tmpReqd + tmpOpt + self.multioptionals + self.multirequired
 *             failed = []
 *             for e in tmpExprs:             # <<<<<<<<<<<<<<
 *                 try:
 *                     tmpLoc = e.tryParse(instring, tmpLoc)
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3706
 *                     elif e in tmpOpt:
 *                         tmpOpt.remove(e)
 *             if len(failed) == len(tmpExprs):             # <<<<<<<<<<<<<<
 *                 keepMatching = False
 * 
 */
    __pyx_t_5 = PyList_GET_SIZE(__pyx_v_failed); if (unlikely(__pyx_t_5 == -1)) __PYX_ERR(0, 3706, __pyx_L1_error)
    __pyx_t_17 = PyObject_Length(__pyx_v_tmpExprs); if (unlikely(__pyx_t_17 == -1)) __PYX_ERR(0, 3706, __pyx_L1_error)
    __pyx_t_2 = ((__pyx_t_5 == __pyx_t_17) != 0);
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":3707
 *                         tmpOpt.remove(e)
 *             if len(failed) == len(tmpExprs):
 *                 keepMatching = False             # <<<<<<<<<<<<<<
 * 
 *         if tmpReqd:
 */
      __pyx_v_keepMatching = 0;

      /* "cPyparsing.pyx":3706
 *                     elif e in tmpOpt:
 *                         tmpOpt.remove(e)
 *             if len(failed) == len(tmpExprs):             # <<<<<<<<<<<<<<
 *                 keepMatching = False
 * 
 */
    }
  }

  /* "cPyparsing.pyx":3709
 *                 keepMatching = False
 * 
 *         if tmpReqd:             # <<<<<<<<<<<<<<
 *             missing = ", ".join(_ustr(e) for e in tmpReqd)
 *             raise ParseException(instring, loc, "Missing one or more required elements (%s)" % missing)
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_tmpReqd); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 3709, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":3710
 * 
 *         if tmpReqd:
 *             missing = ", ".join(_ustr(e) for e in tmpReqd)             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, "Missing one or more required elements (%s)" % missing)
 * 
 */
    __pyx_t_1 = __pyx_pf_10cPyparsing_4Each_9parseImpl_3genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3710, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_15 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3710, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__17, __pyx_t_15); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3710, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_v_missing = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3711
 *         if tmpReqd:
 *             missing = ", ".join(_ustr(e) for e in tmpReqd)
 *             raise ParseException(instring, loc, "Missing one or more required elements (%s)" % missing)             # <<<<<<<<<<<<<<
 * 
 *         # add any unmatched Optionals, in case they have default values defined
 */
    __pyx_t_15 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3711, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_10 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3711, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_4 = PyUnicode_Format(__pyx_kp_u_Missing_one_or_more_required_ele, __pyx_v_missing); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3711, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_9 = NULL;
    __pyx_t_14 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_15))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_15);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_15, function);
        __pyx_t_14 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_15)) {
      PyObject *__pyx_temp[4] = {__pyx_t_9, __pyx_v_instring, __pyx_t_10, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_15, __pyx_temp+1-__pyx_t_14, 3+__pyx_t_14); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3711, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_15)) {
      PyObject *__pyx_temp[4] = {__pyx_t_9, __pyx_v_instring, __pyx_t_10, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_15, __pyx_temp+1-__pyx_t_14, 3+__pyx_t_14); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3711, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    {
      __pyx_t_3 = PyTuple_New(3+__pyx_t_14); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3711, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (__pyx_t_9) {
        __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_9); __pyx_t_9 = NULL;
      }
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      PyTuple_SET_ITEM(__pyx_t_3, 0+__pyx_t_14, __pyx_v_instring);
      __Pyx_GIVEREF(__pyx_t_10);
      PyTuple_SET_ITEM(__pyx_t_3, 1+__pyx_t_14, __pyx_t_10);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_3, 2+__pyx_t_14, __pyx_t_4);
      __pyx_t_10 = 0;
      __pyx_t_4 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_15, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3711, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 3711, __pyx_L1_error)

    /* "cPyparsing.pyx":3709
 *                 keepMatching = False
 * 
 *         if tmpReqd:             # <<<<<<<<<<<<<<
 *             missing = ", ".join(_ustr(e) for e in tmpReqd)
 *             raise ParseException(instring, loc, "Missing one or more required elements (%s)" % missing)
 */
  }

  /* "cPyparsing.pyx":3714
 * 
 *         # add any unmatched Optionals, in case they have default values defined
 *         matchOrder += [e for e in self.exprs if isinstance(e, Optional) and e.expr in tmpOpt]             # <<<<<<<<<<<<<<
 * 
 *         resultlist = []
 */
  { /* enter inner scope */
    PyObject *__pyx_9genexpr38__pyx_v_e = NULL;
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3714, __pyx_L63_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3714, __pyx_L63_error)
    __Pyx_GOTREF(__pyx_t_15);
    if (likely(PyList_CheckExact(__pyx_t_15)) || PyTuple_CheckExact(__pyx_t_15)) {
      __pyx_t_3 = __pyx_t_15; __Pyx_INCREF(__pyx_t_3); __pyx_t_17 = 0;
      __pyx_t_6 = NULL;
    } else {
      __pyx_t_17 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_15); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3714, __pyx_L63_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3714, __pyx_L63_error)
    }
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    for (;;) {
      if (likely(!__pyx_t_6)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          if (__pyx_t_17 >= PyList_GET_SIZE(__pyx_t_3)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_15 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_17); __Pyx_INCREF(__pyx_t_15); __pyx_t_17++; if (unlikely(0 < 0)) __PYX_ERR(0, 3714, __pyx_L63_error)
          #else
          __pyx_t_15 = PySequence_ITEM(__pyx_t_3, __pyx_t_17); __pyx_t_17++; if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3714, __pyx_L63_error)
          __Pyx_GOTREF(__pyx_t_15);
          #endif
        } else {
          if (__pyx_t_17 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_15 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_17); __Pyx_INCREF(__pyx_t_15); __pyx_t_17++; if (unlikely(0 < 0)) __PYX_ERR(0, 3714, __pyx_L63_error)
          #else
          __pyx_t_15 = PySequence_ITEM(__pyx_t_3, __pyx_t_17); __pyx_t_17++; if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3714, __pyx_L63_error)
          __Pyx_GOTREF(__pyx_t_15);
          #endif
        }
      } else {
        __pyx_t_15 = __pyx_t_6(__pyx_t_3);
        if (unlikely(!__pyx_t_15)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 3714, __pyx_L63_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_15);
      }
      __Pyx_XDECREF_SET(__pyx_9genexpr38__pyx_v_e, __pyx_t_15);
      __pyx_t_15 = 0;
      __pyx_t_15 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3714, __pyx_L63_error)
      __Pyx_GOTREF(__pyx_t_15);
      __pyx_t_7 = PyObject_IsInstance(__pyx_9genexpr38__pyx_v_e, __pyx_t_15); if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 3714, __pyx_L63_error)
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_8 = (__pyx_t_7 != 0);
      if (__pyx_t_8) {
      } else {
        __pyx_t_2 = __pyx_t_8;
        goto __pyx_L67_bool_binop_done;
      }
      __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_9genexpr38__pyx_v_e, __pyx_n_s_expr); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3714, __pyx_L63_error)
      __Pyx_GOTREF(__pyx_t_15);
      __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_t_15, __pyx_v_tmpOpt, Py_EQ)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 3714, __pyx_L63_error)
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_7 = (__pyx_t_8 != 0);
      __pyx_t_2 = __pyx_t_7;
      __pyx_L67_bool_binop_done:;
      if (__pyx_t_2) {
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_9genexpr38__pyx_v_e))) __PYX_ERR(0, 3714, __pyx_L63_error)
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_9genexpr38__pyx_v_e);
    goto __pyx_L69_exit_scope;
    __pyx_L63_error:;
    __Pyx_XDECREF(__pyx_9genexpr38__pyx_v_e);
    goto __pyx_L1_error;
    __pyx_L69_exit_scope:;
  } /* exit inner scope */
  __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_v_matchOrder, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_matchOrder, ((PyObject*)__pyx_t_3));
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3716
 *         matchOrder += [e for e in self.exprs if isinstance(e, Optional) and e.expr in tmpOpt]
 * 
 *         resultlist = []             # <<<<<<<<<<<<<<
 *         for e in matchOrder:
 *             loc, results = e._parse(instring, loc, doActions)
 */
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3716, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_resultlist = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3717
 * 
 *         resultlist = []
 *         for e in matchOrder:             # <<<<<<<<<<<<<<
 *             loc, results = e._parse(instring, loc, doActions)
 *             resultlist.append(results)
 */
  __pyx_t_3 = __pyx_v_matchOrder; __Pyx_INCREF(__pyx_t_3); __pyx_t_17 = 0;
  for (;;) {
    if (__pyx_t_17 >= PyList_GET_SIZE(__pyx_t_3)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_1 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_17); __Pyx_INCREF(__pyx_t_1); __pyx_t_17++; if (unlikely(0 < 0)) __PYX_ERR(0, 3717, __pyx_L1_error)
    #else
    __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_17); __pyx_t_17++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3717, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3718
 *         resultlist = []
 *         for e in matchOrder:
 *             loc, results = e._parse(instring, loc, doActions)             # <<<<<<<<<<<<<<
 *             resultlist.append(results)
 * 
 */
    __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_parse); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3718, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3718, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_10 = NULL;
    __pyx_t_14 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_15);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_15, function);
        __pyx_t_14 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_15)) {
      PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_v_instring, __pyx_t_4, __pyx_v_doActions};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_15, __pyx_temp+1-__pyx_t_14, 3+__pyx_t_14); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3718, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_15)) {
      PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_v_instring, __pyx_t_4, __pyx_v_doActions};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_15, __pyx_temp+1-__pyx_t_14, 3+__pyx_t_14); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3718, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(3+__pyx_t_14); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3718, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (__pyx_t_10) {
        __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_10); __pyx_t_10 = NULL;
      }
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_14, __pyx_v_instring);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_14, __pyx_t_4);
      __Pyx_INCREF(__pyx_v_doActions);
      __Pyx_GIVEREF(__pyx_v_doActions);
      PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_14, __pyx_v_doActions);
      __pyx_t_4 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_15, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3718, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
      PyObject* sequence = __pyx_t_1;
      #if !CYTHON_COMPILING_IN_PYPY
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 3718, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_15 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_9 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_15 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_9 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_15);
      __Pyx_INCREF(__pyx_t_9);
      #else
      __pyx_t_15 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3718, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __pyx_t_9 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3718, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3718, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_18 = Py_TYPE(__pyx_t_4)->tp_iternext;
      index = 0; __pyx_t_15 = __pyx_t_18(__pyx_t_4); if (unlikely(!__pyx_t_15)) goto __pyx_L72_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_15);
      index = 1; __pyx_t_9 = __pyx_t_18(__pyx_t_4); if (unlikely(!__pyx_t_9)) goto __pyx_L72_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_9);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_18(__pyx_t_4), 2) < 0) __PYX_ERR(0, 3718, __pyx_L1_error)
      __pyx_t_18 = NULL;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L73_unpacking_done;
      __pyx_L72_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_18 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 3718, __pyx_L1_error)
      __pyx_L73_unpacking_done:;
    }
    __pyx_t_14 = __Pyx_PyInt_As_int(__pyx_t_15); if (unlikely((__pyx_t_14 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3718, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_v_loc = __pyx_t_14;
    __Pyx_XDECREF_SET(__pyx_v_results, __pyx_t_9);
    __pyx_t_9 = 0;

    /* "cPyparsing.pyx":3719
 *         for e in matchOrder:
 *             loc, results = e._parse(instring, loc, doActions)
 *             resultlist.append(results)             # <<<<<<<<<<<<<<
 * 
 *         finalResults = sum(resultlist, ParseResults([]))
 */
    __pyx_t_16 = __Pyx_PyList_Append(__pyx_v_resultlist, __pyx_v_results); if (unlikely(__pyx_t_16 == -1)) __PYX_ERR(0, 3719, __pyx_L1_error)

    /* "cPyparsing.pyx":3717
 * 
 *         resultlist = []
 *         for e in matchOrder:             # <<<<<<<<<<<<<<
 *             loc, results = e._parse(instring, loc, doActions)
 *             resultlist.append(results)
 */
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3721
 *             resultlist.append(results)
 * 
 *         finalResults = sum(resultlist, ParseResults([]))             # <<<<<<<<<<<<<<
 *         return loc, finalResults
 * 
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_9 = PyList_New(0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_15 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_15)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_15);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (!__pyx_t_15) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3721, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_15, __pyx_t_9};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3721, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_15, __pyx_t_9};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3721, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3721, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_15); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_15); __pyx_t_15 = NULL;
      __Pyx_GIVEREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_t_9);
      __pyx_t_9 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3721, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_resultlist);
  __Pyx_GIVEREF(__pyx_v_resultlist);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_resultlist);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_sum, __pyx_t_1, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_finalResults = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3722
 * 
 *         finalResults = sum(resultlist, ParseResults([]))
 *         return loc, finalResults             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_INCREF(__pyx_v_finalResults);
  __Pyx_GIVEREF(__pyx_v_finalResults);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_finalResults);
  __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3675
 *         self.initExprGroups = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.initExprGroups:
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("cPyparsing.Each.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_opt1);
  __Pyx_XDECREF(__pyx_v_opt2);
  __Pyx_XDECREF(__pyx_v_tmpLoc);
  __Pyx_XDECREF(__pyx_v_tmpOpt);
  __Pyx_XDECREF(__pyx_v_matchOrder);
  __Pyx_XDECREF(__pyx_v_tmpExprs);
  __Pyx_XDECREF(__pyx_v_failed);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_missing);
  __Pyx_XDECREF(__pyx_v_resultlist);
  __Pyx_XDECREF(__pyx_v_results);
  __Pyx_XDECREF(__pyx_v_finalResults);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3724
 *         return loc, finalResults
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_4Each_5__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_4Each_5__str__ = {"__str__", (PyCFunction)__pyx_pw_10cPyparsing_4Each_5__str__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_4Each_5__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_4Each_4__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_4Each_7__str___2generator27(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":3729
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + " & ".join(_ustr(e) for e in self.exprs) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */

static PyObject *__pyx_pf_10cPyparsing_4Each_7__str___genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_54_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_54_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3729, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_53___str__ *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_4Each_7__str___2generator27, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_Each___str___locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 3729, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.Each.__str__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_4Each_7__str___2generator27(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 3729, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 3729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 3729, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3729, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3729, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3729, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3729, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 3729, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3729, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3729, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3729, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_cur_scope->__pyx_v_e); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3729, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_e};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3729, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_e};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3729, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3729, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_e);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_e);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_cur_scope->__pyx_v_e);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3729, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_1))) __PYX_ERR(0, 3729, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3724
 *         return loc, finalResults
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

static PyObject *__pyx_pf_10cPyparsing_4Each_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_53___str__ *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("__str__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_53___str__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_53___str__(__pyx_ptype_10cPyparsing___pyx_scope_struct_53___str__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_53___str__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 3724, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);

  /* "cPyparsing.pyx":3725
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_self;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = PyObject_HasAttr(__pyx_t_1, __pyx_n_u_name); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 3725, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":3726
 *     def __str__(self):
 *         if hasattr(self, "name"):
 *             return self.name             # <<<<<<<<<<<<<<
 * 
 *         if self.strRepr is None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3726, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":3725
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  }

  /* "cPyparsing.pyx":3728
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "{" + " & ".join(_ustr(e) for e in self.exprs) + "}"
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = (__pyx_t_1 == Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":3729
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + " & ".join(_ustr(e) for e in self.exprs) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
    __pyx_t_1 = __pyx_pf_10cPyparsing_4Each_7__str___genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3729, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3729, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__119, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3729, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_kp_u__111, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3729, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_t_4, __pyx_kp_u__112); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3729, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_1) < 0) __PYX_ERR(0, 3729, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3728
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "{" + " & ".join(_ustr(e) for e in self.exprs) + "}"
 * 
 */
  }

  /* "cPyparsing.pyx":3731
 *             self.strRepr = "{" + " & ".join(_ustr(e) for e in self.exprs) + "}"
 * 
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 *     def checkRecursion(self, parseElementList):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3724
 *         return loc, finalResults
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.Each.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3733
 *         return self.strRepr
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_4Each_7checkRecursion(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_4Each_7checkRecursion = {"checkRecursion", (PyCFunction)__pyx_pw_10cPyparsing_4Each_7checkRecursion, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_4Each_7checkRecursion(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_parseElementList = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("checkRecursion (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_parseElementList,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_parseElementList)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("checkRecursion", 1, 2, 2, 1); __PYX_ERR(0, 3733, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "checkRecursion") < 0)) __PYX_ERR(0, 3733, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_parseElementList = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("checkRecursion", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3733, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Each.checkRecursion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_4Each_6checkRecursion(__pyx_self, __pyx_v_self, __pyx_v_parseElementList);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_4Each_6checkRecursion(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parseElementList) {
  PyObject *__pyx_v_subRecCheckList = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("checkRecursion", 0);

  /* "cPyparsing.pyx":3734
 * 
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]             # <<<<<<<<<<<<<<
 *         for e in self.exprs:
 *             e.checkRecursion(subRecCheckList)
 */
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_parseElementList, 0, 0, NULL, NULL, &__pyx_slice__120, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_self);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_subRecCheckList = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3735
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.checkRecursion(subRecCheckList)
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_exprs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
    __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3735, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3735, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 3735, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3735, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 3735, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3735, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3735, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3736
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 *             e.checkRecursion(subRecCheckList)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_checkRecursion); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3736, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_subRecCheckList); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3736, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_subRecCheckList};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3736, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_subRecCheckList};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3736, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3736, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_v_subRecCheckList);
        __Pyx_GIVEREF(__pyx_v_subRecCheckList);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_subRecCheckList);
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3736, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3735
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:             # <<<<<<<<<<<<<<
 *             e.checkRecursion(subRecCheckList)
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3733
 *         return self.strRepr
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.Each.checkRecursion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_subRecCheckList);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3744
 *     """
 * 
 *     def __init__(self, expr, savelist=False):             # <<<<<<<<<<<<<<
 *         super(ParseElementEnhance, self).__init__(savelist)
 *         if isinstance(expr, basestring):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_19ParseElementEnhance_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_19ParseElementEnhance_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_savelist = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_expr,&__pyx_n_s_savelist,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_False));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_expr)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 3744, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_savelist);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 3744, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_expr = values[1];
    __pyx_v_savelist = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3744, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_19ParseElementEnhance___init__(__pyx_self, __pyx_v_self, __pyx_v_expr, __pyx_v_savelist);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_savelist) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);
  __Pyx_INCREF(__pyx_v_expr);

  /* "cPyparsing.pyx":3745
 * 
 *     def __init__(self, expr, savelist=False):
 *         super(ParseElementEnhance, self).__init__(savelist)             # <<<<<<<<<<<<<<
 *         if isinstance(expr, basestring):
 *             if issubclass(ParserElement._literalStringClass, Token):
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_savelist); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3745, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_savelist};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3745, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_savelist};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3745, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3745, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_savelist);
      __Pyx_GIVEREF(__pyx_v_savelist);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_savelist);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3745, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3746
 *     def __init__(self, expr, savelist=False):
 *         super(ParseElementEnhance, self).__init__(savelist)
 *         if isinstance(expr, basestring):             # <<<<<<<<<<<<<<
 *             if issubclass(ParserElement._literalStringClass, Token):
 *                 expr = ParserElement._literalStringClass(expr)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyObject_IsInstance(__pyx_v_expr, __pyx_t_1); if (unlikely(__pyx_t_5 == -1)) __PYX_ERR(0, 3746, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":3747
 *         super(ParseElementEnhance, self).__init__(savelist)
 *         if isinstance(expr, basestring):
 *             if issubclass(ParserElement._literalStringClass, Token):             # <<<<<<<<<<<<<<
 *                 expr = ParserElement._literalStringClass(expr)
 *             else:
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3747, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3747, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Token); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3747, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = PyObject_IsSubclass(__pyx_t_3, __pyx_t_1); if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 3747, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = (__pyx_t_6 != 0);
    if (__pyx_t_5) {

      /* "cPyparsing.pyx":3748
 *         if isinstance(expr, basestring):
 *             if issubclass(ParserElement._literalStringClass, Token):
 *                 expr = ParserElement._literalStringClass(expr)             # <<<<<<<<<<<<<<
 *             else:
 *                 expr = ParserElement._literalStringClass(Literal(expr))
 */
      __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3748, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3748, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      if (!__pyx_t_3) {
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3748, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_expr};
          __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3748, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_GOTREF(__pyx_t_1);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_expr};
          __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3748, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_GOTREF(__pyx_t_1);
        } else
        #endif
        {
          __pyx_t_2 = PyTuple_New(1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3748, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3); __pyx_t_3 = NULL;
          __Pyx_INCREF(__pyx_v_expr);
          __Pyx_GIVEREF(__pyx_v_expr);
          PyTuple_SET_ITEM(__pyx_t_2, 0+1, __pyx_v_expr);
          __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3748, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF_SET(__pyx_v_expr, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "cPyparsing.pyx":3747
 *         super(ParseElementEnhance, self).__init__(savelist)
 *         if isinstance(expr, basestring):
 *             if issubclass(ParserElement._literalStringClass, Token):             # <<<<<<<<<<<<<<
 *                 expr = ParserElement._literalStringClass(expr)
 *             else:
 */
      goto __pyx_L4;
    }

    /* "cPyparsing.pyx":3750
 *                 expr = ParserElement._literalStringClass(expr)
 *             else:
 *                 expr = ParserElement._literalStringClass(Literal(expr))             # <<<<<<<<<<<<<<
 *         self.expr = expr
 *         self.strRepr = None
 */
    /*else*/ {
      __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3750, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3750, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_Literal); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3750, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_7) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3750, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_expr};
          __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3750, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_4);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_expr};
          __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3750, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_4);
        } else
        #endif
        {
          __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3750, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_7); __pyx_t_7 = NULL;
          __Pyx_INCREF(__pyx_v_expr);
          __Pyx_GIVEREF(__pyx_v_expr);
          PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_v_expr);
          __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_8, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3750, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      if (!__pyx_t_3) {
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3750, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_2)) {
          PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_4};
          __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3750, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
          PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_4};
          __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3750, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        } else
        #endif
        {
          __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3750, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_3); __pyx_t_3 = NULL;
          __Pyx_GIVEREF(__pyx_t_4);
          PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_4);
          __pyx_t_4 = 0;
          __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3750, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF_SET(__pyx_v_expr, __pyx_t_1);
      __pyx_t_1 = 0;
    }
    __pyx_L4:;

    /* "cPyparsing.pyx":3746
 *     def __init__(self, expr, savelist=False):
 *         super(ParseElementEnhance, self).__init__(savelist)
 *         if isinstance(expr, basestring):             # <<<<<<<<<<<<<<
 *             if issubclass(ParserElement._literalStringClass, Token):
 *                 expr = ParserElement._literalStringClass(expr)
 */
  }

  /* "cPyparsing.pyx":3751
 *             else:
 *                 expr = ParserElement._literalStringClass(Literal(expr))
 *         self.expr = expr             # <<<<<<<<<<<<<<
 *         self.strRepr = None
 *         if expr is not None:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_expr, __pyx_v_expr) < 0) __PYX_ERR(0, 3751, __pyx_L1_error)

  /* "cPyparsing.pyx":3752
 *                 expr = ParserElement._literalStringClass(Literal(expr))
 *         self.expr = expr
 *         self.strRepr = None             # <<<<<<<<<<<<<<
 *         if expr is not None:
 *             self.mayIndexError = expr.mayIndexError
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, Py_None) < 0) __PYX_ERR(0, 3752, __pyx_L1_error)

  /* "cPyparsing.pyx":3753
 *         self.expr = expr
 *         self.strRepr = None
 *         if expr is not None:             # <<<<<<<<<<<<<<
 *             self.mayIndexError = expr.mayIndexError
 *             self.mayReturnEmpty = expr.mayReturnEmpty
 */
  __pyx_t_5 = (__pyx_v_expr != Py_None);
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":3754
 *         self.strRepr = None
 *         if expr is not None:
 *             self.mayIndexError = expr.mayIndexError             # <<<<<<<<<<<<<<
 *             self.mayReturnEmpty = expr.mayReturnEmpty
 *             self.setWhitespaceChars(expr.whiteChars)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_mayIndexError); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3754, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, __pyx_t_1) < 0) __PYX_ERR(0, 3754, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3755
 *         if expr is not None:
 *             self.mayIndexError = expr.mayIndexError
 *             self.mayReturnEmpty = expr.mayReturnEmpty             # <<<<<<<<<<<<<<
 *             self.setWhitespaceChars(expr.whiteChars)
 *             self.skipWhitespace = expr.skipWhitespace
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3755, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_1) < 0) __PYX_ERR(0, 3755, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3756
 *             self.mayIndexError = expr.mayIndexError
 *             self.mayReturnEmpty = expr.mayReturnEmpty
 *             self.setWhitespaceChars(expr.whiteChars)             # <<<<<<<<<<<<<<
 *             self.skipWhitespace = expr.skipWhitespace
 *             self.saveAsList = expr.saveAsList
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_setWhitespaceChars); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3756, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_whiteChars); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3756, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3756, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_8};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3756, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_8};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3756, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_3 = PyTuple_New(1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3756, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_3, 0+1, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3756, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3757
 *             self.mayReturnEmpty = expr.mayReturnEmpty
 *             self.setWhitespaceChars(expr.whiteChars)
 *             self.skipWhitespace = expr.skipWhitespace             # <<<<<<<<<<<<<<
 *             self.saveAsList = expr.saveAsList
 *             self.callPreparse = expr.callPreparse
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_skipWhitespace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3757, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, __pyx_t_1) < 0) __PYX_ERR(0, 3757, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3758
 *             self.setWhitespaceChars(expr.whiteChars)
 *             self.skipWhitespace = expr.skipWhitespace
 *             self.saveAsList = expr.saveAsList             # <<<<<<<<<<<<<<
 *             self.callPreparse = expr.callPreparse
 *             self.ignoreExprs.extend(expr.ignoreExprs)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3758, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList, __pyx_t_1) < 0) __PYX_ERR(0, 3758, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3759
 *             self.skipWhitespace = expr.skipWhitespace
 *             self.saveAsList = expr.saveAsList
 *             self.callPreparse = expr.callPreparse             # <<<<<<<<<<<<<<
 *             self.ignoreExprs.extend(expr.ignoreExprs)
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_callPreparse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3759, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_callPreparse, __pyx_t_1) < 0) __PYX_ERR(0, 3759, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3760
 *             self.saveAsList = expr.saveAsList
 *             self.callPreparse = expr.callPreparse
 *             self.ignoreExprs.extend(expr.ignoreExprs)             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3760, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_extend); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3760, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3760, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (!__pyx_t_8) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3760, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_2};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3760, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_2};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3760, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else
      #endif
      {
        __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3760, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_8); __pyx_t_8 = NULL;
        __Pyx_GIVEREF(__pyx_t_2);
        PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_t_2);
        __pyx_t_2 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3760, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3753
 *         self.expr = expr
 *         self.strRepr = None
 *         if expr is not None:             # <<<<<<<<<<<<<<
 *             self.mayIndexError = expr.mayIndexError
 *             self.mayReturnEmpty = expr.mayReturnEmpty
 */
  }

  /* "cPyparsing.pyx":3744
 *     """
 * 
 *     def __init__(self, expr, savelist=False):             # <<<<<<<<<<<<<<
 *         super(ParseElementEnhance, self).__init__(savelist)
 *         if isinstance(expr, basestring):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_expr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3762
 *             self.ignoreExprs.extend(expr.ignoreExprs)
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             return self.expr._parse(instring, loc, doActions, callPreParse=False)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_19ParseElementEnhance_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_19ParseElementEnhance_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3762, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3762, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3762, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3762, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3762, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_19ParseElementEnhance_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":3763
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if self.expr is not None:             # <<<<<<<<<<<<<<
 *             return self.expr._parse(instring, loc, doActions, callPreParse=False)
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__pyx_t_1 != Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":3764
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if self.expr is not None:
 *             return self.expr._parse(instring, loc, doActions, callPreParse=False)             # <<<<<<<<<<<<<<
 *         else:
 *             raise ParseException("", loc, self.errmsg, self)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_parse); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_instring);
    __Pyx_GIVEREF(__pyx_v_instring);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_instring);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_doActions);
    __Pyx_GIVEREF(__pyx_v_doActions);
    PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_doActions);
    __pyx_t_1 = 0;
    __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_callPreParse, Py_False) < 0) __PYX_ERR(0, 3764, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":3763
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if self.expr is not None:             # <<<<<<<<<<<<<<
 *             return self.expr._parse(instring, loc, doActions, callPreParse=False)
 *         else:
 */
  }

  /* "cPyparsing.pyx":3766
 *             return self.expr._parse(instring, loc, doActions, callPreParse=False)
 *         else:
 *             raise ParseException("", loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *     def leaveWhitespace(self):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3766, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3766, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3766, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_8 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[5] = {__pyx_t_7, __pyx_kp_u__9, __pyx_t_5, __pyx_t_4, __pyx_v_self};
      __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_8, 4+__pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3766, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[5] = {__pyx_t_7, __pyx_kp_u__9, __pyx_t_5, __pyx_t_4, __pyx_v_self};
      __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_8, 4+__pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3766, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(4+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3766, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (__pyx_t_7) {
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
      }
      __Pyx_INCREF(__pyx_kp_u__9);
      __Pyx_GIVEREF(__pyx_kp_u__9);
      PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_kp_u__9);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_8, __pyx_t_4);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_9, 3+__pyx_t_8, __pyx_v_self);
      __pyx_t_5 = 0;
      __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_9, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3766, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(0, 3766, __pyx_L1_error)
  }

  /* "cPyparsing.pyx":3762
 *             self.ignoreExprs.extend(expr.ignoreExprs)
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             return self.expr._parse(instring, loc, doActions, callPreParse=False)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3768
 *             raise ParseException("", loc, self.errmsg, self)
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = False
 *         self.expr = self.expr.copy()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_5leaveWhitespace(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_19ParseElementEnhance_5leaveWhitespace = {"leaveWhitespace", (PyCFunction)__pyx_pw_10cPyparsing_19ParseElementEnhance_5leaveWhitespace, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_5leaveWhitespace(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("leaveWhitespace (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_19ParseElementEnhance_4leaveWhitespace(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_4leaveWhitespace(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  __Pyx_RefNannySetupContext("leaveWhitespace", 0);

  /* "cPyparsing.pyx":3769
 * 
 *     def leaveWhitespace(self):
 *         self.skipWhitespace = False             # <<<<<<<<<<<<<<
 *         self.expr = self.expr.copy()
 *         if self.expr is not None:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, Py_False) < 0) __PYX_ERR(0, 3769, __pyx_L1_error)

  /* "cPyparsing.pyx":3770
 *     def leaveWhitespace(self):
 *         self.skipWhitespace = False
 *         self.expr = self.expr.copy()             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             self.expr.leaveWhitespace()
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_copy); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3770, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3770, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_expr, __pyx_t_1) < 0) __PYX_ERR(0, 3770, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3771
 *         self.skipWhitespace = False
 *         self.expr = self.expr.copy()
 *         if self.expr is not None:             # <<<<<<<<<<<<<<
 *             self.expr.leaveWhitespace()
 *         return self
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = (__pyx_t_1 != Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (__pyx_t_4 != 0);
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":3772
 *         self.expr = self.expr.copy()
 *         if self.expr is not None:
 *             self.expr.leaveWhitespace()             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3772, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_leaveWhitespace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3772, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (__pyx_t_3) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3772, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3772, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3771
 *         self.skipWhitespace = False
 *         self.expr = self.expr.copy()
 *         if self.expr is not None:             # <<<<<<<<<<<<<<
 *             self.expr.leaveWhitespace()
 *         return self
 */
  }

  /* "cPyparsing.pyx":3773
 *         if self.expr is not None:
 *             self.expr.leaveWhitespace()
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def ignore(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3768
 *             raise ParseException("", loc, self.errmsg, self)
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = False
 *         self.expr = self.expr.copy()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.leaveWhitespace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3775
 *         return self
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_7ignore(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_19ParseElementEnhance_7ignore = {"ignore", (PyCFunction)__pyx_pw_10cPyparsing_19ParseElementEnhance_7ignore, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_7ignore(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ignore (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ignore", 1, 2, 2, 1); __PYX_ERR(0, 3775, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "ignore") < 0)) __PYX_ERR(0, 3775, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("ignore", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3775, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.ignore", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_19ParseElementEnhance_6ignore(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_6ignore(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("ignore", 0);

  /* "cPyparsing.pyx":3776
 * 
 *     def ignore(self, other):
 *         if isinstance(other, Suppress):             # <<<<<<<<<<<<<<
 *             if other not in self.ignoreExprs:
 *                 super(ParseElementEnhance, self).ignore(other)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Suppress); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 3776, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":3777
 *     def ignore(self, other):
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:             # <<<<<<<<<<<<<<
 *                 super(ParseElementEnhance, self).ignore(other)
 *                 if self.expr is not None:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3777, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_v_other, __pyx_t_1, Py_NE)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 3777, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = (__pyx_t_3 != 0);
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":3778
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:
 *                 super(ParseElementEnhance, self).ignore(other)             # <<<<<<<<<<<<<<
 *                 if self.expr is not None:
 *                     self.expr.ignore(self.ignoreExprs[-1])
 */
      __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3778, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3778, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_self);
      __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_5, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3778, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_ignore); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3778, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (!__pyx_t_4) {
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3778, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
          __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3778, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_1);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
          __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3778, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_1);
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3778, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
          __Pyx_INCREF(__pyx_v_other);
          __Pyx_GIVEREF(__pyx_v_other);
          PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_other);
          __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3778, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":3779
 *             if other not in self.ignoreExprs:
 *                 super(ParseElementEnhance, self).ignore(other)
 *                 if self.expr is not None:             # <<<<<<<<<<<<<<
 *                     self.expr.ignore(self.ignoreExprs[-1])
 *         else:
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3779, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = (__pyx_t_1 != Py_None);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_3 = (__pyx_t_2 != 0);
      if (__pyx_t_3) {

        /* "cPyparsing.pyx":3780
 *                 super(ParseElementEnhance, self).ignore(other)
 *                 if self.expr is not None:
 *                     self.expr.ignore(self.ignoreExprs[-1])             # <<<<<<<<<<<<<<
 *         else:
 *             super(ParseElementEnhance, self).ignore(other)
 */
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3780, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_ignore); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3780, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3780, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_5, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3780, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
          }
        }
        if (!__pyx_t_5) {
          __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3780, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_1);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_6)) {
            PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
            __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3780, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
            PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
            __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3780, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          } else
          #endif
          {
            __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3780, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
            __Pyx_GIVEREF(__pyx_t_4);
            PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_4);
            __pyx_t_4 = 0;
            __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3780, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "cPyparsing.pyx":3779
 *             if other not in self.ignoreExprs:
 *                 super(ParseElementEnhance, self).ignore(other)
 *                 if self.expr is not None:             # <<<<<<<<<<<<<<
 *                     self.expr.ignore(self.ignoreExprs[-1])
 *         else:
 */
      }

      /* "cPyparsing.pyx":3777
 *     def ignore(self, other):
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:             # <<<<<<<<<<<<<<
 *                 super(ParseElementEnhance, self).ignore(other)
 *                 if self.expr is not None:
 */
    }

    /* "cPyparsing.pyx":3776
 * 
 *     def ignore(self, other):
 *         if isinstance(other, Suppress):             # <<<<<<<<<<<<<<
 *             if other not in self.ignoreExprs:
 *                 super(ParseElementEnhance, self).ignore(other)
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":3782
 *                     self.expr.ignore(self.ignoreExprs[-1])
 *         else:
 *             super(ParseElementEnhance, self).ignore(other)             # <<<<<<<<<<<<<<
 *             if self.expr is not None:
 *                 self.expr.ignore(self.ignoreExprs[-1])
 */
  /*else*/ {
    __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3782, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3782, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_v_self);
    __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_7, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3782, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_ignore); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3782, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3782, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3782, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3782, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3782, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_v_other);
        __Pyx_GIVEREF(__pyx_v_other);
        PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_other);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3782, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3783
 *         else:
 *             super(ParseElementEnhance, self).ignore(other)
 *             if self.expr is not None:             # <<<<<<<<<<<<<<
 *                 self.expr.ignore(self.ignoreExprs[-1])
 *         return self
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (__pyx_t_1 != Py_None);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = (__pyx_t_3 != 0);
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":3784
 *             super(ParseElementEnhance, self).ignore(other)
 *             if self.expr is not None:
 *                 self.expr.ignore(self.ignoreExprs[-1])             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3784, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_ignore); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3784, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3784, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_6 = __Pyx_GetItemInt(__pyx_t_7, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3784, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      if (!__pyx_t_7) {
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3784, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_6};
          __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3784, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_6};
          __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3784, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        } else
        #endif
        {
          __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3784, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7); __pyx_t_7 = NULL;
          __Pyx_GIVEREF(__pyx_t_6);
          PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_6);
          __pyx_t_6 = 0;
          __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3784, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":3783
 *         else:
 *             super(ParseElementEnhance, self).ignore(other)
 *             if self.expr is not None:             # <<<<<<<<<<<<<<
 *                 self.expr.ignore(self.ignoreExprs[-1])
 *         return self
 */
    }
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":3785
 *             if self.expr is not None:
 *                 self.expr.ignore(self.ignoreExprs[-1])
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def streamline(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3775
 *         return self
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.ignore", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3787
 *         return self
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(ParseElementEnhance, self).streamline()
 *         if self.expr is not None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_9streamline(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_19ParseElementEnhance_9streamline = {"streamline", (PyCFunction)__pyx_pw_10cPyparsing_19ParseElementEnhance_9streamline, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_9streamline(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("streamline (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_19ParseElementEnhance_8streamline(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_8streamline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  __Pyx_RefNannySetupContext("streamline", 0);

  /* "cPyparsing.pyx":3788
 * 
 *     def streamline(self):
 *         super(ParseElementEnhance, self).streamline()             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             self.expr.streamline()
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_streamline); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3788, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3788, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3789
 *     def streamline(self):
 *         super(ParseElementEnhance, self).streamline()
 *         if self.expr is not None:             # <<<<<<<<<<<<<<
 *             self.expr.streamline()
 *         return self
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = (__pyx_t_1 != Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (__pyx_t_4 != 0);
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":3790
 *         super(ParseElementEnhance, self).streamline()
 *         if self.expr is not None:
 *             self.expr.streamline()             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3790, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_streamline); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3790, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (__pyx_t_3) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3790, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3790, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3789
 *     def streamline(self):
 *         super(ParseElementEnhance, self).streamline()
 *         if self.expr is not None:             # <<<<<<<<<<<<<<
 *             self.expr.streamline()
 *         return self
 */
  }

  /* "cPyparsing.pyx":3791
 *         if self.expr is not None:
 *             self.expr.streamline()
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def checkRecursion(self, parseElementList):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3787
 *         return self
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(ParseElementEnhance, self).streamline()
 *         if self.expr is not None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.streamline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3793
 *         return self
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         if self in parseElementList:
 *             raise RecursiveGrammarException(parseElementList + [self])
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_11checkRecursion(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_19ParseElementEnhance_11checkRecursion = {"checkRecursion", (PyCFunction)__pyx_pw_10cPyparsing_19ParseElementEnhance_11checkRecursion, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_11checkRecursion(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_parseElementList = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("checkRecursion (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_parseElementList,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_parseElementList)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("checkRecursion", 1, 2, 2, 1); __PYX_ERR(0, 3793, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "checkRecursion") < 0)) __PYX_ERR(0, 3793, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_parseElementList = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("checkRecursion", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3793, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.checkRecursion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_19ParseElementEnhance_10checkRecursion(__pyx_self, __pyx_v_self, __pyx_v_parseElementList);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_10checkRecursion(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parseElementList) {
  PyObject *__pyx_v_subRecCheckList = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("checkRecursion", 0);

  /* "cPyparsing.pyx":3794
 * 
 *     def checkRecursion(self, parseElementList):
 *         if self in parseElementList:             # <<<<<<<<<<<<<<
 *             raise RecursiveGrammarException(parseElementList + [self])
 *         subRecCheckList = parseElementList[:] + [self]
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_v_self, __pyx_v_parseElementList, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 3794, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":3795
 *     def checkRecursion(self, parseElementList):
 *         if self in parseElementList:
 *             raise RecursiveGrammarException(parseElementList + [self])             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         if self.expr is not None:
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_RecursiveGrammarException); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3795, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyList_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3795, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyList_SET_ITEM(__pyx_t_5, 0, __pyx_v_self);
    __pyx_t_6 = PyNumber_Add(__pyx_v_parseElementList, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3795, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3795, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_6};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3795, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_6};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3795, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3795, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3795, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 3795, __pyx_L1_error)

    /* "cPyparsing.pyx":3794
 * 
 *     def checkRecursion(self, parseElementList):
 *         if self in parseElementList:             # <<<<<<<<<<<<<<
 *             raise RecursiveGrammarException(parseElementList + [self])
 *         subRecCheckList = parseElementList[:] + [self]
 */
  }

  /* "cPyparsing.pyx":3796
 *         if self in parseElementList:
 *             raise RecursiveGrammarException(parseElementList + [self])
 *         subRecCheckList = parseElementList[:] + [self]             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             self.expr.checkRecursion(subRecCheckList)
 */
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_parseElementList, 0, 0, NULL, NULL, &__pyx_slice__121, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyList_SET_ITEM(__pyx_t_4, 0, __pyx_v_self);
  __pyx_t_7 = PyNumber_Add(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_subRecCheckList = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3797
 *             raise RecursiveGrammarException(parseElementList + [self])
 *         subRecCheckList = parseElementList[:] + [self]
 *         if self.expr is not None:             # <<<<<<<<<<<<<<
 *             self.expr.checkRecursion(subRecCheckList)
 * 
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3797, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = (__pyx_t_7 != Py_None);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":3798
 *         subRecCheckList = parseElementList[:] + [self]
 *         if self.expr is not None:
 *             self.expr.checkRecursion(subRecCheckList)             # <<<<<<<<<<<<<<
 * 
 *     def validate(self, validateTrace=[]):
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3798, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_checkRecursion); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3798, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_subRecCheckList); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3798, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_subRecCheckList};
        __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3798, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_7);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_subRecCheckList};
        __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3798, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_7);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3798, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_subRecCheckList);
        __Pyx_GIVEREF(__pyx_v_subRecCheckList);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_subRecCheckList);
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3798, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":3797
 *             raise RecursiveGrammarException(parseElementList + [self])
 *         subRecCheckList = parseElementList[:] + [self]
 *         if self.expr is not None:             # <<<<<<<<<<<<<<
 *             self.expr.checkRecursion(subRecCheckList)
 * 
 */
  }

  /* "cPyparsing.pyx":3793
 *         return self
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         if self in parseElementList:
 *             raise RecursiveGrammarException(parseElementList + [self])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.checkRecursion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_subRecCheckList);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3800
 *             self.expr.checkRecursion(subRecCheckList)
 * 
 *     def validate(self, validateTrace=[]):             # <<<<<<<<<<<<<<
 *         tmp = validateTrace[:] + [self]
 *         if self.expr is not None:
 */

static PyObject *__pyx_pf_10cPyparsing_101__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults9, __pyx_self)->__pyx_arg_validateTrace);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults9, __pyx_self)->__pyx_arg_validateTrace);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults9, __pyx_self)->__pyx_arg_validateTrace);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_13validate(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_19ParseElementEnhance_13validate = {"validate", (PyCFunction)__pyx_pw_10cPyparsing_19ParseElementEnhance_13validate, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_13validate(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_validateTrace = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("validate (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_validateTrace,0};
    PyObject* values[2] = {0,0};
    __pyx_defaults9 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults9, __pyx_self);
    values[1] = __pyx_dynamic_args->__pyx_arg_validateTrace;
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_validateTrace);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "validate") < 0)) __PYX_ERR(0, 3800, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_validateTrace = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("validate", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3800, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.validate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_19ParseElementEnhance_12validate(__pyx_self, __pyx_v_self, __pyx_v_validateTrace);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_12validate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_validateTrace) {
  PyObject *__pyx_v_tmp = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("validate", 0);

  /* "cPyparsing.pyx":3801
 * 
 *     def validate(self, validateTrace=[]):
 *         tmp = validateTrace[:] + [self]             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             self.expr.validate(tmp)
 */
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_validateTrace, 0, 0, NULL, NULL, &__pyx_slice__122, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3801, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3801, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_self);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3801, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_tmp = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3802
 *     def validate(self, validateTrace=[]):
 *         tmp = validateTrace[:] + [self]
 *         if self.expr is not None:             # <<<<<<<<<<<<<<
 *             self.expr.validate(tmp)
 *         self.checkRecursion([])
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = (__pyx_t_3 != Py_None);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = (__pyx_t_4 != 0);
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":3803
 *         tmp = validateTrace[:] + [self]
 *         if self.expr is not None:
 *             self.expr.validate(tmp)             # <<<<<<<<<<<<<<
 *         self.checkRecursion([])
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3803, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_validate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3803, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (!__pyx_t_2) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_tmp); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3803, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_tmp};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3803, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_tmp};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3803, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3803, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2); __pyx_t_2 = NULL;
        __Pyx_INCREF(__pyx_v_tmp);
        __Pyx_GIVEREF(__pyx_v_tmp);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_tmp);
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3803, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3802
 *     def validate(self, validateTrace=[]):
 *         tmp = validateTrace[:] + [self]
 *         if self.expr is not None:             # <<<<<<<<<<<<<<
 *             self.expr.validate(tmp)
 *         self.checkRecursion([])
 */
  }

  /* "cPyparsing.pyx":3804
 *         if self.expr is not None:
 *             self.expr.validate(tmp)
 *         self.checkRecursion([])             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_checkRecursion); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyList_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3804, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_6};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3804, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_6};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3804, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3804, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3804, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3800
 *             self.expr.checkRecursion(subRecCheckList)
 * 
 *     def validate(self, validateTrace=[]):             # <<<<<<<<<<<<<<
 *         tmp = validateTrace[:] + [self]
 *         if self.expr is not None:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.validate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tmp);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3806
 *         self.checkRecursion([])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(ParseElementEnhance, self).__str__()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_15__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_19ParseElementEnhance_15__str__ = {"__str__", (PyCFunction)__pyx_pw_10cPyparsing_19ParseElementEnhance_15__str__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_19ParseElementEnhance_15__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_19ParseElementEnhance_14__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_19ParseElementEnhance_14__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "cPyparsing.pyx":3807
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(ParseElementEnhance, self).__str__()
 *         except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":3808
 *     def __str__(self):
 *         try:
 *             return super(ParseElementEnhance, self).__str__()             # <<<<<<<<<<<<<<
 *         except Exception:
 *             pass
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3808, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3808, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_self);
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3808, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_str_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3808, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      if (__pyx_t_5) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3808, __pyx_L3_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else {
        __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3808, __pyx_L3_error)
      }
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":3807
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(ParseElementEnhance, self).__str__()
 *         except Exception:
 */
    }
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":3809
 *         try:
 *             return super(ParseElementEnhance, self).__str__()
 *         except Exception:             # <<<<<<<<<<<<<<
 *             pass
 * 
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_7) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cPyparsing.pyx":3807
 * 
 *     def __str__(self):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(ParseElementEnhance, self).__str__()
 *         except Exception:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L4_exception_handled:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
  }

  /* "cPyparsing.pyx":3812
 *             pass
 * 
 *         if self.strRepr is None and self.expr is not None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "%s:(%s)" % (self.__class__.__name__, _ustr(self.expr))
 *         return self.strRepr
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = (__pyx_t_4 == Py_None);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_10 = (__pyx_t_9 != 0);
  if (__pyx_t_10) {
  } else {
    __pyx_t_8 = __pyx_t_10;
    goto __pyx_L12_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = (__pyx_t_4 != Py_None);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_9 = (__pyx_t_10 != 0);
  __pyx_t_8 = __pyx_t_9;
  __pyx_L12_bool_binop_done:;
  if (__pyx_t_8) {

    /* "cPyparsing.pyx":3813
 * 
 *         if self.strRepr is None and self.expr is not None:
 *             self.strRepr = "%s:(%s)" % (self.__class__.__name__, _ustr(self.expr))             # <<<<<<<<<<<<<<
 *         return self.strRepr
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3813, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_name_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3813, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3813, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3813, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_12 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_12)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_12) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_11); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3813, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_11};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3813, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_11};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3813, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3813, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_12); __pyx_t_12 = NULL;
        __Pyx_GIVEREF(__pyx_t_11);
        PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_t_11);
        __pyx_t_11 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_13, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3813, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3813, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_4);
    __pyx_t_6 = 0;
    __pyx_t_4 = 0;
    __pyx_t_4 = PyUnicode_Format(__pyx_kp_u_s_s_5, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3813, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_4) < 0) __PYX_ERR(0, 3813, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":3812
 *             pass
 * 
 *         if self.strRepr is None and self.expr is not None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "%s:(%s)" % (self.__class__.__name__, _ustr(self.expr))
 *         return self.strRepr
 */
  }

  /* "cPyparsing.pyx":3814
 *         if self.strRepr is None and self.expr is not None:
 *             self.strRepr = "%s:(%s)" % (self.__class__.__name__, _ustr(self.expr))
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3806
 *         self.checkRecursion([])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(ParseElementEnhance, self).__str__()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("cPyparsing.ParseElementEnhance.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3835
 *     """
 * 
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(FollowedBy, self).__init__(expr)
 *         self.mayReturnEmpty = True
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10FollowedBy_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10FollowedBy_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_10FollowedBy_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10FollowedBy_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_expr,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_expr)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 3835, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 3835, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_expr = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3835, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.FollowedBy.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10FollowedBy___init__(__pyx_self, __pyx_v_self, __pyx_v_expr);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10FollowedBy___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":3836
 * 
 *     def __init__(self, expr):
 *         super(FollowedBy, self).__init__(expr)             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_FollowedBy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3836, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_expr};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3836, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_expr};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3836, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3836, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_expr);
      __Pyx_GIVEREF(__pyx_v_expr);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_expr);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3836, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3837
 *     def __init__(self, expr):
 *         super(FollowedBy, self).__init__(expr)
 *         self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 3837, __pyx_L1_error)

  /* "cPyparsing.pyx":3835
 *     """
 * 
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(FollowedBy, self).__init__(expr)
 *         self.mayReturnEmpty = True
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.FollowedBy.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3839
 *         self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         self.expr.tryParse(instring, loc)
 *         return loc, []
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10FollowedBy_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10FollowedBy_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_10FollowedBy_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10FollowedBy_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3839, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3839, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3839, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3839, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3839, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.FollowedBy.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10FollowedBy_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10FollowedBy_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":3840
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         self.expr.tryParse(instring, loc)             # <<<<<<<<<<<<<<
 *         return loc, []
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tryParse); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_instring, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3840, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_instring, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3840, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  {
    __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3840, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_INCREF(__pyx_v_instring);
    __Pyx_GIVEREF(__pyx_v_instring);
    PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_v_instring);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3840, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3841
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         self.expr.tryParse(instring, loc)
 *         return loc, []             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_3);
  __pyx_t_1 = 0;
  __pyx_t_3 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3839
 *         self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         self.expr.tryParse(instring, loc)
 *         return loc, []
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.FollowedBy.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3856
 *     """
 * 
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(NotAny, self).__init__(expr)
 *         #~ self.leaveWhitespace()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_6NotAny_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_6NotAny_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_6NotAny_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_6NotAny_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_expr,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_expr)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 3856, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 3856, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_expr = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3856, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.NotAny.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_6NotAny___init__(__pyx_self, __pyx_v_self, __pyx_v_expr);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_6NotAny___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":3857
 * 
 *     def __init__(self, expr):
 *         super(NotAny, self).__init__(expr)             # <<<<<<<<<<<<<<
 *         #~ self.leaveWhitespace()
 *         self.skipWhitespace = False  # do NOT use self.leaveWhitespace(), don't want to propagate to exprs
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_NotAny); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_expr};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3857, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_expr};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3857, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3857, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_expr);
      __Pyx_GIVEREF(__pyx_v_expr);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_expr);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3857, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3859
 *         super(NotAny, self).__init__(expr)
 *         #~ self.leaveWhitespace()
 *         self.skipWhitespace = False  # do NOT use self.leaveWhitespace(), don't want to propagate to exprs             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 *         self.errmsg = "Found unwanted token, " + _ustr(self.expr)
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, Py_False) < 0) __PYX_ERR(0, 3859, __pyx_L1_error)

  /* "cPyparsing.pyx":3860
 *         #~ self.leaveWhitespace()
 *         self.skipWhitespace = False  # do NOT use self.leaveWhitespace(), don't want to propagate to exprs
 *         self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 *         self.errmsg = "Found unwanted token, " + _ustr(self.expr)
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 3860, __pyx_L1_error)

  /* "cPyparsing.pyx":3861
 *         self.skipWhitespace = False  # do NOT use self.leaveWhitespace(), don't want to propagate to exprs
 *         self.mayReturnEmpty = True
 *         self.errmsg = "Found unwanted token, " + _ustr(self.expr)             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3861, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3861, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3861, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3861, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3861, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Add(__pyx_kp_u_Found_unwanted_token, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_3) < 0) __PYX_ERR(0, 3861, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":3856
 *     """
 * 
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(NotAny, self).__init__(expr)
 *         #~ self.leaveWhitespace()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.NotAny.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3863
 *         self.errmsg = "Found unwanted token, " + _ustr(self.expr)
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.expr.canParseNext(instring, loc):
 *             raise ParseException(instring, loc, self.errmsg, self)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_6NotAny_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_6NotAny_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_6NotAny_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_6NotAny_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  CYTHON_UNUSED PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3863, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3863, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3863, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3863, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3863, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.NotAny.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_6NotAny_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_6NotAny_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":3864
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if self.expr.canParseNext(instring, loc):             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 *         return loc, []
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_canParseNext); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_instring, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3864, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_instring, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3864, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  {
    __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3864, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_INCREF(__pyx_v_instring);
    __Pyx_GIVEREF(__pyx_v_instring);
    PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_v_instring);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3864, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 3864, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_7) {

    /* "cPyparsing.pyx":3865
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if self.expr.canParseNext(instring, loc):
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 *         return loc, []
 * 
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3865, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3865, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3865, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[5] = {__pyx_t_4, __pyx_v_instring, __pyx_t_6, __pyx_t_2, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 4+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3865, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[5] = {__pyx_t_4, __pyx_v_instring, __pyx_t_6, __pyx_t_2, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 4+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3865, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_8 = PyTuple_New(4+__pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3865, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (__pyx_t_4) {
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_4); __pyx_t_4 = NULL;
      }
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_5, __pyx_v_instring);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_5, __pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_5, __pyx_t_2);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_8, 3+__pyx_t_5, __pyx_v_self);
      __pyx_t_6 = 0;
      __pyx_t_2 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3865, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 3865, __pyx_L1_error)

    /* "cPyparsing.pyx":3864
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         if self.expr.canParseNext(instring, loc):             # <<<<<<<<<<<<<<
 *             raise ParseException(instring, loc, self.errmsg, self)
 *         return loc, []
 */
  }

  /* "cPyparsing.pyx":3866
 *         if self.expr.canParseNext(instring, loc):
 *             raise ParseException(instring, loc, self.errmsg, self)
 *         return loc, []             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_3);
  __pyx_t_1 = 0;
  __pyx_t_3 = 0;
  __pyx_r = __pyx_t_8;
  __pyx_t_8 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3863
 *         self.errmsg = "Found unwanted token, " + _ustr(self.expr)
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.expr.canParseNext(instring, loc):
 *             raise ParseException(instring, loc, self.errmsg, self)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing.NotAny.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3868
 *         return loc, []
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_6NotAny_5__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_6NotAny_5__str__ = {"__str__", (PyCFunction)__pyx_pw_10cPyparsing_6NotAny_5__str__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_6NotAny_5__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_6NotAny_4__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_6NotAny_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "cPyparsing.pyx":3869
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  __pyx_t_1 = PyObject_HasAttr(__pyx_v_self, __pyx_n_u_name); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 3869, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":3870
 *     def __str__(self):
 *         if hasattr(self, "name"):
 *             return self.name             # <<<<<<<<<<<<<<
 * 
 *         if self.strRepr is None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3870, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":3869
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  }

  /* "cPyparsing.pyx":3872
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "~{" + _ustr(self.expr) + "}"
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = (__pyx_t_3 == Py_None);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":3873
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "~{" + _ustr(self.expr) + "}"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3873, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3873, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3873, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3873, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3873, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Add(__pyx_kp_u__123, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Add(__pyx_t_4, __pyx_kp_u__112); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_3) < 0) __PYX_ERR(0, 3873, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3872
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "~{" + _ustr(self.expr) + "}"
 * 
 */
  }

  /* "cPyparsing.pyx":3875
 *             self.strRepr = "~{" + _ustr(self.expr) + "}"
 * 
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3868
 *         return loc, []
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.NotAny.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3879
 * 
 * class _MultipleMatch(ParseElementEnhance):
 *     def __init__(self, expr, stopOn=None):             # <<<<<<<<<<<<<<
 *         super(_MultipleMatch, self).__init__(expr)
 *         self.saveAsList = True
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_14_MultipleMatch_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_14_MultipleMatch_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_14_MultipleMatch_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_14_MultipleMatch_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_stopOn = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_expr,&__pyx_n_s_stopOn,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_expr)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 3879, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_stopOn);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 3879, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_expr = values[1];
    __pyx_v_stopOn = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3879, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing._MultipleMatch.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_14_MultipleMatch___init__(__pyx_self, __pyx_v_self, __pyx_v_expr, __pyx_v_stopOn);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_14_MultipleMatch___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_stopOn) {
  PyObject *__pyx_v_ender = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":3880
 * class _MultipleMatch(ParseElementEnhance):
 *     def __init__(self, expr, stopOn=None):
 *         super(_MultipleMatch, self).__init__(expr)             # <<<<<<<<<<<<<<
 *         self.saveAsList = True
 *         ender = stopOn
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_MultipleMatch); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3880, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_expr};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3880, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_expr};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3880, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3880, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_expr);
      __Pyx_GIVEREF(__pyx_v_expr);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_expr);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3880, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3881
 *     def __init__(self, expr, stopOn=None):
 *         super(_MultipleMatch, self).__init__(expr)
 *         self.saveAsList = True             # <<<<<<<<<<<<<<
 *         ender = stopOn
 *         if isinstance(ender, basestring):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList, Py_True) < 0) __PYX_ERR(0, 3881, __pyx_L1_error)

  /* "cPyparsing.pyx":3882
 *         super(_MultipleMatch, self).__init__(expr)
 *         self.saveAsList = True
 *         ender = stopOn             # <<<<<<<<<<<<<<
 *         if isinstance(ender, basestring):
 *             ender = ParserElement._literalStringClass(ender)
 */
  __Pyx_INCREF(__pyx_v_stopOn);
  __pyx_v_ender = __pyx_v_stopOn;

  /* "cPyparsing.pyx":3883
 *         self.saveAsList = True
 *         ender = stopOn
 *         if isinstance(ender, basestring):             # <<<<<<<<<<<<<<
 *             ender = ParserElement._literalStringClass(ender)
 *         self.not_ender = ~ender if ender is not None else None
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyObject_IsInstance(__pyx_v_ender, __pyx_t_1); if (unlikely(__pyx_t_5 == -1)) __PYX_ERR(0, 3883, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":3884
 *         ender = stopOn
 *         if isinstance(ender, basestring):
 *             ender = ParserElement._literalStringClass(ender)             # <<<<<<<<<<<<<<
 *         self.not_ender = ~ender if ender is not None else None
 * 
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3884, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3884, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_3) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_ender); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3884, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_ender};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3884, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_ender};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3884, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_2 = PyTuple_New(1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3884, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3); __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_v_ender);
        __Pyx_GIVEREF(__pyx_v_ender);
        PyTuple_SET_ITEM(__pyx_t_2, 0+1, __pyx_v_ender);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3884, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_ender, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3883
 *         self.saveAsList = True
 *         ender = stopOn
 *         if isinstance(ender, basestring):             # <<<<<<<<<<<<<<
 *             ender = ParserElement._literalStringClass(ender)
 *         self.not_ender = ~ender if ender is not None else None
 */
  }

  /* "cPyparsing.pyx":3885
 *         if isinstance(ender, basestring):
 *             ender = ParserElement._literalStringClass(ender)
 *         self.not_ender = ~ender if ender is not None else None             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  __pyx_t_6 = (__pyx_v_ender != Py_None);
  if ((__pyx_t_6 != 0)) {
    __pyx_t_4 = PyNumber_Invert(__pyx_v_ender); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3885, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __pyx_t_4;
    __pyx_t_4 = 0;
  } else {
    __Pyx_INCREF(Py_None);
    __pyx_t_1 = Py_None;
  }
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_not_ender, __pyx_t_1) < 0) __PYX_ERR(0, 3885, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3879
 * 
 * class _MultipleMatch(ParseElementEnhance):
 *     def __init__(self, expr, stopOn=None):             # <<<<<<<<<<<<<<
 *         super(_MultipleMatch, self).__init__(expr)
 *         self.saveAsList = True
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing._MultipleMatch.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ender);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3887
 *         self.not_ender = ~ender if ender is not None else None
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         self_expr_parse = self.expr._parse
 *         self_skip_ignorables = self._skipIgnorables
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_14_MultipleMatch_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_14_MultipleMatch_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_14_MultipleMatch_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_14_MultipleMatch_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3887, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3887, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3887, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3887, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3887, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing._MultipleMatch.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_14_MultipleMatch_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_14_MultipleMatch_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_self_expr_parse = NULL;
  PyObject *__pyx_v_self_skip_ignorables = NULL;
  PyObject *__pyx_v_check_ender = NULL;
  PyObject *__pyx_v_try_not_ender = NULL;
  PyObject *__pyx_v_tokens = NULL;
  int __pyx_v_hasIgnoreExprs;
  PyObject *__pyx_v_preloc = NULL;
  PyObject *__pyx_v_tmptokens = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":3888
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         self_expr_parse = self.expr._parse             # <<<<<<<<<<<<<<
 *         self_skip_ignorables = self._skipIgnorables
 *         check_ender = self.not_ender is not None
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_parse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self_expr_parse = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3889
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         self_expr_parse = self.expr._parse
 *         self_skip_ignorables = self._skipIgnorables             # <<<<<<<<<<<<<<
 *         check_ender = self.not_ender is not None
 *         if check_ender:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_skipIgnorables); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_self_skip_ignorables = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3890
 *         self_expr_parse = self.expr._parse
 *         self_skip_ignorables = self._skipIgnorables
 *         check_ender = self.not_ender is not None             # <<<<<<<<<<<<<<
 *         if check_ender:
 *             try_not_ender = self.not_ender.tryParse
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_not_ender); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = (__pyx_t_2 != Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_check_ender = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3891
 *         self_skip_ignorables = self._skipIgnorables
 *         check_ender = self.not_ender is not None
 *         if check_ender:             # <<<<<<<<<<<<<<
 *             try_not_ender = self.not_ender.tryParse
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_check_ender); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 3891, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":3892
 *         check_ender = self.not_ender is not None
 *         if check_ender:
 *             try_not_ender = self.not_ender.tryParse             # <<<<<<<<<<<<<<
 * 
 *         # must be at least one (but first see if we are the stopOn sentinel;
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_not_ender); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3892, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tryParse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3892, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_try_not_ender = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3891
 *         self_skip_ignorables = self._skipIgnorables
 *         check_ender = self.not_ender is not None
 *         if check_ender:             # <<<<<<<<<<<<<<
 *             try_not_ender = self.not_ender.tryParse
 * 
 */
  }

  /* "cPyparsing.pyx":3896
 *         # must be at least one (but first see if we are the stopOn sentinel;
 *         # if so, fail)
 *         if check_ender:             # <<<<<<<<<<<<<<
 *             try_not_ender(instring, loc)
 *         loc, tokens = self_expr_parse(instring, loc, doActions, callPreParse=False)
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_check_ender); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 3896, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":3897
 *         # if so, fail)
 *         if check_ender:
 *             try_not_ender(instring, loc)             # <<<<<<<<<<<<<<
 *         loc, tokens = self_expr_parse(instring, loc, doActions, callPreParse=False)
 *         try:
 */
    if (unlikely(!__pyx_v_try_not_ender)) { __Pyx_RaiseUnboundLocalError("try_not_ender"); __PYX_ERR(0, 3897, __pyx_L1_error) }
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3897, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_try_not_ender);
    __pyx_t_4 = __pyx_v_try_not_ender; __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_instring, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3897, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_instring, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3897, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3897, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__pyx_t_5) {
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
      }
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_instring);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3897, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":3896
 *         # must be at least one (but first see if we are the stopOn sentinel;
 *         # if so, fail)
 *         if check_ender:             # <<<<<<<<<<<<<<
 *             try_not_ender(instring, loc)
 *         loc, tokens = self_expr_parse(instring, loc, doActions, callPreParse=False)
 */
  }

  /* "cPyparsing.pyx":3898
 *         if check_ender:
 *             try_not_ender(instring, loc)
 *         loc, tokens = self_expr_parse(instring, loc, doActions, callPreParse=False)             # <<<<<<<<<<<<<<
 *         try:
 *             hasIgnoreExprs = (not not self.ignoreExprs)
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_instring);
  __Pyx_GIVEREF(__pyx_v_instring);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_instring);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
  __Pyx_INCREF(__pyx_v_doActions);
  __Pyx_GIVEREF(__pyx_v_doActions);
  PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_v_doActions);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_callPreParse, Py_False) < 0) __PYX_ERR(0, 3898, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_v_self_expr_parse, __pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_7))) || (PyList_CheckExact(__pyx_t_7))) {
    PyObject* sequence = __pyx_t_7;
    #if !CYTHON_COMPILING_IN_PYPY
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 3898, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3898, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3898, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_2 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3898, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_8 = Py_TYPE(__pyx_t_2)->tp_iternext;
    index = 0; __pyx_t_1 = __pyx_t_8(__pyx_t_2); if (unlikely(!__pyx_t_1)) goto __pyx_L5_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_1);
    index = 1; __pyx_t_4 = __pyx_t_8(__pyx_t_2); if (unlikely(!__pyx_t_4)) goto __pyx_L5_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_2), 2) < 0) __PYX_ERR(0, 3898, __pyx_L1_error)
    __pyx_t_8 = NULL;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L6_unpacking_done;
    __pyx_L5_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_8 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 3898, __pyx_L1_error)
    __pyx_L6_unpacking_done:;
  }
  __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3898, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_loc = __pyx_t_6;
  __pyx_v_tokens = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":3899
 *             try_not_ender(instring, loc)
 *         loc, tokens = self_expr_parse(instring, loc, doActions, callPreParse=False)
 *         try:             # <<<<<<<<<<<<<<
 *             hasIgnoreExprs = (not not self.ignoreExprs)
 *             while True:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
    __Pyx_XGOTREF(__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_11);
    /*try:*/ {

      /* "cPyparsing.pyx":3900
 *         loc, tokens = self_expr_parse(instring, loc, doActions, callPreParse=False)
 *         try:
 *             hasIgnoreExprs = (not not self.ignoreExprs)             # <<<<<<<<<<<<<<
 *             while True:
 *                 if check_ender:
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3900, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 3900, __pyx_L7_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_v_hasIgnoreExprs = (!((!__pyx_t_3) != 0));

      /* "cPyparsing.pyx":3901
 *         try:
 *             hasIgnoreExprs = (not not self.ignoreExprs)
 *             while True:             # <<<<<<<<<<<<<<
 *                 if check_ender:
 *                     try_not_ender(instring, loc)
 */
      while (1) {

        /* "cPyparsing.pyx":3902
 *             hasIgnoreExprs = (not not self.ignoreExprs)
 *             while True:
 *                 if check_ender:             # <<<<<<<<<<<<<<
 *                     try_not_ender(instring, loc)
 *                 if hasIgnoreExprs:
 */
        __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_check_ender); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 3902, __pyx_L7_error)
        if (__pyx_t_3) {

          /* "cPyparsing.pyx":3903
 *             while True:
 *                 if check_ender:
 *                     try_not_ender(instring, loc)             # <<<<<<<<<<<<<<
 *                 if hasIgnoreExprs:
 *                     preloc = self_skip_ignorables(instring, loc)
 */
          if (unlikely(!__pyx_v_try_not_ender)) { __Pyx_RaiseUnboundLocalError("try_not_ender"); __PYX_ERR(0, 3903, __pyx_L7_error) }
          __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3903, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_INCREF(__pyx_v_try_not_ender);
          __pyx_t_1 = __pyx_v_try_not_ender; __pyx_t_2 = NULL;
          __pyx_t_6 = 0;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_2)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_2);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
              __pyx_t_6 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_1)) {
            PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_instring, __pyx_t_4};
            __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3903, __pyx_L7_error)
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
            PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_instring, __pyx_t_4};
            __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3903, __pyx_L7_error)
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          } else
          #endif
          {
            __pyx_t_5 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3903, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_5);
            if (__pyx_t_2) {
              __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2); __pyx_t_2 = NULL;
            }
            __Pyx_INCREF(__pyx_v_instring);
            __Pyx_GIVEREF(__pyx_v_instring);
            PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_6, __pyx_v_instring);
            __Pyx_GIVEREF(__pyx_t_4);
            PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_6, __pyx_t_4);
            __pyx_t_4 = 0;
            __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3903, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

          /* "cPyparsing.pyx":3902
 *             hasIgnoreExprs = (not not self.ignoreExprs)
 *             while True:
 *                 if check_ender:             # <<<<<<<<<<<<<<
 *                     try_not_ender(instring, loc)
 *                 if hasIgnoreExprs:
 */
        }

        /* "cPyparsing.pyx":3904
 *                 if check_ender:
 *                     try_not_ender(instring, loc)
 *                 if hasIgnoreExprs:             # <<<<<<<<<<<<<<
 *                     preloc = self_skip_ignorables(instring, loc)
 *                 else:
 */
        __pyx_t_3 = (__pyx_v_hasIgnoreExprs != 0);
        if (__pyx_t_3) {

          /* "cPyparsing.pyx":3905
 *                     try_not_ender(instring, loc)
 *                 if hasIgnoreExprs:
 *                     preloc = self_skip_ignorables(instring, loc)             # <<<<<<<<<<<<<<
 *                 else:
 *                     preloc = loc
 */
          __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3905, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_INCREF(__pyx_v_self_skip_ignorables);
          __pyx_t_5 = __pyx_v_self_skip_ignorables; __pyx_t_4 = NULL;
          __pyx_t_6 = 0;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
            __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
            if (likely(__pyx_t_4)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
              __Pyx_INCREF(__pyx_t_4);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_5, function);
              __pyx_t_6 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_5)) {
            PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_instring, __pyx_t_1};
            __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3905, __pyx_L7_error)
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
            PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_instring, __pyx_t_1};
            __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3905, __pyx_L7_error)
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          } else
          #endif
          {
            __pyx_t_2 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3905, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_2);
            if (__pyx_t_4) {
              __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_4); __pyx_t_4 = NULL;
            }
            __Pyx_INCREF(__pyx_v_instring);
            __Pyx_GIVEREF(__pyx_v_instring);
            PyTuple_SET_ITEM(__pyx_t_2, 0+__pyx_t_6, __pyx_v_instring);
            __Pyx_GIVEREF(__pyx_t_1);
            PyTuple_SET_ITEM(__pyx_t_2, 1+__pyx_t_6, __pyx_t_1);
            __pyx_t_1 = 0;
            __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_2, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3905, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          }
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF_SET(__pyx_v_preloc, __pyx_t_7);
          __pyx_t_7 = 0;

          /* "cPyparsing.pyx":3904
 *                 if check_ender:
 *                     try_not_ender(instring, loc)
 *                 if hasIgnoreExprs:             # <<<<<<<<<<<<<<
 *                     preloc = self_skip_ignorables(instring, loc)
 *                 else:
 */
          goto __pyx_L18;
        }

        /* "cPyparsing.pyx":3907
 *                     preloc = self_skip_ignorables(instring, loc)
 *                 else:
 *                     preloc = loc             # <<<<<<<<<<<<<<
 *                 loc, tmptokens = self_expr_parse(instring, preloc, doActions)
 *                 if tmptokens or tmptokens.haskeys():
 */
        /*else*/ {
          __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3907, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_XDECREF_SET(__pyx_v_preloc, __pyx_t_7);
          __pyx_t_7 = 0;
        }
        __pyx_L18:;

        /* "cPyparsing.pyx":3908
 *                 else:
 *                     preloc = loc
 *                 loc, tmptokens = self_expr_parse(instring, preloc, doActions)             # <<<<<<<<<<<<<<
 *                 if tmptokens or tmptokens.haskeys():
 *                     tokens += tmptokens
 */
        __Pyx_INCREF(__pyx_v_self_expr_parse);
        __pyx_t_5 = __pyx_v_self_expr_parse; __pyx_t_2 = NULL;
        __pyx_t_6 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_2)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_2);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_6 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[4] = {__pyx_t_2, __pyx_v_instring, __pyx_v_preloc, __pyx_v_doActions};
          __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3908, __pyx_L7_error)
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_GOTREF(__pyx_t_7);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[4] = {__pyx_t_2, __pyx_v_instring, __pyx_v_preloc, __pyx_v_doActions};
          __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3908, __pyx_L7_error)
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_GOTREF(__pyx_t_7);
        } else
        #endif
        {
          __pyx_t_1 = PyTuple_New(3+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3908, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_1);
          if (__pyx_t_2) {
            __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2); __pyx_t_2 = NULL;
          }
          __Pyx_INCREF(__pyx_v_instring);
          __Pyx_GIVEREF(__pyx_v_instring);
          PyTuple_SET_ITEM(__pyx_t_1, 0+__pyx_t_6, __pyx_v_instring);
          __Pyx_INCREF(__pyx_v_preloc);
          __Pyx_GIVEREF(__pyx_v_preloc);
          PyTuple_SET_ITEM(__pyx_t_1, 1+__pyx_t_6, __pyx_v_preloc);
          __Pyx_INCREF(__pyx_v_doActions);
          __Pyx_GIVEREF(__pyx_v_doActions);
          PyTuple_SET_ITEM(__pyx_t_1, 2+__pyx_t_6, __pyx_v_doActions);
          __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_1, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3908, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if ((likely(PyTuple_CheckExact(__pyx_t_7))) || (PyList_CheckExact(__pyx_t_7))) {
          PyObject* sequence = __pyx_t_7;
          #if !CYTHON_COMPILING_IN_PYPY
          Py_ssize_t size = Py_SIZE(sequence);
          #else
          Py_ssize_t size = PySequence_Size(sequence);
          #endif
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 3908, __pyx_L7_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1); 
          } else {
            __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_1 = PyList_GET_ITEM(sequence, 1); 
          }
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_1);
          #else
          __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3908, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_1 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3908, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_2 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3908, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_8 = Py_TYPE(__pyx_t_2)->tp_iternext;
          index = 0; __pyx_t_5 = __pyx_t_8(__pyx_t_2); if (unlikely(!__pyx_t_5)) goto __pyx_L19_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_5);
          index = 1; __pyx_t_1 = __pyx_t_8(__pyx_t_2); if (unlikely(!__pyx_t_1)) goto __pyx_L19_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_1);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_2), 2) < 0) __PYX_ERR(0, 3908, __pyx_L7_error)
          __pyx_t_8 = NULL;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          goto __pyx_L20_unpacking_done;
          __pyx_L19_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_8 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 3908, __pyx_L7_error)
          __pyx_L20_unpacking_done:;
        }
        __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_t_5); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3908, __pyx_L7_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_v_loc = __pyx_t_6;
        __Pyx_XDECREF_SET(__pyx_v_tmptokens, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "cPyparsing.pyx":3909
 *                     preloc = loc
 *                 loc, tmptokens = self_expr_parse(instring, preloc, doActions)
 *                 if tmptokens or tmptokens.haskeys():             # <<<<<<<<<<<<<<
 *                     tokens += tmptokens
 *         except (ParseException, IndexError):
 */
        __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_tmptokens); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 3909, __pyx_L7_error)
        if (!__pyx_t_12) {
        } else {
          __pyx_t_3 = __pyx_t_12;
          goto __pyx_L22_bool_binop_done;
        }
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_tmptokens, __pyx_n_s_haskeys); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3909, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_5 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_1, function);
          }
        }
        if (__pyx_t_5) {
          __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3909, __pyx_L7_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else {
          __pyx_t_7 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3909, __pyx_L7_error)
        }
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 3909, __pyx_L7_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_3 = __pyx_t_12;
        __pyx_L22_bool_binop_done:;
        if (__pyx_t_3) {

          /* "cPyparsing.pyx":3910
 *                 loc, tmptokens = self_expr_parse(instring, preloc, doActions)
 *                 if tmptokens or tmptokens.haskeys():
 *                     tokens += tmptokens             # <<<<<<<<<<<<<<
 *         except (ParseException, IndexError):
 *             pass
 */
          __pyx_t_7 = PyNumber_InPlaceAdd(__pyx_v_tokens, __pyx_v_tmptokens); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3910, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF_SET(__pyx_v_tokens, __pyx_t_7);
          __pyx_t_7 = 0;

          /* "cPyparsing.pyx":3909
 *                     preloc = loc
 *                 loc, tmptokens = self_expr_parse(instring, preloc, doActions)
 *                 if tmptokens or tmptokens.haskeys():             # <<<<<<<<<<<<<<
 *                     tokens += tmptokens
 *         except (ParseException, IndexError):
 */
        }
      }

      /* "cPyparsing.pyx":3899
 *             try_not_ender(instring, loc)
 *         loc, tokens = self_expr_parse(instring, loc, doActions, callPreParse=False)
 *         try:             # <<<<<<<<<<<<<<
 *             hasIgnoreExprs = (not not self.ignoreExprs)
 *             while True:
 */
    }
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    goto __pyx_L14_try_end;
    __pyx_L7_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":3911
 *                 if tmptokens or tmptokens.haskeys():
 *                     tokens += tmptokens
 *         except (ParseException, IndexError):             # <<<<<<<<<<<<<<
 *             pass
 * 
 */
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3911, __pyx_L9_except_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_t_7) || __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (__pyx_t_6) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L8_exception_handled;
    }
    goto __pyx_L9_except_error;
    __pyx_L9_except_error:;

    /* "cPyparsing.pyx":3899
 *             try_not_ender(instring, loc)
 *         loc, tokens = self_expr_parse(instring, loc, doActions, callPreParse=False)
 *         try:             # <<<<<<<<<<<<<<
 *             hasIgnoreExprs = (not not self.ignoreExprs)
 *             while True:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_11);
    __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
    goto __pyx_L1_error;
    __pyx_L8_exception_handled:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_11);
    __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
    __pyx_L14_try_end:;
  }

  /* "cPyparsing.pyx":3914
 *             pass
 * 
 *         return loc, tokens             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_7);
  __Pyx_INCREF(__pyx_v_tokens);
  __Pyx_GIVEREF(__pyx_v_tokens);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_tokens);
  __pyx_t_7 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3887
 *         self.not_ender = ~ender if ender is not None else None
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         self_expr_parse = self.expr._parse
 *         self_skip_ignorables = self._skipIgnorables
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing._MultipleMatch.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_self_expr_parse);
  __Pyx_XDECREF(__pyx_v_self_skip_ignorables);
  __Pyx_XDECREF(__pyx_v_check_ender);
  __Pyx_XDECREF(__pyx_v_try_not_ender);
  __Pyx_XDECREF(__pyx_v_tokens);
  __Pyx_XDECREF(__pyx_v_preloc);
  __Pyx_XDECREF(__pyx_v_tmptokens);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3943
 *     """
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_9OneOrMore_1__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_9OneOrMore_1__str__ = {"__str__", (PyCFunction)__pyx_pw_10cPyparsing_9OneOrMore_1__str__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_9OneOrMore_1__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_9OneOrMore___str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_9OneOrMore___str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "cPyparsing.pyx":3944
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  __pyx_t_1 = PyObject_HasAttr(__pyx_v_self, __pyx_n_u_name); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 3944, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":3945
 *     def __str__(self):
 *         if hasattr(self, "name"):
 *             return self.name             # <<<<<<<<<<<<<<
 * 
 *         if self.strRepr is None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3945, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":3944
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  }

  /* "cPyparsing.pyx":3947
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "{" + _ustr(self.expr) + "}..."
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3947, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = (__pyx_t_3 == Py_None);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":3948
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "{" + _ustr(self.expr) + "}..."             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3948, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3948, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3948, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3948, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3948, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3948, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3948, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Add(__pyx_kp_u__111, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3948, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Add(__pyx_t_4, __pyx_kp_u__124); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3948, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_3) < 0) __PYX_ERR(0, 3948, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3947
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "{" + _ustr(self.expr) + "}..."
 * 
 */
  }

  /* "cPyparsing.pyx":3950
 *             self.strRepr = "{" + _ustr(self.expr) + "}..."
 * 
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3943
 *     """
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.OneOrMore.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3966
 *     """
 * 
 *     def __init__(self, expr, stopOn=None):             # <<<<<<<<<<<<<<
 *         super(ZeroOrMore, self).__init__(expr, stopOn=stopOn)
 *         self.mayReturnEmpty = True
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10ZeroOrMore_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10ZeroOrMore_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_10ZeroOrMore_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10ZeroOrMore_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_stopOn = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_expr,&__pyx_n_s_stopOn,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_expr)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 3966, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_stopOn);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 3966, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_expr = values[1];
    __pyx_v_stopOn = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3966, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ZeroOrMore.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10ZeroOrMore___init__(__pyx_self, __pyx_v_self, __pyx_v_expr, __pyx_v_stopOn);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10ZeroOrMore___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_stopOn) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":3967
 * 
 *     def __init__(self, expr, stopOn=None):
 *         super(ZeroOrMore, self).__init__(expr, stopOn=stopOn)             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 * 
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_self);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_expr);
  __Pyx_GIVEREF(__pyx_v_expr);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_expr);
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_stopOn, __pyx_v_stopOn) < 0) __PYX_ERR(0, 3967, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":3968
 *     def __init__(self, expr, stopOn=None):
 *         super(ZeroOrMore, self).__init__(expr, stopOn=stopOn)
 *         self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 3968, __pyx_L1_error)

  /* "cPyparsing.pyx":3966
 *     """
 * 
 *     def __init__(self, expr, stopOn=None):             # <<<<<<<<<<<<<<
 *         super(ZeroOrMore, self).__init__(expr, stopOn=stopOn)
 *         self.mayReturnEmpty = True
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.ZeroOrMore.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3970
 *         self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(ZeroOrMore, self).parseImpl(instring, loc, doActions)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10ZeroOrMore_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10ZeroOrMore_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_10ZeroOrMore_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_10ZeroOrMore_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 3970, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 3970, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 3970, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3970, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 3970, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.ZeroOrMore.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_10ZeroOrMore_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10ZeroOrMore_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, PyObject *__pyx_v_doActions) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":3971
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(ZeroOrMore, self).parseImpl(instring, loc, doActions)
 *         except (ParseException, IndexError):
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":3972
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         try:
 *             return super(ZeroOrMore, self).parseImpl(instring, loc, doActions)             # <<<<<<<<<<<<<<
 *         except (ParseException, IndexError):
 *             return loc, []
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3972, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3972, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_self);
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3972, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_parseImpl); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3972, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3972, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = NULL;
      __pyx_t_8 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_8 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_v_instring, __pyx_t_5, __pyx_v_doActions};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_8, 3+__pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3972, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_v_instring, __pyx_t_5, __pyx_v_doActions};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_8, 3+__pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3972, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(3+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3972, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_9);
        if (__pyx_t_7) {
          __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
        }
        __Pyx_INCREF(__pyx_v_instring);
        __Pyx_GIVEREF(__pyx_v_instring);
        PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_v_instring);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, __pyx_t_5);
        __Pyx_INCREF(__pyx_v_doActions);
        __Pyx_GIVEREF(__pyx_v_doActions);
        PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_8, __pyx_v_doActions);
        __pyx_t_5 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_9, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3972, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":3971
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(ZeroOrMore, self).parseImpl(instring, loc, doActions)
 *         except (ParseException, IndexError):
 */
    }
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":3973
 *         try:
 *             return super(ZeroOrMore, self).parseImpl(instring, loc, doActions)
 *         except (ParseException, IndexError):             # <<<<<<<<<<<<<<
 *             return loc, []
 * 
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3973, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_t_4) || __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_8) {
      __Pyx_AddTraceback("cPyparsing.ZeroOrMore.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_9) < 0) __PYX_ERR(0, 3973, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_9);

      /* "cPyparsing.pyx":3974
 *             return super(ZeroOrMore, self).parseImpl(instring, loc, doActions)
 *         except (ParseException, IndexError):
 *             return loc, []             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3974, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = PyList_New(0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3974, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3974, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_7);
      __pyx_t_5 = 0;
      __pyx_t_7 = 0;
      __pyx_r = __pyx_t_10;
      __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cPyparsing.pyx":3971
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         try:             # <<<<<<<<<<<<<<
 *             return super(ZeroOrMore, self).parseImpl(instring, loc, doActions)
 *         except (ParseException, IndexError):
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":3970
 *         self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(ZeroOrMore, self).parseImpl(instring, loc, doActions)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("cPyparsing.ZeroOrMore.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3976
 *             return loc, []
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10ZeroOrMore_5__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10ZeroOrMore_5__str__ = {"__str__", (PyCFunction)__pyx_pw_10cPyparsing_10ZeroOrMore_5__str__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_10ZeroOrMore_5__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_10ZeroOrMore_4__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10ZeroOrMore_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "cPyparsing.pyx":3977
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  __pyx_t_1 = PyObject_HasAttr(__pyx_v_self, __pyx_n_u_name); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 3977, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":3978
 *     def __str__(self):
 *         if hasattr(self, "name"):
 *             return self.name             # <<<<<<<<<<<<<<
 * 
 *         if self.strRepr is None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3978, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":3977
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  }

  /* "cPyparsing.pyx":3980
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "[" + _ustr(self.expr) + "]..."
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = (__pyx_t_3 == Py_None);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":3981
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "[" + _ustr(self.expr) + "]..."             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3981, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3981, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3981, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3981, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3981, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3981, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3981, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Add(__pyx_kp_u__16, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3981, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Add(__pyx_t_4, __pyx_kp_u__125); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3981, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_3) < 0) __PYX_ERR(0, 3981, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":3980
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "[" + _ustr(self.expr) + "]..."
 * 
 */
  }

  /* "cPyparsing.pyx":3983
 *             self.strRepr = "[" + _ustr(self.expr) + "]..."
 * 
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3976
 *             return loc, []
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.ZeroOrMore.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3987
 * 
 * class _NullToken(object):
 *     def __bool__(self):             # <<<<<<<<<<<<<<
 *         return False
 *     __nonzero__ = __bool__
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_NullToken_1__bool__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10_NullToken_1__bool__ = {"__bool__", (PyCFunction)__pyx_pw_10cPyparsing_10_NullToken_1__bool__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_10_NullToken_1__bool__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__bool__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_10_NullToken___bool__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_NullToken___bool__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__bool__", 0);

  /* "cPyparsing.pyx":3988
 * class _NullToken(object):
 *     def __bool__(self):
 *         return False             # <<<<<<<<<<<<<<
 *     __nonzero__ = __bool__
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_False);
  __pyx_r = Py_False;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3987
 * 
 * class _NullToken(object):
 *     def __bool__(self):             # <<<<<<<<<<<<<<
 *         return False
 *     __nonzero__ = __bool__
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":3991
 *     __nonzero__ = __bool__
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10_NullToken_3__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10_NullToken_3__str__ = {"__str__", (PyCFunction)__pyx_pw_10cPyparsing_10_NullToken_3__str__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_10_NullToken_3__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_10_NullToken_2__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_10_NullToken_2__str__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "cPyparsing.pyx":3992
 * 
 *     def __str__(self):
 *         return ""             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u__9);
  __pyx_r = __pyx_kp_u__9;
  goto __pyx_L0;

  /* "cPyparsing.pyx":3991
 *     __nonzero__ = __bool__
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4034
 *     """
 * 
 *     def __init__(self, expr, default=_optionalNotMatched):             # <<<<<<<<<<<<<<
 *         super(Optional, self).__init__(expr, savelist=False)
 *         self.saveAsList = self.expr.saveAsList
 */

static PyObject *__pyx_pf_10cPyparsing_103__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults10, __pyx_self)->__pyx_arg_default);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults10, __pyx_self)->__pyx_arg_default);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults10, __pyx_self)->__pyx_arg_default);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_8Optional_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_8Optional_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_8Optional_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_8Optional_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_default = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_expr,&__pyx_n_s_default,0};
    PyObject* values[3] = {0,0,0};
    __pyx_defaults10 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults10, __pyx_self);
    values[2] = __pyx_dynamic_args->__pyx_arg_default;
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_expr)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 4034, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_default);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 4034, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_expr = values[1];
    __pyx_v_default = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4034, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Optional.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_8Optional___init__(__pyx_self, __pyx_v_self, __pyx_v_expr, __pyx_v_default);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_8Optional___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_default) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":4035
 * 
 *     def __init__(self, expr, default=_optionalNotMatched):
 *         super(Optional, self).__init__(expr, savelist=False)             # <<<<<<<<<<<<<<
 *         self.saveAsList = self.expr.saveAsList
 *         self.defaultValue = default
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_self);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_expr);
  __Pyx_GIVEREF(__pyx_v_expr);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_expr);
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_savelist, Py_False) < 0) __PYX_ERR(0, 4035, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":4036
 *     def __init__(self, expr, default=_optionalNotMatched):
 *         super(Optional, self).__init__(expr, savelist=False)
 *         self.saveAsList = self.expr.saveAsList             # <<<<<<<<<<<<<<
 *         self.defaultValue = default
 *         self.mayReturnEmpty = True
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList, __pyx_t_3) < 0) __PYX_ERR(0, 4036, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4037
 *         super(Optional, self).__init__(expr, savelist=False)
 *         self.saveAsList = self.expr.saveAsList
 *         self.defaultValue = default             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = True
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_defaultValue, __pyx_v_default) < 0) __PYX_ERR(0, 4037, __pyx_L1_error)

  /* "cPyparsing.pyx":4038
 *         self.saveAsList = self.expr.saveAsList
 *         self.defaultValue = default
 *         self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 4038, __pyx_L1_error)

  /* "cPyparsing.pyx":4034
 *     """
 * 
 *     def __init__(self, expr, default=_optionalNotMatched):             # <<<<<<<<<<<<<<
 *         super(Optional, self).__init__(expr, savelist=False)
 *         self.saveAsList = self.expr.saveAsList
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.Optional.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4040
 *         self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         try:
 *             loc, tokens = self.expr._parse(instring, loc, doActions, callPreParse=False)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_8Optional_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_8Optional_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_8Optional_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_8Optional_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 4040, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 4040, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 4040, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4040, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4040, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Optional.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_8Optional_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_8Optional_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, PyObject *__pyx_v_doActions) {
  PyObject *__pyx_v_tokens = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":4041
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         try:             # <<<<<<<<<<<<<<
 *             loc, tokens = self.expr._parse(instring, loc, doActions, callPreParse=False)
 *         except (ParseException, IndexError):
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":4042
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         try:
 *             loc, tokens = self.expr._parse(instring, loc, doActions, callPreParse=False)             # <<<<<<<<<<<<<<
 *         except (ParseException, IndexError):
 *             if self.defaultValue is not _optionalNotMatched:
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4042, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_parse); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4042, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4042, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4042, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_instring);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4);
      __Pyx_INCREF(__pyx_v_doActions);
      __Pyx_GIVEREF(__pyx_v_doActions);
      PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_v_doActions);
      __pyx_t_4 = 0;
      __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4042, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_callPreParse, Py_False) < 0) __PYX_ERR(0, 4042, __pyx_L3_error)
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4042, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if ((likely(PyTuple_CheckExact(__pyx_t_7))) || (PyList_CheckExact(__pyx_t_7))) {
        PyObject* sequence = __pyx_t_7;
        #if !CYTHON_COMPILING_IN_PYPY
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 4042, __pyx_L3_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        #else
        __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4042, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4042, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_5 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4042, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_8 = Py_TYPE(__pyx_t_5)->tp_iternext;
        index = 0; __pyx_t_4 = __pyx_t_8(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L11_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_4);
        index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_5); if (unlikely(!__pyx_t_6)) goto __pyx_L11_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_6);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_5), 2) < 0) __PYX_ERR(0, 4042, __pyx_L3_error)
        __pyx_t_8 = NULL;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        goto __pyx_L12_unpacking_done;
        __pyx_L11_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_8 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 4042, __pyx_L3_error)
        __pyx_L12_unpacking_done:;
      }
      __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_t_4); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4042, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_loc = __pyx_t_9;
      __pyx_v_tokens = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "cPyparsing.pyx":4041
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         try:             # <<<<<<<<<<<<<<
 *             loc, tokens = self.expr._parse(instring, loc, doActions, callPreParse=False)
 *         except (ParseException, IndexError):
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L10_try_end;
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":4043
 *         try:
 *             loc, tokens = self.expr._parse(instring, loc, doActions, callPreParse=False)
 *         except (ParseException, IndexError):             # <<<<<<<<<<<<<<
 *             if self.defaultValue is not _optionalNotMatched:
 *                 if self.expr.resultsName:
 */
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4043, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(__pyx_t_7) || __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (__pyx_t_9) {
      __Pyx_AddTraceback("cPyparsing.Optional.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_6, &__pyx_t_4) < 0) __PYX_ERR(0, 4043, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_4);

      /* "cPyparsing.pyx":4044
 *             loc, tokens = self.expr._parse(instring, loc, doActions, callPreParse=False)
 *         except (ParseException, IndexError):
 *             if self.defaultValue is not _optionalNotMatched:             # <<<<<<<<<<<<<<
 *                 if self.expr.resultsName:
 *                     tokens = ParseResults([self.defaultValue])
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_defaultValue); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4044, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_10 = __Pyx_GetModuleGlobalName(__pyx_n_s_optionalNotMatched); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4044, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_11 = (__pyx_t_5 != __pyx_t_10);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_12 = (__pyx_t_11 != 0);
      if (__pyx_t_12) {

        /* "cPyparsing.pyx":4045
 *         except (ParseException, IndexError):
 *             if self.defaultValue is not _optionalNotMatched:
 *                 if self.expr.resultsName:             # <<<<<<<<<<<<<<
 *                     tokens = ParseResults([self.defaultValue])
 *                     tokens[self.expr.resultsName] = self.defaultValue
 */
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4045, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4045, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 4045, __pyx_L5_except_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (__pyx_t_12) {

          /* "cPyparsing.pyx":4046
 *             if self.defaultValue is not _optionalNotMatched:
 *                 if self.expr.resultsName:
 *                     tokens = ParseResults([self.defaultValue])             # <<<<<<<<<<<<<<
 *                     tokens[self.expr.resultsName] = self.defaultValue
 *                 else:
 */
          __pyx_t_10 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4046, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_defaultValue); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4046, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_14 = PyList_New(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4046, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_GIVEREF(__pyx_t_13);
          PyList_SET_ITEM(__pyx_t_14, 0, __pyx_t_13);
          __pyx_t_13 = 0;
          __pyx_t_13 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
            __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_10);
            if (likely(__pyx_t_13)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
              __Pyx_INCREF(__pyx_t_13);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_10, function);
            }
          }
          if (!__pyx_t_13) {
            __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_14); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4046, __pyx_L5_except_error)
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_GOTREF(__pyx_t_5);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_10)) {
              PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_14};
              __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4046, __pyx_L5_except_error)
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
              PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_14};
              __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4046, __pyx_L5_except_error)
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            } else
            #endif
            {
              __pyx_t_15 = PyTuple_New(1+1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 4046, __pyx_L5_except_error)
              __Pyx_GOTREF(__pyx_t_15);
              __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_13); __pyx_t_13 = NULL;
              __Pyx_GIVEREF(__pyx_t_14);
              PyTuple_SET_ITEM(__pyx_t_15, 0+1, __pyx_t_14);
              __pyx_t_14 = 0;
              __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_15, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4046, __pyx_L5_except_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF_SET(__pyx_v_tokens, __pyx_t_5);
          __pyx_t_5 = 0;

          /* "cPyparsing.pyx":4047
 *                 if self.expr.resultsName:
 *                     tokens = ParseResults([self.defaultValue])
 *                     tokens[self.expr.resultsName] = self.defaultValue             # <<<<<<<<<<<<<<
 *                 else:
 *                     tokens = [self.defaultValue]
 */
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_defaultValue); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4047, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4047, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 4047, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_15);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely(PyObject_SetItem(__pyx_v_tokens, __pyx_t_15, __pyx_t_5) < 0)) __PYX_ERR(0, 4047, __pyx_L5_except_error)
          __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "cPyparsing.pyx":4045
 *         except (ParseException, IndexError):
 *             if self.defaultValue is not _optionalNotMatched:
 *                 if self.expr.resultsName:             # <<<<<<<<<<<<<<
 *                     tokens = ParseResults([self.defaultValue])
 *                     tokens[self.expr.resultsName] = self.defaultValue
 */
          goto __pyx_L16;
        }

        /* "cPyparsing.pyx":4049
 *                     tokens[self.expr.resultsName] = self.defaultValue
 *                 else:
 *                     tokens = [self.defaultValue]             # <<<<<<<<<<<<<<
 *             else:
 *                 tokens = []
 */
        /*else*/ {
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_defaultValue); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4049, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_15 = PyList_New(1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 4049, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_15);
          __Pyx_GIVEREF(__pyx_t_5);
          PyList_SET_ITEM(__pyx_t_15, 0, __pyx_t_5);
          __pyx_t_5 = 0;
          __Pyx_XDECREF_SET(__pyx_v_tokens, __pyx_t_15);
          __pyx_t_15 = 0;
        }
        __pyx_L16:;

        /* "cPyparsing.pyx":4044
 *             loc, tokens = self.expr._parse(instring, loc, doActions, callPreParse=False)
 *         except (ParseException, IndexError):
 *             if self.defaultValue is not _optionalNotMatched:             # <<<<<<<<<<<<<<
 *                 if self.expr.resultsName:
 *                     tokens = ParseResults([self.defaultValue])
 */
        goto __pyx_L15;
      }

      /* "cPyparsing.pyx":4051
 *                     tokens = [self.defaultValue]
 *             else:
 *                 tokens = []             # <<<<<<<<<<<<<<
 *         return loc, tokens
 * 
 */
      /*else*/ {
        __pyx_t_15 = PyList_New(0); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 4051, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_XDECREF_SET(__pyx_v_tokens, __pyx_t_15);
        __pyx_t_15 = 0;
      }
      __pyx_L15:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cPyparsing.pyx":4041
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         try:             # <<<<<<<<<<<<<<
 *             loc, tokens = self.expr._parse(instring, loc, doActions, callPreParse=False)
 *         except (ParseException, IndexError):
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L10_try_end:;
  }

  /* "cPyparsing.pyx":4052
 *             else:
 *                 tokens = []
 *         return loc, tokens             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4);
  __Pyx_INCREF(__pyx_v_tokens);
  __Pyx_GIVEREF(__pyx_v_tokens);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_tokens);
  __pyx_t_4 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4040
 *         self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         try:
 *             loc, tokens = self.expr._parse(instring, loc, doActions, callPreParse=False)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("cPyparsing.Optional.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tokens);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4054
 *         return loc, tokens
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_8Optional_5__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_8Optional_5__str__ = {"__str__", (PyCFunction)__pyx_pw_10cPyparsing_8Optional_5__str__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_8Optional_5__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_8Optional_4__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_8Optional_4__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "cPyparsing.pyx":4055
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  __pyx_t_1 = PyObject_HasAttr(__pyx_v_self, __pyx_n_u_name); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 4055, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":4056
 *     def __str__(self):
 *         if hasattr(self, "name"):
 *             return self.name             # <<<<<<<<<<<<<<
 * 
 *         if self.strRepr is None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4056, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":4055
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 * 
 */
  }

  /* "cPyparsing.pyx":4058
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "[" + _ustr(self.expr) + "]"
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = (__pyx_t_3 == Py_None);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":4059
 * 
 *         if self.strRepr is None:
 *             self.strRepr = "[" + _ustr(self.expr) + "]"             # <<<<<<<<<<<<<<
 * 
 *         return self.strRepr
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4059, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4059, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4059, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4059, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4059, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Add(__pyx_kp_u__16, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Add(__pyx_t_4, __pyx_kp_u__18); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, __pyx_t_3) < 0) __PYX_ERR(0, 4059, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "cPyparsing.pyx":4058
 *             return self.name
 * 
 *         if self.strRepr is None:             # <<<<<<<<<<<<<<
 *             self.strRepr = "[" + _ustr(self.expr) + "]"
 * 
 */
  }

  /* "cPyparsing.pyx":4061
 *             self.strRepr = "[" + _ustr(self.expr) + "]"
 * 
 *         return self.strRepr             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_strRepr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4061, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4054
 *         return loc, tokens
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.Optional.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4120
 *     """
 * 
 *     def __init__(self, other, *args, **kwargs):  # include=False, ignore=None, failOn=None             # <<<<<<<<<<<<<<
 *         super(SkipTo, self).__init__(other)
 *         # include is a reserved word, so we have to get creative to allow it as an argument
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_6SkipTo_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_6SkipTo_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_6SkipTo_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_6SkipTo_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  if (PyTuple_GET_SIZE(__pyx_args) > 2) {
    __pyx_v_args = PyTuple_GetSlice(__pyx_args, 2, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v_args)) {
      __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
      __Pyx_RefNannyFinishContext();
      return NULL;
    }
    __Pyx_GOTREF(__pyx_v_args);
  } else {
    __pyx_v_args = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 2, 1); __PYX_ERR(0, 4120, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 2) ? pos_args : 2;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, __pyx_v_kwargs, values, used_pos_args, "__init__") < 0)) __PYX_ERR(0, 4120, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4120, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
  __Pyx_AddTraceback("cPyparsing.SkipTo.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_6SkipTo___init__(__pyx_self, __pyx_v_self, __pyx_v_other, __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_6SkipTo___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_v_failOn = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":4121
 * 
 *     def __init__(self, other, *args, **kwargs):  # include=False, ignore=None, failOn=None
 *         super(SkipTo, self).__init__(other)             # <<<<<<<<<<<<<<
 *         # include is a reserved word, so we have to get creative to allow it as an argument
 *         self.includeMatch, self.ignoreExpr, failOn = (
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_SkipTo); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4121, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4121, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4121, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_other);
      __Pyx_GIVEREF(__pyx_v_other);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_other);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4121, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4124
 *         # include is a reserved word, so we have to get creative to allow it as an argument
 *         self.includeMatch, self.ignoreExpr, failOn = (
 *             args[0] if len(args) >= 1 else kwargs.get("include", False),  # include=False             # <<<<<<<<<<<<<<
 *             args[1] if len(args) >= 2 else kwargs.get("ignore", None),  # ignore=None
 *             args[2] if len(args) >= 3 else kwargs.get("failOn", None),  # failOn=None
 */
  __pyx_t_5 = PyTuple_GET_SIZE(__pyx_v_args); if (unlikely(__pyx_t_5 == -1)) __PYX_ERR(0, 4124, __pyx_L1_error)
  if (((__pyx_t_5 >= 1) != 0)) {
    __pyx_t_3 = __Pyx_GetItemInt_Tuple(__pyx_v_args, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4124, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {
    __pyx_t_3 = __Pyx_PyDict_GetItemDefault(__pyx_v_kwargs, __pyx_n_u_include, Py_False); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4124, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  }

  /* "cPyparsing.pyx":4125
 *         self.includeMatch, self.ignoreExpr, failOn = (
 *             args[0] if len(args) >= 1 else kwargs.get("include", False),  # include=False
 *             args[1] if len(args) >= 2 else kwargs.get("ignore", None),  # ignore=None             # <<<<<<<<<<<<<<
 *             args[2] if len(args) >= 3 else kwargs.get("failOn", None),  # failOn=None
 *         )
 */
  __pyx_t_5 = PyTuple_GET_SIZE(__pyx_v_args); if (unlikely(__pyx_t_5 == -1)) __PYX_ERR(0, 4125, __pyx_L1_error)
  if (((__pyx_t_5 >= 2) != 0)) {
    __pyx_t_4 = __Pyx_GetItemInt_Tuple(__pyx_v_args, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __pyx_t_4;
    __pyx_t_4 = 0;
  } else {
    __pyx_t_4 = __Pyx_PyDict_GetItemDefault(__pyx_v_kwargs, __pyx_n_u_ignore, Py_None); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __pyx_t_4;
    __pyx_t_4 = 0;
  }

  /* "cPyparsing.pyx":4126
 *             args[0] if len(args) >= 1 else kwargs.get("include", False),  # include=False
 *             args[1] if len(args) >= 2 else kwargs.get("ignore", None),  # ignore=None
 *             args[2] if len(args) >= 3 else kwargs.get("failOn", None),  # failOn=None             # <<<<<<<<<<<<<<
 *         )
 *         self.mayReturnEmpty = True
 */
  __pyx_t_5 = PyTuple_GET_SIZE(__pyx_v_args); if (unlikely(__pyx_t_5 == -1)) __PYX_ERR(0, 4126, __pyx_L1_error)
  if (((__pyx_t_5 >= 3) != 0)) {
    __pyx_t_2 = __Pyx_GetItemInt_Tuple(__pyx_v_args, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __pyx_t_2;
    __pyx_t_2 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyDict_GetItemDefault(__pyx_v_kwargs, __pyx_n_u_failOn, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __pyx_t_2;
    __pyx_t_2 = 0;
  }

  /* "cPyparsing.pyx":4123
 *         super(SkipTo, self).__init__(other)
 *         # include is a reserved word, so we have to get creative to allow it as an argument
 *         self.includeMatch, self.ignoreExpr, failOn = (             # <<<<<<<<<<<<<<
 *             args[0] if len(args) >= 1 else kwargs.get("include", False),  # include=False
 *             args[1] if len(args) >= 2 else kwargs.get("ignore", None),  # ignore=None
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_includeMatch, __pyx_t_1) < 0) __PYX_ERR(0, 4123, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExpr, __pyx_t_3) < 0) __PYX_ERR(0, 4123, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_failOn = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":4128
 *             args[2] if len(args) >= 3 else kwargs.get("failOn", None),  # failOn=None
 *         )
 *         self.mayReturnEmpty = True             # <<<<<<<<<<<<<<
 *         self.mayIndexError = False
 *         self.asList = False
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, Py_True) < 0) __PYX_ERR(0, 4128, __pyx_L1_error)

  /* "cPyparsing.pyx":4129
 *         )
 *         self.mayReturnEmpty = True
 *         self.mayIndexError = False             # <<<<<<<<<<<<<<
 *         self.asList = False
 *         if isinstance(failOn, basestring):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, Py_False) < 0) __PYX_ERR(0, 4129, __pyx_L1_error)

  /* "cPyparsing.pyx":4130
 *         self.mayReturnEmpty = True
 *         self.mayIndexError = False
 *         self.asList = False             # <<<<<<<<<<<<<<
 *         if isinstance(failOn, basestring):
 *             self.failOn = ParserElement._literalStringClass(failOn)
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_asList, Py_False) < 0) __PYX_ERR(0, 4130, __pyx_L1_error)

  /* "cPyparsing.pyx":4131
 *         self.mayIndexError = False
 *         self.asList = False
 *         if isinstance(failOn, basestring):             # <<<<<<<<<<<<<<
 *             self.failOn = ParserElement._literalStringClass(failOn)
 *         else:
 */
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = PyObject_IsInstance(__pyx_v_failOn, __pyx_t_4); if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 4131, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (__pyx_t_7) {

    /* "cPyparsing.pyx":4132
 *         self.asList = False
 *         if isinstance(failOn, basestring):
 *             self.failOn = ParserElement._literalStringClass(failOn)             # <<<<<<<<<<<<<<
 *         else:
 *             self.failOn = failOn
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (!__pyx_t_3) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_failOn); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4132, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_failOn};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4132, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_failOn};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4132, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      {
        __pyx_t_2 = PyTuple_New(1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4132, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3); __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_v_failOn);
        __Pyx_GIVEREF(__pyx_v_failOn);
        PyTuple_SET_ITEM(__pyx_t_2, 0+1, __pyx_v_failOn);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4132, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_failOn, __pyx_t_4) < 0) __PYX_ERR(0, 4132, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":4131
 *         self.mayIndexError = False
 *         self.asList = False
 *         if isinstance(failOn, basestring):             # <<<<<<<<<<<<<<
 *             self.failOn = ParserElement._literalStringClass(failOn)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":4134
 *             self.failOn = ParserElement._literalStringClass(failOn)
 *         else:
 *             self.failOn = failOn             # <<<<<<<<<<<<<<
 *         self.errmsg = "No match found for " + _ustr(self.expr)
 * 
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_failOn, __pyx_v_failOn) < 0) __PYX_ERR(0, 4134, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":4135
 *         else:
 *             self.failOn = failOn
 *         self.errmsg = "No match found for " + _ustr(self.expr)             # <<<<<<<<<<<<<<
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4135, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_2};
      __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4135, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_2};
      __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4135, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4135, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_8, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4135, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_kp_u_No_match_found_for, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_errmsg, __pyx_t_1) < 0) __PYX_ERR(0, 4135, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4120
 *     """
 * 
 *     def __init__(self, other, *args, **kwargs):  # include=False, ignore=None, failOn=None             # <<<<<<<<<<<<<<
 *         super(SkipTo, self).__init__(other)
 *         # include is a reserved word, so we have to get creative to allow it as an argument
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing.SkipTo.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_failOn);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4137
 *         self.errmsg = "No match found for " + _ustr(self.expr)
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         startloc = loc
 *         instrlen = len(instring)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_6SkipTo_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_6SkipTo_3parseImpl = {"parseImpl", (PyCFunction)__pyx_pw_10cPyparsing_6SkipTo_3parseImpl, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_6SkipTo_3parseImpl(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_instring = 0;
  int __pyx_v_loc;
  PyObject *__pyx_v_doActions = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parseImpl (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_doActions,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 1); __PYX_ERR(0, 4137, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, 2); __PYX_ERR(0, 4137, __pyx_L3_error)
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_doActions);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parseImpl") < 0)) __PYX_ERR(0, 4137, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_loc == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4137, __pyx_L3_error)
    __pyx_v_doActions = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parseImpl", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4137, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.SkipTo.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_6SkipTo_2parseImpl(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_doActions);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_6SkipTo_2parseImpl(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_instring, int __pyx_v_loc, PyObject *__pyx_v_doActions) {
  int __pyx_v_startloc;
  Py_ssize_t __pyx_v_instrlen;
  CYTHON_UNUSED PyObject *__pyx_v_expr = NULL;
  PyObject *__pyx_v_expr_parse = NULL;
  PyObject *__pyx_v_self_failOn_canParseNext = NULL;
  PyObject *__pyx_v_self_ignoreExpr_tryParse = NULL;
  PyObject *__pyx_v_tmploc = NULL;
  PyObject *__pyx_v_skiptext = NULL;
  PyObject *__pyx_v_skipresult = NULL;
  PyObject *__pyx_v_mat = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *(*__pyx_t_14)(PyObject *);
  __Pyx_RefNannySetupContext("parseImpl", 0);

  /* "cPyparsing.pyx":4138
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         startloc = loc             # <<<<<<<<<<<<<<
 *         instrlen = len(instring)
 *         expr = self.expr
 */
  __pyx_v_startloc = __pyx_v_loc;

  /* "cPyparsing.pyx":4139
 *     def parseImpl(self, instring, int loc, doActions=True):
 *         startloc = loc
 *         instrlen = len(instring)             # <<<<<<<<<<<<<<
 *         expr = self.expr
 *         expr_parse = self.expr._parse
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_instring); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 4139, __pyx_L1_error)
  __pyx_v_instrlen = __pyx_t_1;

  /* "cPyparsing.pyx":4140
 *         startloc = loc
 *         instrlen = len(instring)
 *         expr = self.expr             # <<<<<<<<<<<<<<
 *         expr_parse = self.expr._parse
 *         self_failOn_canParseNext = self.failOn.canParseNext if self.failOn is not None else None
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_expr = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4141
 *         instrlen = len(instring)
 *         expr = self.expr
 *         expr_parse = self.expr._parse             # <<<<<<<<<<<<<<
 *         self_failOn_canParseNext = self.failOn.canParseNext if self.failOn is not None else None
 *         self_ignoreExpr_tryParse = self.ignoreExpr.tryParse if self.ignoreExpr is not None else None
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_parse); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_expr_parse = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4142
 *         expr = self.expr
 *         expr_parse = self.expr._parse
 *         self_failOn_canParseNext = self.failOn.canParseNext if self.failOn is not None else None             # <<<<<<<<<<<<<<
 *         self_ignoreExpr_tryParse = self.ignoreExpr.tryParse if self.ignoreExpr is not None else None
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_failOn); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = (__pyx_t_2 != Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if ((__pyx_t_4 != 0)) {
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_failOn); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4142, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_canParseNext); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4142, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_3 = __pyx_t_5;
    __pyx_t_5 = 0;
  } else {
    __Pyx_INCREF(Py_None);
    __pyx_t_3 = Py_None;
  }
  __pyx_v_self_failOn_canParseNext = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4143
 *         expr_parse = self.expr._parse
 *         self_failOn_canParseNext = self.failOn.canParseNext if self.failOn is not None else None
 *         self_ignoreExpr_tryParse = self.ignoreExpr.tryParse if self.ignoreExpr is not None else None             # <<<<<<<<<<<<<<
 * 
 *         tmploc = loc
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExpr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = (__pyx_t_5 != Py_None);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if ((__pyx_t_4 != 0)) {
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExpr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4143, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_tryParse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4143, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_3 = __pyx_t_2;
    __pyx_t_2 = 0;
  } else {
    __Pyx_INCREF(Py_None);
    __pyx_t_3 = Py_None;
  }
  __pyx_v_self_ignoreExpr_tryParse = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4145
 *         self_ignoreExpr_tryParse = self.ignoreExpr.tryParse if self.ignoreExpr is not None else None
 * 
 *         tmploc = loc             # <<<<<<<<<<<<<<
 *         while tmploc <= instrlen:
 *             if self_failOn_canParseNext is not None:
 */
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_tmploc = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4146
 * 
 *         tmploc = loc
 *         while tmploc <= instrlen:             # <<<<<<<<<<<<<<
 *             if self_failOn_canParseNext is not None:
 *                 # break if failOn expression matches
 */
  while (1) {
    __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_instrlen); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4146, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = PyObject_RichCompare(__pyx_v_tmploc, __pyx_t_3, Py_LE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4146, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 4146, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (!__pyx_t_4) break;

    /* "cPyparsing.pyx":4147
 *         tmploc = loc
 *         while tmploc <= instrlen:
 *             if self_failOn_canParseNext is not None:             # <<<<<<<<<<<<<<
 *                 # break if failOn expression matches
 *                 if self_failOn_canParseNext(instring, tmploc):
 */
    __pyx_t_4 = (__pyx_v_self_failOn_canParseNext != Py_None);
    __pyx_t_6 = (__pyx_t_4 != 0);
    if (__pyx_t_6) {

      /* "cPyparsing.pyx":4149
 *             if self_failOn_canParseNext is not None:
 *                 # break if failOn expression matches
 *                 if self_failOn_canParseNext(instring, tmploc):             # <<<<<<<<<<<<<<
 *                     break
 * 
 */
      __Pyx_INCREF(__pyx_v_self_failOn_canParseNext);
      __pyx_t_3 = __pyx_v_self_failOn_canParseNext; __pyx_t_5 = NULL;
      __pyx_t_7 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_7 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_instring, __pyx_v_tmploc};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4149, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_instring, __pyx_v_tmploc};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4149, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4149, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_5) {
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_5); __pyx_t_5 = NULL;
        }
        __Pyx_INCREF(__pyx_v_instring);
        __Pyx_GIVEREF(__pyx_v_instring);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_v_instring);
        __Pyx_INCREF(__pyx_v_tmploc);
        __Pyx_GIVEREF(__pyx_v_tmploc);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_v_tmploc);
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_8, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4149, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 4149, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_6) {

        /* "cPyparsing.pyx":4150
 *                 # break if failOn expression matches
 *                 if self_failOn_canParseNext(instring, tmploc):
 *                     break             # <<<<<<<<<<<<<<
 * 
 *             if self_ignoreExpr_tryParse is not None:
 */
        goto __pyx_L4_break;

        /* "cPyparsing.pyx":4149
 *             if self_failOn_canParseNext is not None:
 *                 # break if failOn expression matches
 *                 if self_failOn_canParseNext(instring, tmploc):             # <<<<<<<<<<<<<<
 *                     break
 * 
 */
      }

      /* "cPyparsing.pyx":4147
 *         tmploc = loc
 *         while tmploc <= instrlen:
 *             if self_failOn_canParseNext is not None:             # <<<<<<<<<<<<<<
 *                 # break if failOn expression matches
 *                 if self_failOn_canParseNext(instring, tmploc):
 */
    }

    /* "cPyparsing.pyx":4152
 *                     break
 * 
 *             if self_ignoreExpr_tryParse is not None:             # <<<<<<<<<<<<<<
 *                 # advance past ignore expressions
 *                 while True:
 */
    __pyx_t_6 = (__pyx_v_self_ignoreExpr_tryParse != Py_None);
    __pyx_t_4 = (__pyx_t_6 != 0);
    if (__pyx_t_4) {

      /* "cPyparsing.pyx":4154
 *             if self_ignoreExpr_tryParse is not None:
 *                 # advance past ignore expressions
 *                 while True:             # <<<<<<<<<<<<<<
 *                     try:
 *                         tmploc = self_ignoreExpr_tryParse(instring, tmploc)
 */
      while (1) {

        /* "cPyparsing.pyx":4155
 *                 # advance past ignore expressions
 *                 while True:
 *                     try:             # <<<<<<<<<<<<<<
 *                         tmploc = self_ignoreExpr_tryParse(instring, tmploc)
 *                     except ParseBaseException:
 */
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_9);
          __Pyx_XGOTREF(__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_11);
          /*try:*/ {

            /* "cPyparsing.pyx":4156
 *                 while True:
 *                     try:
 *                         tmploc = self_ignoreExpr_tryParse(instring, tmploc)             # <<<<<<<<<<<<<<
 *                     except ParseBaseException:
 *                         break
 */
            __Pyx_INCREF(__pyx_v_self_ignoreExpr_tryParse);
            __pyx_t_3 = __pyx_v_self_ignoreExpr_tryParse; __pyx_t_8 = NULL;
            __pyx_t_7 = 0;
            if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
              __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
              if (likely(__pyx_t_8)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
                __Pyx_INCREF(__pyx_t_8);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_3, function);
                __pyx_t_7 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_3)) {
              PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_instring, __pyx_v_tmploc};
              __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4156, __pyx_L10_error)
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_GOTREF(__pyx_t_2);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
              PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_instring, __pyx_v_tmploc};
              __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4156, __pyx_L10_error)
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_GOTREF(__pyx_t_2);
            } else
            #endif
            {
              __pyx_t_5 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4156, __pyx_L10_error)
              __Pyx_GOTREF(__pyx_t_5);
              if (__pyx_t_8) {
                __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_8); __pyx_t_8 = NULL;
              }
              __Pyx_INCREF(__pyx_v_instring);
              __Pyx_GIVEREF(__pyx_v_instring);
              PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_7, __pyx_v_instring);
              __Pyx_INCREF(__pyx_v_tmploc);
              __Pyx_GIVEREF(__pyx_v_tmploc);
              PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_7, __pyx_v_tmploc);
              __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4156, __pyx_L10_error)
              __Pyx_GOTREF(__pyx_t_2);
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            }
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_DECREF_SET(__pyx_v_tmploc, __pyx_t_2);
            __pyx_t_2 = 0;

            /* "cPyparsing.pyx":4155
 *                 # advance past ignore expressions
 *                 while True:
 *                     try:             # <<<<<<<<<<<<<<
 *                         tmploc = self_ignoreExpr_tryParse(instring, tmploc)
 *                     except ParseBaseException:
 */
          }
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          goto __pyx_L17_try_end;
          __pyx_L10_error:;
          __Pyx_PyThreadState_assign
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "cPyparsing.pyx":4157
 *                     try:
 *                         tmploc = self_ignoreExpr_tryParse(instring, tmploc)
 *                     except ParseBaseException:             # <<<<<<<<<<<<<<
 *                         break
 * 
 */
          __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4157, __pyx_L12_except_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (__pyx_t_7) {
            __Pyx_AddTraceback("cPyparsing.SkipTo.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_3, &__pyx_t_5) < 0) __PYX_ERR(0, 4157, __pyx_L12_except_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_GOTREF(__pyx_t_5);

            /* "cPyparsing.pyx":4158
 *                         tmploc = self_ignoreExpr_tryParse(instring, tmploc)
 *                     except ParseBaseException:
 *                         break             # <<<<<<<<<<<<<<
 * 
 *             try:
 */
            goto __pyx_L18_except_break;
            __pyx_L18_except_break:;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            goto __pyx_L15_try_break;
          }
          goto __pyx_L12_except_error;
          __pyx_L12_except_error:;

          /* "cPyparsing.pyx":4155
 *                 # advance past ignore expressions
 *                 while True:
 *                     try:             # <<<<<<<<<<<<<<
 *                         tmploc = self_ignoreExpr_tryParse(instring, tmploc)
 *                     except ParseBaseException:
 */
          __Pyx_PyThreadState_assign
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
          goto __pyx_L1_error;
          __pyx_L15_try_break:;
          __Pyx_PyThreadState_assign
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
          goto __pyx_L9_break;
          __pyx_L17_try_end:;
        }
      }
      __pyx_L9_break:;

      /* "cPyparsing.pyx":4152
 *                     break
 * 
 *             if self_ignoreExpr_tryParse is not None:             # <<<<<<<<<<<<<<
 *                 # advance past ignore expressions
 *                 while True:
 */
    }

    /* "cPyparsing.pyx":4160
 *                         break
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 expr_parse(instring, tmploc, doActions=False, callPreParse=False)
 *             except (ParseException, IndexError):
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_10, &__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_9);
      /*try:*/ {

        /* "cPyparsing.pyx":4161
 * 
 *             try:
 *                 expr_parse(instring, tmploc, doActions=False, callPreParse=False)             # <<<<<<<<<<<<<<
 *             except (ParseException, IndexError):
 *                 # no match, advance loc in string
 */
        __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4161, __pyx_L20_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_v_instring);
        __Pyx_GIVEREF(__pyx_v_instring);
        PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_instring);
        __Pyx_INCREF(__pyx_v_tmploc);
        __Pyx_GIVEREF(__pyx_v_tmploc);
        PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_tmploc);
        __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4161, __pyx_L20_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_doActions, Py_False) < 0) __PYX_ERR(0, 4161, __pyx_L20_error)
        if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_callPreParse, Py_False) < 0) __PYX_ERR(0, 4161, __pyx_L20_error)
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_v_expr_parse, __pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4161, __pyx_L20_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "cPyparsing.pyx":4160
 *                         break
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 expr_parse(instring, tmploc, doActions=False, callPreParse=False)
 *             except (ParseException, IndexError):
 */
      }

      /* "cPyparsing.pyx":4167
 *             else:
 *                 # matched skipto expr, done
 *                 break             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
      /*else:*/ {
        goto __pyx_L25_try_break;
      }
      __pyx_L20_error:;
      __Pyx_PyThreadState_assign
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "cPyparsing.pyx":4162
 *             try:
 *                 expr_parse(instring, tmploc, doActions=False, callPreParse=False)
 *             except (ParseException, IndexError):             # <<<<<<<<<<<<<<
 *                 # no match, advance loc in string
 *                 tmploc += 1
 */
      __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4162, __pyx_L22_except_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_t_2) || __Pyx_PyErr_ExceptionMatches(__pyx_builtin_IndexError);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_7) {
        __Pyx_AddTraceback("cPyparsing.SkipTo.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_3, &__pyx_t_5) < 0) __PYX_ERR(0, 4162, __pyx_L22_except_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GOTREF(__pyx_t_5);

        /* "cPyparsing.pyx":4164
 *             except (ParseException, IndexError):
 *                 # no match, advance loc in string
 *                 tmploc += 1             # <<<<<<<<<<<<<<
 *             else:
 *                 # matched skipto expr, done
 */
        __pyx_t_8 = __Pyx_PyInt_AddObjC(__pyx_v_tmploc, __pyx_int_1, 1, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4164, __pyx_L22_except_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF_SET(__pyx_v_tmploc, __pyx_t_8);
        __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        goto __pyx_L21_exception_handled;
      }
      goto __pyx_L22_except_error;
      __pyx_L22_except_error:;

      /* "cPyparsing.pyx":4160
 *                         break
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 expr_parse(instring, tmploc, doActions=False, callPreParse=False)
 *             except (ParseException, IndexError):
 */
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_10, __pyx_t_9);
      goto __pyx_L1_error;
      __pyx_L25_try_break:;
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_10, __pyx_t_9);
      goto __pyx_L4_break;
      __pyx_L21_exception_handled:;
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_10, __pyx_t_9);
    }
  }

  /* "cPyparsing.pyx":4171
 *         else:
 *             # ran off the end of the input string without matching skipto expr, fail
 *             raise ParseException(instring, loc, self.errmsg, self)             # <<<<<<<<<<<<<<
 * 
 *         # build up return values
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4171, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4171, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_errmsg); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4171, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_12 = NULL;
    __pyx_t_7 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_12)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[5] = {__pyx_t_12, __pyx_v_instring, __pyx_t_2, __pyx_t_8, __pyx_v_self};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 4+__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4171, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[5] = {__pyx_t_12, __pyx_v_instring, __pyx_t_2, __pyx_t_8, __pyx_v_self};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 4+__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4171, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    } else
    #endif
    {
      __pyx_t_13 = PyTuple_New(4+__pyx_t_7); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4171, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      if (__pyx_t_12) {
        __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_12); __pyx_t_12 = NULL;
      }
      __Pyx_INCREF(__pyx_v_instring);
      __Pyx_GIVEREF(__pyx_v_instring);
      PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_7, __pyx_v_instring);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_7, __pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_8);
      PyTuple_SET_ITEM(__pyx_t_13, 2+__pyx_t_7, __pyx_t_8);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_13, 3+__pyx_t_7, __pyx_v_self);
      __pyx_t_2 = 0;
      __pyx_t_8 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_13, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4171, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(0, 4171, __pyx_L1_error)
  }
  __pyx_L4_break:;

  /* "cPyparsing.pyx":4174
 * 
 *         # build up return values
 *         loc = tmploc             # <<<<<<<<<<<<<<
 *         skiptext = instring[startloc:loc]
 *         skipresult = ParseResults(skiptext)
 */
  __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_v_tmploc); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4174, __pyx_L1_error)
  __pyx_v_loc = __pyx_t_7;

  /* "cPyparsing.pyx":4175
 *         # build up return values
 *         loc = tmploc
 *         skiptext = instring[startloc:loc]             # <<<<<<<<<<<<<<
 *         skipresult = ParseResults(skiptext)
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_v_instring, __pyx_v_startloc, __pyx_v_loc, NULL, NULL, NULL, 1, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_skiptext = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "cPyparsing.pyx":4176
 *         loc = tmploc
 *         skiptext = instring[startloc:loc]
 *         skipresult = ParseResults(skiptext)             # <<<<<<<<<<<<<<
 * 
 *         if self.includeMatch:
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_13) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_skiptext); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4176, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_v_skiptext};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4176, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_t_5);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_v_skiptext};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4176, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_t_5);
    } else
    #endif
    {
      __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4176, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_13); __pyx_t_13 = NULL;
      __Pyx_INCREF(__pyx_v_skiptext);
      __Pyx_GIVEREF(__pyx_v_skiptext);
      PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_v_skiptext);
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_8, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4176, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_skipresult = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "cPyparsing.pyx":4178
 *         skipresult = ParseResults(skiptext)
 * 
 *         if self.includeMatch:             # <<<<<<<<<<<<<<
 *             loc, mat = expr_parse(instring, loc, doActions, callPreParse=False)
 *             skipresult += mat
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_includeMatch); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 4178, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":4179
 * 
 *         if self.includeMatch:
 *             loc, mat = expr_parse(instring, loc, doActions, callPreParse=False)             # <<<<<<<<<<<<<<
 *             skipresult += mat
 * 
 */
    __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_instring);
    __Pyx_GIVEREF(__pyx_v_instring);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_instring);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_5);
    __Pyx_INCREF(__pyx_v_doActions);
    __Pyx_GIVEREF(__pyx_v_doActions);
    PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_doActions);
    __pyx_t_5 = 0;
    __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_callPreParse, Py_False) < 0) __PYX_ERR(0, 4179, __pyx_L1_error)
    __pyx_t_8 = __Pyx_PyObject_Call(__pyx_v_expr_parse, __pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if ((likely(PyTuple_CheckExact(__pyx_t_8))) || (PyList_CheckExact(__pyx_t_8))) {
      PyObject* sequence = __pyx_t_8;
      #if !CYTHON_COMPILING_IN_PYPY
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 4179, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_3);
      #else
      __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4179, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4179, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      #endif
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_13 = PyObject_GetIter(__pyx_t_8); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4179, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_14 = Py_TYPE(__pyx_t_13)->tp_iternext;
      index = 0; __pyx_t_5 = __pyx_t_14(__pyx_t_13); if (unlikely(!__pyx_t_5)) goto __pyx_L31_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      index = 1; __pyx_t_3 = __pyx_t_14(__pyx_t_13); if (unlikely(!__pyx_t_3)) goto __pyx_L31_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_14(__pyx_t_13), 2) < 0) __PYX_ERR(0, 4179, __pyx_L1_error)
      __pyx_t_14 = NULL;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      goto __pyx_L32_unpacking_done;
      __pyx_L31_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_14 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 4179, __pyx_L1_error)
      __pyx_L32_unpacking_done:;
    }
    __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_5); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4179, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_loc = __pyx_t_7;
    __pyx_v_mat = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":4180
 *         if self.includeMatch:
 *             loc, mat = expr_parse(instring, loc, doActions, callPreParse=False)
 *             skipresult += mat             # <<<<<<<<<<<<<<
 * 
 *         return loc, skipresult
 */
    __pyx_t_8 = PyNumber_InPlaceAdd(__pyx_v_skipresult, __pyx_v_mat); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF_SET(__pyx_v_skipresult, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "cPyparsing.pyx":4178
 *         skipresult = ParseResults(skiptext)
 * 
 *         if self.includeMatch:             # <<<<<<<<<<<<<<
 *             loc, mat = expr_parse(instring, loc, doActions, callPreParse=False)
 *             skipresult += mat
 */
  }

  /* "cPyparsing.pyx":4182
 *             skipresult += mat
 * 
 *         return loc, skipresult             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_loc); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_8);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_8);
  __Pyx_INCREF(__pyx_v_skipresult);
  __Pyx_GIVEREF(__pyx_v_skipresult);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_skipresult);
  __pyx_t_8 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4137
 *         self.errmsg = "No match found for " + _ustr(self.expr)
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         startloc = loc
 *         instrlen = len(instring)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("cPyparsing.SkipTo.parseImpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_expr);
  __Pyx_XDECREF(__pyx_v_expr_parse);
  __Pyx_XDECREF(__pyx_v_self_failOn_canParseNext);
  __Pyx_XDECREF(__pyx_v_self_ignoreExpr_tryParse);
  __Pyx_XDECREF(__pyx_v_tmploc);
  __Pyx_XDECREF(__pyx_v_skiptext);
  __Pyx_XDECREF(__pyx_v_skipresult);
  __Pyx_XDECREF(__pyx_v_mat);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4205
 *     """
 * 
 *     def __init__(self, other=None):             # <<<<<<<<<<<<<<
 *         super(Forward, self).__init__(other, savelist=False)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Forward_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_7Forward_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_7Forward_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_7Forward_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 4205, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4205, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Forward.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Forward___init__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Forward___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":4206
 * 
 *     def __init__(self, other=None):
 *         super(Forward, self).__init__(other, savelist=False)             # <<<<<<<<<<<<<<
 * 
 *     def __lshift__(self, other):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Forward); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_self);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_other);
  __Pyx_GIVEREF(__pyx_v_other);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_other);
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_savelist, Py_False) < 0) __PYX_ERR(0, 4206, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":4205
 *     """
 * 
 *     def __init__(self, other=None):             # <<<<<<<<<<<<<<
 *         super(Forward, self).__init__(other, savelist=False)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.Forward.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4208
 *         super(Forward, self).__init__(other, savelist=False)
 * 
 *     def __lshift__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Forward_3__lshift__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_7Forward_3__lshift__ = {"__lshift__", (PyCFunction)__pyx_pw_10cPyparsing_7Forward_3__lshift__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_7Forward_3__lshift__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__lshift__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__lshift__", 1, 2, 2, 1); __PYX_ERR(0, 4208, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__lshift__") < 0)) __PYX_ERR(0, 4208, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__lshift__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4208, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Forward.__lshift__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Forward_2__lshift__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Forward_2__lshift__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("__lshift__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "cPyparsing.pyx":4209
 * 
 *     def __lshift__(self, other):
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         self.expr = other
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_other, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 4209, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":4210
 *     def __lshift__(self, other):
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)             # <<<<<<<<<<<<<<
 *         self.expr = other
 *         self.strRepr = None
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4210, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_literalStringClass); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4210, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4210, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4210, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4210, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4210, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_other);
        __Pyx_GIVEREF(__pyx_v_other);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_other);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4210, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4209
 * 
 *     def __lshift__(self, other):
 *         if isinstance(other, basestring):             # <<<<<<<<<<<<<<
 *             other = ParserElement._literalStringClass(other)
 *         self.expr = other
 */
  }

  /* "cPyparsing.pyx":4211
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 *         self.expr = other             # <<<<<<<<<<<<<<
 *         self.strRepr = None
 *         self.mayIndexError = self.expr.mayIndexError
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_expr, __pyx_v_other) < 0) __PYX_ERR(0, 4211, __pyx_L1_error)

  /* "cPyparsing.pyx":4212
 *             other = ParserElement._literalStringClass(other)
 *         self.expr = other
 *         self.strRepr = None             # <<<<<<<<<<<<<<
 *         self.mayIndexError = self.expr.mayIndexError
 *         self.mayReturnEmpty = self.expr.mayReturnEmpty
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_strRepr, Py_None) < 0) __PYX_ERR(0, 4212, __pyx_L1_error)

  /* "cPyparsing.pyx":4213
 *         self.expr = other
 *         self.strRepr = None
 *         self.mayIndexError = self.expr.mayIndexError             # <<<<<<<<<<<<<<
 *         self.mayReturnEmpty = self.expr.mayReturnEmpty
 *         self.setWhitespaceChars(self.expr.whiteChars)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_mayIndexError); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayIndexError, __pyx_t_5) < 0) __PYX_ERR(0, 4213, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cPyparsing.pyx":4214
 *         self.strRepr = None
 *         self.mayIndexError = self.expr.mayIndexError
 *         self.mayReturnEmpty = self.expr.mayReturnEmpty             # <<<<<<<<<<<<<<
 *         self.setWhitespaceChars(self.expr.whiteChars)
 *         self.skipWhitespace = self.expr.skipWhitespace
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_mayReturnEmpty); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_mayReturnEmpty, __pyx_t_1) < 0) __PYX_ERR(0, 4214, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4215
 *         self.mayIndexError = self.expr.mayIndexError
 *         self.mayReturnEmpty = self.expr.mayReturnEmpty
 *         self.setWhitespaceChars(self.expr.whiteChars)             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = self.expr.skipWhitespace
 *         self.saveAsList = self.expr.saveAsList
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_setWhitespaceChars); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_whiteChars); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (!__pyx_t_6) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4215, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4215, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4215, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4215, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4215, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4216
 *         self.mayReturnEmpty = self.expr.mayReturnEmpty
 *         self.setWhitespaceChars(self.expr.whiteChars)
 *         self.skipWhitespace = self.expr.skipWhitespace             # <<<<<<<<<<<<<<
 *         self.saveAsList = self.expr.saveAsList
 *         self.ignoreExprs.extend(self.expr.ignoreExprs)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_skipWhitespace); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, __pyx_t_5) < 0) __PYX_ERR(0, 4216, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cPyparsing.pyx":4217
 *         self.setWhitespaceChars(self.expr.whiteChars)
 *         self.skipWhitespace = self.expr.skipWhitespace
 *         self.saveAsList = self.expr.saveAsList             # <<<<<<<<<<<<<<
 *         self.ignoreExprs.extend(self.expr.ignoreExprs)
 *         return self
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_saveAsList); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList, __pyx_t_1) < 0) __PYX_ERR(0, 4217, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4218
 *         self.skipWhitespace = self.expr.skipWhitespace
 *         self.saveAsList = self.expr.saveAsList
 *         self.ignoreExprs.extend(self.expr.ignoreExprs)             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_extend); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  if (!__pyx_t_5) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4218, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4218, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4218, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4218, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4218, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4219
 *         self.saveAsList = self.expr.saveAsList
 *         self.ignoreExprs.extend(self.expr.ignoreExprs)
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def __ilshift__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4208
 *         super(Forward, self).__init__(other, savelist=False)
 * 
 *     def __lshift__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.Forward.__lshift__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4221
 *         return self
 * 
 *     def __ilshift__(self, other):             # <<<<<<<<<<<<<<
 *         return self << other
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Forward_5__ilshift__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_7Forward_5__ilshift__ = {"__ilshift__", (PyCFunction)__pyx_pw_10cPyparsing_7Forward_5__ilshift__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_7Forward_5__ilshift__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__ilshift__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__ilshift__", 1, 2, 2, 1); __PYX_ERR(0, 4221, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__ilshift__") < 0)) __PYX_ERR(0, 4221, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__ilshift__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4221, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Forward.__ilshift__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Forward_4__ilshift__(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Forward_4__ilshift__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__ilshift__", 0);

  /* "cPyparsing.pyx":4222
 * 
 *     def __ilshift__(self, other):
 *         return self << other             # <<<<<<<<<<<<<<
 * 
 *     def leaveWhitespace(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Lshift(__pyx_v_self, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4221
 *         return self
 * 
 *     def __ilshift__(self, other):             # <<<<<<<<<<<<<<
 *         return self << other
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.Forward.__ilshift__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4224
 *         return self << other
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = False
 *         return self
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Forward_7leaveWhitespace(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_7Forward_7leaveWhitespace = {"leaveWhitespace", (PyCFunction)__pyx_pw_10cPyparsing_7Forward_7leaveWhitespace, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_7Forward_7leaveWhitespace(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("leaveWhitespace (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_7Forward_6leaveWhitespace(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Forward_6leaveWhitespace(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("leaveWhitespace", 0);

  /* "cPyparsing.pyx":4225
 * 
 *     def leaveWhitespace(self):
 *         self.skipWhitespace = False             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, Py_False) < 0) __PYX_ERR(0, 4225, __pyx_L1_error)

  /* "cPyparsing.pyx":4226
 *     def leaveWhitespace(self):
 *         self.skipWhitespace = False
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def streamline(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4224
 *         return self << other
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = False
 *         return self
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.Forward.leaveWhitespace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4228
 *         return self
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         if not self.streamlined:
 *             self.streamlined = True
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Forward_9streamline(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_7Forward_9streamline = {"streamline", (PyCFunction)__pyx_pw_10cPyparsing_7Forward_9streamline, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_7Forward_9streamline(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("streamline (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_7Forward_8streamline(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Forward_8streamline(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("streamline", 0);

  /* "cPyparsing.pyx":4229
 * 
 *     def streamline(self):
 *         if not self.streamlined:             # <<<<<<<<<<<<<<
 *             self.streamlined = True
 *             if self.expr is not None:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_streamlined); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 4229, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = ((!__pyx_t_2) != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":4230
 *     def streamline(self):
 *         if not self.streamlined:
 *             self.streamlined = True             # <<<<<<<<<<<<<<
 *             if self.expr is not None:
 *                 self.expr.streamline()
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_streamlined, Py_True) < 0) __PYX_ERR(0, 4230, __pyx_L1_error)

    /* "cPyparsing.pyx":4231
 *         if not self.streamlined:
 *             self.streamlined = True
 *             if self.expr is not None:             # <<<<<<<<<<<<<<
 *                 self.expr.streamline()
 *         return self
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4231, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (__pyx_t_1 != Py_None);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = (__pyx_t_3 != 0);
    if (__pyx_t_2) {

      /* "cPyparsing.pyx":4232
 *             self.streamlined = True
 *             if self.expr is not None:
 *                 self.expr.streamline()             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4232, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_streamline); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4232, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (__pyx_t_4) {
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4232, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else {
        __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4232, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":4231
 *         if not self.streamlined:
 *             self.streamlined = True
 *             if self.expr is not None:             # <<<<<<<<<<<<<<
 *                 self.expr.streamline()
 *         return self
 */
    }

    /* "cPyparsing.pyx":4229
 * 
 *     def streamline(self):
 *         if not self.streamlined:             # <<<<<<<<<<<<<<
 *             self.streamlined = True
 *             if self.expr is not None:
 */
  }

  /* "cPyparsing.pyx":4233
 *             if self.expr is not None:
 *                 self.expr.streamline()
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def validate(self, validateTrace=[]):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4228
 *         return self
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         if not self.streamlined:
 *             self.streamlined = True
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.Forward.streamline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4235
 *         return self
 * 
 *     def validate(self, validateTrace=[]):             # <<<<<<<<<<<<<<
 *         if self not in validateTrace:
 *             tmp = validateTrace[:] + [self]
 */

static PyObject *__pyx_pf_10cPyparsing_105__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__defaults__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults11, __pyx_self)->__pyx_arg_validateTrace);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults11, __pyx_self)->__pyx_arg_validateTrace);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults11, __pyx_self)->__pyx_arg_validateTrace);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Forward_11validate(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_7Forward_11validate = {"validate", (PyCFunction)__pyx_pw_10cPyparsing_7Forward_11validate, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_7Forward_11validate(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_validateTrace = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("validate (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_validateTrace,0};
    PyObject* values[2] = {0,0};
    __pyx_defaults11 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults11, __pyx_self);
    values[1] = __pyx_dynamic_args->__pyx_arg_validateTrace;
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_validateTrace);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "validate") < 0)) __PYX_ERR(0, 4235, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_validateTrace = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("validate", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4235, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Forward.validate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Forward_10validate(__pyx_self, __pyx_v_self, __pyx_v_validateTrace);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Forward_10validate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_validateTrace) {
  PyObject *__pyx_v_tmp = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("validate", 0);

  /* "cPyparsing.pyx":4236
 * 
 *     def validate(self, validateTrace=[]):
 *         if self not in validateTrace:             # <<<<<<<<<<<<<<
 *             tmp = validateTrace[:] + [self]
 *             if self.expr is not None:
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_v_self, __pyx_v_validateTrace, Py_NE)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 4236, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":4237
 *     def validate(self, validateTrace=[]):
 *         if self not in validateTrace:
 *             tmp = validateTrace[:] + [self]             # <<<<<<<<<<<<<<
 *             if self.expr is not None:
 *                 self.expr.validate(tmp)
 */
    __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_validateTrace, 0, 0, NULL, NULL, &__pyx_slice__126, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4237, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4237, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyList_SET_ITEM(__pyx_t_4, 0, __pyx_v_self);
    __pyx_t_5 = PyNumber_Add(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4237, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_tmp = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "cPyparsing.pyx":4238
 *         if self not in validateTrace:
 *             tmp = validateTrace[:] + [self]
 *             if self.expr is not None:             # <<<<<<<<<<<<<<
 *                 self.expr.validate(tmp)
 *         self.checkRecursion([])
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = (__pyx_t_5 != Py_None);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (__pyx_t_1) {

      /* "cPyparsing.pyx":4239
 *             tmp = validateTrace[:] + [self]
 *             if self.expr is not None:
 *                 self.expr.validate(tmp)             # <<<<<<<<<<<<<<
 *         self.checkRecursion([])
 * 
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4239, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_validate); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4239, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_4) {
        __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_tmp); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4239, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_tmp};
          __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4239, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_5);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_tmp};
          __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4239, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_5);
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4239, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
          __Pyx_INCREF(__pyx_v_tmp);
          __Pyx_GIVEREF(__pyx_v_tmp);
          PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_tmp);
          __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4239, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "cPyparsing.pyx":4238
 *         if self not in validateTrace:
 *             tmp = validateTrace[:] + [self]
 *             if self.expr is not None:             # <<<<<<<<<<<<<<
 *                 self.expr.validate(tmp)
 *         self.checkRecursion([])
 */
    }

    /* "cPyparsing.pyx":4236
 * 
 *     def validate(self, validateTrace=[]):
 *         if self not in validateTrace:             # <<<<<<<<<<<<<<
 *             tmp = validateTrace[:] + [self]
 *             if self.expr is not None:
 */
  }

  /* "cPyparsing.pyx":4240
 *             if self.expr is not None:
 *                 self.expr.validate(tmp)
 *         self.checkRecursion([])             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_checkRecursion); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyList_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4240, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_5);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_6};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4240, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_6};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4240, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4240, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_7, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4240, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cPyparsing.pyx":4235
 *         return self
 * 
 *     def validate(self, validateTrace=[]):             # <<<<<<<<<<<<<<
 *         if self not in validateTrace:
 *             tmp = validateTrace[:] + [self]
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.Forward.validate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tmp);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4242
 *         self.checkRecursion([])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Forward_13__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_7Forward_13__str__ = {"__str__", (PyCFunction)__pyx_pw_10cPyparsing_7Forward_13__str__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_7Forward_13__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_7Forward_12__str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Forward_12__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "cPyparsing.pyx":4243
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 *         return self.__class__.__name__ + ": ..."
 */
  __pyx_t_1 = PyObject_HasAttr(__pyx_v_self, __pyx_n_u_name); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 4243, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":4244
 *     def __str__(self):
 *         if hasattr(self, "name"):
 *             return self.name             # <<<<<<<<<<<<<<
 *         return self.__class__.__name__ + ": ..."
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":4243
 * 
 *     def __str__(self):
 *         if hasattr(self, "name"):             # <<<<<<<<<<<<<<
 *             return self.name
 *         return self.__class__.__name__ + ": ..."
 */
  }

  /* "cPyparsing.pyx":4245
 *         if hasattr(self, "name"):
 *             return self.name
 *         return self.__class__.__name__ + ": ..."             # <<<<<<<<<<<<<<
 * 
 *         # stubbed out for now - creates awful memory and perf issues
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_name_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Add(__pyx_t_4, __pyx_kp_u__127); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4242
 *         self.checkRecursion([])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.Forward.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4259
 *         # return self.__class__.__name__ + ": " + retString
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             return super(Forward, self).copy()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Forward_15copy(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_7Forward_15copy = {"copy", (PyCFunction)__pyx_pw_10cPyparsing_7Forward_15copy, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_7Forward_15copy(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_7Forward_14copy(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Forward_14copy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("copy", 0);

  /* "cPyparsing.pyx":4260
 * 
 *     def copy(self):
 *         if self.expr is not None:             # <<<<<<<<<<<<<<
 *             return super(Forward, self).copy()
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__pyx_t_1 != Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":4261
 *     def copy(self):
 *         if self.expr is not None:
 *             return super(Forward, self).copy()             # <<<<<<<<<<<<<<
 *         else:
 *             ret = Forward()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_Forward); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4261, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4261, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_self);
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_5, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4261, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_copy); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4261, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4261, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4261, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":4260
 * 
 *     def copy(self):
 *         if self.expr is not None:             # <<<<<<<<<<<<<<
 *             return super(Forward, self).copy()
 *         else:
 */
  }

  /* "cPyparsing.pyx":4263
 *             return super(Forward, self).copy()
 *         else:
 *             ret = Forward()             # <<<<<<<<<<<<<<
 *             ret <<= self
 *             return ret
 */
  /*else*/ {
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_Forward); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4263, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4263, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4263, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_ret = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4264
 *         else:
 *             ret = Forward()
 *             ret <<= self             # <<<<<<<<<<<<<<
 *             return ret
 * 
 */
    __pyx_t_1 = PyNumber_InPlaceLshift(__pyx_v_ret, __pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4264, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_ret, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4265
 *             ret = Forward()
 *             ret <<= self
 *             return ret             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_ret);
    __pyx_r = __pyx_v_ret;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":4259
 *         # return self.__class__.__name__ + ": " + retString
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             return super(Forward, self).copy()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.Forward.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4269
 * 
 * class _ForwardNoRecurse(Forward):
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "..."
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_17_ForwardNoRecurse_1__str__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_17_ForwardNoRecurse_1__str__ = {"__str__", (PyCFunction)__pyx_pw_10cPyparsing_17_ForwardNoRecurse_1__str__, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_17_ForwardNoRecurse_1__str__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_17_ForwardNoRecurse___str__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_17_ForwardNoRecurse___str__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "cPyparsing.pyx":4270
 * class _ForwardNoRecurse(Forward):
 *     def __str__(self):
 *         return "..."             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u__88);
  __pyx_r = __pyx_kp_u__88;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4269
 * 
 * class _ForwardNoRecurse(Forward):
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "..."
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4278
 *     """
 * 
 *     def __init__(self, expr, savelist=False):             # <<<<<<<<<<<<<<
 *         super(TokenConverter, self).__init__(expr)  # , savelist )
 *         self.saveAsList = False
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_14TokenConverter_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_14TokenConverter_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_14TokenConverter_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_14TokenConverter_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_expr = 0;
  CYTHON_UNUSED PyObject *__pyx_v_savelist = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_expr,&__pyx_n_s_savelist,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_False));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_expr)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 4278, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_savelist);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 4278, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_expr = values[1];
    __pyx_v_savelist = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4278, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.TokenConverter.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_14TokenConverter___init__(__pyx_self, __pyx_v_self, __pyx_v_expr, __pyx_v_savelist);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_14TokenConverter___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, CYTHON_UNUSED PyObject *__pyx_v_savelist) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":4279
 * 
 *     def __init__(self, expr, savelist=False):
 *         super(TokenConverter, self).__init__(expr)  # , savelist )             # <<<<<<<<<<<<<<
 *         self.saveAsList = False
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_TokenConverter); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4279, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_expr};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4279, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_expr};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4279, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4279, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_expr);
      __Pyx_GIVEREF(__pyx_v_expr);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_expr);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4279, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4280
 *     def __init__(self, expr, savelist=False):
 *         super(TokenConverter, self).__init__(expr)  # , savelist )
 *         self.saveAsList = False             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList, Py_False) < 0) __PYX_ERR(0, 4280, __pyx_L1_error)

  /* "cPyparsing.pyx":4278
 *     """
 * 
 *     def __init__(self, expr, savelist=False):             # <<<<<<<<<<<<<<
 *         super(TokenConverter, self).__init__(expr)  # , savelist )
 *         self.saveAsList = False
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.TokenConverter.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4301
 *     """
 * 
 *     def __init__(self, expr, joinString="", adjacent=True):             # <<<<<<<<<<<<<<
 *         super(Combine, self).__init__(expr)
 *         # suppress whitespace-stripping in contained parse expressions, but re-enable it on the Combine itself
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Combine_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_7Combine_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_7Combine_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_7Combine_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_joinString = 0;
  PyObject *__pyx_v_adjacent = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_expr,&__pyx_n_s_joinString,&__pyx_n_s_adjacent,0};
    PyObject* values[4] = {0,0,0,0};
    values[2] = ((PyObject *)((PyObject*)__pyx_kp_u__9));
    values[3] = ((PyObject *)((PyObject *)Py_True));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_expr)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 4, 1); __PYX_ERR(0, 4301, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_joinString);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_adjacent);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 4301, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_expr = values[1];
    __pyx_v_joinString = values[2];
    __pyx_v_adjacent = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4301, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Combine.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Combine___init__(__pyx_self, __pyx_v_self, __pyx_v_expr, __pyx_v_joinString, __pyx_v_adjacent);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Combine___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_joinString, PyObject *__pyx_v_adjacent) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":4302
 * 
 *     def __init__(self, expr, joinString="", adjacent=True):
 *         super(Combine, self).__init__(expr)             # <<<<<<<<<<<<<<
 *         # suppress whitespace-stripping in contained parse expressions, but re-enable it on the Combine itself
 *         if adjacent:
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Combine); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4302, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_expr};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4302, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_expr};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4302, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4302, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_expr);
      __Pyx_GIVEREF(__pyx_v_expr);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_expr);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4302, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4304
 *         super(Combine, self).__init__(expr)
 *         # suppress whitespace-stripping in contained parse expressions, but re-enable it on the Combine itself
 *         if adjacent:             # <<<<<<<<<<<<<<
 *             self.leaveWhitespace()
 *         self.adjacent = adjacent
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_adjacent); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 4304, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":4305
 *         # suppress whitespace-stripping in contained parse expressions, but re-enable it on the Combine itself
 *         if adjacent:
 *             self.leaveWhitespace()             # <<<<<<<<<<<<<<
 *         self.adjacent = adjacent
 *         self.skipWhitespace = True
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_leaveWhitespace); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4305, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4305, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4305, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4304
 *         super(Combine, self).__init__(expr)
 *         # suppress whitespace-stripping in contained parse expressions, but re-enable it on the Combine itself
 *         if adjacent:             # <<<<<<<<<<<<<<
 *             self.leaveWhitespace()
 *         self.adjacent = adjacent
 */
  }

  /* "cPyparsing.pyx":4306
 *         if adjacent:
 *             self.leaveWhitespace()
 *         self.adjacent = adjacent             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = True
 *         self.joinString = joinString
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_adjacent, __pyx_v_adjacent) < 0) __PYX_ERR(0, 4306, __pyx_L1_error)

  /* "cPyparsing.pyx":4307
 *             self.leaveWhitespace()
 *         self.adjacent = adjacent
 *         self.skipWhitespace = True             # <<<<<<<<<<<<<<
 *         self.joinString = joinString
 *         self.callPreparse = True
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_skipWhitespace, Py_True) < 0) __PYX_ERR(0, 4307, __pyx_L1_error)

  /* "cPyparsing.pyx":4308
 *         self.adjacent = adjacent
 *         self.skipWhitespace = True
 *         self.joinString = joinString             # <<<<<<<<<<<<<<
 *         self.callPreparse = True
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_joinString, __pyx_v_joinString) < 0) __PYX_ERR(0, 4308, __pyx_L1_error)

  /* "cPyparsing.pyx":4309
 *         self.skipWhitespace = True
 *         self.joinString = joinString
 *         self.callPreparse = True             # <<<<<<<<<<<<<<
 * 
 *     def ignore(self, other):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_callPreparse, Py_True) < 0) __PYX_ERR(0, 4309, __pyx_L1_error)

  /* "cPyparsing.pyx":4301
 *     """
 * 
 *     def __init__(self, expr, joinString="", adjacent=True):             # <<<<<<<<<<<<<<
 *         super(Combine, self).__init__(expr)
 *         # suppress whitespace-stripping in contained parse expressions, but re-enable it on the Combine itself
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.Combine.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4311
 *         self.callPreparse = True
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         if self.adjacent:
 *             ParserElement.ignore(self, other)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Combine_3ignore(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_7Combine_3ignore = {"ignore", (PyCFunction)__pyx_pw_10cPyparsing_7Combine_3ignore, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_7Combine_3ignore(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ignore (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_other)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("ignore", 1, 2, 2, 1); __PYX_ERR(0, 4311, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "ignore") < 0)) __PYX_ERR(0, 4311, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("ignore", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4311, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Combine.ignore", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Combine_2ignore(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Combine_2ignore(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("ignore", 0);

  /* "cPyparsing.pyx":4312
 * 
 *     def ignore(self, other):
 *         if self.adjacent:             # <<<<<<<<<<<<<<
 *             ParserElement.ignore(self, other)
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_adjacent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 4312, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":4313
 *     def ignore(self, other):
 *         if self.adjacent:
 *             ParserElement.ignore(self, other)             # <<<<<<<<<<<<<<
 *         else:
 *             super(Combine, self).ignore(other)
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4313, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ignore); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4313, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_self, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4313, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_self, __pyx_v_other};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4313, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4313, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__pyx_t_3) {
        __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_3); __pyx_t_3 = NULL;
      }
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_v_self);
      __Pyx_INCREF(__pyx_v_other);
      __Pyx_GIVEREF(__pyx_v_other);
      PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_v_other);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4313, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4312
 * 
 *     def ignore(self, other):
 *         if self.adjacent:             # <<<<<<<<<<<<<<
 *             ParserElement.ignore(self, other)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":4315
 *             ParserElement.ignore(self, other)
 *         else:
 *             super(Combine, self).ignore(other)             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  /*else*/ {
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_Combine); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4315, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4315, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_self);
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_6, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4315, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_ignore); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4315, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4315, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4315, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_other};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4315, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_3 = PyTuple_New(1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4315, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_other);
        __Pyx_GIVEREF(__pyx_v_other);
        PyTuple_SET_ITEM(__pyx_t_3, 0+1, __pyx_v_other);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4315, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":4316
 *         else:
 *             super(Combine, self).ignore(other)
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def postParse(self, instring, loc, tokenlist):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4311
 *         self.callPreparse = True
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         if self.adjacent:
 *             ParserElement.ignore(self, other)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.Combine.ignore", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4318
 *         return self
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         retToks = tokenlist.copy()
 *         del retToks[:]
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7Combine_5postParse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_7Combine_5postParse = {"postParse", (PyCFunction)__pyx_pw_10cPyparsing_7Combine_5postParse, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_7Combine_5postParse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  CYTHON_UNUSED PyObject *__pyx_v_instring = 0;
  CYTHON_UNUSED PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_tokenlist = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("postParse (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_tokenlist,0};
    PyObject* values[4] = {0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 1); __PYX_ERR(0, 4318, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 2); __PYX_ERR(0, 4318, __pyx_L3_error)
        }
        case  3:
        if (likely((values[3] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_tokenlist)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 3); __PYX_ERR(0, 4318, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "postParse") < 0)) __PYX_ERR(0, 4318, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 4) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_tokenlist = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4318, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Combine.postParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_7Combine_4postParse(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_tokenlist);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_7Combine_4postParse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_loc, PyObject *__pyx_v_tokenlist) {
  PyObject *__pyx_v_retToks = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  __Pyx_RefNannySetupContext("postParse", 0);

  /* "cPyparsing.pyx":4319
 * 
 *     def postParse(self, instring, loc, tokenlist):
 *         retToks = tokenlist.copy()             # <<<<<<<<<<<<<<
 *         del retToks[:]
 *         retToks += ParseResults(["".join(tokenlist._asStringList(self.joinString))], modal=self.modalResults)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_tokenlist, __pyx_n_s_copy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4319, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4319, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_retToks = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4320
 *     def postParse(self, instring, loc, tokenlist):
 *         retToks = tokenlist.copy()
 *         del retToks[:]             # <<<<<<<<<<<<<<
 *         retToks += ParseResults(["".join(tokenlist._asStringList(self.joinString))], modal=self.modalResults)
 * 
 */
  if (__Pyx_PyObject_DelSlice(__pyx_v_retToks, 0, 0, NULL, NULL, &__pyx_slice__128, 0, 0, 1) < 0) __PYX_ERR(0, 4320, __pyx_L1_error)

  /* "cPyparsing.pyx":4321
 *         retToks = tokenlist.copy()
 *         del retToks[:]
 *         retToks += ParseResults(["".join(tokenlist._asStringList(self.joinString))], modal=self.modalResults)             # <<<<<<<<<<<<<<
 * 
 *         if self.resultsName and retToks.haskeys():
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_tokenlist, __pyx_n_s_asStringList); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_joinString); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_5) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4321, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4321, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4321, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4321, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4321, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyUnicode_Join(__pyx_kp_u__9, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_modalResults); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_modal, __pyx_t_6) < 0) __PYX_ERR(0, 4321, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_retToks, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF_SET(__pyx_v_retToks, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4323
 *         retToks += ParseResults(["".join(tokenlist._asStringList(self.joinString))], modal=self.modalResults)
 * 
 *         if self.resultsName and retToks.haskeys():             # <<<<<<<<<<<<<<
 *             return [retToks]
 *         else:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 4323, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_8) {
  } else {
    __pyx_t_7 = __pyx_t_8;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_retToks, __pyx_n_s_haskeys); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4323, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4323, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 4323, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __pyx_t_8;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_7) {

    /* "cPyparsing.pyx":4324
 * 
 *         if self.resultsName and retToks.haskeys():
 *             return [retToks]             # <<<<<<<<<<<<<<
 *         else:
 *             return retToks
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4324, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_retToks);
    __Pyx_GIVEREF(__pyx_v_retToks);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_retToks);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":4323
 *         retToks += ParseResults(["".join(tokenlist._asStringList(self.joinString))], modal=self.modalResults)
 * 
 *         if self.resultsName and retToks.haskeys():             # <<<<<<<<<<<<<<
 *             return [retToks]
 *         else:
 */
  }

  /* "cPyparsing.pyx":4326
 *             return [retToks]
 *         else:
 *             return retToks             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_retToks);
    __pyx_r = __pyx_v_retToks;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":4318
 *         return self
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         retToks = tokenlist.copy()
 *         del retToks[:]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.Combine.postParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_retToks);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4344
 *     """
 * 
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(Group, self).__init__(expr)
 *         self.saveAsList = True
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5Group_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_5Group_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_5Group_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_5Group_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_expr,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_expr)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 4344, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 4344, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_expr = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4344, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Group.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_5Group___init__(__pyx_self, __pyx_v_self, __pyx_v_expr);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_5Group___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":4345
 * 
 *     def __init__(self, expr):
 *         super(Group, self).__init__(expr)             # <<<<<<<<<<<<<<
 *         self.saveAsList = True
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4345, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4345, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4345, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4345, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4345, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_expr};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4345, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_expr};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4345, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4345, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_expr);
      __Pyx_GIVEREF(__pyx_v_expr);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_expr);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4345, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4346
 *     def __init__(self, expr):
 *         super(Group, self).__init__(expr)
 *         self.saveAsList = True             # <<<<<<<<<<<<<<
 * 
 *     def postParse(self, instring, loc, tokenlist):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList, Py_True) < 0) __PYX_ERR(0, 4346, __pyx_L1_error)

  /* "cPyparsing.pyx":4344
 *     """
 * 
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(Group, self).__init__(expr)
 *         self.saveAsList = True
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.Group.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4348
 *         self.saveAsList = True
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         return [tokenlist]
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5Group_3postParse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_5Group_3postParse = {"postParse", (PyCFunction)__pyx_pw_10cPyparsing_5Group_3postParse, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_5Group_3postParse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  CYTHON_UNUSED PyObject *__pyx_v_instring = 0;
  CYTHON_UNUSED PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_tokenlist = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("postParse (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_tokenlist,0};
    PyObject* values[4] = {0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 1); __PYX_ERR(0, 4348, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 2); __PYX_ERR(0, 4348, __pyx_L3_error)
        }
        case  3:
        if (likely((values[3] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_tokenlist)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 3); __PYX_ERR(0, 4348, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "postParse") < 0)) __PYX_ERR(0, 4348, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 4) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_tokenlist = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4348, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Group.postParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_5Group_2postParse(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_tokenlist);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_5Group_2postParse(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_loc, PyObject *__pyx_v_tokenlist) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("postParse", 0);

  /* "cPyparsing.pyx":4349
 * 
 *     def postParse(self, instring, loc, tokenlist):
 *         return [tokenlist]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_tokenlist);
  __Pyx_GIVEREF(__pyx_v_tokenlist);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_tokenlist);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4348
 *         self.saveAsList = True
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         return [tokenlist]
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.Group.postParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4389
 *     """
 * 
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(Dict, self).__init__(expr)
 *         self.saveAsList = True
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_4Dict_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_4Dict_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_4Dict_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_4Dict_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_expr,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_expr)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 4389, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 4389, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_expr = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4389, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Dict.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_4Dict___init__(__pyx_self, __pyx_v_self, __pyx_v_expr);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_4Dict___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_expr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":4390
 * 
 *     def __init__(self, expr):
 *         super(Dict, self).__init__(expr)             # <<<<<<<<<<<<<<
 *         self.saveAsList = True
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Dict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_init); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4390, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_expr};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4390, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_expr};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4390, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4390, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_expr);
      __Pyx_GIVEREF(__pyx_v_expr);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_expr);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4390, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4391
 *     def __init__(self, expr):
 *         super(Dict, self).__init__(expr)
 *         self.saveAsList = True             # <<<<<<<<<<<<<<
 * 
 *     def postParse(self, instring, loc, tokenlist):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_saveAsList, Py_True) < 0) __PYX_ERR(0, 4391, __pyx_L1_error)

  /* "cPyparsing.pyx":4389
 *     """
 * 
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(Dict, self).__init__(expr)
 *         self.saveAsList = True
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.Dict.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4393
 *         self.saveAsList = True
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         for i, tok in enumerate(tokenlist):
 *             if len(tok) == 0:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_4Dict_3postParse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_4Dict_3postParse = {"postParse", (PyCFunction)__pyx_pw_10cPyparsing_4Dict_3postParse, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_4Dict_3postParse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  CYTHON_UNUSED PyObject *__pyx_v_instring = 0;
  CYTHON_UNUSED PyObject *__pyx_v_loc = 0;
  PyObject *__pyx_v_tokenlist = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("postParse (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_tokenlist,0};
    PyObject* values[4] = {0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 1); __PYX_ERR(0, 4393, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 2); __PYX_ERR(0, 4393, __pyx_L3_error)
        }
        case  3:
        if (likely((values[3] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_tokenlist)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 3); __PYX_ERR(0, 4393, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "postParse") < 0)) __PYX_ERR(0, 4393, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 4) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_tokenlist = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4393, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Dict.postParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_4Dict_2postParse(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_tokenlist);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_4Dict_2postParse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_loc, PyObject *__pyx_v_tokenlist) {
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_tok = NULL;
  PyObject *__pyx_v_ikey = NULL;
  PyObject *__pyx_v_dictvalue = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  int __pyx_t_15;
  __Pyx_RefNannySetupContext("postParse", 0);

  /* "cPyparsing.pyx":4394
 * 
 *     def postParse(self, instring, loc, tokenlist):
 *         for i, tok in enumerate(tokenlist):             # <<<<<<<<<<<<<<
 *             if len(tok) == 0:
 *                 continue
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_t_1 = __pyx_int_0;
  if (likely(PyList_CheckExact(__pyx_v_tokenlist)) || PyTuple_CheckExact(__pyx_v_tokenlist)) {
    __pyx_t_2 = __pyx_v_tokenlist; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_tokenlist); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4394, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4394, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 4394, __pyx_L1_error)
        #else
        __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4394, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 4394, __pyx_L1_error)
        #else
        __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4394, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      }
    } else {
      __pyx_t_5 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 4394, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_tok, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_1);
    __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_t_1, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4394, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1);
    __pyx_t_1 = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "cPyparsing.pyx":4395
 *     def postParse(self, instring, loc, tokenlist):
 *         for i, tok in enumerate(tokenlist):
 *             if len(tok) == 0:             # <<<<<<<<<<<<<<
 *                 continue
 *             ikey = tok[0]
 */
    __pyx_t_6 = PyObject_Length(__pyx_v_tok); if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 4395, __pyx_L1_error)
    __pyx_t_7 = ((__pyx_t_6 == 0) != 0);
    if (__pyx_t_7) {

      /* "cPyparsing.pyx":4396
 *         for i, tok in enumerate(tokenlist):
 *             if len(tok) == 0:
 *                 continue             # <<<<<<<<<<<<<<
 *             ikey = tok[0]
 *             if isinstance(ikey, int):
 */
      goto __pyx_L3_continue;

      /* "cPyparsing.pyx":4395
 *     def postParse(self, instring, loc, tokenlist):
 *         for i, tok in enumerate(tokenlist):
 *             if len(tok) == 0:             # <<<<<<<<<<<<<<
 *                 continue
 *             ikey = tok[0]
 */
    }

    /* "cPyparsing.pyx":4397
 *             if len(tok) == 0:
 *                 continue
 *             ikey = tok[0]             # <<<<<<<<<<<<<<
 *             if isinstance(ikey, int):
 *                 ikey = _ustr(tok[0]).strip()
 */
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_tok, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4397, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_XDECREF_SET(__pyx_v_ikey, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "cPyparsing.pyx":4398
 *                 continue
 *             ikey = tok[0]
 *             if isinstance(ikey, int):             # <<<<<<<<<<<<<<
 *                 ikey = _ustr(tok[0]).strip()
 *             if len(tok) == 1:
 */
    __pyx_t_7 = PyInt_Check(__pyx_v_ikey); 
    __pyx_t_8 = (__pyx_t_7 != 0);
    if (__pyx_t_8) {

      /* "cPyparsing.pyx":4399
 *             ikey = tok[0]
 *             if isinstance(ikey, int):
 *                 ikey = _ustr(tok[0]).strip()             # <<<<<<<<<<<<<<
 *             if len(tok) == 1:
 *                 tokenlist[ikey] = _ParseResultsWithOffset("", i)
 */
      __pyx_t_10 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4399, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_11 = __Pyx_GetItemInt(__pyx_v_tok, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4399, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_12 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_12)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_12);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      if (!__pyx_t_12) {
        __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_11); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4399, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_9);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_10)) {
          PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_11};
          __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4399, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
          PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_11};
          __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4399, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        } else
        #endif
        {
          __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4399, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_12); __pyx_t_12 = NULL;
          __Pyx_GIVEREF(__pyx_t_11);
          PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_t_11);
          __pyx_t_11 = 0;
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4399, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_strip); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4399, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      if (__pyx_t_9) {
        __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4399, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else {
        __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_10); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4399, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF_SET(__pyx_v_ikey, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "cPyparsing.pyx":4398
 *                 continue
 *             ikey = tok[0]
 *             if isinstance(ikey, int):             # <<<<<<<<<<<<<<
 *                 ikey = _ustr(tok[0]).strip()
 *             if len(tok) == 1:
 */
    }

    /* "cPyparsing.pyx":4400
 *             if isinstance(ikey, int):
 *                 ikey = _ustr(tok[0]).strip()
 *             if len(tok) == 1:             # <<<<<<<<<<<<<<
 *                 tokenlist[ikey] = _ParseResultsWithOffset("", i)
 *             elif len(tok) == 2 and not isinstance(tok[1], ParseResults):
 */
    __pyx_t_6 = PyObject_Length(__pyx_v_tok); if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 4400, __pyx_L1_error)
    __pyx_t_8 = ((__pyx_t_6 == 1) != 0);
    if (__pyx_t_8) {

      /* "cPyparsing.pyx":4401
 *                 ikey = _ustr(tok[0]).strip()
 *             if len(tok) == 1:
 *                 tokenlist[ikey] = _ParseResultsWithOffset("", i)             # <<<<<<<<<<<<<<
 *             elif len(tok) == 2 and not isinstance(tok[1], ParseResults):
 *                 tokenlist[ikey] = _ParseResultsWithOffset(tok[1], i)
 */
      __pyx_t_10 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResultsWithOffset); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4401, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_9 = NULL;
      __pyx_t_14 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_14 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u__9, __pyx_v_i};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4401, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_5);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u__9, __pyx_v_i};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4401, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_5);
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(2+__pyx_t_14); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4401, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u__9);
        __Pyx_GIVEREF(__pyx_kp_u__9);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_14, __pyx_kp_u__9);
        __Pyx_INCREF(__pyx_v_i);
        __Pyx_GIVEREF(__pyx_v_i);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_14, __pyx_v_i);
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4401, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(PyObject_SetItem(__pyx_v_tokenlist, __pyx_v_ikey, __pyx_t_5) < 0)) __PYX_ERR(0, 4401, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "cPyparsing.pyx":4400
 *             if isinstance(ikey, int):
 *                 ikey = _ustr(tok[0]).strip()
 *             if len(tok) == 1:             # <<<<<<<<<<<<<<
 *                 tokenlist[ikey] = _ParseResultsWithOffset("", i)
 *             elif len(tok) == 2 and not isinstance(tok[1], ParseResults):
 */
      goto __pyx_L7;
    }

    /* "cPyparsing.pyx":4402
 *             if len(tok) == 1:
 *                 tokenlist[ikey] = _ParseResultsWithOffset("", i)
 *             elif len(tok) == 2 and not isinstance(tok[1], ParseResults):             # <<<<<<<<<<<<<<
 *                 tokenlist[ikey] = _ParseResultsWithOffset(tok[1], i)
 *             else:
 */
    __pyx_t_6 = PyObject_Length(__pyx_v_tok); if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 4402, __pyx_L1_error)
    __pyx_t_7 = ((__pyx_t_6 == 2) != 0);
    if (__pyx_t_7) {
    } else {
      __pyx_t_8 = __pyx_t_7;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_tok, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4402, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_10 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4402, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_7 = PyObject_IsInstance(__pyx_t_5, __pyx_t_10); if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 4402, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_15 = ((!(__pyx_t_7 != 0)) != 0);
    __pyx_t_8 = __pyx_t_15;
    __pyx_L8_bool_binop_done:;
    if (__pyx_t_8) {

      /* "cPyparsing.pyx":4403
 *                 tokenlist[ikey] = _ParseResultsWithOffset("", i)
 *             elif len(tok) == 2 and not isinstance(tok[1], ParseResults):
 *                 tokenlist[ikey] = _ParseResultsWithOffset(tok[1], i)             # <<<<<<<<<<<<<<
 *             else:
 *                 dictvalue = tok.copy()  # ParseResults(i)
 */
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResultsWithOffset); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4403, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_13 = __Pyx_GetItemInt(__pyx_v_tok, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4403, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_9 = NULL;
      __pyx_t_14 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_14 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_t_13, __pyx_v_i};
        __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4403, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_t_13, __pyx_v_i};
        __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4403, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_14); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4403, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_GIVEREF(__pyx_t_13);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_14, __pyx_t_13);
        __Pyx_INCREF(__pyx_v_i);
        __Pyx_GIVEREF(__pyx_v_i);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_14, __pyx_v_i);
        __pyx_t_13 = 0;
        __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_11, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4403, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(PyObject_SetItem(__pyx_v_tokenlist, __pyx_v_ikey, __pyx_t_10) < 0)) __PYX_ERR(0, 4403, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "cPyparsing.pyx":4402
 *             if len(tok) == 1:
 *                 tokenlist[ikey] = _ParseResultsWithOffset("", i)
 *             elif len(tok) == 2 and not isinstance(tok[1], ParseResults):             # <<<<<<<<<<<<<<
 *                 tokenlist[ikey] = _ParseResultsWithOffset(tok[1], i)
 *             else:
 */
      goto __pyx_L7;
    }

    /* "cPyparsing.pyx":4405
 *                 tokenlist[ikey] = _ParseResultsWithOffset(tok[1], i)
 *             else:
 *                 dictvalue = tok.copy()  # ParseResults(i)             # <<<<<<<<<<<<<<
 *                 del dictvalue[0]
 *                 if len(dictvalue) != 1 or (isinstance(dictvalue, ParseResults) and dictvalue.haskeys()):
 */
    /*else*/ {
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_tok, __pyx_n_s_copy); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4405, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_11 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (__pyx_t_11) {
        __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_11); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4405, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      } else {
        __pyx_t_10 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4405, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF_SET(__pyx_v_dictvalue, __pyx_t_10);
      __pyx_t_10 = 0;

      /* "cPyparsing.pyx":4406
 *             else:
 *                 dictvalue = tok.copy()  # ParseResults(i)
 *                 del dictvalue[0]             # <<<<<<<<<<<<<<
 *                 if len(dictvalue) != 1 or (isinstance(dictvalue, ParseResults) and dictvalue.haskeys()):
 *                     tokenlist[ikey] = _ParseResultsWithOffset(dictvalue, i)
 */
      if (unlikely(__Pyx_DelItemInt(__pyx_v_dictvalue, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1) < 0)) __PYX_ERR(0, 4406, __pyx_L1_error)

      /* "cPyparsing.pyx":4407
 *                 dictvalue = tok.copy()  # ParseResults(i)
 *                 del dictvalue[0]
 *                 if len(dictvalue) != 1 or (isinstance(dictvalue, ParseResults) and dictvalue.haskeys()):             # <<<<<<<<<<<<<<
 *                     tokenlist[ikey] = _ParseResultsWithOffset(dictvalue, i)
 *                 else:
 */
      __pyx_t_6 = PyObject_Length(__pyx_v_dictvalue); if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 4407, __pyx_L1_error)
      __pyx_t_15 = ((__pyx_t_6 != 1) != 0);
      if (!__pyx_t_15) {
      } else {
        __pyx_t_8 = __pyx_t_15;
        goto __pyx_L11_bool_binop_done;
      }
      __pyx_t_10 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4407, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_15 = PyObject_IsInstance(__pyx_v_dictvalue, __pyx_t_10); if (unlikely(__pyx_t_15 == -1)) __PYX_ERR(0, 4407, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_7 = (__pyx_t_15 != 0);
      if (__pyx_t_7) {
      } else {
        __pyx_t_8 = __pyx_t_7;
        goto __pyx_L11_bool_binop_done;
      }
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_dictvalue, __pyx_n_s_haskeys); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4407, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_11 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (__pyx_t_11) {
        __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_11); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4407, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      } else {
        __pyx_t_10 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4407, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 4407, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_8 = __pyx_t_7;
      __pyx_L11_bool_binop_done:;
      if (__pyx_t_8) {

        /* "cPyparsing.pyx":4408
 *                 del dictvalue[0]
 *                 if len(dictvalue) != 1 or (isinstance(dictvalue, ParseResults) and dictvalue.haskeys()):
 *                     tokenlist[ikey] = _ParseResultsWithOffset(dictvalue, i)             # <<<<<<<<<<<<<<
 *                 else:
 *                     tokenlist[ikey] = _ParseResultsWithOffset(dictvalue[0], i)
 */
        __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResultsWithOffset); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4408, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_11 = NULL;
        __pyx_t_14 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_11)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_11);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_14 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_v_dictvalue, __pyx_v_i};
          __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4408, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_GOTREF(__pyx_t_10);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_v_dictvalue, __pyx_v_i};
          __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4408, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_GOTREF(__pyx_t_10);
        } else
        #endif
        {
          __pyx_t_13 = PyTuple_New(2+__pyx_t_14); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4408, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          if (__pyx_t_11) {
            __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
          }
          __Pyx_INCREF(__pyx_v_dictvalue);
          __Pyx_GIVEREF(__pyx_v_dictvalue);
          PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_14, __pyx_v_dictvalue);
          __Pyx_INCREF(__pyx_v_i);
          __Pyx_GIVEREF(__pyx_v_i);
          PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_14, __pyx_v_i);
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_13, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4408, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        }
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(PyObject_SetItem(__pyx_v_tokenlist, __pyx_v_ikey, __pyx_t_10) < 0)) __PYX_ERR(0, 4408, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

        /* "cPyparsing.pyx":4407
 *                 dictvalue = tok.copy()  # ParseResults(i)
 *                 del dictvalue[0]
 *                 if len(dictvalue) != 1 or (isinstance(dictvalue, ParseResults) and dictvalue.haskeys()):             # <<<<<<<<<<<<<<
 *                     tokenlist[ikey] = _ParseResultsWithOffset(dictvalue, i)
 *                 else:
 */
        goto __pyx_L10;
      }

      /* "cPyparsing.pyx":4410
 *                     tokenlist[ikey] = _ParseResultsWithOffset(dictvalue, i)
 *                 else:
 *                     tokenlist[ikey] = _ParseResultsWithOffset(dictvalue[0], i)             # <<<<<<<<<<<<<<
 * 
 *         if self.resultsName:
 */
      /*else*/ {
        __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResultsWithOffset); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4410, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_13 = __Pyx_GetItemInt(__pyx_v_dictvalue, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4410, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_11 = NULL;
        __pyx_t_14 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_11)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_11);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_14 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_t_13, __pyx_v_i};
          __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4410, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_t_13, __pyx_v_i};
          __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4410, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        } else
        #endif
        {
          __pyx_t_9 = PyTuple_New(2+__pyx_t_14); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4410, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          if (__pyx_t_11) {
            __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_11); __pyx_t_11 = NULL;
          }
          __Pyx_GIVEREF(__pyx_t_13);
          PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_14, __pyx_t_13);
          __Pyx_INCREF(__pyx_v_i);
          __Pyx_GIVEREF(__pyx_v_i);
          PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_14, __pyx_v_i);
          __pyx_t_13 = 0;
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_9, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4410, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(PyObject_SetItem(__pyx_v_tokenlist, __pyx_v_ikey, __pyx_t_10) < 0)) __PYX_ERR(0, 4410, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __pyx_L10:;
    }
    __pyx_L7:;

    /* "cPyparsing.pyx":4394
 * 
 *     def postParse(self, instring, loc, tokenlist):
 *         for i, tok in enumerate(tokenlist):             # <<<<<<<<<<<<<<
 *             if len(tok) == 0:
 *                 continue
 */
    __pyx_L3_continue:;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4412
 *                     tokenlist[ikey] = _ParseResultsWithOffset(dictvalue[0], i)
 * 
 *         if self.resultsName:             # <<<<<<<<<<<<<<
 *             return [tokenlist]
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_resultsName); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 4412, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_8) {

    /* "cPyparsing.pyx":4413
 * 
 *         if self.resultsName:
 *             return [tokenlist]             # <<<<<<<<<<<<<<
 *         else:
 *             return tokenlist
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4413, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_tokenlist);
    __Pyx_GIVEREF(__pyx_v_tokenlist);
    PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_tokenlist);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":4412
 *                     tokenlist[ikey] = _ParseResultsWithOffset(dictvalue[0], i)
 * 
 *         if self.resultsName:             # <<<<<<<<<<<<<<
 *             return [tokenlist]
 *         else:
 */
  }

  /* "cPyparsing.pyx":4415
 *             return [tokenlist]
 *         else:
 *             return tokenlist             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_tokenlist);
    __pyx_r = __pyx_v_tokenlist;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":4393
 *         self.saveAsList = True
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         for i, tok in enumerate(tokenlist):
 *             if len(tok) == 0:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("cPyparsing.Dict.postParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_tok);
  __Pyx_XDECREF(__pyx_v_ikey);
  __Pyx_XDECREF(__pyx_v_dictvalue);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4438
 *     """
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         return []
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_8Suppress_1postParse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_8Suppress_1postParse = {"postParse", (PyCFunction)__pyx_pw_10cPyparsing_8Suppress_1postParse, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_8Suppress_1postParse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  CYTHON_UNUSED PyObject *__pyx_v_instring = 0;
  CYTHON_UNUSED PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_tokenlist = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("postParse (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_instring,&__pyx_n_s_loc,&__pyx_n_s_tokenlist,0};
    PyObject* values[4] = {0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_instring)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 1); __PYX_ERR(0, 4438, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 2); __PYX_ERR(0, 4438, __pyx_L3_error)
        }
        case  3:
        if (likely((values[3] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_tokenlist)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, 3); __PYX_ERR(0, 4438, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "postParse") < 0)) __PYX_ERR(0, 4438, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 4) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
    }
    __pyx_v_self = values[0];
    __pyx_v_instring = values[1];
    __pyx_v_loc = values[2];
    __pyx_v_tokenlist = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("postParse", 1, 4, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4438, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.Suppress.postParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_8Suppress_postParse(__pyx_self, __pyx_v_self, __pyx_v_instring, __pyx_v_loc, __pyx_v_tokenlist);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_8Suppress_postParse(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_instring, CYTHON_UNUSED PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_tokenlist) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("postParse", 0);

  /* "cPyparsing.pyx":4439
 * 
 *     def postParse(self, instring, loc, tokenlist):
 *         return []             # <<<<<<<<<<<<<<
 * 
 *     def suppress(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4438
 *     """
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         return []
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.Suppress.postParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4441
 *         return []
 * 
 *     def suppress(self):             # <<<<<<<<<<<<<<
 *         return self
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_8Suppress_3suppress(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_8Suppress_3suppress = {"suppress", (PyCFunction)__pyx_pw_10cPyparsing_8Suppress_3suppress, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_8Suppress_3suppress(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("suppress (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_8Suppress_2suppress(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_8Suppress_2suppress(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("suppress", 0);

  /* "cPyparsing.pyx":4442
 * 
 *     def suppress(self):
 *         return self             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self);
  __pyx_r = __pyx_v_self;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4441
 *         return []
 * 
 *     def suppress(self):             # <<<<<<<<<<<<<<
 *         return self
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4450
 *     """
 * 
 *     def __init__(self, methodCall):             # <<<<<<<<<<<<<<
 *         self.callable = _trim_arity(methodCall)
 *         self.called = False
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_8OnlyOnce_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_8OnlyOnce_1__init__ = {"__init__", (PyCFunction)__pyx_pw_10cPyparsing_8OnlyOnce_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_8OnlyOnce_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_methodCall = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_methodCall,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_methodCall)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 4450, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 4450, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_methodCall = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4450, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.OnlyOnce.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_8OnlyOnce___init__(__pyx_self, __pyx_v_self, __pyx_v_methodCall);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_8OnlyOnce___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_methodCall) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cPyparsing.pyx":4451
 * 
 *     def __init__(self, methodCall):
 *         self.callable = _trim_arity(methodCall)             # <<<<<<<<<<<<<<
 *         self.called = False
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_trim_arity); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_methodCall); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4451, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_methodCall};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4451, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_methodCall};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4451, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4451, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_v_methodCall);
      __Pyx_GIVEREF(__pyx_v_methodCall);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_methodCall);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4451, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_callable, __pyx_t_1) < 0) __PYX_ERR(0, 4451, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4452
 *     def __init__(self, methodCall):
 *         self.callable = _trim_arity(methodCall)
 *         self.called = False             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, s, l, t):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_called, Py_False) < 0) __PYX_ERR(0, 4452, __pyx_L1_error)

  /* "cPyparsing.pyx":4450
 *     """
 * 
 *     def __init__(self, methodCall):             # <<<<<<<<<<<<<<
 *         self.callable = _trim_arity(methodCall)
 *         self.called = False
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.OnlyOnce.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4454
 *         self.called = False
 * 
 *     def __call__(self, s, l, t):             # <<<<<<<<<<<<<<
 *         if not self.called:
 *             results = self.callable(s, l, t)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_8OnlyOnce_3__call__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_8OnlyOnce_3__call__ = {"__call__", (PyCFunction)__pyx_pw_10cPyparsing_8OnlyOnce_3__call__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_8OnlyOnce_3__call__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_s = 0;
  PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    PyObject* values[4] = {0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__call__", 1, 4, 4, 1); __PYX_ERR(0, 4454, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__call__", 1, 4, 4, 2); __PYX_ERR(0, 4454, __pyx_L3_error)
        }
        case  3:
        if (likely((values[3] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__call__", 1, 4, 4, 3); __PYX_ERR(0, 4454, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__call__") < 0)) __PYX_ERR(0, 4454, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 4) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
    }
    __pyx_v_self = values[0];
    __pyx_v_s = values[1];
    __pyx_v_l = values[2];
    __pyx_v_t = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 1, 4, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4454, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.OnlyOnce.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_8OnlyOnce_2__call__(__pyx_self, __pyx_v_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_8OnlyOnce_2__call__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  PyObject *__pyx_v_results = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "cPyparsing.pyx":4455
 * 
 *     def __call__(self, s, l, t):
 *         if not self.called:             # <<<<<<<<<<<<<<
 *             results = self.callable(s, l, t)
 *             self.called = True
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_called); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 4455, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = ((!__pyx_t_2) != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":4456
 *     def __call__(self, s, l, t):
 *         if not self.called:
 *             results = self.callable(s, l, t)             # <<<<<<<<<<<<<<
 *             self.called = True
 *             return results
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_callable); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_v_s, __pyx_v_l, __pyx_v_t};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4456, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_v_s, __pyx_v_l, __pyx_v_t};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4456, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(3+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4456, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__pyx_t_5) {
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
      }
      __Pyx_INCREF(__pyx_v_s);
      __Pyx_GIVEREF(__pyx_v_s);
      PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_s);
      __Pyx_INCREF(__pyx_v_l);
      __Pyx_GIVEREF(__pyx_v_l);
      PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_v_l);
      __Pyx_INCREF(__pyx_v_t);
      __Pyx_GIVEREF(__pyx_v_t);
      PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_6, __pyx_v_t);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4456, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_results = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4457
 *         if not self.called:
 *             results = self.callable(s, l, t)
 *             self.called = True             # <<<<<<<<<<<<<<
 *             return results
 *         raise ParseException(s, l, "")
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_called, Py_True) < 0) __PYX_ERR(0, 4457, __pyx_L1_error)

    /* "cPyparsing.pyx":4458
 *             results = self.callable(s, l, t)
 *             self.called = True
 *             return results             # <<<<<<<<<<<<<<
 *         raise ParseException(s, l, "")
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_results);
    __pyx_r = __pyx_v_results;
    goto __pyx_L0;

    /* "cPyparsing.pyx":4455
 * 
 *     def __call__(self, s, l, t):
 *         if not self.called:             # <<<<<<<<<<<<<<
 *             results = self.callable(s, l, t)
 *             self.called = True
 */
  }

  /* "cPyparsing.pyx":4459
 *             self.called = True
 *             return results
 *         raise ParseException(s, l, "")             # <<<<<<<<<<<<<<
 * 
 *     def reset(self):
 */
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_4)) {
    PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_v_s, __pyx_v_l, __pyx_kp_u__9};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4459, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
    PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_v_s, __pyx_v_l, __pyx_kp_u__9};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4459, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(3+__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4459, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_7) {
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7); __pyx_t_7 = NULL;
    }
    __Pyx_INCREF(__pyx_v_s);
    __Pyx_GIVEREF(__pyx_v_s);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_6, __pyx_v_s);
    __Pyx_INCREF(__pyx_v_l);
    __Pyx_GIVEREF(__pyx_v_l);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_6, __pyx_v_l);
    __Pyx_INCREF(__pyx_kp_u__9);
    __Pyx_GIVEREF(__pyx_kp_u__9);
    PyTuple_SET_ITEM(__pyx_t_5, 2+__pyx_t_6, __pyx_kp_u__9);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4459, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 4459, __pyx_L1_error)

  /* "cPyparsing.pyx":4454
 *         self.called = False
 * 
 *     def __call__(self, s, l, t):             # <<<<<<<<<<<<<<
 *         if not self.called:
 *             results = self.callable(s, l, t)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.OnlyOnce.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_results);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4461
 *         raise ParseException(s, l, "")
 * 
 *     def reset(self):             # <<<<<<<<<<<<<<
 *         self.called = False
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_8OnlyOnce_5reset(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_8OnlyOnce_5reset = {"reset", (PyCFunction)__pyx_pw_10cPyparsing_8OnlyOnce_5reset, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_8OnlyOnce_5reset(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reset (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_8OnlyOnce_4reset(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_8OnlyOnce_4reset(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reset", 0);

  /* "cPyparsing.pyx":4462
 * 
 *     def reset(self):
 *         self.called = False             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_called, Py_False) < 0) __PYX_ERR(0, 4462, __pyx_L1_error)

  /* "cPyparsing.pyx":4461
 *         raise ParseException(s, l, "")
 * 
 *     def reset(self):             # <<<<<<<<<<<<<<
 *         self.called = False
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.OnlyOnce.reset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4465
 * 
 * 
 * def traceParseAction(f):             # <<<<<<<<<<<<<<
 *     """
 *     Decorator for debugging parse actions.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_23traceParseAction(PyObject *__pyx_self, PyObject *__pyx_v_f); /*proto*/
static char __pyx_doc_10cPyparsing_22traceParseAction[] = "\n    Decorator for debugging parse actions.\n\n    When the parse action is called, this decorator will print C{\">> entering I{method-name}(line:I{current_source_line}, I{parse_location}, I{matched_tokens})\".}\n    When the parse action completes, the decorator will print C{\"<<\"} followed by the returned value, or any exception that the parse action raised.\n\n    Example::\n        wd = Word(alphas)\n\n        @traceParseAction\n        def remove_duplicate_chars(tokens):\n            return ''.join(sorted(set(''.join(tokens)))\n\n        wds = OneOrMore(wd).setParseAction(remove_duplicate_chars)\n        print(wds.parseString(\"slkdjs sld sldd sdlf sdljf\"))\n    prints::\n        >>entering remove_duplicate_chars(line: 'slkdjs sld sldd sdlf sdljf', 0, (['slkdjs', 'sld', 'sldd', 'sdlf', 'sdljf'], {}))\n        <<leaving remove_duplicate_chars (ret: 'dfjkls')\n        ['dfjkls']\n    ";
static PyMethodDef __pyx_mdef_10cPyparsing_23traceParseAction = {"traceParseAction", (PyCFunction)__pyx_pw_10cPyparsing_23traceParseAction, METH_O, __pyx_doc_10cPyparsing_22traceParseAction};
static PyObject *__pyx_pw_10cPyparsing_23traceParseAction(PyObject *__pyx_self, PyObject *__pyx_v_f) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("traceParseAction (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_22traceParseAction(__pyx_self, ((PyObject *)__pyx_v_f));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4488
 *     f = _trim_arity(f)
 * 
 *     def z(*paArgs):             # <<<<<<<<<<<<<<
 *         thisFunc = f.__name__
 *         s, l, t = paArgs[-3:]
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_16traceParseAction_1z(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_16traceParseAction_1z = {"z", (PyCFunction)__pyx_pw_10cPyparsing_16traceParseAction_1z, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_16traceParseAction_1z(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_paArgs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("z (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "z", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_paArgs = __pyx_args;
  __pyx_r = __pyx_pf_10cPyparsing_16traceParseAction_z(__pyx_self, __pyx_v_paArgs);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_paArgs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_16traceParseAction_z(PyObject *__pyx_self, PyObject *__pyx_v_paArgs) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_traceParseAction *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_traceParseAction *__pyx_outer_scope;
  PyObject *__pyx_v_thisFunc = NULL;
  PyObject *__pyx_v_s = NULL;
  PyObject *__pyx_v_l = NULL;
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  char const *__pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  __Pyx_RefNannySetupContext("z", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_traceParseAction *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":4489
 * 
 *     def z(*paArgs):
 *         thisFunc = f.__name__             # <<<<<<<<<<<<<<
 *         s, l, t = paArgs[-3:]
 *         if len(paArgs) > 3:
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_f)) { __Pyx_RaiseClosureNameError("f"); __PYX_ERR(0, 4489, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_f, __pyx_n_s_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_thisFunc = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4490
 *     def z(*paArgs):
 *         thisFunc = f.__name__
 *         s, l, t = paArgs[-3:]             # <<<<<<<<<<<<<<
 *         if len(paArgs) > 3:
 *             thisFunc = paArgs[0].__class__.__name__ + '.' + thisFunc
 */
  __pyx_t_1 = __Pyx_PyTuple_GetSlice(__pyx_v_paArgs, -3L, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (1) {
    PyObject* sequence = __pyx_t_1;
    #if !CYTHON_COMPILING_IN_PYPY
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 3)) {
      if (size > 3) __Pyx_RaiseTooManyValuesError(3);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 4490, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
    __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    __pyx_t_4 = PyTuple_GET_ITEM(sequence, 2); 
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4490, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4490, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4490, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_v_s = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_l = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_t = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":4491
 *         thisFunc = f.__name__
 *         s, l, t = paArgs[-3:]
 *         if len(paArgs) > 3:             # <<<<<<<<<<<<<<
 *             thisFunc = paArgs[0].__class__.__name__ + '.' + thisFunc
 *         sys.stderr.write(">>entering %s(line: '%s', %d, %r)\n" % (thisFunc, line(l, s), l, t))
 */
  __pyx_t_5 = PyTuple_GET_SIZE(__pyx_v_paArgs); if (unlikely(__pyx_t_5 == -1)) __PYX_ERR(0, 4491, __pyx_L1_error)
  __pyx_t_6 = ((__pyx_t_5 > 3) != 0);
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":4492
 *         s, l, t = paArgs[-3:]
 *         if len(paArgs) > 3:
 *             thisFunc = paArgs[0].__class__.__name__ + '.' + thisFunc             # <<<<<<<<<<<<<<
 *         sys.stderr.write(">>entering %s(line: '%s', %d, %r)\n" % (thisFunc, line(l, s), l, t))
 *         try:
 */
    __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v_paArgs, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4492, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_class); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4492, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4492, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Add(__pyx_t_1, __pyx_kp_u__129); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4492, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Add(__pyx_t_4, __pyx_v_thisFunc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4492, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_thisFunc, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4491
 *         thisFunc = f.__name__
 *         s, l, t = paArgs[-3:]
 *         if len(paArgs) > 3:             # <<<<<<<<<<<<<<
 *             thisFunc = paArgs[0].__class__.__name__ + '.' + thisFunc
 *         sys.stderr.write(">>entering %s(line: '%s', %d, %r)\n" % (thisFunc, line(l, s), l, t))
 */
  }

  /* "cPyparsing.pyx":4493
 *         if len(paArgs) > 3:
 *             thisFunc = paArgs[0].__class__.__name__ + '.' + thisFunc
 *         sys.stderr.write(">>entering %s(line: '%s', %d, %r)\n" % (thisFunc, line(l, s), l, t))             # <<<<<<<<<<<<<<
 *         try:
 *             ret = f(*paArgs)
 */
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_stderr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_write); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_line); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = NULL;
  __pyx_t_8 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_8 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_v_l, __pyx_v_s};
    __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4493, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_v_l, __pyx_v_s};
    __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4493, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else
  #endif
  {
    __pyx_t_9 = PyTuple_New(2+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4493, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (__pyx_t_7) {
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
    }
    __Pyx_INCREF(__pyx_v_l);
    __Pyx_GIVEREF(__pyx_v_l);
    PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_v_l);
    __Pyx_INCREF(__pyx_v_s);
    __Pyx_GIVEREF(__pyx_v_s);
    PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, __pyx_v_s);
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_9, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4493, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_thisFunc);
  __Pyx_GIVEREF(__pyx_v_thisFunc);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_thisFunc);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3);
  __Pyx_INCREF(__pyx_v_l);
  __Pyx_GIVEREF(__pyx_v_l);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_l);
  __Pyx_INCREF(__pyx_v_t);
  __Pyx_GIVEREF(__pyx_v_t);
  PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_v_t);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyUnicode_Format(__pyx_kp_u_entering_s_line_s_d_r, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4493, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4493, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4493, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4493, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4493, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4494
 *             thisFunc = paArgs[0].__class__.__name__ + '.' + thisFunc
 *         sys.stderr.write(">>entering %s(line: '%s', %d, %r)\n" % (thisFunc, line(l, s), l, t))
 *         try:             # <<<<<<<<<<<<<<
 *             ret = f(*paArgs)
 *         except Exception as exc:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
    __Pyx_XGOTREF(__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_11);
    __Pyx_XGOTREF(__pyx_t_12);
    /*try:*/ {

      /* "cPyparsing.pyx":4495
 *         sys.stderr.write(">>entering %s(line: '%s', %d, %r)\n" % (thisFunc, line(l, s), l, t))
 *         try:
 *             ret = f(*paArgs)             # <<<<<<<<<<<<<<
 *         except Exception as exc:
 *             sys.stderr.write("<<leaving %s (exception: %s)\n" % (thisFunc, exc))
 */
      if (unlikely(!__pyx_cur_scope->__pyx_v_f)) { __Pyx_RaiseClosureNameError("f"); __PYX_ERR(0, 4495, __pyx_L4_error) }
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_cur_scope->__pyx_v_f, __pyx_v_paArgs, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4495, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_ret = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "cPyparsing.pyx":4494
 *             thisFunc = paArgs[0].__class__.__name__ + '.' + thisFunc
 *         sys.stderr.write(">>entering %s(line: '%s', %d, %r)\n" % (thisFunc, line(l, s), l, t))
 *         try:             # <<<<<<<<<<<<<<
 *             ret = f(*paArgs)
 *         except Exception as exc:
 */
    }
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    goto __pyx_L11_try_end;
    __pyx_L4_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4496
 *         try:
 *             ret = f(*paArgs)
 *         except Exception as exc:             # <<<<<<<<<<<<<<
 *             sys.stderr.write("<<leaving %s (exception: %s)\n" % (thisFunc, exc))
 *             raise
 */
    __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_8) {
      __Pyx_AddTraceback("cPyparsing.traceParseAction.z", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_4, &__pyx_t_9) < 0) __PYX_ERR(0, 4496, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_v_exc = __pyx_t_4;
      /*try:*/ {

        /* "cPyparsing.pyx":4497
 *             ret = f(*paArgs)
 *         except Exception as exc:
 *             sys.stderr.write("<<leaving %s (exception: %s)\n" % (thisFunc, exc))             # <<<<<<<<<<<<<<
 *             raise
 *         sys.stderr.write("<<leaving %s (ret: %r)\n" % (thisFunc, ret))
 */
        __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4497, __pyx_L17_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_stderr); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4497, __pyx_L17_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_write); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4497, __pyx_L17_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4497, __pyx_L17_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_INCREF(__pyx_v_thisFunc);
        __Pyx_GIVEREF(__pyx_v_thisFunc);
        PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_v_thisFunc);
        __Pyx_INCREF(__pyx_v_exc);
        __Pyx_GIVEREF(__pyx_v_exc);
        PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_v_exc);
        __pyx_t_13 = PyUnicode_Format(__pyx_kp_u_leaving_s_exception_s, __pyx_t_7); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4497, __pyx_L17_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
          }
        }
        if (!__pyx_t_7) {
          __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_13); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4497, __pyx_L17_error)
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_2)) {
            PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_13};
            __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4497, __pyx_L17_error)
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
            PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_13};
            __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4497, __pyx_L17_error)
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          } else
          #endif
          {
            __pyx_t_14 = PyTuple_New(1+1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4497, __pyx_L17_error)
            __Pyx_GOTREF(__pyx_t_14);
            __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_7); __pyx_t_7 = NULL;
            __Pyx_GIVEREF(__pyx_t_13);
            PyTuple_SET_ITEM(__pyx_t_14, 0+1, __pyx_t_13);
            __pyx_t_13 = 0;
            __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_14, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4497, __pyx_L17_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "cPyparsing.pyx":4498
 *         except Exception as exc:
 *             sys.stderr.write("<<leaving %s (exception: %s)\n" % (thisFunc, exc))
 *             raise             # <<<<<<<<<<<<<<
 *         sys.stderr.write("<<leaving %s (ret: %r)\n" % (thisFunc, ret))
 *         return ret
 */
        __Pyx_GIVEREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_4);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_ErrRestoreWithState(__pyx_t_1, __pyx_t_4, __pyx_t_9);
        __pyx_t_1 = 0; __pyx_t_4 = 0; __pyx_t_9 = 0; 
        __PYX_ERR(0, 4498, __pyx_L17_error)
      }

      /* "cPyparsing.pyx":4496
 *         try:
 *             ret = f(*paArgs)
 *         except Exception as exc:             # <<<<<<<<<<<<<<
 *             sys.stderr.write("<<leaving %s (exception: %s)\n" % (thisFunc, exc))
 *             raise
 */
      /*finally:*/ {
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __pyx_L17_error:;
          __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
          __Pyx_PyThreadState_assign
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19) < 0)) __Pyx_ErrFetch(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_22);
          __pyx_t_8 = __pyx_lineno; __pyx_t_15 = __pyx_clineno; __pyx_t_16 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
          }
          __Pyx_PyThreadState_assign
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_XGIVEREF(__pyx_t_22);
            __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_21, __pyx_t_22);
          }
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_ErrRestore(__pyx_t_17, __pyx_t_18, __pyx_t_19);
          __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
          __pyx_lineno = __pyx_t_8; __pyx_clineno = __pyx_t_15; __pyx_filename = __pyx_t_16;
          goto __pyx_L6_except_error;
        }
      }
    }
    goto __pyx_L6_except_error;
    __pyx_L6_except_error:;

    /* "cPyparsing.pyx":4494
 *             thisFunc = paArgs[0].__class__.__name__ + '.' + thisFunc
 *         sys.stderr.write(">>entering %s(line: '%s', %d, %r)\n" % (thisFunc, line(l, s), l, t))
 *         try:             # <<<<<<<<<<<<<<
 *             ret = f(*paArgs)
 *         except Exception as exc:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_11);
    __Pyx_XGIVEREF(__pyx_t_12);
    __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
    goto __pyx_L1_error;
    __pyx_L11_try_end:;
  }

  /* "cPyparsing.pyx":4499
 *             sys.stderr.write("<<leaving %s (exception: %s)\n" % (thisFunc, exc))
 *             raise
 *         sys.stderr.write("<<leaving %s (ret: %r)\n" % (thisFunc, ret))             # <<<<<<<<<<<<<<
 *         return ret
 *     try:
 */
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_stderr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_write); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_thisFunc);
  __Pyx_GIVEREF(__pyx_v_thisFunc);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_thisFunc);
  __Pyx_INCREF(__pyx_v_ret);
  __Pyx_GIVEREF(__pyx_v_ret);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_ret);
  __pyx_t_3 = PyUnicode_Format(__pyx_kp_u_leaving_s_ret_r, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (!__pyx_t_1) {
    __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4499, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_9);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_3};
      __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4499, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_3};
      __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4499, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_2 = PyTuple_New(1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4499, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1); __pyx_t_1 = NULL;
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_2, 0+1, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_2, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4499, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":4500
 *             raise
 *         sys.stderr.write("<<leaving %s (ret: %r)\n" % (thisFunc, ret))
 *         return ret             # <<<<<<<<<<<<<<
 *     try:
 *         z.__name__ = f.__name__
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ret);
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4488
 *     f = _trim_arity(f)
 * 
 *     def z(*paArgs):             # <<<<<<<<<<<<<<
 *         thisFunc = f.__name__
 *         s, l, t = paArgs[-3:]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("cPyparsing.traceParseAction.z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_thisFunc);
  __Pyx_XDECREF(__pyx_v_s);
  __Pyx_XDECREF(__pyx_v_l);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4465
 * 
 * 
 * def traceParseAction(f):             # <<<<<<<<<<<<<<
 *     """
 *     Decorator for debugging parse actions.
 */

static PyObject *__pyx_pf_10cPyparsing_22traceParseAction(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_f) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_traceParseAction *__pyx_cur_scope;
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  __Pyx_RefNannySetupContext("traceParseAction", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_traceParseAction *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_55_traceParseAction(__pyx_ptype_10cPyparsing___pyx_scope_struct_55_traceParseAction, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_traceParseAction *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4465, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_f = __pyx_v_f;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_f);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_f);

  /* "cPyparsing.pyx":4486
 *         ['dfjkls']
 *     """
 *     f = _trim_arity(f)             # <<<<<<<<<<<<<<
 * 
 *     def z(*paArgs):
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_trim_arity); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_cur_scope->__pyx_v_f); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4486, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_cur_scope->__pyx_v_f};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4486, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_cur_scope->__pyx_v_f};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4486, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_f);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_f);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_cur_scope->__pyx_v_f);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_f);
  __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_f, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4488
 *     f = _trim_arity(f)
 * 
 *     def z(*paArgs):             # <<<<<<<<<<<<<<
 *         thisFunc = f.__name__
 *         s, l, t = paArgs[-3:]
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_16traceParseAction_1z, 0, __pyx_n_s_traceParseAction_locals_z, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__131)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_z = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4501
 *         sys.stderr.write("<<leaving %s (ret: %r)\n" % (thisFunc, ret))
 *         return ret
 *     try:             # <<<<<<<<<<<<<<
 *         z.__name__ = f.__name__
 *     except AttributeError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_7);
    /*try:*/ {

      /* "cPyparsing.pyx":4502
 *         return ret
 *     try:
 *         z.__name__ = f.__name__             # <<<<<<<<<<<<<<
 *     except AttributeError:
 *         pass
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_f, __pyx_n_s_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4502, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_z, __pyx_n_s_name_2, __pyx_t_1) < 0) __PYX_ERR(0, 4502, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":4501
 *         sys.stderr.write("<<leaving %s (ret: %r)\n" % (thisFunc, ret))
 *         return ret
 *     try:             # <<<<<<<<<<<<<<
 *         z.__name__ = f.__name__
 *     except AttributeError:
 */
    }
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    goto __pyx_L10_try_end;
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4503
 *     try:
 *         z.__name__ = f.__name__
 *     except AttributeError:             # <<<<<<<<<<<<<<
 *         pass
 *     return z
 */
    __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
    if (__pyx_t_8) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cPyparsing.pyx":4501
 *         sys.stderr.write("<<leaving %s (ret: %r)\n" % (thisFunc, ret))
 *         return ret
 *     try:             # <<<<<<<<<<<<<<
 *         z.__name__ = f.__name__
 *     except AttributeError:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
    __pyx_L10_try_end:;
  }

  /* "cPyparsing.pyx":4505
 *     except AttributeError:
 *         pass
 *     return z             # <<<<<<<<<<<<<<
 * 
 * #
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_z);
  __pyx_r = __pyx_v_z;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4465
 * 
 * 
 * def traceParseAction(f):             # <<<<<<<<<<<<<<
 *     """
 *     Decorator for debugging parse actions.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.traceParseAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_z);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4512
 * 
 * 
 * def delimitedList(expr, delim=",", combine=False):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define a delimited list of expressions - the delimiter defaults to ','.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_25delimitedList(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_24delimitedList[] = "\n    Helper to define a delimited list of expressions - the delimiter defaults to ','.\n    By default, the list elements and delimiters can have intervening whitespace, and\n    comments, but this can be overridden by passing C{combine=True} in the constructor.\n    If C{combine} is set to C{True}, the matching tokens are returned as a single token\n    string, with the delimiters included; otherwise, the matching tokens are returned\n    as a list of tokens, with the delimiters suppressed.\n\n    Example::\n        delimitedList(Word(alphas)).parseString(\"aa,bb,cc\") # -> ['aa', 'bb', 'cc']\n        delimitedList(Word(hexnums), delim=':', combine=True).parseString(\"AA:BB:CC:DD:EE\") # -> ['AA:BB:CC:DD:EE']\n    ";
static PyMethodDef __pyx_mdef_10cPyparsing_25delimitedList = {"delimitedList", (PyCFunction)__pyx_pw_10cPyparsing_25delimitedList, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_24delimitedList};
static PyObject *__pyx_pw_10cPyparsing_25delimitedList(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_delim = 0;
  PyObject *__pyx_v_combine = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("delimitedList (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_expr,&__pyx_n_s_delim,&__pyx_n_s_combine,0};
    PyObject* values[3] = {0,0,0};
    values[1] = ((PyObject *)__pyx_kp_u__132);
    values[2] = ((PyObject *)Py_False);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_expr)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_delim);
          if (value) { values[1] = value; kw_args--; }
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_combine);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "delimitedList") < 0)) __PYX_ERR(0, 4512, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_expr = values[0];
    __pyx_v_delim = values[1];
    __pyx_v_combine = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("delimitedList", 0, 1, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4512, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.delimitedList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_24delimitedList(__pyx_self, __pyx_v_expr, __pyx_v_delim, __pyx_v_combine);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_24delimitedList(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_delim, PyObject *__pyx_v_combine) {
  PyObject *__pyx_v_dlName = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("delimitedList", 0);

  /* "cPyparsing.pyx":4525
 *         delimitedList(Word(hexnums), delim=':', combine=True).parseString("AA:BB:CC:DD:EE") # -> ['AA:BB:CC:DD:EE']
 *     """
 *     dlName = _ustr(expr) + " [" + _ustr(delim) + " " + _ustr(expr) + "]..."             # <<<<<<<<<<<<<<
 *     if combine:
 *         return Combine(expr + ZeroOrMore(delim + expr)).setName(dlName)
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_expr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4525, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_expr};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4525, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_expr};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4525, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4525, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_v_expr);
      __Pyx_GIVEREF(__pyx_v_expr);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_expr);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4525, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_kp_u__133); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_delim); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4525, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_delim};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4525, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_delim};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4525, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4525, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_v_delim);
      __Pyx_GIVEREF(__pyx_v_delim);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_delim);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4525, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_Add(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_4, __pyx_kp_u__84); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_5) {
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_expr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4525, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_expr};
      __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4525, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_4);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_expr};
      __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4525, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_4);
    } else
    #endif
    {
      __pyx_t_3 = PyTuple_New(1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4525, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5); __pyx_t_5 = NULL;
      __Pyx_INCREF(__pyx_v_expr);
      __Pyx_GIVEREF(__pyx_v_expr);
      PyTuple_SET_ITEM(__pyx_t_3, 0+1, __pyx_v_expr);
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4525, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_Add(__pyx_t_2, __pyx_kp_u__125); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_dlName = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cPyparsing.pyx":4526
 *     """
 *     dlName = _ustr(expr) + " [" + _ustr(delim) + " " + _ustr(expr) + "]..."
 *     if combine:             # <<<<<<<<<<<<<<
 *         return Combine(expr + ZeroOrMore(delim + expr)).setName(dlName)
 *     else:
 */
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_combine); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 4526, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":4527
 *     dlName = _ustr(expr) + " [" + _ustr(delim) + " " + _ustr(expr) + "]..."
 *     if combine:
 *         return Combine(expr + ZeroOrMore(delim + expr)).setName(dlName)             # <<<<<<<<<<<<<<
 *     else:
 *         return (expr + ZeroOrMore(Suppress(delim) + expr)).setName(dlName)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Combine); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4527, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4527, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = PyNumber_Add(__pyx_v_delim, __pyx_v_expr); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4527, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_8) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4527, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_7};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4527, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_7};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4527, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4527, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_9, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4527, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyNumber_Add(__pyx_v_expr, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4527, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (!__pyx_t_3) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4527, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_5};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4527, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_5};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4527, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4527, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_3); __pyx_t_3 = NULL;
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_9, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4527, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setName); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4527, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (!__pyx_t_2) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_dlName); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4527, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_dlName};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4527, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_dlName};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4527, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4527, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_2); __pyx_t_2 = NULL;
        __Pyx_INCREF(__pyx_v_dlName);
        __Pyx_GIVEREF(__pyx_v_dlName);
        PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_v_dlName);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_9, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4527, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":4526
 *     """
 *     dlName = _ustr(expr) + " [" + _ustr(delim) + " " + _ustr(expr) + "]..."
 *     if combine:             # <<<<<<<<<<<<<<
 *         return Combine(expr + ZeroOrMore(delim + expr)).setName(dlName)
 *     else:
 */
  }

  /* "cPyparsing.pyx":4529
 *         return Combine(expr + ZeroOrMore(delim + expr)).setName(dlName)
 *     else:
 *         return (expr + ZeroOrMore(Suppress(delim) + expr)).setName(dlName)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4529, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_Suppress); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4529, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_3) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_delim); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4529, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_delim};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4529, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_delim};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4529, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4529, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_3); __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_v_delim);
        __Pyx_GIVEREF(__pyx_v_delim);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_delim);
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4529, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyNumber_Add(__pyx_t_2, __pyx_v_expr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4529, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
      }
    }
    if (!__pyx_t_2) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4529, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_5};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4529, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_5};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4529, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4529, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_2); __pyx_t_2 = NULL;
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4529, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = PyNumber_Add(__pyx_v_expr, __pyx_t_1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4529, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_setName); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4529, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (!__pyx_t_9) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_dlName); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4529, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_v_dlName};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4529, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_v_dlName};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4529, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4529, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_9); __pyx_t_9 = NULL;
        __Pyx_INCREF(__pyx_v_dlName);
        __Pyx_GIVEREF(__pyx_v_dlName);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_dlName);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4529, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":4512
 * 
 * 
 * def delimitedList(expr, delim=",", combine=False):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define a delimited list of expressions - the delimiter defaults to ','.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.delimitedList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_dlName);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4532
 * 
 * 
 * def countedArray(expr, intExpr=None):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define a counted list of expressions.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_27countedArray(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_26countedArray[] = "\n    Helper to define a counted list of expressions.\n    This helper defines a pattern of the form::\n        integer expr expr expr...\n    where the leading integer tells how many expr expressions follow.\n    The matched tokens returns the array of expr tokens as a list - the leading count token is suppressed.\n\n    If C{intExpr} is specified, it should be a pyparsing expression that produces an integer value.\n\n    Example::\n        countedArray(Word(alphas)).parseString('2 ab cd ef')  # -> ['ab', 'cd']\n\n        # in this parser, the leading integer value is given in binary,\n        # '10' indicating that 2 values are in the array\n        binaryConstant = Word('01').setParseAction(lambda t: int(t[0], 2))\n        countedArray(Word(alphas), intExpr=binaryConstant).parseString('10 ab cd ef')  # -> ['ab', 'cd']\n    ";
static PyMethodDef __pyx_mdef_10cPyparsing_27countedArray = {"countedArray", (PyCFunction)__pyx_pw_10cPyparsing_27countedArray, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_26countedArray};
static PyObject *__pyx_pw_10cPyparsing_27countedArray(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_intExpr = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("countedArray (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_expr,&__pyx_n_s_intExpr,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_expr)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_intExpr);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "countedArray") < 0)) __PYX_ERR(0, 4532, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_expr = values[0];
    __pyx_v_intExpr = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("countedArray", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4532, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.countedArray", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_26countedArray(__pyx_self, __pyx_v_expr, __pyx_v_intExpr);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4552
 *     arrayExpr = Forward()
 * 
 *     def countFieldParseAction(s, l, t):             # <<<<<<<<<<<<<<
 *         n = t[0]
 *         arrayExpr << (n and Group(And([expr] * n)) or Group(empty))
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12countedArray_1countFieldParseAction(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12countedArray_1countFieldParseAction = {"countFieldParseAction", (PyCFunction)__pyx_pw_10cPyparsing_12countedArray_1countFieldParseAction, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_12countedArray_1countFieldParseAction(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("countFieldParseAction (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("countFieldParseAction", 1, 3, 3, 1); __PYX_ERR(0, 4552, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("countFieldParseAction", 1, 3, 3, 2); __PYX_ERR(0, 4552, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "countFieldParseAction") < 0)) __PYX_ERR(0, 4552, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("countFieldParseAction", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4552, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.countedArray.countFieldParseAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_12countedArray_countFieldParseAction(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_12countedArray_countFieldParseAction(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_countedArray *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_countedArray *__pyx_outer_scope;
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("countFieldParseAction", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_countedArray *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":4553
 * 
 *     def countFieldParseAction(s, l, t):
 *         n = t[0]             # <<<<<<<<<<<<<<
 *         arrayExpr << (n and Group(And([expr] * n)) or Group(empty))
 *         return []
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_n = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4554
 *     def countFieldParseAction(s, l, t):
 *         n = t[0]
 *         arrayExpr << (n and Group(And([expr] * n)) or Group(empty))             # <<<<<<<<<<<<<<
 *         return []
 *     if intExpr is None:
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_arrayExpr)) { __Pyx_RaiseClosureNameError("arrayExpr"); __PYX_ERR(0, 4554, __pyx_L1_error) }
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_n); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 4554, __pyx_L1_error)
  if (!__pyx_t_2) {
    goto __pyx_L4_next_or;
  } else {
  }
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_And); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (unlikely(!__pyx_cur_scope->__pyx_v_expr)) { __Pyx_RaiseClosureNameError("expr"); __PYX_ERR(0, 4554, __pyx_L1_error) }
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_expr);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_expr);
  PyList_SET_ITEM(__pyx_t_7, 0, __pyx_cur_scope->__pyx_v_expr);
  { PyObject* __pyx_temp = PyNumber_InPlaceMultiply(__pyx_t_7, __pyx_v_n); if (unlikely(!__pyx_temp)) __PYX_ERR(0, 4554, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_temp);
    __Pyx_DECREF(__pyx_t_7);
    __pyx_t_7 = __pyx_temp;
  }
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  if (!__pyx_t_8) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4554, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_5);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_7};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4554, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_7};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4554, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4554, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_7);
      __pyx_t_7 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_9, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4554, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (!__pyx_t_6) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4554, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4554, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4554, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4554, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_6); __pyx_t_6 = NULL;
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_5);
      __pyx_t_5 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_9, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4554, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 4554, __pyx_L1_error)
  if (!__pyx_t_2) {
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_L4_next_or:;
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_empty); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (!__pyx_t_5) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4554, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_9};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4554, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_9};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4554, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4554, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
      __Pyx_GIVEREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_9);
      __pyx_t_9 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4554, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_1 = __pyx_t_3;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_L3_bool_binop_done:;
  __pyx_t_3 = PyNumber_Lshift(__pyx_cur_scope->__pyx_v_arrayExpr, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4555
 *         n = t[0]
 *         arrayExpr << (n and Group(And([expr] * n)) or Group(empty))
 *         return []             # <<<<<<<<<<<<<<
 *     if intExpr is None:
 *         intExpr = Word(nums).setParseAction(lambda t: int(t[0]))
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4552
 *     arrayExpr = Forward()
 * 
 *     def countFieldParseAction(s, l, t):             # <<<<<<<<<<<<<<
 *         n = t[0]
 *         arrayExpr << (n and Group(And([expr] * n)) or Group(empty))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.countedArray.countFieldParseAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4557
 *         return []
 *     if intExpr is None:
 *         intExpr = Word(nums).setParseAction(lambda t: int(t[0]))             # <<<<<<<<<<<<<<
 *     else:
 *         intExpr = intExpr.copy()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_12countedArray_2lambda28(PyObject *__pyx_self, PyObject *__pyx_v_t); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_12countedArray_2lambda28 = {"lambda28", (PyCFunction)__pyx_pw_10cPyparsing_12countedArray_2lambda28, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_12countedArray_2lambda28(PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda28 (wrapper)", 0);
  __pyx_r = __pyx_lambda_funcdef_lambda28(__pyx_self, ((PyObject *)__pyx_v_t));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda28(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("lambda28", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyNumber_Int(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.countedArray.lambda28", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4532
 * 
 * 
 * def countedArray(expr, intExpr=None):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define a counted list of expressions.
 */

static PyObject *__pyx_pf_10cPyparsing_26countedArray(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_intExpr) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_countedArray *__pyx_cur_scope;
  PyObject *__pyx_v_countFieldParseAction = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("countedArray", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_countedArray *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_56_countedArray(__pyx_ptype_10cPyparsing___pyx_scope_struct_56_countedArray, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_countedArray *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4532, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_expr = __pyx_v_expr;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_expr);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_expr);
  __Pyx_INCREF(__pyx_v_intExpr);

  /* "cPyparsing.pyx":4550
 *         countedArray(Word(alphas), intExpr=binaryConstant).parseString('10 ab cd ef')  # -> ['ab', 'cd']
 *     """
 *     arrayExpr = Forward()             # <<<<<<<<<<<<<<
 * 
 *     def countFieldParseAction(s, l, t):
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Forward); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4550, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4550, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_arrayExpr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4552
 *     arrayExpr = Forward()
 * 
 *     def countFieldParseAction(s, l, t):             # <<<<<<<<<<<<<<
 *         n = t[0]
 *         arrayExpr << (n and Group(And([expr] * n)) or Group(empty))
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12countedArray_1countFieldParseAction, 0, __pyx_n_s_countedArray_locals_countFieldPa, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__135)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_countFieldParseAction = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4556
 *         arrayExpr << (n and Group(And([expr] * n)) or Group(empty))
 *         return []
 *     if intExpr is None:             # <<<<<<<<<<<<<<
 *         intExpr = Word(nums).setParseAction(lambda t: int(t[0]))
 *     else:
 */
  __pyx_t_4 = (__pyx_v_intExpr == Py_None);
  __pyx_t_5 = (__pyx_t_4 != 0);
  if (__pyx_t_5) {

    /* "cPyparsing.pyx":4557
 *         return []
 *     if intExpr is None:
 *         intExpr = Word(nums).setParseAction(lambda t: int(t[0]))             # <<<<<<<<<<<<<<
 *     else:
 *         intExpr = intExpr.copy()
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_Word); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4557, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_nums); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4557, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (!__pyx_t_7) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4557, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_6};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4557, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_6};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4557, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4557, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_7); __pyx_t_7 = NULL;
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_8, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4557, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4557, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12countedArray_2lambda28, 0, __pyx_n_s_countedArray_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4557, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (!__pyx_t_8) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4557, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_2};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4557, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_2};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4557, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4557, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_8); __pyx_t_8 = NULL;
        __Pyx_GIVEREF(__pyx_t_2);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_2);
        __pyx_t_2 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4557, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_intExpr, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4556
 *         arrayExpr << (n and Group(And([expr] * n)) or Group(empty))
 *         return []
 *     if intExpr is None:             # <<<<<<<<<<<<<<
 *         intExpr = Word(nums).setParseAction(lambda t: int(t[0]))
 *     else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":4559
 *         intExpr = Word(nums).setParseAction(lambda t: int(t[0]))
 *     else:
 *         intExpr = intExpr.copy()             # <<<<<<<<<<<<<<
 *     intExpr.setName("arrayLen")
 *     intExpr.addParseAction(countFieldParseAction, callDuringTry=True)
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_intExpr, __pyx_n_s_copy); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4559, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (__pyx_t_6) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4559, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4559, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_intExpr, __pyx_t_1);
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":4560
 *     else:
 *         intExpr = intExpr.copy()
 *     intExpr.setName("arrayLen")             # <<<<<<<<<<<<<<
 *     intExpr.addParseAction(countFieldParseAction, callDuringTry=True)
 *     return (intExpr + arrayExpr).setName('(len) ' + _ustr(expr) + '...')
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_intExpr, __pyx_n_s_setName); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__136, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4561
 *         intExpr = intExpr.copy()
 *     intExpr.setName("arrayLen")
 *     intExpr.addParseAction(countFieldParseAction, callDuringTry=True)             # <<<<<<<<<<<<<<
 *     return (intExpr + arrayExpr).setName('(len) ' + _ustr(expr) + '...')
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_intExpr, __pyx_n_s_addParseAction); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_countFieldParseAction);
  __Pyx_GIVEREF(__pyx_v_countFieldParseAction);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_countFieldParseAction);
  __pyx_t_6 = PyDict_New(); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_callDuringTry, Py_True) < 0) __PYX_ERR(0, 4561, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_1, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4562
 *     intExpr.setName("arrayLen")
 *     intExpr.addParseAction(countFieldParseAction, callDuringTry=True)
 *     return (intExpr + arrayExpr).setName('(len) ' + _ustr(expr) + '...')             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = PyNumber_Add(__pyx_v_intExpr, __pyx_cur_scope->__pyx_v_arrayExpr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_setName); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_8) {
    __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_cur_scope->__pyx_v_expr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4562, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_cur_scope->__pyx_v_expr};
      __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4562, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_6);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_cur_scope->__pyx_v_expr};
      __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4562, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_6);
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4562, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_8); __pyx_t_8 = NULL;
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_expr);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_expr);
      PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_cur_scope->__pyx_v_expr);
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_7, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4562, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Add(__pyx_kp_u_len_2, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Add(__pyx_t_3, __pyx_kp_u__88); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4562, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_6};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4562, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_6};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4562, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4562, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4562, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4532
 * 
 * 
 * def countedArray(expr, intExpr=None):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define a counted list of expressions.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cPyparsing.countedArray", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_countFieldParseAction);
  __Pyx_XDECREF(__pyx_v_intExpr);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4565
 * 
 * 
 * def _flatten(L):             # <<<<<<<<<<<<<<
 *     ret = []
 *     for i in L:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_29_flatten(PyObject *__pyx_self, PyObject *__pyx_v_L); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_29_flatten = {"_flatten", (PyCFunction)__pyx_pw_10cPyparsing_29_flatten, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_29_flatten(PyObject *__pyx_self, PyObject *__pyx_v_L) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_flatten (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_28_flatten(__pyx_self, ((PyObject *)__pyx_v_L));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_28_flatten(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_L) {
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  __Pyx_RefNannySetupContext("_flatten", 0);

  /* "cPyparsing.pyx":4566
 * 
 * def _flatten(L):
 *     ret = []             # <<<<<<<<<<<<<<
 *     for i in L:
 *         if isinstance(i, list):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_ret = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4567
 * def _flatten(L):
 *     ret = []
 *     for i in L:             # <<<<<<<<<<<<<<
 *         if isinstance(i, list):
 *             ret.extend(_flatten(i))
 */
  if (likely(PyList_CheckExact(__pyx_v_L)) || PyTuple_CheckExact(__pyx_v_L)) {
    __pyx_t_1 = __pyx_v_L; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_L); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4567, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4567, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 4567, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4567, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 4567, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4567, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 4567, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":4568
 *     ret = []
 *     for i in L:
 *         if isinstance(i, list):             # <<<<<<<<<<<<<<
 *             ret.extend(_flatten(i))
 *         else:
 */
    __pyx_t_5 = PyList_Check(__pyx_v_i); 
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {

      /* "cPyparsing.pyx":4569
 *     for i in L:
 *         if isinstance(i, list):
 *             ret.extend(_flatten(i))             # <<<<<<<<<<<<<<
 *         else:
 *             ret.append(i)
 */
      __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_flatten); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4569, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      if (!__pyx_t_8) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_i); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4569, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_7)) {
          PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_v_i};
          __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4569, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_GOTREF(__pyx_t_4);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
          PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_v_i};
          __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4569, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_GOTREF(__pyx_t_4);
        } else
        #endif
        {
          __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4569, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
          __Pyx_INCREF(__pyx_v_i);
          __Pyx_GIVEREF(__pyx_v_i);
          PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_v_i);
          __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_9, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4569, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_10 = __Pyx_PyList_Extend(__pyx_v_ret, __pyx_t_4); if (unlikely(__pyx_t_10 == -1)) __PYX_ERR(0, 4569, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "cPyparsing.pyx":4568
 *     ret = []
 *     for i in L:
 *         if isinstance(i, list):             # <<<<<<<<<<<<<<
 *             ret.extend(_flatten(i))
 *         else:
 */
      goto __pyx_L5;
    }

    /* "cPyparsing.pyx":4571
 *             ret.extend(_flatten(i))
 *         else:
 *             ret.append(i)             # <<<<<<<<<<<<<<
 *     return ret
 * 
 */
    /*else*/ {
      __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_ret, __pyx_v_i); if (unlikely(__pyx_t_10 == -1)) __PYX_ERR(0, 4571, __pyx_L1_error)
    }
    __pyx_L5:;

    /* "cPyparsing.pyx":4567
 * def _flatten(L):
 *     ret = []
 *     for i in L:             # <<<<<<<<<<<<<<
 *         if isinstance(i, list):
 *             ret.extend(_flatten(i))
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4572
 *         else:
 *             ret.append(i)
 *     return ret             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ret);
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4565
 * 
 * 
 * def _flatten(L):             # <<<<<<<<<<<<<<
 *     ret = []
 *     for i in L:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing._flatten", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4575
 * 
 * 
 * def matchPreviousLiteral(expr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define an expression that is indirectly defined from
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_31matchPreviousLiteral(PyObject *__pyx_self, PyObject *__pyx_v_expr); /*proto*/
static char __pyx_doc_10cPyparsing_30matchPreviousLiteral[] = "\n    Helper to define an expression that is indirectly defined from\n    the tokens matched in a previous expression, that is, it looks\n    for a 'repeat' of a previous expression.  For example::\n        first = Word(nums)\n        second = matchPreviousLiteral(first)\n        matchExpr = first + \":\" + second\n    will match C{\"1:1\"}, but not C{\"1:2\"}.  Because this matches a\n    previous literal, will also match the leading C{\"1:1\"} in C{\"1:10\"}.\n    If this is not desired, use C{matchPreviousExpr}.\n    Do I{not} use with packrat parsing enabled.\n    ";
static PyMethodDef __pyx_mdef_10cPyparsing_31matchPreviousLiteral = {"matchPreviousLiteral", (PyCFunction)__pyx_pw_10cPyparsing_31matchPreviousLiteral, METH_O, __pyx_doc_10cPyparsing_30matchPreviousLiteral};
static PyObject *__pyx_pw_10cPyparsing_31matchPreviousLiteral(PyObject *__pyx_self, PyObject *__pyx_v_expr) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("matchPreviousLiteral (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_30matchPreviousLiteral(__pyx_self, ((PyObject *)__pyx_v_expr));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4590
 *     rep = Forward()
 * 
 *     def copyTokenToRepeater(s, l, t):             # <<<<<<<<<<<<<<
 *         if t:
 *             if len(t) == 1:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_20matchPreviousLiteral_1copyTokenToRepeater(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_20matchPreviousLiteral_1copyTokenToRepeater = {"copyTokenToRepeater", (PyCFunction)__pyx_pw_10cPyparsing_20matchPreviousLiteral_1copyTokenToRepeater, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_20matchPreviousLiteral_1copyTokenToRepeater(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copyTokenToRepeater (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("copyTokenToRepeater", 1, 3, 3, 1); __PYX_ERR(0, 4590, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("copyTokenToRepeater", 1, 3, 3, 2); __PYX_ERR(0, 4590, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "copyTokenToRepeater") < 0)) __PYX_ERR(0, 4590, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("copyTokenToRepeater", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4590, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.matchPreviousLiteral.copyTokenToRepeater", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_20matchPreviousLiteral_copyTokenToRepeater(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_20matchPreviousLiteral_19copyTokenToRepeater_2generator28(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":4597
 *                 # flatten t tokens
 *                 tflat = _flatten(t.asList())
 *                 rep << And(Literal(tt) for tt in tflat)             # <<<<<<<<<<<<<<
 *         else:
 *             rep << Empty()
 */

static PyObject *__pyx_pf_10cPyparsing_20matchPreviousLiteral_19copyTokenToRepeater_genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_59_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_59_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4597, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_20matchPreviousLiteral_19copyTokenToRepeater_2generator28, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_matchPreviousLiteral_locals_copy, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 4597, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.matchPreviousLiteral.copyTokenToRepeater.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_20matchPreviousLiteral_19copyTokenToRepeater_2generator28(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 4597, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_tflat)) { __Pyx_RaiseClosureNameError("tflat"); __PYX_ERR(0, 4597, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_tflat)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_tflat)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_outer_scope->__pyx_v_tflat; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_tflat); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4597, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4597, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 4597, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4597, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 4597, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4597, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 4597, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_tt);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_tt, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_Literal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4597, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_cur_scope->__pyx_v_tt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4597, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_tt};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4597, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_tt};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4597, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4597, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_tt);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_tt);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_cur_scope->__pyx_v_tt);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4597, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    __Pyx_XGIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_1);
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 4597, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4590
 *     rep = Forward()
 * 
 *     def copyTokenToRepeater(s, l, t):             # <<<<<<<<<<<<<<
 *         if t:
 *             if len(t) == 1:
 */

static PyObject *__pyx_pf_10cPyparsing_20matchPreviousLiteral_copyTokenToRepeater(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("copyTokenToRepeater", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater(__pyx_ptype_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4590, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);

  /* "cPyparsing.pyx":4591
 * 
 *     def copyTokenToRepeater(s, l, t):
 *         if t:             # <<<<<<<<<<<<<<
 *             if len(t) == 1:
 *                 rep << t[0]
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_t); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 4591, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":4592
 *     def copyTokenToRepeater(s, l, t):
 *         if t:
 *             if len(t) == 1:             # <<<<<<<<<<<<<<
 *                 rep << t[0]
 *             else:
 */
    __pyx_t_2 = PyObject_Length(__pyx_v_t); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 4592, __pyx_L1_error)
    __pyx_t_1 = ((__pyx_t_2 == 1) != 0);
    if (__pyx_t_1) {

      /* "cPyparsing.pyx":4593
 *         if t:
 *             if len(t) == 1:
 *                 rep << t[0]             # <<<<<<<<<<<<<<
 *             else:
 *                 # flatten t tokens
 */
      if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_rep)) { __Pyx_RaiseClosureNameError("rep"); __PYX_ERR(0, 4593, __pyx_L1_error) }
      __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4593, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyNumber_Lshift(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_rep, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4593, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "cPyparsing.pyx":4592
 *     def copyTokenToRepeater(s, l, t):
 *         if t:
 *             if len(t) == 1:             # <<<<<<<<<<<<<<
 *                 rep << t[0]
 *             else:
 */
      goto __pyx_L4;
    }

    /* "cPyparsing.pyx":4596
 *             else:
 *                 # flatten t tokens
 *                 tflat = _flatten(t.asList())             # <<<<<<<<<<<<<<
 *                 rep << And(Literal(tt) for tt in tflat)
 *         else:
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_flatten); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4596, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_asList); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4596, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      if (__pyx_t_7) {
        __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4596, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else {
        __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4596, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_6) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4596, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
          __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4596, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
          __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4596, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4596, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
          __Pyx_GIVEREF(__pyx_t_5);
          PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_5);
          __pyx_t_5 = 0;
          __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4596, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GIVEREF(__pyx_t_4);
      __pyx_cur_scope->__pyx_v_tflat = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "cPyparsing.pyx":4597
 *                 # flatten t tokens
 *                 tflat = _flatten(t.asList())
 *                 rep << And(Literal(tt) for tt in tflat)             # <<<<<<<<<<<<<<
 *         else:
 *             rep << Empty()
 */
      if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_rep)) { __Pyx_RaiseClosureNameError("rep"); __PYX_ERR(0, 4597, __pyx_L1_error) }
      __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_And); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4597, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = __pyx_pf_10cPyparsing_20matchPreviousLiteral_19copyTokenToRepeater_genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4597, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_5) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4597, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_7};
          __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4597, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_7};
          __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4597, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4597, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
          __Pyx_GIVEREF(__pyx_t_7);
          PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_7);
          __pyx_t_7 = 0;
          __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4597, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyNumber_Lshift(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_rep, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4597, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_L4:;

    /* "cPyparsing.pyx":4591
 * 
 *     def copyTokenToRepeater(s, l, t):
 *         if t:             # <<<<<<<<<<<<<<
 *             if len(t) == 1:
 *                 rep << t[0]
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":4599
 *                 rep << And(Literal(tt) for tt in tflat)
 *         else:
 *             rep << Empty()             # <<<<<<<<<<<<<<
 *     expr.addParseAction(copyTokenToRepeater, callDuringTry=True)
 *     rep.setName('(prev) ' + _ustr(expr))
 */
  /*else*/ {
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_rep)) { __Pyx_RaiseClosureNameError("rep"); __PYX_ERR(0, 4599, __pyx_L1_error) }
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_Empty); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4599, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (__pyx_t_6) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4599, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else {
      __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4599, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Lshift(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_rep, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4599, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":4590
 *     rep = Forward()
 * 
 *     def copyTokenToRepeater(s, l, t):             # <<<<<<<<<<<<<<
 *         if t:
 *             if len(t) == 1:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.matchPreviousLiteral.copyTokenToRepeater", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4575
 * 
 * 
 * def matchPreviousLiteral(expr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define an expression that is indirectly defined from
 */

static PyObject *__pyx_pf_10cPyparsing_30matchPreviousLiteral(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral *__pyx_cur_scope;
  PyObject *__pyx_v_copyTokenToRepeater = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("matchPreviousLiteral", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral(__pyx_ptype_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4575, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }

  /* "cPyparsing.pyx":4588
 *     Do I{not} use with packrat parsing enabled.
 *     """
 *     rep = Forward()             # <<<<<<<<<<<<<<
 * 
 *     def copyTokenToRepeater(s, l, t):
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Forward); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4588, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4588, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_rep = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4590
 *     rep = Forward()
 * 
 *     def copyTokenToRepeater(s, l, t):             # <<<<<<<<<<<<<<
 *         if t:
 *             if len(t) == 1:
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_20matchPreviousLiteral_1copyTokenToRepeater, 0, __pyx_n_s_matchPreviousLiteral_locals_copy_2, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__138)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_copyTokenToRepeater = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4600
 *         else:
 *             rep << Empty()
 *     expr.addParseAction(copyTokenToRepeater, callDuringTry=True)             # <<<<<<<<<<<<<<
 *     rep.setName('(prev) ' + _ustr(expr))
 *     return rep
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_addParseAction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_copyTokenToRepeater);
  __Pyx_GIVEREF(__pyx_v_copyTokenToRepeater);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_copyTokenToRepeater);
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_callDuringTry, Py_True) < 0) __PYX_ERR(0, 4600, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":4601
 *             rep << Empty()
 *     expr.addParseAction(copyTokenToRepeater, callDuringTry=True)
 *     rep.setName('(prev) ' + _ustr(expr))             # <<<<<<<<<<<<<<
 *     return rep
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_rep, __pyx_n_s_setName); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (!__pyx_t_5) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4601, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_expr};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4601, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_expr};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4601, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4601, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
      __Pyx_INCREF(__pyx_v_expr);
      __Pyx_GIVEREF(__pyx_v_expr);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_expr);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4601, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_kp_u_prev, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4601, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_1};
      __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4601, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_1};
      __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4601, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4601, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4601, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":4602
 *     expr.addParseAction(copyTokenToRepeater, callDuringTry=True)
 *     rep.setName('(prev) ' + _ustr(expr))
 *     return rep             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_rep);
  __pyx_r = __pyx_cur_scope->__pyx_v_rep;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4575
 * 
 * 
 * def matchPreviousLiteral(expr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define an expression that is indirectly defined from
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.matchPreviousLiteral", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_copyTokenToRepeater);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4605
 * 
 * 
 * def matchPreviousExpr(expr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define an expression that is indirectly defined from
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_33matchPreviousExpr(PyObject *__pyx_self, PyObject *__pyx_v_expr); /*proto*/
static char __pyx_doc_10cPyparsing_32matchPreviousExpr[] = "\n    Helper to define an expression that is indirectly defined from\n    the tokens matched in a previous expression, that is, it looks\n    for a 'repeat' of a previous expression.  For example::\n        first = Word(nums)\n        second = matchPreviousExpr(first)\n        matchExpr = first + \":\" + second\n    will match C{\"1:1\"}, but not C{\"1:2\"}.  Because this matches by\n    expressions, will I{not} match the leading C{\"1:1\"} in C{\"1:10\"};\n    the expressions are evaluated first, and then compared, so\n    C{\"1\"} is compared with C{\"10\"}.\n    Do I{not} use with packrat parsing enabled.\n    ";
static PyMethodDef __pyx_mdef_10cPyparsing_33matchPreviousExpr = {"matchPreviousExpr", (PyCFunction)__pyx_pw_10cPyparsing_33matchPreviousExpr, METH_O, __pyx_doc_10cPyparsing_32matchPreviousExpr};
static PyObject *__pyx_pw_10cPyparsing_33matchPreviousExpr(PyObject *__pyx_self, PyObject *__pyx_v_expr) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("matchPreviousExpr (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_32matchPreviousExpr(__pyx_self, ((PyObject *)__pyx_v_expr));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4623
 *     rep <<= e2
 * 
 *     def copyTokenToRepeater(s, l, t):             # <<<<<<<<<<<<<<
 *         matchTokens = _flatten(t.asList())
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_17matchPreviousExpr_1copyTokenToRepeater(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_17matchPreviousExpr_1copyTokenToRepeater = {"copyTokenToRepeater", (PyCFunction)__pyx_pw_10cPyparsing_17matchPreviousExpr_1copyTokenToRepeater, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_17matchPreviousExpr_1copyTokenToRepeater(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copyTokenToRepeater (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("copyTokenToRepeater", 1, 3, 3, 1); __PYX_ERR(0, 4623, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("copyTokenToRepeater", 1, 3, 3, 2); __PYX_ERR(0, 4623, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "copyTokenToRepeater") < 0)) __PYX_ERR(0, 4623, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("copyTokenToRepeater", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4623, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.matchPreviousExpr.copyTokenToRepeater", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_17matchPreviousExpr_copyTokenToRepeater(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4626
 *         matchTokens = _flatten(t.asList())
 * 
 *         def mustMatchTheseTokens(s, l, t):             # <<<<<<<<<<<<<<
 *             theseTokens = _flatten(t.asList())
 *             if theseTokens != matchTokens:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_17matchPreviousExpr_19copyTokenToRepeater_1mustMatchTheseTokens(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_17matchPreviousExpr_19copyTokenToRepeater_1mustMatchTheseTokens = {"mustMatchTheseTokens", (PyCFunction)__pyx_pw_10cPyparsing_17matchPreviousExpr_19copyTokenToRepeater_1mustMatchTheseTokens, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_17matchPreviousExpr_19copyTokenToRepeater_1mustMatchTheseTokens(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mustMatchTheseTokens (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("mustMatchTheseTokens", 1, 3, 3, 1); __PYX_ERR(0, 4626, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("mustMatchTheseTokens", 1, 3, 3, 2); __PYX_ERR(0, 4626, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "mustMatchTheseTokens") < 0)) __PYX_ERR(0, 4626, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("mustMatchTheseTokens", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4626, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.matchPreviousExpr.copyTokenToRepeater.mustMatchTheseTokens", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_17matchPreviousExpr_19copyTokenToRepeater_mustMatchTheseTokens(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_17matchPreviousExpr_19copyTokenToRepeater_mustMatchTheseTokens(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater *__pyx_outer_scope;
  PyObject *__pyx_v_theseTokens = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  __Pyx_RefNannySetupContext("mustMatchTheseTokens", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":4627
 * 
 *         def mustMatchTheseTokens(s, l, t):
 *             theseTokens = _flatten(t.asList())             # <<<<<<<<<<<<<<
 *             if theseTokens != matchTokens:
 *                 raise ParseException("", 0, "")
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_flatten); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_asList); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4627, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4627, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4627, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4627, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4627, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4627, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4627, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_theseTokens = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4628
 *         def mustMatchTheseTokens(s, l, t):
 *             theseTokens = _flatten(t.asList())
 *             if theseTokens != matchTokens:             # <<<<<<<<<<<<<<
 *                 raise ParseException("", 0, "")
 *         rep.setParseAction(mustMatchTheseTokens, callDuringTry=True)
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_matchTokens)) { __Pyx_RaiseClosureNameError("matchTokens"); __PYX_ERR(0, 4628, __pyx_L1_error) }
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_theseTokens, __pyx_cur_scope->__pyx_v_matchTokens, Py_NE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4628, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 4628, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":4629
 *             theseTokens = _flatten(t.asList())
 *             if theseTokens != matchTokens:
 *                 raise ParseException("", 0, "")             # <<<<<<<<<<<<<<
 *         rep.setParseAction(mustMatchTheseTokens, callDuringTry=True)
 *     expr.addParseAction(copyTokenToRepeater, callDuringTry=True)
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4629, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__139, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4629, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 4629, __pyx_L1_error)

    /* "cPyparsing.pyx":4628
 *         def mustMatchTheseTokens(s, l, t):
 *             theseTokens = _flatten(t.asList())
 *             if theseTokens != matchTokens:             # <<<<<<<<<<<<<<
 *                 raise ParseException("", 0, "")
 *         rep.setParseAction(mustMatchTheseTokens, callDuringTry=True)
 */
  }

  /* "cPyparsing.pyx":4626
 *         matchTokens = _flatten(t.asList())
 * 
 *         def mustMatchTheseTokens(s, l, t):             # <<<<<<<<<<<<<<
 *             theseTokens = _flatten(t.asList())
 *             if theseTokens != matchTokens:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.matchPreviousExpr.copyTokenToRepeater.mustMatchTheseTokens", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_theseTokens);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4623
 *     rep <<= e2
 * 
 *     def copyTokenToRepeater(s, l, t):             # <<<<<<<<<<<<<<
 *         matchTokens = _flatten(t.asList())
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_17matchPreviousExpr_copyTokenToRepeater(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater *__pyx_cur_scope;
  PyObject *__pyx_v_mustMatchTheseTokens = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("copyTokenToRepeater", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater(__pyx_ptype_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4623, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);

  /* "cPyparsing.pyx":4624
 * 
 *     def copyTokenToRepeater(s, l, t):
 *         matchTokens = _flatten(t.asList())             # <<<<<<<<<<<<<<
 * 
 *         def mustMatchTheseTokens(s, l, t):
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_flatten); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_asList); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4624, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4624, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4624, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4624, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4624, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4624, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4624, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_matchTokens = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4626
 *         matchTokens = _flatten(t.asList())
 * 
 *         def mustMatchTheseTokens(s, l, t):             # <<<<<<<<<<<<<<
 *             theseTokens = _flatten(t.asList())
 *             if theseTokens != matchTokens:
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_17matchPreviousExpr_19copyTokenToRepeater_1mustMatchTheseTokens, 0, __pyx_n_s_matchPreviousExpr_locals_copyTok, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__141)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_mustMatchTheseTokens = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4630
 *             if theseTokens != matchTokens:
 *                 raise ParseException("", 0, "")
 *         rep.setParseAction(mustMatchTheseTokens, callDuringTry=True)             # <<<<<<<<<<<<<<
 *     expr.addParseAction(copyTokenToRepeater, callDuringTry=True)
 *     rep.setName('(prev) ' + _ustr(expr))
 */
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_rep)) { __Pyx_RaiseClosureNameError("rep"); __PYX_ERR(0, 4630, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_rep, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_mustMatchTheseTokens);
  __Pyx_GIVEREF(__pyx_v_mustMatchTheseTokens);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_mustMatchTheseTokens);
  __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_callDuringTry, Py_True) < 0) __PYX_ERR(0, 4630, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4623
 *     rep <<= e2
 * 
 *     def copyTokenToRepeater(s, l, t):             # <<<<<<<<<<<<<<
 *         matchTokens = _flatten(t.asList())
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.matchPreviousExpr.copyTokenToRepeater", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_mustMatchTheseTokens);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4605
 * 
 * 
 * def matchPreviousExpr(expr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define an expression that is indirectly defined from
 */

static PyObject *__pyx_pf_10cPyparsing_32matchPreviousExpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr *__pyx_cur_scope;
  PyObject *__pyx_v_e2 = NULL;
  PyObject *__pyx_v_copyTokenToRepeater = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("matchPreviousExpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4605, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }

  /* "cPyparsing.pyx":4619
 *     Do I{not} use with packrat parsing enabled.
 *     """
 *     rep = Forward()             # <<<<<<<<<<<<<<
 *     e2 = expr.copy()
 *     rep <<= e2
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Forward); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4619, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4619, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_rep = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4620
 *     """
 *     rep = Forward()
 *     e2 = expr.copy()             # <<<<<<<<<<<<<<
 *     rep <<= e2
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_copy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4620, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4620, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_e2 = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4621
 *     rep = Forward()
 *     e2 = expr.copy()
 *     rep <<= e2             # <<<<<<<<<<<<<<
 * 
 *     def copyTokenToRepeater(s, l, t):
 */
  __pyx_t_1 = PyNumber_InPlaceLshift(__pyx_cur_scope->__pyx_v_rep, __pyx_v_e2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_rep);
  __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_rep, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4623
 *     rep <<= e2
 * 
 *     def copyTokenToRepeater(s, l, t):             # <<<<<<<<<<<<<<
 *         matchTokens = _flatten(t.asList())
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_17matchPreviousExpr_1copyTokenToRepeater, 0, __pyx_n_s_matchPreviousExpr_locals_copyTok_2, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__143)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_copyTokenToRepeater = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4631
 *                 raise ParseException("", 0, "")
 *         rep.setParseAction(mustMatchTheseTokens, callDuringTry=True)
 *     expr.addParseAction(copyTokenToRepeater, callDuringTry=True)             # <<<<<<<<<<<<<<
 *     rep.setName('(prev) ' + _ustr(expr))
 *     return rep
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_addParseAction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_copyTokenToRepeater);
  __Pyx_GIVEREF(__pyx_v_copyTokenToRepeater);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_copyTokenToRepeater);
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_callDuringTry, Py_True) < 0) __PYX_ERR(0, 4631, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":4632
 *         rep.setParseAction(mustMatchTheseTokens, callDuringTry=True)
 *     expr.addParseAction(copyTokenToRepeater, callDuringTry=True)
 *     rep.setName('(prev) ' + _ustr(expr))             # <<<<<<<<<<<<<<
 *     return rep
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_rep, __pyx_n_s_setName); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (!__pyx_t_5) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4632, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_expr};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4632, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_expr};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4632, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4632, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
      __Pyx_INCREF(__pyx_v_expr);
      __Pyx_GIVEREF(__pyx_v_expr);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_expr);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4632, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_kp_u_prev, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4632, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_1};
      __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4632, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_1};
      __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4632, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4632, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4632, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cPyparsing.pyx":4633
 *     expr.addParseAction(copyTokenToRepeater, callDuringTry=True)
 *     rep.setName('(prev) ' + _ustr(expr))
 *     return rep             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_rep);
  __pyx_r = __pyx_cur_scope->__pyx_v_rep;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4605
 * 
 * 
 * def matchPreviousExpr(expr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define an expression that is indirectly defined from
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.matchPreviousExpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_e2);
  __Pyx_XDECREF(__pyx_v_copyTokenToRepeater);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4636
 * 
 * 
 * def _escapeRegexRangeChars(s):             # <<<<<<<<<<<<<<
 *     #~  escape these chars: ^-]
 *     for c in r"\^-]":
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_35_escapeRegexRangeChars(PyObject *__pyx_self, PyObject *__pyx_v_s); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_35_escapeRegexRangeChars = {"_escapeRegexRangeChars", (PyCFunction)__pyx_pw_10cPyparsing_35_escapeRegexRangeChars, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_35_escapeRegexRangeChars(PyObject *__pyx_self, PyObject *__pyx_v_s) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_escapeRegexRangeChars (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_34_escapeRegexRangeChars(__pyx_self, ((PyObject *)__pyx_v_s));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_34_escapeRegexRangeChars(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s) {
  Py_UCS4 __pyx_v_c;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  unsigned char const *__pyx_t_1;
  unsigned char const *__pyx_t_2;
  unsigned char const *__pyx_t_3;
  unsigned char const *__pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  __Pyx_RefNannySetupContext("_escapeRegexRangeChars", 0);
  __Pyx_INCREF(__pyx_v_s);

  /* "cPyparsing.pyx":4638
 * def _escapeRegexRangeChars(s):
 *     #~  escape these chars: ^-]
 *     for c in r"\^-]":             # <<<<<<<<<<<<<<
 *         s = s.replace(c, _bslash + c)
 *     s = s.replace("\n", r"\n")
 */
  __pyx_t_2 = ((unsigned char const *)((char const *)"\\^-]"));
  __pyx_t_3 = (__pyx_t_2 + 4);
  for (__pyx_t_4 = __pyx_t_2; __pyx_t_4 < __pyx_t_3; __pyx_t_4++) {
    __pyx_t_1 = __pyx_t_4;
    __pyx_v_c = (__pyx_t_1[0]);

    /* "cPyparsing.pyx":4639
 *     #~  escape these chars: ^-]
 *     for c in r"\^-]":
 *         s = s.replace(c, _bslash + c)             # <<<<<<<<<<<<<<
 *     s = s.replace("\n", r"\n")
 *     s = s.replace("\t", r"\t")
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_s, __pyx_n_s_replace); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4639, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = PyUnicode_FromOrdinal(__pyx_v_c); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4639, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_bslash); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4639, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = PyUnicode_FromOrdinal(__pyx_v_c); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4639, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_10 = PyNumber_Add(__pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4639, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = NULL;
    __pyx_t_11 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_11 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_t_7, __pyx_t_10};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4639, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_t_7, __pyx_t_10};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4639, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    } else
    #endif
    {
      __pyx_t_8 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4639, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (__pyx_t_9) {
        __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_9); __pyx_t_9 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_11, __pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_10);
      PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_11, __pyx_t_10);
      __pyx_t_7 = 0;
      __pyx_t_10 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_8, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4639, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF_SET(__pyx_v_s, __pyx_t_5);
    __pyx_t_5 = 0;
  }

  /* "cPyparsing.pyx":4640
 *     for c in r"\^-]":
 *         s = s.replace(c, _bslash + c)
 *     s = s.replace("\n", r"\n")             # <<<<<<<<<<<<<<
 *     s = s.replace("\t", r"\t")
 *     return _ustr(s)
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_s, __pyx_n_s_replace); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__144, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF_SET(__pyx_v_s, __pyx_t_6);
  __pyx_t_6 = 0;

  /* "cPyparsing.pyx":4641
 *         s = s.replace(c, _bslash + c)
 *     s = s.replace("\n", r"\n")
 *     s = s.replace("\t", r"\t")             # <<<<<<<<<<<<<<
 *     return _ustr(s)
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_s, __pyx_n_s_replace); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__145, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF_SET(__pyx_v_s, __pyx_t_5);
  __pyx_t_5 = 0;

  /* "cPyparsing.pyx":4642
 *     s = s.replace("\n", r"\n")
 *     s = s.replace("\t", r"\t")
 *     return _ustr(s)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  if (!__pyx_t_8) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_s); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4642, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_v_s};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4642, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_5);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_v_s};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4642, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_5);
    } else
    #endif
    {
      __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4642, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
      __Pyx_INCREF(__pyx_v_s);
      __Pyx_GIVEREF(__pyx_v_s);
      PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_v_s);
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_10, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4642, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4636
 * 
 * 
 * def _escapeRegexRangeChars(s):             # <<<<<<<<<<<<<<
 *     #~  escape these chars: ^-]
 *     for c in r"\^-]":
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("cPyparsing._escapeRegexRangeChars", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_s);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4645
 * 
 * 
 * def oneOf(strs, caseless=False, useRegex=True):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to quickly define a set of alternative Literals, and makes sure to do
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_37oneOf(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_36oneOf[] = "\n    Helper to quickly define a set of alternative Literals, and makes sure to do\n    longest-first testing when there is a conflict, regardless of the input order,\n    but returns a C{L{MatchFirst}} for best performance.\n\n    Parameters:\n     - strs - a string of space-delimited literals, or a collection of string literals\n     - caseless - (default=C{False}) - treat all literals as caseless\n     - useRegex - (default=C{True}) - as an optimization, will generate a Regex\n          object; otherwise, will generate a C{MatchFirst} object (if C{caseless=True}, or\n          if creating a C{Regex} raises an exception)\n\n    Example::\n        comp_oper = oneOf(\"< = > <= >= !=\")\n        var = Word(alphas)\n        number = Word(nums)\n        term = var | number\n        comparison_expr = term + comp_oper + term\n        print(comparison_expr.searchString(\"B = 12  AA=23 B<=AA AA>12\"))\n    prints::\n        [['B', '=', '12'], ['AA', '=', '23'], ['B', '<=', 'AA'], ['AA', '>', '12']]\n    ";
static PyMethodDef __pyx_mdef_10cPyparsing_37oneOf = {"oneOf", (PyCFunction)__pyx_pw_10cPyparsing_37oneOf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_36oneOf};
static PyObject *__pyx_pw_10cPyparsing_37oneOf(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_strs = 0;
  PyObject *__pyx_v_caseless = 0;
  PyObject *__pyx_v_useRegex = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("oneOf (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_strs,&__pyx_n_s_caseless,&__pyx_n_s_useRegex,0};
    PyObject* values[3] = {0,0,0};
    values[1] = ((PyObject *)Py_False);
    values[2] = ((PyObject *)Py_True);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_strs)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_caseless);
          if (value) { values[1] = value; kw_args--; }
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_useRegex);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "oneOf") < 0)) __PYX_ERR(0, 4645, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_strs = values[0];
    __pyx_v_caseless = values[1];
    __pyx_v_useRegex = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("oneOf", 0, 1, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4645, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.oneOf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_36oneOf(__pyx_self, __pyx_v_strs, __pyx_v_caseless, __pyx_v_useRegex);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4669
 *     """
 *     if caseless:
 *         isequal = (lambda a, b: a.upper() == b.upper())             # <<<<<<<<<<<<<<
 *         masks = (lambda a, b: b.upper().startswith(a.upper()))
 *         parseElementClass = CaselessLiteral
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5oneOf_lambda30(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_5oneOf_lambda30 = {"lambda30", (PyCFunction)__pyx_pw_10cPyparsing_5oneOf_lambda30, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_5oneOf_lambda30(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_a = 0;
  PyObject *__pyx_v_b = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda30 (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_a,&__pyx_n_s_b_2,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_a)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_b_2)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("lambda30", 1, 2, 2, 1); __PYX_ERR(0, 4669, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "lambda30") < 0)) __PYX_ERR(0, 4669, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_a = values[0];
    __pyx_v_b = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda30", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4669, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.oneOf.lambda30", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda30(__pyx_self, __pyx_v_a, __pyx_v_b);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda30(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_a, PyObject *__pyx_v_b) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("lambda30", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_a, __pyx_n_s_upper); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4669, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4669, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_b, __pyx_n_s_upper); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4669, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4669, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4669, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.oneOf.lambda30", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4670
 *     if caseless:
 *         isequal = (lambda a, b: a.upper() == b.upper())
 *         masks = (lambda a, b: b.upper().startswith(a.upper()))             # <<<<<<<<<<<<<<
 *         parseElementClass = CaselessLiteral
 *     else:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5oneOf_1lambda31(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_5oneOf_1lambda31 = {"lambda31", (PyCFunction)__pyx_pw_10cPyparsing_5oneOf_1lambda31, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_5oneOf_1lambda31(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_a = 0;
  PyObject *__pyx_v_b = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda31 (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_a,&__pyx_n_s_b_2,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_a)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_b_2)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("lambda31", 1, 2, 2, 1); __PYX_ERR(0, 4670, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "lambda31") < 0)) __PYX_ERR(0, 4670, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_a = values[0];
    __pyx_v_b = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda31", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4670, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.oneOf.lambda31", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda31(__pyx_self, __pyx_v_a, __pyx_v_b);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda31(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_a, PyObject *__pyx_v_b) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("lambda31", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_b, __pyx_n_s_upper); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4670, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4670, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_startswith); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_a, __pyx_n_s_upper); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4670, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4670, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4670, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4670, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4670, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4670, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4670, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.oneOf.lambda31", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4673
 *         parseElementClass = CaselessLiteral
 *     else:
 *         isequal = (lambda a, b: a == b)             # <<<<<<<<<<<<<<
 *         masks = (lambda a, b: b.startswith(a))
 *         parseElementClass = Literal
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5oneOf_2lambda32(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_5oneOf_2lambda32 = {"lambda32", (PyCFunction)__pyx_pw_10cPyparsing_5oneOf_2lambda32, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_5oneOf_2lambda32(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_a = 0;
  PyObject *__pyx_v_b = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda32 (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_a,&__pyx_n_s_b_2,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_a)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_b_2)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("lambda32", 1, 2, 2, 1); __PYX_ERR(0, 4673, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "lambda32") < 0)) __PYX_ERR(0, 4673, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_a = values[0];
    __pyx_v_b = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda32", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4673, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.oneOf.lambda32", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda32(__pyx_self, __pyx_v_a, __pyx_v_b);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda32(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_a, PyObject *__pyx_v_b) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("lambda32", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_a, __pyx_v_b, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4673, __pyx_L1_error)
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.oneOf.lambda32", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4674
 *     else:
 *         isequal = (lambda a, b: a == b)
 *         masks = (lambda a, b: b.startswith(a))             # <<<<<<<<<<<<<<
 *         parseElementClass = Literal
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_5oneOf_3lambda33(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_5oneOf_3lambda33 = {"lambda33", (PyCFunction)__pyx_pw_10cPyparsing_5oneOf_3lambda33, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_5oneOf_3lambda33(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_a = 0;
  PyObject *__pyx_v_b = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda33 (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_a,&__pyx_n_s_b_2,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_a)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_b_2)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("lambda33", 1, 2, 2, 1); __PYX_ERR(0, 4674, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "lambda33") < 0)) __PYX_ERR(0, 4674, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_a = values[0];
    __pyx_v_b = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda33", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4674, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.oneOf.lambda33", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda33(__pyx_self, __pyx_v_a, __pyx_v_b);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda33(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_a, PyObject *__pyx_v_b) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("lambda33", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_b, __pyx_n_s_startswith); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_a); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4674, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_a};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4674, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_a};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4674, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4674, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_v_a);
      __Pyx_GIVEREF(__pyx_v_a);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_a);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4674, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.oneOf.lambda33", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_5oneOf_6generator29(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":4707
 *         try:
 *             if len(symbols) == len("".join(symbols)):
 *                 return Regex("[%s]" % "".join(_escapeRegexRangeChars(sym) for sym in symbols)).setName(' | '.join(symbols))             # <<<<<<<<<<<<<<
 *             else:
 *                 return Regex("|".join(re.escape(sym) for sym in symbols)).setName(' | '.join(symbols))
 */

static PyObject *__pyx_pf_10cPyparsing_5oneOf_4genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_63_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_63_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4707, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_5oneOf_6generator29, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_oneOf_locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 4707, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.oneOf.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_5oneOf_6generator29(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 4707, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 4707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_symbols)) { __Pyx_RaiseClosureNameError("symbols"); __PYX_ERR(0, 4707, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_symbols)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_symbols)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_outer_scope->__pyx_v_symbols; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_symbols); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4707, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4707, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 4707, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4707, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 4707, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4707, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 4707, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_sym);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_sym, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_escapeRegexRangeChars); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4707, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_cur_scope->__pyx_v_sym); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4707, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_sym};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4707, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_sym};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4707, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4707, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sym);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sym);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_cur_scope->__pyx_v_sym);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4707, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_4))) __PYX_ERR(0, 4707, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_5oneOf_9generator30(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":4709
 *                 return Regex("[%s]" % "".join(_escapeRegexRangeChars(sym) for sym in symbols)).setName(' | '.join(symbols))
 *             else:
 *                 return Regex("|".join(re.escape(sym) for sym in symbols)).setName(' | '.join(symbols))             # <<<<<<<<<<<<<<
 *         except Exception:
 *             warnings.warn("Exception creating Regex for oneOf, building MatchFirst",
 */

static PyObject *__pyx_pf_10cPyparsing_5oneOf_7genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_64_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_64_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4709, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_5oneOf_9generator30, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_oneOf_locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 4709, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.oneOf.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_5oneOf_9generator30(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 4709, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 4709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_symbols)) { __Pyx_RaiseClosureNameError("symbols"); __PYX_ERR(0, 4709, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_symbols)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_symbols)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_outer_scope->__pyx_v_symbols; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_symbols); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4709, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4709, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 4709, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4709, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 4709, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4709, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 4709, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_sym);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_sym, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_re); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4709, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_escape); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4709, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_cur_scope->__pyx_v_sym); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4709, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_cur_scope->__pyx_v_sym};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4709, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_cur_scope->__pyx_v_sym};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4709, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4709, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sym);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sym);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_cur_scope->__pyx_v_sym);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4709, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_4))) __PYX_ERR(0, 4709, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_5oneOf_12generator31(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":4715
 * 
 *     # last resort, just use MatchFirst
 *     return MatchFirst(parseElementClass(sym) for sym in symbols).setName(' | '.join(symbols))             # <<<<<<<<<<<<<<
 * 
 * 
 */

static PyObject *__pyx_pf_10cPyparsing_5oneOf_10genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_65_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_65_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4715, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_5oneOf_12generator31, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_oneOf_locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 4715, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.oneOf.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_5oneOf_12generator31(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 4715, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_symbols)) { __Pyx_RaiseClosureNameError("symbols"); __PYX_ERR(0, 4715, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_symbols)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_symbols)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_outer_scope->__pyx_v_symbols; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_symbols); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4715, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4715, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 4715, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4715, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 4715, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4715, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 4715, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_sym);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_sym, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_parseElementClass)) { __Pyx_RaiseClosureNameError("parseElementClass"); __PYX_ERR(0, 4715, __pyx_L1_error) }
    __Pyx_INCREF(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_parseElementClass);
    __pyx_t_5 = __pyx_cur_scope->__pyx_outer_scope->__pyx_v_parseElementClass; __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_cur_scope->__pyx_v_sym); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4715, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_sym};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4715, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_sym};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4715, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4715, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sym);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sym);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_cur_scope->__pyx_v_sym);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4715, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    __Pyx_XGIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_1);
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 4715, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4645
 * 
 * 
 * def oneOf(strs, caseless=False, useRegex=True):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to quickly define a set of alternative Literals, and makes sure to do
 */

static PyObject *__pyx_pf_10cPyparsing_36oneOf(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_strs, PyObject *__pyx_v_caseless, PyObject *__pyx_v_useRegex) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf *__pyx_cur_scope;
  PyObject *__pyx_v_isequal = NULL;
  PyObject *__pyx_v_masks = NULL;
  long __pyx_v_i;
  PyObject *__pyx_v_cur = NULL;
  PyObject *__pyx_v_j = NULL;
  PyObject *__pyx_v_other = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  long __pyx_t_10;
  PyObject *(*__pyx_t_11)(PyObject *);
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  __Pyx_RefNannySetupContext("oneOf", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_62_oneOf(__pyx_ptype_10cPyparsing___pyx_scope_struct_62_oneOf, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4645, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }

  /* "cPyparsing.pyx":4668
 *         [['B', '=', '12'], ['AA', '=', '23'], ['B', '<=', 'AA'], ['AA', '>', '12']]
 *     """
 *     if caseless:             # <<<<<<<<<<<<<<
 *         isequal = (lambda a, b: a.upper() == b.upper())
 *         masks = (lambda a, b: b.upper().startswith(a.upper()))
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_caseless); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 4668, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":4669
 *     """
 *     if caseless:
 *         isequal = (lambda a, b: a.upper() == b.upper())             # <<<<<<<<<<<<<<
 *         masks = (lambda a, b: b.upper().startswith(a.upper()))
 *         parseElementClass = CaselessLiteral
 */
    __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_5oneOf_lambda30, 0, __pyx_n_s_oneOf_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4669, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_isequal = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":4670
 *     if caseless:
 *         isequal = (lambda a, b: a.upper() == b.upper())
 *         masks = (lambda a, b: b.upper().startswith(a.upper()))             # <<<<<<<<<<<<<<
 *         parseElementClass = CaselessLiteral
 *     else:
 */
    __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_5oneOf_1lambda31, 0, __pyx_n_s_oneOf_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4670, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_masks = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":4671
 *         isequal = (lambda a, b: a.upper() == b.upper())
 *         masks = (lambda a, b: b.upper().startswith(a.upper()))
 *         parseElementClass = CaselessLiteral             # <<<<<<<<<<<<<<
 *     else:
 *         isequal = (lambda a, b: a == b)
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_CaselessLiteral); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4671, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_cur_scope->__pyx_v_parseElementClass = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":4668
 *         [['B', '=', '12'], ['AA', '=', '23'], ['B', '<=', 'AA'], ['AA', '>', '12']]
 *     """
 *     if caseless:             # <<<<<<<<<<<<<<
 *         isequal = (lambda a, b: a.upper() == b.upper())
 *         masks = (lambda a, b: b.upper().startswith(a.upper()))
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":4673
 *         parseElementClass = CaselessLiteral
 *     else:
 *         isequal = (lambda a, b: a == b)             # <<<<<<<<<<<<<<
 *         masks = (lambda a, b: b.startswith(a))
 *         parseElementClass = Literal
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_5oneOf_2lambda32, 0, __pyx_n_s_oneOf_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4673, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_isequal = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":4674
 *     else:
 *         isequal = (lambda a, b: a == b)
 *         masks = (lambda a, b: b.startswith(a))             # <<<<<<<<<<<<<<
 *         parseElementClass = Literal
 * 
 */
    __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_5oneOf_3lambda33, 0, __pyx_n_s_oneOf_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4674, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_masks = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":4675
 *         isequal = (lambda a, b: a == b)
 *         masks = (lambda a, b: b.startswith(a))
 *         parseElementClass = Literal             # <<<<<<<<<<<<<<
 * 
 *     symbols = []
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Literal); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4675, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_cur_scope->__pyx_v_parseElementClass = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":4677
 *         parseElementClass = Literal
 * 
 *     symbols = []             # <<<<<<<<<<<<<<
 *     if isinstance(strs, basestring):
 *         symbols = strs.split()
 */
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_cur_scope->__pyx_v_symbols = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4678
 * 
 *     symbols = []
 *     if isinstance(strs, basestring):             # <<<<<<<<<<<<<<
 *         symbols = strs.split()
 *     elif isinstance(strs, collections.Iterable):
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyObject_IsInstance(__pyx_v_strs, __pyx_t_2); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 4678, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = (__pyx_t_1 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":4679
 *     symbols = []
 *     if isinstance(strs, basestring):
 *         symbols = strs.split()             # <<<<<<<<<<<<<<
 *     elif isinstance(strs, collections.Iterable):
 *         symbols = list(strs)
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_strs, __pyx_n_s_split); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4679, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (__pyx_t_5) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4679, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4679, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_symbols);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_symbols, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":4678
 * 
 *     symbols = []
 *     if isinstance(strs, basestring):             # <<<<<<<<<<<<<<
 *         symbols = strs.split()
 *     elif isinstance(strs, collections.Iterable):
 */
    goto __pyx_L4;
  }

  /* "cPyparsing.pyx":4680
 *     if isinstance(strs, basestring):
 *         symbols = strs.split()
 *     elif isinstance(strs, collections.Iterable):             # <<<<<<<<<<<<<<
 *         symbols = list(strs)
 *     else:
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_collections); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_Iterable); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = PyObject_IsInstance(__pyx_v_strs, __pyx_t_4); if (unlikely(__pyx_t_3 == -1)) __PYX_ERR(0, 4680, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = (__pyx_t_3 != 0);
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":4681
 *         symbols = strs.split()
 *     elif isinstance(strs, collections.Iterable):
 *         symbols = list(strs)             # <<<<<<<<<<<<<<
 *     else:
 *         warnings.warn("Invalid argument to oneOf, expected string or iterable",
 */
    __pyx_t_4 = PySequence_List(__pyx_v_strs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_symbols);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_symbols, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;

    /* "cPyparsing.pyx":4680
 *     if isinstance(strs, basestring):
 *         symbols = strs.split()
 *     elif isinstance(strs, collections.Iterable):             # <<<<<<<<<<<<<<
 *         symbols = list(strs)
 *     else:
 */
    goto __pyx_L4;
  }

  /* "cPyparsing.pyx":4683
 *         symbols = list(strs)
 *     else:
 *         warnings.warn("Invalid argument to oneOf, expected string or iterable",             # <<<<<<<<<<<<<<
 *                       SyntaxWarning, stacklevel=2)
 *     if not symbols:
 */
  /*else*/ {
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_warnings); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4683, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_warn); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4683, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":4684
 *     else:
 *         warnings.warn("Invalid argument to oneOf, expected string or iterable",
 *                       SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 *     if not symbols:
 *         return NoMatch()
 */
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4683, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_kp_u_Invalid_argument_to_oneOf_expect);
    __Pyx_GIVEREF(__pyx_kp_u_Invalid_argument_to_oneOf_expect);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_kp_u_Invalid_argument_to_oneOf_expect);
    __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
    __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_builtin_SyntaxWarning);
    __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4684, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 4684, __pyx_L1_error)

    /* "cPyparsing.pyx":4683
 *         symbols = list(strs)
 *     else:
 *         warnings.warn("Invalid argument to oneOf, expected string or iterable",             # <<<<<<<<<<<<<<
 *                       SyntaxWarning, stacklevel=2)
 *     if not symbols:
 */
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4683, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_L4:;

  /* "cPyparsing.pyx":4685
 *         warnings.warn("Invalid argument to oneOf, expected string or iterable",
 *                       SyntaxWarning, stacklevel=2)
 *     if not symbols:             # <<<<<<<<<<<<<<
 *         return NoMatch()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_symbols); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 4685, __pyx_L1_error)
  __pyx_t_3 = ((!__pyx_t_1) != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":4686
 *                       SyntaxWarning, stacklevel=2)
 *     if not symbols:
 *         return NoMatch()             # <<<<<<<<<<<<<<
 * 
 *     i = 0
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_NoMatch); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4686, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4686, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_6 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4686, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "cPyparsing.pyx":4685
 *         warnings.warn("Invalid argument to oneOf, expected string or iterable",
 *                       SyntaxWarning, stacklevel=2)
 *     if not symbols:             # <<<<<<<<<<<<<<
 *         return NoMatch()
 * 
 */
  }

  /* "cPyparsing.pyx":4688
 *         return NoMatch()
 * 
 *     i = 0             # <<<<<<<<<<<<<<
 *     while i < len(symbols) - 1:
 *         cur = symbols[i]
 */
  __pyx_v_i = 0;

  /* "cPyparsing.pyx":4689
 * 
 *     i = 0
 *     while i < len(symbols) - 1:             # <<<<<<<<<<<<<<
 *         cur = symbols[i]
 *         for j, other in enumerate(symbols[i + 1:]):
 */
  while (1) {
    __pyx_t_7 = 0;
    __pyx_t_6 = __pyx_cur_scope->__pyx_v_symbols;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_8 = PyObject_Length(__pyx_t_6); if (unlikely(__pyx_t_8 == -1)) __PYX_ERR(0, 4689, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_9 = __Pyx_sub_const_Py_ssize_t_checking_overflow(__pyx_t_8, 1, &__pyx_t_7);
    if (unlikely(__pyx_t_7)) {
      PyErr_SetString(PyExc_OverflowError, "value too large");
      __PYX_ERR(0, 4689, __pyx_L1_error)
    }
    __pyx_t_3 = ((__pyx_v_i < __pyx_t_9) != 0);
    if (!__pyx_t_3) break;

    /* "cPyparsing.pyx":4690
 *     i = 0
 *     while i < len(symbols) - 1:
 *         cur = symbols[i]             # <<<<<<<<<<<<<<
 *         for j, other in enumerate(symbols[i + 1:]):
 *             if (isequal(other, cur)):
 */
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_symbols, __pyx_v_i, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4690, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_XDECREF_SET(__pyx_v_cur, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "cPyparsing.pyx":4691
 *     while i < len(symbols) - 1:
 *         cur = symbols[i]
 *         for j, other in enumerate(symbols[i + 1:]):             # <<<<<<<<<<<<<<
 *             if (isequal(other, cur)):
 *                 del symbols[i + j + 1]
 */
    __Pyx_INCREF(__pyx_int_0);
    __pyx_t_6 = __pyx_int_0;
    __pyx_t_7 = 0;
    __pyx_t_10 = __Pyx_add_const_long_checking_overflow(__pyx_v_i, 1, &__pyx_t_7);
    if (unlikely(__pyx_t_7)) {
      PyErr_SetString(PyExc_OverflowError, "value too large");
      __PYX_ERR(0, 4691, __pyx_L1_error)
    }
    __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_cur_scope->__pyx_v_symbols, __pyx_t_10, 0, NULL, NULL, NULL, 1, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4691, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (likely(PyList_CheckExact(__pyx_t_5)) || PyTuple_CheckExact(__pyx_t_5)) {
      __pyx_t_4 = __pyx_t_5; __Pyx_INCREF(__pyx_t_4); __pyx_t_9 = 0;
      __pyx_t_11 = NULL;
    } else {
      __pyx_t_9 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4691, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_11 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4691, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    for (;;) {
      if (likely(!__pyx_t_11)) {
        if (likely(PyList_CheckExact(__pyx_t_4))) {
          if (__pyx_t_9 >= PyList_GET_SIZE(__pyx_t_4)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_9); __Pyx_INCREF(__pyx_t_5); __pyx_t_9++; if (unlikely(0 < 0)) __PYX_ERR(0, 4691, __pyx_L1_error)
          #else
          __pyx_t_5 = PySequence_ITEM(__pyx_t_4, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4691, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        } else {
          if (__pyx_t_9 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_9); __Pyx_INCREF(__pyx_t_5); __pyx_t_9++; if (unlikely(0 < 0)) __PYX_ERR(0, 4691, __pyx_L1_error)
          #else
          __pyx_t_5 = PySequence_ITEM(__pyx_t_4, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4691, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        }
      } else {
        __pyx_t_5 = __pyx_t_11(__pyx_t_4);
        if (unlikely(!__pyx_t_5)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 4691, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_XDECREF_SET(__pyx_v_other, __pyx_t_5);
      __pyx_t_5 = 0;
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_XDECREF_SET(__pyx_v_j, __pyx_t_6);
      __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_t_6, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4691, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6);
      __pyx_t_6 = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "cPyparsing.pyx":4692
 *         cur = symbols[i]
 *         for j, other in enumerate(symbols[i + 1:]):
 *             if (isequal(other, cur)):             # <<<<<<<<<<<<<<
 *                 del symbols[i + j + 1]
 *                 break
 */
      __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4692, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_other);
      __Pyx_GIVEREF(__pyx_v_other);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_other);
      __Pyx_INCREF(__pyx_v_cur);
      __Pyx_GIVEREF(__pyx_v_cur);
      PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_cur);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_v_isequal, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4692, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 4692, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_3) {

        /* "cPyparsing.pyx":4693
 *         for j, other in enumerate(symbols[i + 1:]):
 *             if (isequal(other, cur)):
 *                 del symbols[i + j + 1]             # <<<<<<<<<<<<<<
 *                 break
 *             elif (masks(cur, other)):
 */
        __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v_i); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4693, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_5 = PyNumber_Add(__pyx_t_2, __pyx_v_j); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4693, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_t_5, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4693, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(PyObject_DelItem(__pyx_cur_scope->__pyx_v_symbols, __pyx_t_2) < 0)) __PYX_ERR(0, 4693, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "cPyparsing.pyx":4694
 *             if (isequal(other, cur)):
 *                 del symbols[i + j + 1]
 *                 break             # <<<<<<<<<<<<<<
 *             elif (masks(cur, other)):
 *                 del symbols[i + j + 1]
 */
        goto __pyx_L9_break;

        /* "cPyparsing.pyx":4692
 *         cur = symbols[i]
 *         for j, other in enumerate(symbols[i + 1:]):
 *             if (isequal(other, cur)):             # <<<<<<<<<<<<<<
 *                 del symbols[i + j + 1]
 *                 break
 */
      }

      /* "cPyparsing.pyx":4695
 *                 del symbols[i + j + 1]
 *                 break
 *             elif (masks(cur, other)):             # <<<<<<<<<<<<<<
 *                 del symbols[i + j + 1]
 *                 symbols.insert(i, other)
 */
      __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4695, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_v_cur);
      __Pyx_GIVEREF(__pyx_v_cur);
      PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_cur);
      __Pyx_INCREF(__pyx_v_other);
      __Pyx_GIVEREF(__pyx_v_other);
      PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_other);
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_v_masks, __pyx_t_2, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4695, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 4695, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_3) {

        /* "cPyparsing.pyx":4696
 *                 break
 *             elif (masks(cur, other)):
 *                 del symbols[i + j + 1]             # <<<<<<<<<<<<<<
 *                 symbols.insert(i, other)
 *                 cur = other
 */
        __pyx_t_5 = __Pyx_PyInt_From_long(__pyx_v_i); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4696, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_2 = PyNumber_Add(__pyx_t_5, __pyx_v_j); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4696, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_t_2, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4696, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(PyObject_DelItem(__pyx_cur_scope->__pyx_v_symbols, __pyx_t_5) < 0)) __PYX_ERR(0, 4696, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "cPyparsing.pyx":4697
 *             elif (masks(cur, other)):
 *                 del symbols[i + j + 1]
 *                 symbols.insert(i, other)             # <<<<<<<<<<<<<<
 *                 cur = other
 *                 break
 */
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_symbols, __pyx_n_s_insert); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4697, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_12 = __Pyx_PyInt_From_long(__pyx_v_i); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4697, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_13 = NULL;
        __pyx_t_7 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_13)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_13);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
            __pyx_t_7 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_2)) {
          PyObject *__pyx_temp[3] = {__pyx_t_13, __pyx_t_12, __pyx_v_other};
          __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4697, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
          PyObject *__pyx_temp[3] = {__pyx_t_13, __pyx_t_12, __pyx_v_other};
          __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4697, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        } else
        #endif
        {
          __pyx_t_14 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4697, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          if (__pyx_t_13) {
            __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_13); __pyx_t_13 = NULL;
          }
          __Pyx_GIVEREF(__pyx_t_12);
          PyTuple_SET_ITEM(__pyx_t_14, 0+__pyx_t_7, __pyx_t_12);
          __Pyx_INCREF(__pyx_v_other);
          __Pyx_GIVEREF(__pyx_v_other);
          PyTuple_SET_ITEM(__pyx_t_14, 1+__pyx_t_7, __pyx_v_other);
          __pyx_t_12 = 0;
          __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_14, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4697, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        }
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "cPyparsing.pyx":4698
 *                 del symbols[i + j + 1]
 *                 symbols.insert(i, other)
 *                 cur = other             # <<<<<<<<<<<<<<
 *                 break
 *         else:
 */
        __Pyx_INCREF(__pyx_v_other);
        __Pyx_DECREF_SET(__pyx_v_cur, __pyx_v_other);

        /* "cPyparsing.pyx":4699
 *                 symbols.insert(i, other)
 *                 cur = other
 *                 break             # <<<<<<<<<<<<<<
 *         else:
 *             i += 1
 */
        goto __pyx_L9_break;

        /* "cPyparsing.pyx":4695
 *                 del symbols[i + j + 1]
 *                 break
 *             elif (masks(cur, other)):             # <<<<<<<<<<<<<<
 *                 del symbols[i + j + 1]
 *                 symbols.insert(i, other)
 */
      }

      /* "cPyparsing.pyx":4691
 *     while i < len(symbols) - 1:
 *         cur = symbols[i]
 *         for j, other in enumerate(symbols[i + 1:]):             # <<<<<<<<<<<<<<
 *             if (isequal(other, cur)):
 *                 del symbols[i + j + 1]
 */
    }
    /*else*/ {

      /* "cPyparsing.pyx":4701
 *                 break
 *         else:
 *             i += 1             # <<<<<<<<<<<<<<
 * 
 *     if not caseless and useRegex:
 */
      __pyx_t_7 = 0;
      __pyx_t_10 = __Pyx_add_const_long_checking_overflow(__pyx_v_i, 1, &__pyx_t_7);
      if (unlikely(__pyx_t_7)) {
        PyErr_SetString(PyExc_OverflowError, "value too large");
        __PYX_ERR(0, 4701, __pyx_L1_error)
      }
      __pyx_v_i = __pyx_t_10;
    }

    /* "cPyparsing.pyx":4691
 *     while i < len(symbols) - 1:
 *         cur = symbols[i]
 *         for j, other in enumerate(symbols[i + 1:]):             # <<<<<<<<<<<<<<
 *             if (isequal(other, cur)):
 *                 del symbols[i + j + 1]
 */
    __pyx_L9_break:;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }

  /* "cPyparsing.pyx":4703
 *             i += 1
 * 
 *     if not caseless and useRegex:             # <<<<<<<<<<<<<<
 *         #~ print (strs,"->", "|".join( [ _escapeRegexChars(sym) for sym in symbols] ))
 *         try:
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_caseless); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 4703, __pyx_L1_error)
  __pyx_t_15 = ((!__pyx_t_1) != 0);
  if (__pyx_t_15) {
  } else {
    __pyx_t_3 = __pyx_t_15;
    goto __pyx_L13_bool_binop_done;
  }
  __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_v_useRegex); if (unlikely(__pyx_t_15 < 0)) __PYX_ERR(0, 4703, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_15;
  __pyx_L13_bool_binop_done:;
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":4705
 *     if not caseless and useRegex:
 *         #~ print (strs,"->", "|".join( [ _escapeRegexChars(sym) for sym in symbols] ))
 *         try:             # <<<<<<<<<<<<<<
 *             if len(symbols) == len("".join(symbols)):
 *                 return Regex("[%s]" % "".join(_escapeRegexRangeChars(sym) for sym in symbols)).setName(' | '.join(symbols))
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
      __Pyx_XGOTREF(__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_17);
      __Pyx_XGOTREF(__pyx_t_18);
      /*try:*/ {

        /* "cPyparsing.pyx":4706
 *         #~ print (strs,"->", "|".join( [ _escapeRegexChars(sym) for sym in symbols] ))
 *         try:
 *             if len(symbols) == len("".join(symbols)):             # <<<<<<<<<<<<<<
 *                 return Regex("[%s]" % "".join(_escapeRegexRangeChars(sym) for sym in symbols)).setName(' | '.join(symbols))
 *             else:
 */
        __pyx_t_6 = __pyx_cur_scope->__pyx_v_symbols;
        __Pyx_INCREF(__pyx_t_6);
        __pyx_t_9 = PyObject_Length(__pyx_t_6); if (unlikely(__pyx_t_9 == -1)) __PYX_ERR(0, 4706, __pyx_L15_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = __pyx_cur_scope->__pyx_v_symbols;
        __Pyx_INCREF(__pyx_t_6);
        __pyx_t_4 = PyUnicode_Join(__pyx_kp_u__9, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4706, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_8 = __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4); if (unlikely(__pyx_t_8 == -1)) __PYX_ERR(0, 4706, __pyx_L15_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_3 = ((__pyx_t_9 == __pyx_t_8) != 0);
        if (__pyx_t_3) {

          /* "cPyparsing.pyx":4707
 *         try:
 *             if len(symbols) == len("".join(symbols)):
 *                 return Regex("[%s]" % "".join(_escapeRegexRangeChars(sym) for sym in symbols)).setName(' | '.join(symbols))             # <<<<<<<<<<<<<<
 *             else:
 *                 return Regex("|".join(re.escape(sym) for sym in symbols)).setName(' | '.join(symbols))
 */
          __Pyx_XDECREF(__pyx_r);
          __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4707, __pyx_L15_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_2 = __pyx_pf_10cPyparsing_5oneOf_4genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4707, __pyx_L15_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_14 = __Pyx_Generator_Next(__pyx_t_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4707, __pyx_L15_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_2 = PyUnicode_Join(__pyx_kp_u__9, __pyx_t_14); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4707, __pyx_L15_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_14 = PyUnicode_Format(__pyx_kp_u_s_8, __pyx_t_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4707, __pyx_L15_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_2 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
            __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
            if (likely(__pyx_t_2)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
              __Pyx_INCREF(__pyx_t_2);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_5, function);
            }
          }
          if (!__pyx_t_2) {
            __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_14); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4707, __pyx_L15_error)
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_GOTREF(__pyx_t_6);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_5)) {
              PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_14};
              __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4707, __pyx_L15_error)
              __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
              PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_14};
              __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4707, __pyx_L15_error)
              __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            } else
            #endif
            {
              __pyx_t_12 = PyTuple_New(1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4707, __pyx_L15_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_2); __pyx_t_2 = NULL;
              __Pyx_GIVEREF(__pyx_t_14);
              PyTuple_SET_ITEM(__pyx_t_12, 0+1, __pyx_t_14);
              __pyx_t_14 = 0;
              __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_12, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4707, __pyx_L15_error)
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_setName); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4707, __pyx_L15_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = __pyx_cur_scope->__pyx_v_symbols;
          __Pyx_INCREF(__pyx_t_6);
          __pyx_t_12 = PyUnicode_Join(__pyx_kp_u__115, __pyx_t_6); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4707, __pyx_L15_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_5, function);
            }
          }
          if (!__pyx_t_6) {
            __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4707, __pyx_L15_error)
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_GOTREF(__pyx_t_4);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_5)) {
              PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_12};
              __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4707, __pyx_L15_error)
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
              PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_12};
              __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4707, __pyx_L15_error)
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            } else
            #endif
            {
              __pyx_t_14 = PyTuple_New(1+1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4707, __pyx_L15_error)
              __Pyx_GOTREF(__pyx_t_14);
              __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_6); __pyx_t_6 = NULL;
              __Pyx_GIVEREF(__pyx_t_12);
              PyTuple_SET_ITEM(__pyx_t_14, 0+1, __pyx_t_12);
              __pyx_t_12 = 0;
              __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_14, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4707, __pyx_L15_error)
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_r = __pyx_t_4;
          __pyx_t_4 = 0;
          goto __pyx_L19_try_return;

          /* "cPyparsing.pyx":4706
 *         #~ print (strs,"->", "|".join( [ _escapeRegexChars(sym) for sym in symbols] ))
 *         try:
 *             if len(symbols) == len("".join(symbols)):             # <<<<<<<<<<<<<<
 *                 return Regex("[%s]" % "".join(_escapeRegexRangeChars(sym) for sym in symbols)).setName(' | '.join(symbols))
 *             else:
 */
        }

        /* "cPyparsing.pyx":4709
 *                 return Regex("[%s]" % "".join(_escapeRegexRangeChars(sym) for sym in symbols)).setName(' | '.join(symbols))
 *             else:
 *                 return Regex("|".join(re.escape(sym) for sym in symbols)).setName(' | '.join(symbols))             # <<<<<<<<<<<<<<
 *         except Exception:
 *             warnings.warn("Exception creating Regex for oneOf, building MatchFirst",
 */
        /*else*/ {
          __Pyx_XDECREF(__pyx_r);
          __pyx_t_14 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4709, __pyx_L15_error)
          __Pyx_GOTREF(__pyx_t_14);
          __pyx_t_12 = __pyx_pf_10cPyparsing_5oneOf_7genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4709, __pyx_L15_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_6 = __Pyx_Generator_Next(__pyx_t_12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4709, __pyx_L15_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = PyUnicode_Join(__pyx_kp_u__146, __pyx_t_6); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4709, __pyx_L15_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_14))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_14);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_14, function);
            }
          }
          if (!__pyx_t_6) {
            __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4709, __pyx_L15_error)
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_GOTREF(__pyx_t_5);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_14)) {
              PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_12};
              __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_14, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4709, __pyx_L15_error)
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_14)) {
              PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_12};
              __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_14, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4709, __pyx_L15_error)
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            } else
            #endif
            {
              __pyx_t_2 = PyTuple_New(1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4709, __pyx_L15_error)
              __Pyx_GOTREF(__pyx_t_2);
              __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_6); __pyx_t_6 = NULL;
              __Pyx_GIVEREF(__pyx_t_12);
              PyTuple_SET_ITEM(__pyx_t_2, 0+1, __pyx_t_12);
              __pyx_t_12 = 0;
              __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_t_2, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4709, __pyx_L15_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_setName); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4709, __pyx_L15_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = __pyx_cur_scope->__pyx_v_symbols;
          __Pyx_INCREF(__pyx_t_5);
          __pyx_t_2 = PyUnicode_Join(__pyx_kp_u__115, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4709, __pyx_L15_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
            __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_14);
            if (likely(__pyx_t_5)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
              __Pyx_INCREF(__pyx_t_5);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_14, function);
            }
          }
          if (!__pyx_t_5) {
            __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4709, __pyx_L15_error)
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_GOTREF(__pyx_t_4);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_14)) {
              PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_2};
              __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_14, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4709, __pyx_L15_error)
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_14)) {
              PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_2};
              __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_14, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4709, __pyx_L15_error)
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            } else
            #endif
            {
              __pyx_t_12 = PyTuple_New(1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4709, __pyx_L15_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_5); __pyx_t_5 = NULL;
              __Pyx_GIVEREF(__pyx_t_2);
              PyTuple_SET_ITEM(__pyx_t_12, 0+1, __pyx_t_2);
              __pyx_t_2 = 0;
              __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_t_12, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4709, __pyx_L15_error)
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_r = __pyx_t_4;
          __pyx_t_4 = 0;
          goto __pyx_L19_try_return;
        }

        /* "cPyparsing.pyx":4705
 *     if not caseless and useRegex:
 *         #~ print (strs,"->", "|".join( [ _escapeRegexChars(sym) for sym in symbols] ))
 *         try:             # <<<<<<<<<<<<<<
 *             if len(symbols) == len("".join(symbols)):
 *                 return Regex("[%s]" % "".join(_escapeRegexRangeChars(sym) for sym in symbols)).setName(' | '.join(symbols))
 */
      }
      __pyx_L15_error:;
      __Pyx_PyThreadState_assign
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "cPyparsing.pyx":4710
 *             else:
 *                 return Regex("|".join(re.escape(sym) for sym in symbols)).setName(' | '.join(symbols))
 *         except Exception:             # <<<<<<<<<<<<<<
 *             warnings.warn("Exception creating Regex for oneOf, building MatchFirst",
 *                           SyntaxWarning, stacklevel=2)
 */
      __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_7) {
        __Pyx_AddTraceback("cPyparsing.oneOf", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_14, &__pyx_t_12) < 0) __PYX_ERR(0, 4710, __pyx_L17_except_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_GOTREF(__pyx_t_12);

        /* "cPyparsing.pyx":4711
 *                 return Regex("|".join(re.escape(sym) for sym in symbols)).setName(' | '.join(symbols))
 *         except Exception:
 *             warnings.warn("Exception creating Regex for oneOf, building MatchFirst",             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 * 
 */
        __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_warnings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4711, __pyx_L17_except_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_warn); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4711, __pyx_L17_except_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "cPyparsing.pyx":4712
 *         except Exception:
 *             warnings.warn("Exception creating Regex for oneOf, building MatchFirst",
 *                           SyntaxWarning, stacklevel=2)             # <<<<<<<<<<<<<<
 * 
 *     # last resort, just use MatchFirst
 */
        __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4711, __pyx_L17_except_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_INCREF(__pyx_kp_u_Exception_creating_Regex_for_one);
        __Pyx_GIVEREF(__pyx_kp_u_Exception_creating_Regex_for_one);
        PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_u_Exception_creating_Regex_for_one);
        __Pyx_INCREF(__pyx_builtin_SyntaxWarning);
        __Pyx_GIVEREF(__pyx_builtin_SyntaxWarning);
        PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_builtin_SyntaxWarning);
        __pyx_t_6 = PyDict_New(); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4712, __pyx_L17_except_error)
        __Pyx_GOTREF(__pyx_t_6);
        if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_stacklevel, __pyx_int_2) < 0) __PYX_ERR(0, 4712, __pyx_L17_except_error)

        /* "cPyparsing.pyx":4711
 *                 return Regex("|".join(re.escape(sym) for sym in symbols)).setName(' | '.join(symbols))
 *         except Exception:
 *             warnings.warn("Exception creating Regex for oneOf, building MatchFirst",             # <<<<<<<<<<<<<<
 *                           SyntaxWarning, stacklevel=2)
 * 
 */
        __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_2, __pyx_t_6); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4711, __pyx_L17_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        goto __pyx_L16_exception_handled;
      }
      goto __pyx_L17_except_error;
      __pyx_L17_except_error:;

      /* "cPyparsing.pyx":4705
 *     if not caseless and useRegex:
 *         #~ print (strs,"->", "|".join( [ _escapeRegexChars(sym) for sym in symbols] ))
 *         try:             # <<<<<<<<<<<<<<
 *             if len(symbols) == len("".join(symbols)):
 *                 return Regex("[%s]" % "".join(_escapeRegexRangeChars(sym) for sym in symbols)).setName(' | '.join(symbols))
 */
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_17);
      __Pyx_XGIVEREF(__pyx_t_18);
      __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_17, __pyx_t_18);
      goto __pyx_L1_error;
      __pyx_L19_try_return:;
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_17);
      __Pyx_XGIVEREF(__pyx_t_18);
      __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_17, __pyx_t_18);
      goto __pyx_L0;
      __pyx_L16_exception_handled:;
      __Pyx_PyThreadState_assign
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_17);
      __Pyx_XGIVEREF(__pyx_t_18);
      __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_17, __pyx_t_18);
    }

    /* "cPyparsing.pyx":4703
 *             i += 1
 * 
 *     if not caseless and useRegex:             # <<<<<<<<<<<<<<
 *         #~ print (strs,"->", "|".join( [ _escapeRegexChars(sym) for sym in symbols] ))
 *         try:
 */
  }

  /* "cPyparsing.pyx":4715
 * 
 *     # last resort, just use MatchFirst
 *     return MatchFirst(parseElementClass(sym) for sym in symbols).setName(' | '.join(symbols))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_MatchFirst); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_13 = __pyx_pf_10cPyparsing_5oneOf_10genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (!__pyx_t_6) {
    __pyx_t_14 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_13); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4715, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_GOTREF(__pyx_t_14);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_13};
      __pyx_t_14 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4715, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_13};
      __pyx_t_14 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4715, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    } else
    #endif
    {
      __pyx_t_2 = PyTuple_New(1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4715, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_6); __pyx_t_6 = NULL;
      __Pyx_GIVEREF(__pyx_t_13);
      PyTuple_SET_ITEM(__pyx_t_2, 0+1, __pyx_t_13);
      __pyx_t_13 = 0;
      __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_2, NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4715, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_setName); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __pyx_cur_scope->__pyx_v_symbols;
  __Pyx_INCREF(__pyx_t_14);
  __pyx_t_2 = PyUnicode_Join(__pyx_kp_u__115, __pyx_t_14); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_14)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_14);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (!__pyx_t_14) {
    __pyx_t_12 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4715, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_12);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_14, __pyx_t_2};
      __pyx_t_12 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4715, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_14, __pyx_t_2};
      __pyx_t_12 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4715, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4715, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_GIVEREF(__pyx_t_14); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_14); __pyx_t_14 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_13, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4715, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_12;
  __pyx_t_12 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4645
 * 
 * 
 * def oneOf(strs, caseless=False, useRegex=True):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to quickly define a set of alternative Literals, and makes sure to do
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("cPyparsing.oneOf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_isequal);
  __Pyx_XDECREF(__pyx_v_masks);
  __Pyx_XDECREF(__pyx_v_cur);
  __Pyx_XDECREF(__pyx_v_j);
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4718
 * 
 * 
 * def dictOf(key, value):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to easily and clearly define a dictionary by specifying the respective patterns
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_39dictOf(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_38dictOf[] = "\n    Helper to easily and clearly define a dictionary by specifying the respective patterns\n    for the key and value.  Takes care of defining the C{L{Dict}}, C{L{ZeroOrMore}}, and C{L{Group}} tokens\n    in the proper order.  The key pattern can include delimiting markers or punctuation,\n    as long as they are suppressed, thereby leaving the significant key text.  The value\n    pattern can include named results, so that the C{Dict} results can include named token\n    fields.\n\n    Example::\n        text = \"shape: SQUARE posn: upper left color: light blue texture: burlap\"\n        attr_expr = (label + Suppress(':') + OneOrMore(data_word, stopOn=label).setParseAction(' '.join))\n        print(OneOrMore(attr_expr).parseString(text).dump())\n\n        attr_label = label\n        attr_value = Suppress(':') + OneOrMore(data_word, stopOn=label).setParseAction(' '.join)\n\n        # similar to Dict, but simpler call format\n        result = dictOf(attr_label, attr_value).parseString(text)\n        print(result.dump())\n        print(result['shape'])\n        print(result.shape)  # object attribute access works too\n        print(result.asDict())\n    prints::\n        [['shape', 'SQUARE'], ['posn', 'upper left'], ['color', 'light blue'], ['texture', 'burlap']]\n        - color: light blue\n        - posn: upper left\n        - shape: SQUARE\n        - texture: burlap\n        SQUARE\n        SQUARE\n        {'color': 'light blue', 'shape': 'SQUARE', 'posn': 'upper left', 'texture': 'burlap'}\n    ";
static PyMethodDef __pyx_mdef_10cPyparsing_39dictOf = {"dictOf", (PyCFunction)__pyx_pw_10cPyparsing_39dictOf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_38dictOf};
static PyObject *__pyx_pw_10cPyparsing_39dictOf(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_key = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dictOf (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_key,&__pyx_n_s_value,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_key)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("dictOf", 1, 2, 2, 1); __PYX_ERR(0, 4718, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "dictOf") < 0)) __PYX_ERR(0, 4718, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_key = values[0];
    __pyx_v_value = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("dictOf", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4718, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.dictOf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_38dictOf(__pyx_self, __pyx_v_key, __pyx_v_value);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_38dictOf(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("dictOf", 0);

  /* "cPyparsing.pyx":4751
 *         {'color': 'light blue', 'shape': 'SQUARE', 'posn': 'upper left', 'texture': 'burlap'}
 *     """
 *     return Dict(ZeroOrMore(Group(key + value)))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Dict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyNumber_Add(__pyx_v_key, __pyx_v_value); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  if (!__pyx_t_8) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4751, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_5);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_7};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4751, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_7};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4751, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4751, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_7);
      __pyx_t_7 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_9, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4751, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (!__pyx_t_6) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4751, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4751, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4751, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4751, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_6); __pyx_t_6 = NULL;
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_5);
      __pyx_t_5 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_9, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4751, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4751, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4751, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4751, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4751, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4751, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4718
 * 
 * 
 * def dictOf(key, value):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to easily and clearly define a dictionary by specifying the respective patterns
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.dictOf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4754
 * 
 * 
 * def originalTextFor(expr, asString=True):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to return the original, untokenized text for a given expression.  Useful to
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_41originalTextFor(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_40originalTextFor[] = "\n    Helper to return the original, untokenized text for a given expression.  Useful to\n    restore the parsed fields of an HTML start tag into the raw tag text itself, or to\n    revert separate tokens with intervening whitespace back to the original matching\n    input text. By default, returns astring containing the original parsed text.\n\n    If the optional C{asString} argument is passed as C{False}, then the return value is a\n    C{L{ParseResults}} containing any results names that were originally matched, and a\n    single token containing the original matched text from the input string.  So if\n    the expression passed to C{L{originalTextFor}} contains expressions with defined\n    results names, you must set C{asString} to C{False} if you want to preserve those\n    results name values.\n\n    Example::\n        src = \"this is test <b> bold <i>text</i> </b> normal text \"\n        for tag in (\"b\",\"i\"):\n            opener,closer = makeHTMLTags(tag)\n            patt = originalTextFor(opener + SkipTo(closer) + closer)\n            print(patt.searchString(src)[0])\n    prints::\n        ['<b> bold <i>text</i> </b>']\n        ['<i>text</i>']\n    ";
static PyMethodDef __pyx_mdef_10cPyparsing_41originalTextFor = {"originalTextFor", (PyCFunction)__pyx_pw_10cPyparsing_41originalTextFor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_40originalTextFor};
static PyObject *__pyx_pw_10cPyparsing_41originalTextFor(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_expr = 0;
  PyObject *__pyx_v_asString = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("originalTextFor (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_expr,&__pyx_n_s_asString,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)Py_True);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_expr)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_asString);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "originalTextFor") < 0)) __PYX_ERR(0, 4754, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_expr = values[0];
    __pyx_v_asString = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("originalTextFor", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4754, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.originalTextFor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_40originalTextFor(__pyx_self, __pyx_v_expr, __pyx_v_asString);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4783
 *     matchExpr = locMarker("_original_start") + expr + endlocMarker("_original_end")
 *     if asString:
 *         def extractText(s, l, t): return s[t._original_start:t._original_end]             # <<<<<<<<<<<<<<
 *     else:
 *         def extractText(s, l, t):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15originalTextFor_1extractText(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15originalTextFor_1extractText = {"extractText", (PyCFunction)__pyx_pw_10cPyparsing_15originalTextFor_1extractText, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_15originalTextFor_1extractText(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("extractText (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("extractText", 1, 3, 3, 1); __PYX_ERR(0, 4783, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("extractText", 1, 3, 3, 2); __PYX_ERR(0, 4783, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "extractText") < 0)) __PYX_ERR(0, 4783, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("extractText", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4783, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.originalTextFor.extractText", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15originalTextFor_extractText(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15originalTextFor_extractText(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("extractText", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_original_start); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_original_end); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_s, 0, 0, &__pyx_t_1, &__pyx_t_2, NULL, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.originalTextFor.extractText", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4785
 *         def extractText(s, l, t): return s[t._original_start:t._original_end]
 *     else:
 *         def extractText(s, l, t):             # <<<<<<<<<<<<<<
 *             t[:] = [s[t.pop('_original_start'):t.pop('_original_end')]]
 *     matchExpr.setParseAction(extractText)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15originalTextFor_3extractText(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15originalTextFor_3extractText = {"extractText", (PyCFunction)__pyx_pw_10cPyparsing_15originalTextFor_3extractText, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_15originalTextFor_3extractText(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("extractText (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("extractText", 1, 3, 3, 1); __PYX_ERR(0, 4785, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("extractText", 1, 3, 3, 2); __PYX_ERR(0, 4785, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "extractText") < 0)) __PYX_ERR(0, 4785, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("extractText", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4785, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.originalTextFor.extractText", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_15originalTextFor_2extractText(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_15originalTextFor_2extractText(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("extractText", 0);

  /* "cPyparsing.pyx":4786
 *     else:
 *         def extractText(s, l, t):
 *             t[:] = [s[t.pop('_original_start'):t.pop('_original_end')]]             # <<<<<<<<<<<<<<
 *     matchExpr.setParseAction(extractText)
 *     matchExpr.ignoreExprs = expr.ignoreExprs
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_pop); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4786, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__147, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4786, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_pop); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4786, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__148, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4786, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_s, 0, 0, &__pyx_t_2, &__pyx_t_3, NULL, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4786, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4786, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  PyList_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetSlice(__pyx_v_t, __pyx_t_3, 0, 0, NULL, NULL, &__pyx_slice__149, 0, 0, 1) < 0) __PYX_ERR(0, 4786, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":4785
 *         def extractText(s, l, t): return s[t._original_start:t._original_end]
 *     else:
 *         def extractText(s, l, t):             # <<<<<<<<<<<<<<
 *             t[:] = [s[t.pop('_original_start'):t.pop('_original_end')]]
 *     matchExpr.setParseAction(extractText)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.originalTextFor.extractText", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4778
 *         ['<i>text</i>']
 *     """
 *     locMarker = Empty().setParseAction(lambda s, loc, t: loc)             # <<<<<<<<<<<<<<
 *     endlocMarker = locMarker.copy()
 *     endlocMarker.callPreparse = False
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_15originalTextFor_4lambda37(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_15originalTextFor_4lambda37 = {"lambda37", (PyCFunction)__pyx_pw_10cPyparsing_15originalTextFor_4lambda37, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_15originalTextFor_4lambda37(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  PyObject *__pyx_v_loc = 0;
  CYTHON_UNUSED PyObject *__pyx_v_t = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda37 (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_loc,&__pyx_n_s_t,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_loc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("lambda37", 1, 3, 3, 1); __PYX_ERR(0, 4778, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("lambda37", 1, 3, 3, 2); __PYX_ERR(0, 4778, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "lambda37") < 0)) __PYX_ERR(0, 4778, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_loc = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda37", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4778, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.originalTextFor.lambda37", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda37(__pyx_self, __pyx_v_s, __pyx_v_loc, __pyx_v_t);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda37(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, PyObject *__pyx_v_loc, CYTHON_UNUSED PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda37", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_loc);
  __pyx_r = __pyx_v_loc;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4754
 * 
 * 
 * def originalTextFor(expr, asString=True):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to return the original, untokenized text for a given expression.  Useful to
 */

static PyObject *__pyx_pf_10cPyparsing_40originalTextFor(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr, PyObject *__pyx_v_asString) {
  PyObject *__pyx_v_locMarker = NULL;
  PyObject *__pyx_v_endlocMarker = NULL;
  PyObject *__pyx_v_matchExpr = NULL;
  PyObject *__pyx_v_extractText = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  __Pyx_RefNannySetupContext("originalTextFor", 0);

  /* "cPyparsing.pyx":4778
 *         ['<i>text</i>']
 *     """
 *     locMarker = Empty().setParseAction(lambda s, loc, t: loc)             # <<<<<<<<<<<<<<
 *     endlocMarker = locMarker.copy()
 *     endlocMarker.callPreparse = False
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_Empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4778, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4778, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_15originalTextFor_4lambda37, 0, __pyx_n_s_originalTextFor_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4778, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4778, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4778, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4778, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4778, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_locMarker = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4779
 *     """
 *     locMarker = Empty().setParseAction(lambda s, loc, t: loc)
 *     endlocMarker = locMarker.copy()             # <<<<<<<<<<<<<<
 *     endlocMarker.callPreparse = False
 *     matchExpr = locMarker("_original_start") + expr + endlocMarker("_original_end")
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_locMarker, __pyx_n_s_copy); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4779, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4779, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_endlocMarker = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4780
 *     locMarker = Empty().setParseAction(lambda s, loc, t: loc)
 *     endlocMarker = locMarker.copy()
 *     endlocMarker.callPreparse = False             # <<<<<<<<<<<<<<
 *     matchExpr = locMarker("_original_start") + expr + endlocMarker("_original_end")
 *     if asString:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_endlocMarker, __pyx_n_s_callPreparse, Py_False) < 0) __PYX_ERR(0, 4780, __pyx_L1_error)

  /* "cPyparsing.pyx":4781
 *     endlocMarker = locMarker.copy()
 *     endlocMarker.callPreparse = False
 *     matchExpr = locMarker("_original_start") + expr + endlocMarker("_original_end")             # <<<<<<<<<<<<<<
 *     if asString:
 *         def extractText(s, l, t): return s[t._original_start:t._original_end]
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_v_locMarker, __pyx_tuple__150, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_expr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_v_endlocMarker, __pyx_tuple__151, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyNumber_Add(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_matchExpr = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "cPyparsing.pyx":4782
 *     endlocMarker.callPreparse = False
 *     matchExpr = locMarker("_original_start") + expr + endlocMarker("_original_end")
 *     if asString:             # <<<<<<<<<<<<<<
 *         def extractText(s, l, t): return s[t._original_start:t._original_end]
 *     else:
 */
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_asString); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 4782, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":4783
 *     matchExpr = locMarker("_original_start") + expr + endlocMarker("_original_end")
 *     if asString:
 *         def extractText(s, l, t): return s[t._original_start:t._original_end]             # <<<<<<<<<<<<<<
 *     else:
 *         def extractText(s, l, t):
 */
    __pyx_t_5 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_15originalTextFor_1extractText, 0, __pyx_n_s_originalTextFor_locals_extractTe, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__153)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_v_extractText = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "cPyparsing.pyx":4782
 *     endlocMarker.callPreparse = False
 *     matchExpr = locMarker("_original_start") + expr + endlocMarker("_original_end")
 *     if asString:             # <<<<<<<<<<<<<<
 *         def extractText(s, l, t): return s[t._original_start:t._original_end]
 *     else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":4785
 *         def extractText(s, l, t): return s[t._original_start:t._original_end]
 *     else:
 *         def extractText(s, l, t):             # <<<<<<<<<<<<<<
 *             t[:] = [s[t.pop('_original_start'):t.pop('_original_end')]]
 *     matchExpr.setParseAction(extractText)
 */
  /*else*/ {
    __pyx_t_5 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_15originalTextFor_3extractText, 0, __pyx_n_s_originalTextFor_locals_extractTe, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__155)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4785, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_v_extractText = __pyx_t_5;
    __pyx_t_5 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":4787
 *         def extractText(s, l, t):
 *             t[:] = [s[t.pop('_original_start'):t.pop('_original_end')]]
 *     matchExpr.setParseAction(extractText)             # <<<<<<<<<<<<<<
 *     matchExpr.ignoreExprs = expr.ignoreExprs
 *     return matchExpr
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_matchExpr, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4787, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_extractText); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4787, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_extractText};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4787, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_5);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_extractText};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4787, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_5);
    } else
    #endif
    {
      __pyx_t_2 = PyTuple_New(1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4787, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_v_extractText);
      __Pyx_GIVEREF(__pyx_v_extractText);
      PyTuple_SET_ITEM(__pyx_t_2, 0+1, __pyx_v_extractText);
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4787, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cPyparsing.pyx":4788
 *             t[:] = [s[t.pop('_original_start'):t.pop('_original_end')]]
 *     matchExpr.setParseAction(extractText)
 *     matchExpr.ignoreExprs = expr.ignoreExprs             # <<<<<<<<<<<<<<
 *     return matchExpr
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_expr, __pyx_n_s_ignoreExprs); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_matchExpr, __pyx_n_s_ignoreExprs, __pyx_t_5) < 0) __PYX_ERR(0, 4788, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "cPyparsing.pyx":4789
 *     matchExpr.setParseAction(extractText)
 *     matchExpr.ignoreExprs = expr.ignoreExprs
 *     return matchExpr             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_matchExpr);
  __pyx_r = __pyx_v_matchExpr;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4754
 * 
 * 
 * def originalTextFor(expr, asString=True):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to return the original, untokenized text for a given expression.  Useful to
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.originalTextFor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_locMarker);
  __Pyx_XDECREF(__pyx_v_endlocMarker);
  __Pyx_XDECREF(__pyx_v_matchExpr);
  __Pyx_XDECREF(__pyx_v_extractText);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4792
 * 
 * 
 * def ungroup(expr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to undo pyparsing's default grouping of And expressions, even
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_43ungroup(PyObject *__pyx_self, PyObject *__pyx_v_expr); /*proto*/
static char __pyx_doc_10cPyparsing_42ungroup[] = "\n    Helper to undo pyparsing's default grouping of And expressions, even\n    if all but one are non-empty.\n    ";
static PyMethodDef __pyx_mdef_10cPyparsing_43ungroup = {"ungroup", (PyCFunction)__pyx_pw_10cPyparsing_43ungroup, METH_O, __pyx_doc_10cPyparsing_42ungroup};
static PyObject *__pyx_pw_10cPyparsing_43ungroup(PyObject *__pyx_self, PyObject *__pyx_v_expr) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ungroup (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_42ungroup(__pyx_self, ((PyObject *)__pyx_v_expr));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4797
 *     if all but one are non-empty.
 *     """
 *     return TokenConverter(expr).setParseAction(lambda t: t[0])             # <<<<<<<<<<<<<<
 * 
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_7ungroup_lambda38(PyObject *__pyx_self, PyObject *__pyx_v_t); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_7ungroup_lambda38 = {"lambda38", (PyCFunction)__pyx_pw_10cPyparsing_7ungroup_lambda38, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_7ungroup_lambda38(PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda38 (wrapper)", 0);
  __pyx_r = __pyx_lambda_funcdef_lambda38(__pyx_self, ((PyObject *)__pyx_v_t));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda38(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("lambda38", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4797, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.ungroup.lambda38", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4792
 * 
 * 
 * def ungroup(expr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to undo pyparsing's default grouping of And expressions, even
 */

static PyObject *__pyx_pf_10cPyparsing_42ungroup(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("ungroup", 0);

  /* "cPyparsing.pyx":4797
 *     if all but one are non-empty.
 *     """
 *     return TokenConverter(expr).setParseAction(lambda t: t[0])             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_TokenConverter); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4797, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4797, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_expr};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4797, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_expr};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4797, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4797, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_INCREF(__pyx_v_expr);
      __Pyx_GIVEREF(__pyx_v_expr);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_expr);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4797, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4797, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_7ungroup_lambda38, 0, __pyx_n_s_ungroup_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4797, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_5) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4797, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4797, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4797, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4797, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5); __pyx_t_5 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4797, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4792
 * 
 * 
 * def ungroup(expr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to undo pyparsing's default grouping of And expressions, even
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.ungroup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4800
 * 
 * 
 * def locatedExpr(expr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to decorate a returned token with its starting and ending locations in the input string.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_45locatedExpr(PyObject *__pyx_self, PyObject *__pyx_v_expr); /*proto*/
static char __pyx_doc_10cPyparsing_44locatedExpr[] = "\n    Helper to decorate a returned token with its starting and ending locations in the input string.\n    This helper adds the following results names:\n     - locn_start = location where matched expression begins\n     - locn_end = location where matched expression ends\n     - value = the actual parsed results\n\n    Be careful if the input text contains C{<TAB>} characters, you may want to call\n    C{L{ParserElement.parseWithTabs}}\n\n    Example::\n        wd = Word(alphas)\n        for match in locatedExpr(wd).searchString(\"ljsdf123lksdjjf123lkkjj1222\"):\n            print(match)\n    prints::\n        [[0, 'ljsdf', 5]]\n        [[8, 'lksdjjf', 15]]\n        [[18, 'lkkjj', 23]]\n    ";
static PyMethodDef __pyx_mdef_10cPyparsing_45locatedExpr = {"locatedExpr", (PyCFunction)__pyx_pw_10cPyparsing_45locatedExpr, METH_O, __pyx_doc_10cPyparsing_44locatedExpr};
static PyObject *__pyx_pw_10cPyparsing_45locatedExpr(PyObject *__pyx_self, PyObject *__pyx_v_expr) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("locatedExpr (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_44locatedExpr(__pyx_self, ((PyObject *)__pyx_v_expr));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4820
 *         [[18, 'lkkjj', 23]]
 *     """
 *     locator = Empty().setParseAction(lambda s, l, t: l)             # <<<<<<<<<<<<<<
 *     return Group(locator("locn_start") + expr("value") + locator.copy().leaveWhitespace()("locn_end"))
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_11locatedExpr_lambda39(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_11locatedExpr_lambda39 = {"lambda39", (PyCFunction)__pyx_pw_10cPyparsing_11locatedExpr_lambda39, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_11locatedExpr_lambda39(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  PyObject *__pyx_v_l = 0;
  CYTHON_UNUSED PyObject *__pyx_v_t = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda39 (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("lambda39", 1, 3, 3, 1); __PYX_ERR(0, 4820, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("lambda39", 1, 3, 3, 2); __PYX_ERR(0, 4820, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "lambda39") < 0)) __PYX_ERR(0, 4820, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda39", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4820, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.locatedExpr.lambda39", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda39(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda39(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, PyObject *__pyx_v_l, CYTHON_UNUSED PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda39", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_l);
  __pyx_r = __pyx_v_l;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4800
 * 
 * 
 * def locatedExpr(expr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to decorate a returned token with its starting and ending locations in the input string.
 */

static PyObject *__pyx_pf_10cPyparsing_44locatedExpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expr) {
  PyObject *__pyx_v_locator = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("locatedExpr", 0);

  /* "cPyparsing.pyx":4820
 *         [[18, 'lkkjj', 23]]
 *     """
 *     locator = Empty().setParseAction(lambda s, l, t: l)             # <<<<<<<<<<<<<<
 *     return Group(locator("locn_start") + expr("value") + locator.copy().leaveWhitespace()("locn_end"))
 * 
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_Empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4820, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4820, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_11locatedExpr_lambda39, 0, __pyx_n_s_locatedExpr_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4820, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4820, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4820, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4820, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4820, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_locator = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4821
 *     """
 *     locator = Empty().setParseAction(lambda s, l, t: l)
 *     return Group(locator("locn_start") + expr("value") + locator.copy().leaveWhitespace()("locn_end"))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_v_locator, __pyx_tuple__156, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_v_expr, __pyx_tuple__157, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyNumber_Add(__pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_locator, __pyx_n_s_copy); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  if (__pyx_t_7) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4821, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  } else {
    __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4821, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_leaveWhitespace); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4821, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4821, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__158, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_6) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4821, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4821, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4821, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4821, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6); __pyx_t_6 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4821, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4800
 * 
 * 
 * def locatedExpr(expr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to decorate a returned token with its starting and ending locations in the input string.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.locatedExpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_locator);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4839
 * 
 * 
 * def srange(s):             # <<<<<<<<<<<<<<
 *     r"""
 *     Helper to easily define string ranges for use in Word construction.  Borrows
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_47srange(PyObject *__pyx_self, PyObject *__pyx_v_s); /*proto*/
static char __pyx_doc_10cPyparsing_46srange[] = "\n    Helper to easily define string ranges for use in Word construction.  Borrows\n    syntax from regexp '[]' string range definitions::\n        srange(\"[0-9]\")   -> \"0123456789\"\n        srange(\"[a-z]\")   -> \"abcdefghijklmnopqrstuvwxyz\"\n        srange(\"[a-z$_]\") -> \"abcdefghijklmnopqrstuvwxyz$_\"\n    The input string must be enclosed in []'s, and the returned string is the expanded\n    character set joined into a single string.\n    The values enclosed in the []'s may be:\n     - a single character\n     - an escaped character with a leading backslash (such as C{\\-} or C{\\]})\n     - an escaped hex character with a leading C{'\\x'} (C{\\x21}, which is a C{'!'} character)\n         (C{\\0x##} is also supported for backwards compatibility)\n     - an escaped octal character with a leading C{'\\0'} (C{\\041}, which is a C{'!'} character)\n     - a range of any of the above, separated by a dash (C{'a-z'}, etc.)\n     - any combination of the above (C{'aeiouy'}, C{'a-zA-Z0-9_$'}, etc.)\n    ";
static PyMethodDef __pyx_mdef_10cPyparsing_47srange = {"srange", (PyCFunction)__pyx_pw_10cPyparsing_47srange, METH_O, __pyx_doc_10cPyparsing_46srange};
static PyObject *__pyx_pw_10cPyparsing_47srange(PyObject *__pyx_self, PyObject *__pyx_v_s) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("srange (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_46srange(__pyx_self, ((PyObject *)__pyx_v_s));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4857
 *      - any combination of the above (C{'aeiouy'}, C{'a-zA-Z0-9_$'}, etc.)
 *     """
 *     def _expanded(p): return p if not isinstance(p, ParseResults) else ''.join(unichr(c) for c in range(ord(p[0]), ord(p[1]) + 1))             # <<<<<<<<<<<<<<
 *     try:
 *         return "".join(_expanded(part) for part in _reBracketExpr.parseString(s).body)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_6srange_1_expanded(PyObject *__pyx_self, PyObject *__pyx_v_p); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_6srange_1_expanded = {"_expanded", (PyCFunction)__pyx_pw_10cPyparsing_6srange_1_expanded, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_6srange_1_expanded(PyObject *__pyx_self, PyObject *__pyx_v_p) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_expanded (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_6srange__expanded(__pyx_self, ((PyObject *)__pyx_v_p));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_6srange_9_expanded_2generator32(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

static PyObject *__pyx_pf_10cPyparsing_6srange_9_expanded_genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_68_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_68_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_68_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_68_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_68_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4857, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_67__expanded *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_6srange_9_expanded_2generator32, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_srange_locals__expanded_locals_g, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 4857, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.srange._expanded.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_6srange_9_expanded_2generator32(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_68_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_68_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  long __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  long __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  Py_ssize_t __pyx_t_10;
  PyObject *(*__pyx_t_11)(PyObject *);
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 4857, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 4857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_range); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_p)) { __Pyx_RaiseClosureNameError("p"); __PYX_ERR(0, 4857, __pyx_L1_error) }
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_p, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_Ord(__pyx_t_3); if (unlikely(__pyx_t_4 == (long)(Py_UCS4)-1)) __PYX_ERR(0, 4857, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyInt_From_long(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = 0;
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_p)) { __Pyx_RaiseClosureNameError("p"); __PYX_ERR(0, 4857, __pyx_L1_error) }
  __pyx_t_6 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_p, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = __Pyx_PyObject_Ord(__pyx_t_6); if (unlikely(__pyx_t_4 == (long)(Py_UCS4)-1)) __PYX_ERR(0, 4857, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_7 = __Pyx_add_const_long_checking_overflow(__pyx_t_4, 1, &__pyx_t_5);
  if (unlikely(__pyx_t_5)) {
    PyErr_SetString(PyExc_OverflowError, "value too large");
    __PYX_ERR(0, 4857, __pyx_L1_error)
  }
  __pyx_t_6 = __Pyx_PyInt_From_long(__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_t_3, __pyx_t_6};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4857, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_t_3, __pyx_t_6};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4857, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else
  #endif
  {
    __pyx_t_9 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (__pyx_t_8) {
      __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_5, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_5, __pyx_t_6);
    __pyx_t_3 = 0;
    __pyx_t_6 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_10 = 0;
    __pyx_t_11 = NULL;
  } else {
    __pyx_t_10 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_11 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4857, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_11)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_10 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_10); __Pyx_INCREF(__pyx_t_1); __pyx_t_10++; if (unlikely(0 < 0)) __PYX_ERR(0, 4857, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_10); __pyx_t_10++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4857, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_10 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_10); __Pyx_INCREF(__pyx_t_1); __pyx_t_10++; if (unlikely(0 < 0)) __PYX_ERR(0, 4857, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_10); __pyx_t_10++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4857, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_11(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 4857, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_c);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_c, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_unichr); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_cur_scope->__pyx_v_c); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4857, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_c};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4857, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_c};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4857, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_3 = PyTuple_New(1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4857, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_c);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_c);
        PyTuple_SET_ITEM(__pyx_t_3, 0+1, __pyx_cur_scope->__pyx_v_c);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4857, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_1))) __PYX_ERR(0, 4857, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_6srange__expanded(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_p) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_67__expanded *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  __Pyx_RefNannySetupContext("_expanded", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_67__expanded *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_67__expanded(__pyx_ptype_10cPyparsing___pyx_scope_struct_67__expanded, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_67__expanded *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4857, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_p = __pyx_v_p;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_p);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_p);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_cur_scope->__pyx_v_p;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyObject_IsInstance(__pyx_t_2, __pyx_t_3); if (unlikely(__pyx_t_4 == -1)) __PYX_ERR(0, 4857, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (((!(__pyx_t_4 != 0)) != 0)) {
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_p);
    __pyx_t_1 = __pyx_cur_scope->__pyx_v_p;
  } else {
    __pyx_t_3 = __pyx_pf_10cPyparsing_6srange_9_expanded_genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_Generator_Next(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyUnicode_Join(__pyx_kp_u__9, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.srange._expanded", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_6srange_4generator33(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":4859
 *     def _expanded(p): return p if not isinstance(p, ParseResults) else ''.join(unichr(c) for c in range(ord(p[0]), ord(p[1]) + 1))
 *     try:
 *         return "".join(_expanded(part) for part in _reBracketExpr.parseString(s).body)             # <<<<<<<<<<<<<<
 *     except Exception:
 *         return ""
 */

static PyObject *__pyx_pf_10cPyparsing_6srange_2genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_69_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_69_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_69_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_69_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_69_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4859, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_srange *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_6srange_4generator33, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_srange_locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 4859, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.srange.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_6srange_4generator33(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_69_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_69_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 4859, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 4859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_reBracketExpr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_parseString); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_s)) { __Pyx_RaiseClosureNameError("s"); __PYX_ERR(0, 4859, __pyx_L1_error) }
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_cur_scope->__pyx_outer_scope->__pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4859, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_cur_scope->__pyx_outer_scope->__pyx_v_s};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4859, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_cur_scope->__pyx_outer_scope->__pyx_v_s};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4859, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4859, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_s);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_s);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_cur_scope->__pyx_outer_scope->__pyx_v_s);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4859, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_body); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
    __pyx_t_1 = __pyx_t_3; __Pyx_INCREF(__pyx_t_1); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
  } else {
    __pyx_t_5 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4859, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4859, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  for (;;) {
    if (likely(!__pyx_t_6)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 4859, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4859, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 4859, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4859, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_6(__pyx_t_1);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 4859, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_part);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_part, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v__expanded)) { __Pyx_RaiseClosureNameError("_expanded"); __PYX_ERR(0, 4859, __pyx_L1_error) }
    __pyx_t_3 = __pyx_pf_10cPyparsing_6srange__expanded(__pyx_cur_scope->__pyx_outer_scope->__pyx_v__expanded, __pyx_cur_scope->__pyx_v_part); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4859, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_3))) __PYX_ERR(0, 4859, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4839
 * 
 * 
 * def srange(s):             # <<<<<<<<<<<<<<
 *     r"""
 *     Helper to easily define string ranges for use in Word construction.  Borrows
 */

static PyObject *__pyx_pf_10cPyparsing_46srange(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_srange *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("srange", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_srange *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_66_srange(__pyx_ptype_10cPyparsing___pyx_scope_struct_66_srange, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_srange *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4839, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_s = __pyx_v_s;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_s);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_s);

  /* "cPyparsing.pyx":4857
 *      - any combination of the above (C{'aeiouy'}, C{'a-zA-Z0-9_$'}, etc.)
 *     """
 *     def _expanded(p): return p if not isinstance(p, ParseResults) else ''.join(unichr(c) for c in range(ord(p[0]), ord(p[1]) + 1))             # <<<<<<<<<<<<<<
 *     try:
 *         return "".join(_expanded(part) for part in _reBracketExpr.parseString(s).body)
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_6srange_1_expanded, 0, __pyx_n_s_srange_locals__expanded, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__160)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v__expanded = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4858
 *     """
 *     def _expanded(p): return p if not isinstance(p, ParseResults) else ''.join(unichr(c) for c in range(ord(p[0]), ord(p[1]) + 1))
 *     try:             # <<<<<<<<<<<<<<
 *         return "".join(_expanded(part) for part in _reBracketExpr.parseString(s).body)
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "cPyparsing.pyx":4859
 *     def _expanded(p): return p if not isinstance(p, ParseResults) else ''.join(unichr(c) for c in range(ord(p[0]), ord(p[1]) + 1))
 *     try:
 *         return "".join(_expanded(part) for part in _reBracketExpr.parseString(s).body)             # <<<<<<<<<<<<<<
 *     except Exception:
 *         return ""
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_1 = __pyx_pf_10cPyparsing_6srange_2genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4859, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4859, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__9, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4859, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":4858
 *     """
 *     def _expanded(p): return p if not isinstance(p, ParseResults) else ''.join(unichr(c) for c in range(ord(p[0]), ord(p[1]) + 1))
 *     try:             # <<<<<<<<<<<<<<
 *         return "".join(_expanded(part) for part in _reBracketExpr.parseString(s).body)
 *     except Exception:
 */
    }
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":4860
 *     try:
 *         return "".join(_expanded(part) for part in _reBracketExpr.parseString(s).body)
 *     except Exception:             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_6) {
      __Pyx_AddTraceback("cPyparsing.srange", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_5, &__pyx_t_7) < 0) __PYX_ERR(0, 4860, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_7);

      /* "cPyparsing.pyx":4861
 *         return "".join(_expanded(part) for part in _reBracketExpr.parseString(s).body)
 *     except Exception:
 *         return ""             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__9);
      __pyx_r = __pyx_kp_u__9;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cPyparsing.pyx":4858
 *     """
 *     def _expanded(p): return p if not isinstance(p, ParseResults) else ''.join(unichr(c) for c in range(ord(p[0]), ord(p[1]) + 1))
 *     try:             # <<<<<<<<<<<<<<
 *         return "".join(_expanded(part) for part in _reBracketExpr.parseString(s).body)
 *     except Exception:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":4839
 * 
 * 
 * def srange(s):             # <<<<<<<<<<<<<<
 *     r"""
 *     Helper to easily define string ranges for use in Word construction.  Borrows
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.srange", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4864
 * 
 * 
 * def matchOnlyAtCol(n):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for defining parse actions that require matching at a specific
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_49matchOnlyAtCol(PyObject *__pyx_self, PyObject *__pyx_v_n); /*proto*/
static char __pyx_doc_10cPyparsing_48matchOnlyAtCol[] = "\n    Helper method for defining parse actions that require matching at a specific\n    column in the input text.\n    ";
static PyMethodDef __pyx_mdef_10cPyparsing_49matchOnlyAtCol = {"matchOnlyAtCol", (PyCFunction)__pyx_pw_10cPyparsing_49matchOnlyAtCol, METH_O, __pyx_doc_10cPyparsing_48matchOnlyAtCol};
static PyObject *__pyx_pw_10cPyparsing_49matchOnlyAtCol(PyObject *__pyx_self, PyObject *__pyx_v_n) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("matchOnlyAtCol (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_48matchOnlyAtCol(__pyx_self, ((PyObject *)__pyx_v_n));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4869
 *     column in the input text.
 *     """
 *     def verifyCol(strg, locn, toks):             # <<<<<<<<<<<<<<
 *         if col(locn, strg) != n:
 *             raise ParseException(strg, locn, "matched token not at column %d" % n)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_14matchOnlyAtCol_1verifyCol(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_14matchOnlyAtCol_1verifyCol = {"verifyCol", (PyCFunction)__pyx_pw_10cPyparsing_14matchOnlyAtCol_1verifyCol, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_14matchOnlyAtCol_1verifyCol(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_strg = 0;
  PyObject *__pyx_v_locn = 0;
  CYTHON_UNUSED PyObject *__pyx_v_toks = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("verifyCol (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_strg,&__pyx_n_s_locn,&__pyx_n_s_toks,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_strg)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_locn)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("verifyCol", 1, 3, 3, 1); __PYX_ERR(0, 4869, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_toks)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("verifyCol", 1, 3, 3, 2); __PYX_ERR(0, 4869, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "verifyCol") < 0)) __PYX_ERR(0, 4869, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_strg = values[0];
    __pyx_v_locn = values[1];
    __pyx_v_toks = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("verifyCol", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4869, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.matchOnlyAtCol.verifyCol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_14matchOnlyAtCol_verifyCol(__pyx_self, __pyx_v_strg, __pyx_v_locn, __pyx_v_toks);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_14matchOnlyAtCol_verifyCol(PyObject *__pyx_self, PyObject *__pyx_v_strg, PyObject *__pyx_v_locn, CYTHON_UNUSED PyObject *__pyx_v_toks) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("verifyCol", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":4870
 *     """
 *     def verifyCol(strg, locn, toks):
 *         if col(locn, strg) != n:             # <<<<<<<<<<<<<<
 *             raise ParseException(strg, locn, "matched token not at column %d" % n)
 *     return verifyCol
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_col); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_locn, __pyx_v_strg};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4870, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_locn, __pyx_v_strg};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4870, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4870, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_locn);
    __Pyx_GIVEREF(__pyx_v_locn);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_locn);
    __Pyx_INCREF(__pyx_v_strg);
    __Pyx_GIVEREF(__pyx_v_strg);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_strg);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4870, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_cur_scope->__pyx_v_n)) { __Pyx_RaiseClosureNameError("n"); __PYX_ERR(0, 4870, __pyx_L1_error) }
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_cur_scope->__pyx_v_n, Py_NE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4870, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 4870, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":4871
 *     def verifyCol(strg, locn, toks):
 *         if col(locn, strg) != n:
 *             raise ParseException(strg, locn, "matched token not at column %d" % n)             # <<<<<<<<<<<<<<
 *     return verifyCol
 * 
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4871, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely(!__pyx_cur_scope->__pyx_v_n)) { __Pyx_RaiseClosureNameError("n"); __PYX_ERR(0, 4871, __pyx_L1_error) }
    __pyx_t_5 = PyUnicode_Format(__pyx_kp_u_matched_token_not_at_column_d, __pyx_cur_scope->__pyx_v_n); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4871, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[4] = {__pyx_t_3, __pyx_v_strg, __pyx_v_locn, __pyx_t_5};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_4, 3+__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4871, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[4] = {__pyx_t_3, __pyx_v_strg, __pyx_v_locn, __pyx_t_5};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_4, 3+__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4871, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(3+__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4871, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__pyx_t_3) {
        __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_3); __pyx_t_3 = NULL;
      }
      __Pyx_INCREF(__pyx_v_strg);
      __Pyx_GIVEREF(__pyx_v_strg);
      PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_4, __pyx_v_strg);
      __Pyx_INCREF(__pyx_v_locn);
      __Pyx_GIVEREF(__pyx_v_locn);
      PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_4, __pyx_v_locn);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_4, __pyx_t_5);
      __pyx_t_5 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4871, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 4871, __pyx_L1_error)

    /* "cPyparsing.pyx":4870
 *     """
 *     def verifyCol(strg, locn, toks):
 *         if col(locn, strg) != n:             # <<<<<<<<<<<<<<
 *             raise ParseException(strg, locn, "matched token not at column %d" % n)
 *     return verifyCol
 */
  }

  /* "cPyparsing.pyx":4869
 *     column in the input text.
 *     """
 *     def verifyCol(strg, locn, toks):             # <<<<<<<<<<<<<<
 *         if col(locn, strg) != n:
 *             raise ParseException(strg, locn, "matched token not at column %d" % n)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.matchOnlyAtCol.verifyCol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4864
 * 
 * 
 * def matchOnlyAtCol(n):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for defining parse actions that require matching at a specific
 */

static PyObject *__pyx_pf_10cPyparsing_48matchOnlyAtCol(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_n) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol *__pyx_cur_scope;
  PyObject *__pyx_v_verifyCol = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("matchOnlyAtCol", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol(__pyx_ptype_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4864, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_n = __pyx_v_n;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_n);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_n);

  /* "cPyparsing.pyx":4869
 *     column in the input text.
 *     """
 *     def verifyCol(strg, locn, toks):             # <<<<<<<<<<<<<<
 *         if col(locn, strg) != n:
 *             raise ParseException(strg, locn, "matched token not at column %d" % n)
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_14matchOnlyAtCol_1verifyCol, 0, __pyx_n_s_matchOnlyAtCol_locals_verifyCol, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__162)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_verifyCol = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4872
 *         if col(locn, strg) != n:
 *             raise ParseException(strg, locn, "matched token not at column %d" % n)
 *     return verifyCol             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_verifyCol);
  __pyx_r = __pyx_v_verifyCol;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4864
 * 
 * 
 * def matchOnlyAtCol(n):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for defining parse actions that require matching at a specific
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.matchOnlyAtCol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_verifyCol);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4875
 * 
 * 
 * def replaceWith(replStr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for common parse actions that simply return a literal value.  Especially
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_51replaceWith(PyObject *__pyx_self, PyObject *__pyx_v_replStr); /*proto*/
static char __pyx_doc_10cPyparsing_50replaceWith[] = "\n    Helper method for common parse actions that simply return a literal value.  Especially\n    useful when used with C{L{transformString<ParserElement.transformString>}()}.\n\n    Example::\n        num = Word(nums).setParseAction(lambda toks: int(toks[0]))\n        na = oneOf(\"N/A NA\").setParseAction(replaceWith(math.nan))\n        term = na | num\n\n        OneOrMore(term).parseString(\"324 234 N/A 234\") # -> [324, 234, nan, 234]\n    ";
static PyMethodDef __pyx_mdef_10cPyparsing_51replaceWith = {"replaceWith", (PyCFunction)__pyx_pw_10cPyparsing_51replaceWith, METH_O, __pyx_doc_10cPyparsing_50replaceWith};
static PyObject *__pyx_pw_10cPyparsing_51replaceWith(PyObject *__pyx_self, PyObject *__pyx_v_replStr) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("replaceWith (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_50replaceWith(__pyx_self, ((PyObject *)__pyx_v_replStr));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4887
 *         OneOrMore(term).parseString("324 234 N/A 234") # -> [324, 234, nan, 234]
 *     """
 *     return lambda s, l, t: [replStr]             # <<<<<<<<<<<<<<
 * 
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_11replaceWith_lambda45(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_11replaceWith_lambda45 = {"lambda45", (PyCFunction)__pyx_pw_10cPyparsing_11replaceWith_lambda45, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_11replaceWith_lambda45(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  CYTHON_UNUSED PyObject *__pyx_v_t = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda45 (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("lambda45", 1, 3, 3, 1); __PYX_ERR(0, 4887, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("lambda45", 1, 3, 3, 2); __PYX_ERR(0, 4887, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "lambda45") < 0)) __PYX_ERR(0, 4887, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda45", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4887, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.replaceWith.lambda45", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda45(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda45(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, CYTHON_UNUSED PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_replaceWith *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_replaceWith *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("lambda45", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_replaceWith *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_v_replStr)) { __Pyx_RaiseClosureNameError("replStr"); __PYX_ERR(0, 4887, __pyx_L1_error) }
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_replStr);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_replStr);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_cur_scope->__pyx_v_replStr);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.replaceWith.lambda45", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4875
 * 
 * 
 * def replaceWith(replStr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for common parse actions that simply return a literal value.  Especially
 */

static PyObject *__pyx_pf_10cPyparsing_50replaceWith(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_replStr) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_replaceWith *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("replaceWith", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_replaceWith *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_71_replaceWith(__pyx_ptype_10cPyparsing___pyx_scope_struct_71_replaceWith, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_replaceWith *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4875, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_replStr = __pyx_v_replStr;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_replStr);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_replStr);

  /* "cPyparsing.pyx":4887
 *         OneOrMore(term).parseString("324 234 N/A 234") # -> [324, 234, nan, 234]
 *     """
 *     return lambda s, l, t: [replStr]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_11replaceWith_lambda45, 0, __pyx_n_s_replaceWith_locals_lambda, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4875
 * 
 * 
 * def replaceWith(replStr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for common parse actions that simply return a literal value.  Especially
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.replaceWith", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4890
 * 
 * 
 * def removeQuotes(s, l, t):             # <<<<<<<<<<<<<<
 *     """
 *     Helper parse action for removing quotation marks from parsed quoted strings.
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_53removeQuotes(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_52removeQuotes[] = "\n    Helper parse action for removing quotation marks from parsed quoted strings.\n\n    Example::\n        # by default, quotation marks are included in parsed results\n        quotedString.parseString(\"'Now is the Winter of our Discontent'\") # -> [\"'Now is the Winter of our Discontent'\"]\n\n        # use removeQuotes to strip quotation marks from parsed results\n        quotedString.setParseAction(removeQuotes)\n        quotedString.parseString(\"'Now is the Winter of our Discontent'\") # -> [\"Now is the Winter of our Discontent\"]\n    ";
static PyMethodDef __pyx_mdef_10cPyparsing_53removeQuotes = {"removeQuotes", (PyCFunction)__pyx_pw_10cPyparsing_53removeQuotes, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_52removeQuotes};
static PyObject *__pyx_pw_10cPyparsing_53removeQuotes(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("removeQuotes (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("removeQuotes", 1, 3, 3, 1); __PYX_ERR(0, 4890, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("removeQuotes", 1, 3, 3, 2); __PYX_ERR(0, 4890, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "removeQuotes") < 0)) __PYX_ERR(0, 4890, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("removeQuotes", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4890, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.removeQuotes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_52removeQuotes(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_52removeQuotes(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("removeQuotes", 0);

  /* "cPyparsing.pyx":4902
 *         quotedString.parseString("'Now is the Winter of our Discontent'") # -> ["Now is the Winter of our Discontent"]
 *     """
 *     return t[0][1:-1]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_t_1, 1, -1L, NULL, NULL, &__pyx_slice__163, 1, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4890
 * 
 * 
 * def removeQuotes(s, l, t):             # <<<<<<<<<<<<<<
 *     """
 *     Helper parse action for removing quotation marks from parsed quoted strings.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.removeQuotes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4905
 * 
 * 
 * def tokenMap(func, *args):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define a parse action by mapping a function to all elements of a ParseResults list.If any additional
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_55tokenMap(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_54tokenMap[] = "\n    Helper to define a parse action by mapping a function to all elements of a ParseResults list.If any additional\n    args are passed, they are forwarded to the given function as additional arguments after\n    the token, as in C{hex_integer = Word(hexnums).setParseAction(tokenMap(int, 16))}, which will convert the\n    parsed data to an integer using base 16.\n\n    Example (compare the last to example in L{ParserElement.transformString}::\n        hex_ints = OneOrMore(Word(hexnums)).setParseAction(tokenMap(int, 16))\n        hex_ints.runTests('''\n            00 11 22 aa FF 0a 0d 1a\n            ''')\n\n        upperword = Word(alphas).setParseAction(tokenMap(str.upper))\n        OneOrMore(upperword).runTests('''\n            my kingdom for a horse\n            ''')\n\n        wd = Word(alphas).setParseAction(tokenMap(str.title))\n        OneOrMore(wd).setParseAction(' '.join).runTests('''\n            now is the winter of our discontent made glorious summer by this sun of york\n            ''')\n    prints::\n        00 11 22 aa FF 0a 0d 1a\n        [0, 17, 34, 170, 255, 10, 13, 26]\n\n        my kingdom for a horse\n        ['MY', 'KINGDOM', 'FOR', 'A', 'HORSE']\n\n        now is the winter of our discontent made glorious summer by this sun of york\n        ['Now Is The Winter Of Our Discontent Made Glorious Summer By This Sun Of York']\n    ";
static PyMethodDef __pyx_mdef_10cPyparsing_55tokenMap = {"tokenMap", (PyCFunction)__pyx_pw_10cPyparsing_55tokenMap, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_54tokenMap};
static PyObject *__pyx_pw_10cPyparsing_55tokenMap(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_func = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tokenMap (wrapper)", 0);
  if (PyTuple_GET_SIZE(__pyx_args) > 1) {
    __pyx_v_args = PyTuple_GetSlice(__pyx_args, 1, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v_args)) {
      __Pyx_RefNannyFinishContext();
      return NULL;
    }
    __Pyx_GOTREF(__pyx_v_args);
  } else {
    __pyx_v_args = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_func,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_func)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 1) ? pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, used_pos_args, "tokenMap") < 0)) __PYX_ERR(0, 4905, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_func = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("tokenMap", 0, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4905, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_CLEAR(__pyx_v_args);
  __Pyx_AddTraceback("cPyparsing.tokenMap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_54tokenMap(__pyx_self, __pyx_v_func, __pyx_v_args);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4937
 *         ['Now Is The Winter Of Our Discontent Made Glorious Summer By This Sun Of York']
 *     """
 *     def pa(s, l, t):             # <<<<<<<<<<<<<<
 *         return [func(tokn, *args) for tokn in t]
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_8tokenMap_1pa(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_8tokenMap_1pa = {"pa", (PyCFunction)__pyx_pw_10cPyparsing_8tokenMap_1pa, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_8tokenMap_1pa(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pa (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pa", 1, 3, 3, 1); __PYX_ERR(0, 4937, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pa", 1, 3, 3, 2); __PYX_ERR(0, 4937, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "pa") < 0)) __PYX_ERR(0, 4937, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pa", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4937, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.tokenMap.pa", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_8tokenMap_pa(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_8tokenMap_pa(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_tokenMap *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_tokenMap *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("pa", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_tokenMap *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":4938
 *     """
 *     def pa(s, l, t):
 *         return [func(tokn, *args) for tokn in t]             # <<<<<<<<<<<<<<
 * 
 *     try:
 */
  __Pyx_XDECREF(__pyx_r);
  { /* enter inner scope */
    PyObject *__pyx_9genexpr46__pyx_v_tokn = NULL;
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4938, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(PyList_CheckExact(__pyx_v_t)) || PyTuple_CheckExact(__pyx_v_t)) {
      __pyx_t_2 = __pyx_v_t; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
      __pyx_t_4 = NULL;
    } else {
      __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_t); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4938, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4938, __pyx_L5_error)
    }
    for (;;) {
      if (likely(!__pyx_t_4)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 4938, __pyx_L5_error)
          #else
          __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4938, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        } else {
          if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 4938, __pyx_L5_error)
          #else
          __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4938, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        }
      } else {
        __pyx_t_5 = __pyx_t_4(__pyx_t_2);
        if (unlikely(!__pyx_t_5)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 4938, __pyx_L5_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_XDECREF_SET(__pyx_9genexpr46__pyx_v_tokn, __pyx_t_5);
      __pyx_t_5 = 0;
      if (unlikely(!__pyx_cur_scope->__pyx_v_func)) { __Pyx_RaiseClosureNameError("func"); __PYX_ERR(0, 4938, __pyx_L5_error) }
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4938, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_9genexpr46__pyx_v_tokn);
      __Pyx_GIVEREF(__pyx_9genexpr46__pyx_v_tokn);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_9genexpr46__pyx_v_tokn);
      if (unlikely(!__pyx_cur_scope->__pyx_v_args)) { __Pyx_RaiseClosureNameError("args"); __PYX_ERR(0, 4938, __pyx_L5_error) }
      if (unlikely(__pyx_cur_scope->__pyx_v_args == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
        __PYX_ERR(0, 4938, __pyx_L5_error)
      }
      __pyx_t_6 = PyNumber_Add(__pyx_t_5, __pyx_cur_scope->__pyx_v_args); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4938, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_cur_scope->__pyx_v_func, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4938, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_5))) __PYX_ERR(0, 4938, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_9genexpr46__pyx_v_tokn);
    goto __pyx_L8_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_9genexpr46__pyx_v_tokn);
    goto __pyx_L1_error;
    __pyx_L8_exit_scope:;
  } /* exit inner scope */
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4937
 *         ['Now Is The Winter Of Our Discontent Made Glorious Summer By This Sun Of York']
 *     """
 *     def pa(s, l, t):             # <<<<<<<<<<<<<<
 *         return [func(tokn, *args) for tokn in t]
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cPyparsing.tokenMap.pa", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4905
 * 
 * 
 * def tokenMap(func, *args):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define a parse action by mapping a function to all elements of a ParseResults list.If any additional
 */

static PyObject *__pyx_pf_10cPyparsing_54tokenMap(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_func, PyObject *__pyx_v_args) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_tokenMap *__pyx_cur_scope;
  PyObject *__pyx_v_pa = 0;
  PyObject *__pyx_v_func_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  __Pyx_RefNannySetupContext("tokenMap", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_tokenMap *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_72_tokenMap(__pyx_ptype_10cPyparsing___pyx_scope_struct_72_tokenMap, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_tokenMap *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4905, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_func = __pyx_v_func;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_func);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_func);
  __pyx_cur_scope->__pyx_v_args = __pyx_v_args;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_args);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_args);

  /* "cPyparsing.pyx":4937
 *         ['Now Is The Winter Of Our Discontent Made Glorious Summer By This Sun Of York']
 *     """
 *     def pa(s, l, t):             # <<<<<<<<<<<<<<
 *         return [func(tokn, *args) for tokn in t]
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_8tokenMap_1pa, 0, __pyx_n_s_tokenMap_locals_pa, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__165)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4937, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pa = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":4940
 *         return [func(tokn, *args) for tokn in t]
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         func_name = getattr(func, '__name__',
 *                             getattr(func, '__class__').__name__)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "cPyparsing.pyx":4941
 * 
 *     try:
 *         func_name = getattr(func, '__name__',             # <<<<<<<<<<<<<<
 *                             getattr(func, '__class__').__name__)
 *     except Exception:
 */
      __pyx_t_1 = __pyx_cur_scope->__pyx_v_func;
      __Pyx_INCREF(__pyx_t_1);

      /* "cPyparsing.pyx":4942
 *     try:
 *         func_name = getattr(func, '__name__',
 *                             getattr(func, '__class__').__name__)             # <<<<<<<<<<<<<<
 *     except Exception:
 *         func_name = str(func)
 */
      __pyx_t_5 = __pyx_cur_scope->__pyx_v_func;
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_GetAttr(__pyx_t_5, __pyx_n_u_class); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4942, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_name_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4942, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "cPyparsing.pyx":4941
 * 
 *     try:
 *         func_name = getattr(func, '__name__',             # <<<<<<<<<<<<<<
 *                             getattr(func, '__class__').__name__)
 *     except Exception:
 */
      __pyx_t_6 = __Pyx_GetAttr3(__pyx_t_1, __pyx_n_u_name_2, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4941, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_func_name = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "cPyparsing.pyx":4940
 *         return [func(tokn, *args) for tokn in t]
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         func_name = getattr(func, '__name__',
 *                             getattr(func, '__class__').__name__)
 */
    }
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L10_try_end;
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":4943
 *         func_name = getattr(func, '__name__',
 *                             getattr(func, '__class__').__name__)
 *     except Exception:             # <<<<<<<<<<<<<<
 *         func_name = str(func)
 *     pa.__name__ = func_name
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_7) {
      __Pyx_AddTraceback("cPyparsing.tokenMap", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_5, &__pyx_t_1) < 0) __PYX_ERR(0, 4943, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_1);

      /* "cPyparsing.pyx":4944
 *                             getattr(func, '__class__').__name__)
 *     except Exception:
 *         func_name = str(func)             # <<<<<<<<<<<<<<
 *     pa.__name__ = func_name
 * 
 */
      __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_str); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4944, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      if (!__pyx_t_10) {
        __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_cur_scope->__pyx_v_func); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4944, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_8);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_9)) {
          PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_cur_scope->__pyx_v_func};
          __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4944, __pyx_L5_except_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_t_8);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
          PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_cur_scope->__pyx_v_func};
          __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4944, __pyx_L5_except_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_t_8);
        } else
        #endif
        {
          __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4944, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_10); __pyx_t_10 = NULL;
          __Pyx_INCREF(__pyx_cur_scope->__pyx_v_func);
          __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_func);
          PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_cur_scope->__pyx_v_func);
          __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_11, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4944, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF_SET(__pyx_v_func_name, __pyx_t_8);
      __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cPyparsing.pyx":4940
 *         return [func(tokn, *args) for tokn in t]
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         func_name = getattr(func, '__name__',
 *                             getattr(func, '__class__').__name__)
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    __pyx_L10_try_end:;
  }

  /* "cPyparsing.pyx":4945
 *     except Exception:
 *         func_name = str(func)
 *     pa.__name__ = func_name             # <<<<<<<<<<<<<<
 * 
 *     return pa
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_pa, __pyx_n_s_name_2, __pyx_v_func_name) < 0) __PYX_ERR(0, 4945, __pyx_L1_error)

  /* "cPyparsing.pyx":4947
 *     pa.__name__ = func_name
 * 
 *     return pa             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_pa);
  __pyx_r = __pyx_v_pa;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4905
 * 
 * 
 * def tokenMap(func, *args):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define a parse action by mapping a function to all elements of a ParseResults list.If any additional
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("cPyparsing.tokenMap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pa);
  __Pyx_XDECREF(__pyx_v_func_name);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4957
 * 
 * 
 * def _makeTags(tagStr, xml):             # <<<<<<<<<<<<<<
 *     """Internal helper to construct opening and closing tag expressions, given a tag name"""
 *     if isinstance(tagStr, basestring):
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_57_makeTags(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_56_makeTags[] = "Internal helper to construct opening and closing tag expressions, given a tag name";
static PyMethodDef __pyx_mdef_10cPyparsing_57_makeTags = {"_makeTags", (PyCFunction)__pyx_pw_10cPyparsing_57_makeTags, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_56_makeTags};
static PyObject *__pyx_pw_10cPyparsing_57_makeTags(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_tagStr = 0;
  PyObject *__pyx_v_xml = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_makeTags (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_tagStr,&__pyx_n_s_xml,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_tagStr)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_xml)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_makeTags", 1, 2, 2, 1); __PYX_ERR(0, 4957, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "_makeTags") < 0)) __PYX_ERR(0, 4957, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_tagStr = values[0];
    __pyx_v_xml = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_makeTags", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4957, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing._makeTags", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_56_makeTags(__pyx_self, __pyx_v_tagStr, __pyx_v_xml);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4970
 *         openTag = Suppress("<") + tagStr("tag") + \
 *             Dict(ZeroOrMore(Group(tagAttrName + Suppress("=") + tagAttrValue))) + \
 *             Optional("/", default=[False]).setResultsName("empty").setParseAction(lambda s, l, t: t[0] == '/') + Suppress(">")             # <<<<<<<<<<<<<<
 *     else:
 *         printablesLessRAbrack = "".join(c for c in printables if c not in ">")
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_9_makeTags_lambda48(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_9_makeTags_lambda48 = {"lambda48", (PyCFunction)__pyx_pw_10cPyparsing_9_makeTags_lambda48, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_9_makeTags_lambda48(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda48 (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("lambda48", 1, 3, 3, 1); __PYX_ERR(0, 4970, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("lambda48", 1, 3, 3, 2); __PYX_ERR(0, 4970, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "lambda48") < 0)) __PYX_ERR(0, 4970, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda48", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4970, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing._makeTags.lambda48", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda48(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda48(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("lambda48", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_kp_u__166, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4970, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing._makeTags.lambda48", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_9_makeTags_3generator34(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "cPyparsing.pyx":4972
 *             Optional("/", default=[False]).setResultsName("empty").setParseAction(lambda s, l, t: t[0] == '/') + Suppress(">")
 *     else:
 *         printablesLessRAbrack = "".join(c for c in printables if c not in ">")             # <<<<<<<<<<<<<<
 *         tagAttrValue = quotedString.copy().setParseAction(removeQuotes) | Word(printablesLessRAbrack)
 *         openTag = Suppress("<") + tagStr("tag") + \
 */

static PyObject *__pyx_pf_10cPyparsing_9_makeTags_1genexpr(CYTHON_UNUSED PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_73_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_73_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4972, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_9_makeTags_3generator34, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_makeTags_locals_genexpr, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 4972, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing._makeTags.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_9_makeTags_3generator34(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  int __pyx_t_5;
  int __pyx_t_6;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 4972, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 4972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_printables); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4972, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4972, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 4972, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4972, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 4972, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4972, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 4972, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_c);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_c, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_5 = (__Pyx_PyUnicode_ContainsTF(__pyx_cur_scope->__pyx_v_c, __pyx_kp_u__24, Py_NE)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 4972, __pyx_L1_error)
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {
      if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_cur_scope->__pyx_v_c))) __PYX_ERR(0, 4972, __pyx_L1_error)
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4977
 *             Dict(ZeroOrMore(Group(tagAttrName.setParseAction(downcaseTokens) +
 *                                   Optional(Suppress("=") + tagAttrValue)))) + \
 *             Optional("/", default=[False]).setResultsName("empty").setParseAction(lambda s, l, t: t[0] == '/') + Suppress(">")             # <<<<<<<<<<<<<<
 *     closeTag = Combine(_L("</") + tagStr + ">")
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_9_makeTags_4lambda50(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_9_makeTags_4lambda50 = {"lambda50", (PyCFunction)__pyx_pw_10cPyparsing_9_makeTags_4lambda50, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_9_makeTags_4lambda50(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda50 (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("lambda50", 1, 3, 3, 1); __PYX_ERR(0, 4977, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("lambda50", 1, 3, 3, 2); __PYX_ERR(0, 4977, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "lambda50") < 0)) __PYX_ERR(0, 4977, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda50", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 4977, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing._makeTags.lambda50", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda50(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda50(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("lambda50", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_kp_u__166, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4977, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing._makeTags.lambda50", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4957
 * 
 * 
 * def _makeTags(tagStr, xml):             # <<<<<<<<<<<<<<
 *     """Internal helper to construct opening and closing tag expressions, given a tag name"""
 *     if isinstance(tagStr, basestring):
 */

static PyObject *__pyx_pf_10cPyparsing_56_makeTags(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tagStr, PyObject *__pyx_v_xml) {
  PyObject *__pyx_v_resname = NULL;
  PyObject *__pyx_v_tagAttrName = NULL;
  PyObject *__pyx_v_tagAttrValue = NULL;
  PyObject *__pyx_v_openTag = NULL;
  PyObject *__pyx_v_printablesLessRAbrack = NULL;
  PyObject *__pyx_v_closeTag = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  __Pyx_RefNannySetupContext("_makeTags", 0);
  __Pyx_INCREF(__pyx_v_tagStr);

  /* "cPyparsing.pyx":4959
 * def _makeTags(tagStr, xml):
 *     """Internal helper to construct opening and closing tag expressions, given a tag name"""
 *     if isinstance(tagStr, basestring):             # <<<<<<<<<<<<<<
 *         resname = tagStr
 *         tagStr = Keyword(tagStr, caseless=not xml)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4959, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_tagStr, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 4959, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":4960
 *     """Internal helper to construct opening and closing tag expressions, given a tag name"""
 *     if isinstance(tagStr, basestring):
 *         resname = tagStr             # <<<<<<<<<<<<<<
 *         tagStr = Keyword(tagStr, caseless=not xml)
 *     else:
 */
    __Pyx_INCREF(__pyx_v_tagStr);
    __pyx_v_resname = __pyx_v_tagStr;

    /* "cPyparsing.pyx":4961
 *     if isinstance(tagStr, basestring):
 *         resname = tagStr
 *         tagStr = Keyword(tagStr, caseless=not xml)             # <<<<<<<<<<<<<<
 *     else:
 *         resname = tagStr.name
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Keyword); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4961, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4961, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_tagStr);
    __Pyx_GIVEREF(__pyx_v_tagStr);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_tagStr);
    __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4961, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_xml); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 4961, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyBool_FromLong((!__pyx_t_3)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4961, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_caseless, __pyx_t_6) < 0) __PYX_ERR(0, 4961, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4961, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_tagStr, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "cPyparsing.pyx":4959
 * def _makeTags(tagStr, xml):
 *     """Internal helper to construct opening and closing tag expressions, given a tag name"""
 *     if isinstance(tagStr, basestring):             # <<<<<<<<<<<<<<
 *         resname = tagStr
 *         tagStr = Keyword(tagStr, caseless=not xml)
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":4963
 *         tagStr = Keyword(tagStr, caseless=not xml)
 *     else:
 *         resname = tagStr.name             # <<<<<<<<<<<<<<
 * 
 *     tagAttrName = Word(alphas, alphanums + "_-:")
 */
  /*else*/ {
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_tagStr, __pyx_n_s_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4963, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_v_resname = __pyx_t_6;
    __pyx_t_6 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":4965
 *         resname = tagStr.name
 * 
 *     tagAttrName = Word(alphas, alphanums + "_-:")             # <<<<<<<<<<<<<<
 *     if (xml):
 *         tagAttrValue = dblQuotedString.copy().setParseAction(removeQuotes)
 */
  __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_Word); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_alphas); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_alphanums); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = PyNumber_Add(__pyx_t_1, __pyx_kp_u__167); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  __pyx_t_8 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_8 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_5)) {
    PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_t_4, __pyx_t_7};
    __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4965, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
    PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_t_4, __pyx_t_7};
    __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4965, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  } else
  #endif
  {
    __pyx_t_9 = PyTuple_New(2+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4965, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (__pyx_t_1) {
      __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_1); __pyx_t_1 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, __pyx_t_7);
    __pyx_t_4 = 0;
    __pyx_t_7 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_9, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4965, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_tagAttrName = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "cPyparsing.pyx":4966
 * 
 *     tagAttrName = Word(alphas, alphanums + "_-:")
 *     if (xml):             # <<<<<<<<<<<<<<
 *         tagAttrValue = dblQuotedString.copy().setParseAction(removeQuotes)
 *         openTag = Suppress("<") + tagStr("tag") + \
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_xml); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 4966, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":4967
 *     tagAttrName = Word(alphas, alphanums + "_-:")
 *     if (xml):
 *         tagAttrValue = dblQuotedString.copy().setParseAction(removeQuotes)             # <<<<<<<<<<<<<<
 *         openTag = Suppress("<") + tagStr("tag") + \
 *             Dict(ZeroOrMore(Group(tagAttrName + Suppress("=") + tagAttrValue))) + \
 */
    __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_dblQuotedString); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4967, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_copy); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4967, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    if (__pyx_t_9) {
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4967, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else {
      __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4967, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4967, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_removeQuotes); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4967, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    if (!__pyx_t_9) {
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4967, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_6);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_5};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4967, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_5};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4967, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4967, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_9); __pyx_t_9 = NULL;
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_4, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4967, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_v_tagAttrValue = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "cPyparsing.pyx":4968
 *     if (xml):
 *         tagAttrValue = dblQuotedString.copy().setParseAction(removeQuotes)
 *         openTag = Suppress("<") + tagStr("tag") + \             # <<<<<<<<<<<<<<
 *             Dict(ZeroOrMore(Group(tagAttrName + Suppress("=") + tagAttrValue))) + \
 *             Optional("/", default=[False]).setResultsName("empty").setParseAction(lambda s, l, t: t[0] == '/') + Suppress(">")
 */
    __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_Suppress); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4968, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__168, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4968, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_v_tagStr, __pyx_tuple__169, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4968, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = PyNumber_Add(__pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4968, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":4969
 *         tagAttrValue = dblQuotedString.copy().setParseAction(removeQuotes)
 *         openTag = Suppress("<") + tagStr("tag") + \
 *             Dict(ZeroOrMore(Group(tagAttrName + Suppress("=") + tagAttrValue))) + \             # <<<<<<<<<<<<<<
 *             Optional("/", default=[False]).setResultsName("empty").setParseAction(lambda s, l, t: t[0] == '/') + Suppress(">")
 *     else:
 */
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_Dict); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4969, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4969, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_10 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4969, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_11 = __Pyx_GetModuleGlobalName(__pyx_n_s_Suppress); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4969, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_tuple__171, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4969, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_11 = PyNumber_Add(__pyx_v_tagAttrName, __pyx_t_12); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4969, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_12 = PyNumber_Add(__pyx_t_11, __pyx_v_tagAttrValue); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4969, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_11 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
      }
    }
    if (!__pyx_t_11) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4969, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_t_12};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4969, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_t_12};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4969, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4969, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
        __Pyx_GIVEREF(__pyx_t_12);
        PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_t_12);
        __pyx_t_12 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4969, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
      }
    }
    if (!__pyx_t_10) {
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4969, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_5);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_1};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4969, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_1};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4969, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4969, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_10); __pyx_t_10 = NULL;
        __Pyx_GIVEREF(__pyx_t_1);
        PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_t_1);
        __pyx_t_1 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_13, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4969, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    if (!__pyx_t_9) {
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4969, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_6);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_5};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4969, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_5};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4969, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4969, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_9); __pyx_t_9 = NULL;
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_13, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4969, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":4968
 *     if (xml):
 *         tagAttrValue = dblQuotedString.copy().setParseAction(removeQuotes)
 *         openTag = Suppress("<") + tagStr("tag") + \             # <<<<<<<<<<<<<<
 *             Dict(ZeroOrMore(Group(tagAttrName + Suppress("=") + tagAttrValue))) + \
 *             Optional("/", default=[False]).setResultsName("empty").setParseAction(lambda s, l, t: t[0] == '/') + Suppress(">")
 */
    __pyx_t_7 = PyNumber_Add(__pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4968, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":4970
 *         openTag = Suppress("<") + tagStr("tag") + \
 *             Dict(ZeroOrMore(Group(tagAttrName + Suppress("=") + tagAttrValue))) + \
 *             Optional("/", default=[False]).setResultsName("empty").setParseAction(lambda s, l, t: t[0] == '/') + Suppress(">")             # <<<<<<<<<<<<<<
 *     else:
 *         printablesLessRAbrack = "".join(c for c in printables if c not in ">")
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4970, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_13 = PyDict_New(); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4970, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_5 = PyList_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4970, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    PyList_SET_ITEM(__pyx_t_5, 0, Py_False);
    if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_default, __pyx_t_5) < 0) __PYX_ERR(0, 4970, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__172, __pyx_t_13); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4970, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_setResultsName); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4970, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_tuple__173, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4970, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4970, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_9_makeTags_lambda48, 0, __pyx_n_s_makeTags_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4970, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_13);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_13, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4970, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_6);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_13)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_5};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4970, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_13)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_5};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4970, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4970, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_9, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4970, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

    /* "cPyparsing.pyx":4969
 *         tagAttrValue = dblQuotedString.copy().setParseAction(removeQuotes)
 *         openTag = Suppress("<") + tagStr("tag") + \
 *             Dict(ZeroOrMore(Group(tagAttrName + Suppress("=") + tagAttrValue))) + \             # <<<<<<<<<<<<<<
 *             Optional("/", default=[False]).setResultsName("empty").setParseAction(lambda s, l, t: t[0] == '/') + Suppress(">")
 *     else:
 */
    __pyx_t_13 = PyNumber_Add(__pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4969, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "cPyparsing.pyx":4970
 *         openTag = Suppress("<") + tagStr("tag") + \
 *             Dict(ZeroOrMore(Group(tagAttrName + Suppress("=") + tagAttrValue))) + \
 *             Optional("/", default=[False]).setResultsName("empty").setParseAction(lambda s, l, t: t[0] == '/') + Suppress(">")             # <<<<<<<<<<<<<<
 *     else:
 *         printablesLessRAbrack = "".join(c for c in printables if c not in ">")
 */
    __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_Suppress); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4970, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__174, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4970, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyNumber_Add(__pyx_t_13, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4970, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_v_openTag = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "cPyparsing.pyx":4966
 * 
 *     tagAttrName = Word(alphas, alphanums + "_-:")
 *     if (xml):             # <<<<<<<<<<<<<<
 *         tagAttrValue = dblQuotedString.copy().setParseAction(removeQuotes)
 *         openTag = Suppress("<") + tagStr("tag") + \
 */
    goto __pyx_L4;
  }

  /* "cPyparsing.pyx":4972
 *             Optional("/", default=[False]).setResultsName("empty").setParseAction(lambda s, l, t: t[0] == '/') + Suppress(">")
 *     else:
 *         printablesLessRAbrack = "".join(c for c in printables if c not in ">")             # <<<<<<<<<<<<<<
 *         tagAttrValue = quotedString.copy().setParseAction(removeQuotes) | Word(printablesLessRAbrack)
 *         openTag = Suppress("<") + tagStr("tag") + \
 */
  /*else*/ {
    __pyx_t_6 = __pyx_pf_10cPyparsing_9_makeTags_1genexpr(NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4972, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_Generator_Next(__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4972, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyUnicode_Join(__pyx_kp_u__9, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4972, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_v_printablesLessRAbrack = ((PyObject*)__pyx_t_6);
    __pyx_t_6 = 0;

    /* "cPyparsing.pyx":4973
 *     else:
 *         printablesLessRAbrack = "".join(c for c in printables if c not in ">")
 *         tagAttrValue = quotedString.copy().setParseAction(removeQuotes) | Word(printablesLessRAbrack)             # <<<<<<<<<<<<<<
 *         openTag = Suppress("<") + tagStr("tag") + \
 *             Dict(ZeroOrMore(Group(tagAttrName.setParseAction(downcaseTokens) +
 */
    __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_quotedString); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4973, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_copy); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4973, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_13)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
      }
    }
    if (__pyx_t_13) {
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_13); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4973, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    } else {
      __pyx_t_7 = __Pyx_PyObject_CallNoArg(__pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4973, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4973, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_removeQuotes); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4973, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_13 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_13)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
      }
    }
    if (!__pyx_t_13) {
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4973, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_6);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4973, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4973, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4973, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_13); __pyx_t_13 = NULL;
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_5, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4973, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_Word); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4973, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_7) {
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_printablesLessRAbrack); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4973, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_printablesLessRAbrack};
        __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4973, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_9);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_printablesLessRAbrack};
        __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4973, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_9);
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4973, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_7); __pyx_t_7 = NULL;
        __Pyx_INCREF(__pyx_v_printablesLessRAbrack);
        __Pyx_GIVEREF(__pyx_v_printablesLessRAbrack);
        PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_v_printablesLessRAbrack);
        __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_13, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4973, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyNumber_Or(__pyx_t_6, __pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4973, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_v_tagAttrValue = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "cPyparsing.pyx":4974
 *         printablesLessRAbrack = "".join(c for c in printables if c not in ">")
 *         tagAttrValue = quotedString.copy().setParseAction(removeQuotes) | Word(printablesLessRAbrack)
 *         openTag = Suppress("<") + tagStr("tag") + \             # <<<<<<<<<<<<<<
 *             Dict(ZeroOrMore(Group(tagAttrName.setParseAction(downcaseTokens) +
 *                                   Optional(Suppress("=") + tagAttrValue)))) + \
 */
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_Suppress); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4974, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__175, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4974, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_v_tagStr, __pyx_tuple__176, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4974, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = PyNumber_Add(__pyx_t_9, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4974, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "cPyparsing.pyx":4975
 *         tagAttrValue = quotedString.copy().setParseAction(removeQuotes) | Word(printablesLessRAbrack)
 *         openTag = Suppress("<") + tagStr("tag") + \
 *             Dict(ZeroOrMore(Group(tagAttrName.setParseAction(downcaseTokens) +             # <<<<<<<<<<<<<<
 *                                   Optional(Suppress("=") + tagAttrValue)))) + \
 *             Optional("/", default=[False]).setResultsName("empty").setParseAction(lambda s, l, t: t[0] == '/') + Suppress(">")
 */
    __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_Dict); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4975, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4975, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4975, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_tagAttrName, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4975, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_11 = __Pyx_GetModuleGlobalName(__pyx_n_s_downcaseTokens); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4975, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_14 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
      __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_12);
      if (likely(__pyx_t_14)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
        __Pyx_INCREF(__pyx_t_14);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_12, function);
      }
    }
    if (!__pyx_t_14) {
      __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_11); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4975, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_GOTREF(__pyx_t_10);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_12)) {
        PyObject *__pyx_temp[2] = {__pyx_t_14, __pyx_t_11};
        __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4975, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
        PyObject *__pyx_temp[2] = {__pyx_t_14, __pyx_t_11};
        __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4975, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      } else
      #endif
      {
        __pyx_t_15 = PyTuple_New(1+1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 4975, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_GIVEREF(__pyx_t_14); PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_14); __pyx_t_14 = NULL;
        __Pyx_GIVEREF(__pyx_t_11);
        PyTuple_SET_ITEM(__pyx_t_15, 0+1, __pyx_t_11);
        __pyx_t_11 = 0;
        __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_15, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4975, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

    /* "cPyparsing.pyx":4976
 *         openTag = Suppress("<") + tagStr("tag") + \
 *             Dict(ZeroOrMore(Group(tagAttrName.setParseAction(downcaseTokens) +
 *                                   Optional(Suppress("=") + tagAttrValue)))) + \             # <<<<<<<<<<<<<<
 *             Optional("/", default=[False]).setResultsName("empty").setParseAction(lambda s, l, t: t[0] == '/') + Suppress(">")
 *     closeTag = Combine(_L("</") + tagStr + ">")
 */
    __pyx_t_15 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 4976, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_11 = __Pyx_GetModuleGlobalName(__pyx_n_s_Suppress); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4976, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_tuple__177, NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4976, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_11 = PyNumber_Add(__pyx_t_14, __pyx_v_tagAttrValue); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4976, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_15))) {
      __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_15);
      if (likely(__pyx_t_14)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
        __Pyx_INCREF(__pyx_t_14);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_15, function);
      }
    }
    if (!__pyx_t_14) {
      __pyx_t_12 = __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4976, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_GOTREF(__pyx_t_12);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_15)) {
        PyObject *__pyx_temp[2] = {__pyx_t_14, __pyx_t_11};
        __pyx_t_12 = __Pyx_PyFunction_FastCall(__pyx_t_15, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4976, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_15)) {
        PyObject *__pyx_temp[2] = {__pyx_t_14, __pyx_t_11};
        __pyx_t_12 = __Pyx_PyCFunction_FastCall(__pyx_t_15, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4976, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      } else
      #endif
      {
        __pyx_t_16 = PyTuple_New(1+1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 4976, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        __Pyx_GIVEREF(__pyx_t_14); PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_t_14); __pyx_t_14 = NULL;
        __Pyx_GIVEREF(__pyx_t_11);
        PyTuple_SET_ITEM(__pyx_t_16, 0+1, __pyx_t_11);
        __pyx_t_11 = 0;
        __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_15, __pyx_t_16, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4976, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

    /* "cPyparsing.pyx":4975
 *         tagAttrValue = quotedString.copy().setParseAction(removeQuotes) | Word(printablesLessRAbrack)
 *         openTag = Suppress("<") + tagStr("tag") + \
 *             Dict(ZeroOrMore(Group(tagAttrName.setParseAction(downcaseTokens) +             # <<<<<<<<<<<<<<
 *                                   Optional(Suppress("=") + tagAttrValue)))) + \
 *             Optional("/", default=[False]).setResultsName("empty").setParseAction(lambda s, l, t: t[0] == '/') + Suppress(">")
 */
    __pyx_t_15 = PyNumber_Add(__pyx_t_10, __pyx_t_12); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 4975, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_12 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_12)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (!__pyx_t_12) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_15); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4975, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_15};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4975, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_15};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4975, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4975, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_12); __pyx_t_12 = NULL;
        __Pyx_GIVEREF(__pyx_t_15);
        PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_15);
        __pyx_t_15 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_10, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4975, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    if (!__pyx_t_1) {
      __pyx_t_13 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_4); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4975, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_13);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_4};
        __pyx_t_13 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4975, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_4};
        __pyx_t_13 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4975, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4975, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_1); __pyx_t_1 = NULL;
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4975, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
      }
    }
    if (!__pyx_t_7) {
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_13); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4975, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_t_5);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_13};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4975, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_13};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4975, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4975, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_7); __pyx_t_7 = NULL;
        __Pyx_GIVEREF(__pyx_t_13);
        PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_13);
        __pyx_t_13 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_10, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4975, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "cPyparsing.pyx":4974
 *         printablesLessRAbrack = "".join(c for c in printables if c not in ">")
 *         tagAttrValue = quotedString.copy().setParseAction(removeQuotes) | Word(printablesLessRAbrack)
 *         openTag = Suppress("<") + tagStr("tag") + \             # <<<<<<<<<<<<<<
 *             Dict(ZeroOrMore(Group(tagAttrName.setParseAction(downcaseTokens) +
 *                                   Optional(Suppress("=") + tagAttrValue)))) + \
 */
    __pyx_t_9 = PyNumber_Add(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4974, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "cPyparsing.pyx":4977
 *             Dict(ZeroOrMore(Group(tagAttrName.setParseAction(downcaseTokens) +
 *                                   Optional(Suppress("=") + tagAttrValue)))) + \
 *             Optional("/", default=[False]).setResultsName("empty").setParseAction(lambda s, l, t: t[0] == '/') + Suppress(">")             # <<<<<<<<<<<<<<
 *     closeTag = Combine(_L("</") + tagStr + ">")
 * 
 */
    __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4977, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_10 = PyDict_New(); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4977, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_13 = PyList_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4977, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    PyList_SET_ITEM(__pyx_t_13, 0, Py_False);
    if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_default, __pyx_t_13) < 0) __PYX_ERR(0, 4977, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__178, __pyx_t_10); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4977, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_setResultsName); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4977, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_tuple__179, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4977, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4977, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_9_makeTags_4lambda50, 0, __pyx_n_s_makeTags_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4977, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_13); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4977, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_t_5);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_13};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4977, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_13};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4977, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4977, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_GIVEREF(__pyx_t_13);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_13);
        __pyx_t_13 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_7, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4977, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "cPyparsing.pyx":4976
 *         openTag = Suppress("<") + tagStr("tag") + \
 *             Dict(ZeroOrMore(Group(tagAttrName.setParseAction(downcaseTokens) +
 *                                   Optional(Suppress("=") + tagAttrValue)))) + \             # <<<<<<<<<<<<<<
 *             Optional("/", default=[False]).setResultsName("empty").setParseAction(lambda s, l, t: t[0] == '/') + Suppress(">")
 *     closeTag = Combine(_L("</") + tagStr + ">")
 */
    __pyx_t_10 = PyNumber_Add(__pyx_t_9, __pyx_t_5); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4976, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "cPyparsing.pyx":4977
 *             Dict(ZeroOrMore(Group(tagAttrName.setParseAction(downcaseTokens) +
 *                                   Optional(Suppress("=") + tagAttrValue)))) + \
 *             Optional("/", default=[False]).setResultsName("empty").setParseAction(lambda s, l, t: t[0] == '/') + Suppress(">")             # <<<<<<<<<<<<<<
 *     closeTag = Combine(_L("</") + tagStr + ">")
 * 
 */
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_Suppress); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4977, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__180, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4977, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyNumber_Add(__pyx_t_10, __pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4977, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_v_openTag = __pyx_t_5;
    __pyx_t_5 = 0;
  }
  __pyx_L4:;

  /* "cPyparsing.pyx":4978
 *                                   Optional(Suppress("=") + tagAttrValue)))) + \
 *             Optional("/", default=[False]).setResultsName("empty").setParseAction(lambda s, l, t: t[0] == '/') + Suppress(">")
 *     closeTag = Combine(_L("</") + tagStr + ">")             # <<<<<<<<<<<<<<
 * 
 *     openTag = openTag.setResultsName("start" + "".join(resname.replace(":", " ").title().split())).setName("<%s>" % resname)
 */
  __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_Combine); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_10 = __Pyx_GetModuleGlobalName(__pyx_n_s_L); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_tuple__181, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = PyNumber_Add(__pyx_t_7, __pyx_v_tagStr); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_t_10, __pyx_kp_u__24); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  if (!__pyx_t_10) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4978, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_5);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_7};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4978, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_7};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4978, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else
    #endif
    {
      __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4978, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_10); __pyx_t_10 = NULL;
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_t_7);
      __pyx_t_7 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_13, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4978, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_v_closeTag = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "cPyparsing.pyx":4980
 *     closeTag = Combine(_L("</") + tagStr + ">")
 * 
 *     openTag = openTag.setResultsName("start" + "".join(resname.replace(":", " ").title().split())).setName("<%s>" % resname)             # <<<<<<<<<<<<<<
 *     closeTag = closeTag.setResultsName("end" + "".join(resname.replace(":", " ").title().split())).setName("</%s>" % resname)
 *     openTag.tag = resname
 */
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_openTag, __pyx_n_s_setResultsName); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_resname, __pyx_n_s_replace); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__183, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_title); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4980, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_10 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4980, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_split); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  if (__pyx_t_10) {
    __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_10); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4980, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  } else {
    __pyx_t_7 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4980, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyUnicode_Join(__pyx_kp_u__9, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyUnicode_Concat(__pyx_n_u_start, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  if (!__pyx_t_6) {
    __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_7); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4980, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_9);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_7};
      __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4980, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_7};
      __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4980, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else
    #endif
    {
      __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4980, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_6); __pyx_t_6 = NULL;
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_7);
      __pyx_t_7 = 0;
      __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_10, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4980, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_setName); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = PyUnicode_Format(__pyx_kp_u_s_9, __pyx_v_resname); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  if (!__pyx_t_10) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4980, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_GOTREF(__pyx_t_5);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_9};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4980, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_9};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4980, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4980, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_10); __pyx_t_10 = NULL;
      __Pyx_GIVEREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_9);
      __pyx_t_9 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_7, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4980, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF_SET(__pyx_v_openTag, __pyx_t_5);
  __pyx_t_5 = 0;

  /* "cPyparsing.pyx":4981
 * 
 *     openTag = openTag.setResultsName("start" + "".join(resname.replace(":", " ").title().split())).setName("<%s>" % resname)
 *     closeTag = closeTag.setResultsName("end" + "".join(resname.replace(":", " ").title().split())).setName("</%s>" % resname)             # <<<<<<<<<<<<<<
 *     openTag.tag = resname
 *     closeTag.tag = resname
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_closeTag, __pyx_n_s_setResultsName); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4981, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_resname, __pyx_n_s_replace); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4981, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__184, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4981, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_title); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4981, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4981, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_10 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4981, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_split); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4981, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  if (__pyx_t_10) {
    __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_10); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4981, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  } else {
    __pyx_t_9 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4981, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyUnicode_Join(__pyx_kp_u__9, __pyx_t_9); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4981, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyUnicode_Concat(__pyx_n_u_end, __pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4981, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  if (!__pyx_t_6) {
    __pyx_t_13 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_9); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4981, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_GOTREF(__pyx_t_13);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_9};
      __pyx_t_13 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4981, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_9};
      __pyx_t_13 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4981, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    {
      __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4981, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_6); __pyx_t_6 = NULL;
      __Pyx_GIVEREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_9);
      __pyx_t_9 = 0;
      __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4981, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_setName); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4981, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = PyUnicode_Format(__pyx_kp_u_s_10, __pyx_v_resname); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4981, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  if (!__pyx_t_10) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_13); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4981, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_GOTREF(__pyx_t_5);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_13};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4981, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_13};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4981, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4981, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_10); __pyx_t_10 = NULL;
      __Pyx_GIVEREF(__pyx_t_13);
      PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_13);
      __pyx_t_13 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_9, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4981, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF_SET(__pyx_v_closeTag, __pyx_t_5);
  __pyx_t_5 = 0;

  /* "cPyparsing.pyx":4982
 *     openTag = openTag.setResultsName("start" + "".join(resname.replace(":", " ").title().split())).setName("<%s>" % resname)
 *     closeTag = closeTag.setResultsName("end" + "".join(resname.replace(":", " ").title().split())).setName("</%s>" % resname)
 *     openTag.tag = resname             # <<<<<<<<<<<<<<
 *     closeTag.tag = resname
 *     return openTag, closeTag
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_openTag, __pyx_n_s_tag, __pyx_v_resname) < 0) __PYX_ERR(0, 4982, __pyx_L1_error)

  /* "cPyparsing.pyx":4983
 *     closeTag = closeTag.setResultsName("end" + "".join(resname.replace(":", " ").title().split())).setName("</%s>" % resname)
 *     openTag.tag = resname
 *     closeTag.tag = resname             # <<<<<<<<<<<<<<
 *     return openTag, closeTag
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_closeTag, __pyx_n_s_tag, __pyx_v_resname) < 0) __PYX_ERR(0, 4983, __pyx_L1_error)

  /* "cPyparsing.pyx":4984
 *     openTag.tag = resname
 *     closeTag.tag = resname
 *     return openTag, closeTag             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_openTag);
  __Pyx_GIVEREF(__pyx_v_openTag);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_openTag);
  __Pyx_INCREF(__pyx_v_closeTag);
  __Pyx_GIVEREF(__pyx_v_closeTag);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_closeTag);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4957
 * 
 * 
 * def _makeTags(tagStr, xml):             # <<<<<<<<<<<<<<
 *     """Internal helper to construct opening and closing tag expressions, given a tag name"""
 *     if isinstance(tagStr, basestring):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("cPyparsing._makeTags", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_resname);
  __Pyx_XDECREF(__pyx_v_tagAttrName);
  __Pyx_XDECREF(__pyx_v_tagAttrValue);
  __Pyx_XDECREF(__pyx_v_openTag);
  __Pyx_XDECREF(__pyx_v_printablesLessRAbrack);
  __Pyx_XDECREF(__pyx_v_closeTag);
  __Pyx_XDECREF(__pyx_v_tagStr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":4987
 * 
 * 
 * def makeHTMLTags(tagStr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to construct opening and closing tag expressions for HTML, given a tag name. Matches
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_59makeHTMLTags(PyObject *__pyx_self, PyObject *__pyx_v_tagStr); /*proto*/
static char __pyx_doc_10cPyparsing_58makeHTMLTags[] = "\n    Helper to construct opening and closing tag expressions for HTML, given a tag name. Matches\n    tags in either upper or lower case, attributes with namespaces and with quoted or unquoted values.\n\n    Example::\n        text = '<td>More info at the <a href=\"http://pyparsing.wikispaces.com\">pyparsing</a> wiki page</td>'\n        # makeHTMLTags returns pyparsing expressions for the opening and closing tags as a 2-tuple\n        a,a_end = makeHTMLTags(\"A\")\n        link_expr = a + SkipTo(a_end)(\"link_text\") + a_end\n\n        for link in link_expr.searchString(text):\n            # attributes in the <A> tag (like \"href\" shown here) are also accessible as named results\n            print(link.link_text, '->', link.href)\n    prints::\n        pyparsing -> http://pyparsing.wikispaces.com\n    ";
static PyMethodDef __pyx_mdef_10cPyparsing_59makeHTMLTags = {"makeHTMLTags", (PyCFunction)__pyx_pw_10cPyparsing_59makeHTMLTags, METH_O, __pyx_doc_10cPyparsing_58makeHTMLTags};
static PyObject *__pyx_pw_10cPyparsing_59makeHTMLTags(PyObject *__pyx_self, PyObject *__pyx_v_tagStr) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("makeHTMLTags (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_58makeHTMLTags(__pyx_self, ((PyObject *)__pyx_v_tagStr));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_58makeHTMLTags(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tagStr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("makeHTMLTags", 0);

  /* "cPyparsing.pyx":5004
 *         pyparsing -> http://pyparsing.wikispaces.com
 *     """
 *     return _makeTags(tagStr, False)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_makeTags); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_tagStr, Py_False};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5004, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_tagStr, Py_False};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5004, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_tagStr);
    __Pyx_GIVEREF(__pyx_v_tagStr);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_tagStr);
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, Py_False);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":4987
 * 
 * 
 * def makeHTMLTags(tagStr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to construct opening and closing tag expressions for HTML, given a tag name. Matches
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.makeHTMLTags", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5007
 * 
 * 
 * def makeXMLTags(tagStr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to construct opening and closing tag expressions for XML, given a tag name. Matches
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_61makeXMLTags(PyObject *__pyx_self, PyObject *__pyx_v_tagStr); /*proto*/
static char __pyx_doc_10cPyparsing_60makeXMLTags[] = "\n    Helper to construct opening and closing tag expressions for XML, given a tag name. Matches\n    tags only in the given upper/lower case.\n\n    Example: similar to L{makeHTMLTags}\n    ";
static PyMethodDef __pyx_mdef_10cPyparsing_61makeXMLTags = {"makeXMLTags", (PyCFunction)__pyx_pw_10cPyparsing_61makeXMLTags, METH_O, __pyx_doc_10cPyparsing_60makeXMLTags};
static PyObject *__pyx_pw_10cPyparsing_61makeXMLTags(PyObject *__pyx_self, PyObject *__pyx_v_tagStr) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("makeXMLTags (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_60makeXMLTags(__pyx_self, ((PyObject *)__pyx_v_tagStr));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_60makeXMLTags(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_tagStr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("makeXMLTags", 0);

  /* "cPyparsing.pyx":5014
 *     Example: similar to L{makeHTMLTags}
 *     """
 *     return _makeTags(tagStr, True)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_makeTags); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_tagStr, Py_True};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5014, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_tagStr, Py_True};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5014, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5014, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_tagStr);
    __Pyx_GIVEREF(__pyx_v_tagStr);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_tagStr);
    __Pyx_INCREF(Py_True);
    __Pyx_GIVEREF(Py_True);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, Py_True);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5014, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5007
 * 
 * 
 * def makeXMLTags(tagStr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to construct opening and closing tag expressions for XML, given a tag name. Matches
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.makeXMLTags", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5069
 *     ANY_VALUE = object()
 * 
 *     def __new__(cls, *args, **attrDict):             # <<<<<<<<<<<<<<
 *         if args:
 *             attrs = args[:]
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13withAttribute_1__new__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13withAttribute_1__new__ = {"__new__", (PyCFunction)__pyx_pw_10cPyparsing_13withAttribute_1__new__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13withAttribute_1__new__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_cls = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_attrDict = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__new__ (wrapper)", 0);
  __pyx_v_attrDict = PyDict_New(); if (unlikely(!__pyx_v_attrDict)) return NULL;
  __Pyx_GOTREF(__pyx_v_attrDict);
  if (PyTuple_GET_SIZE(__pyx_args) > 1) {
    __pyx_v_args = PyTuple_GetSlice(__pyx_args, 1, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v_args)) {
      __Pyx_DECREF(__pyx_v_attrDict); __pyx_v_attrDict = 0;
      __Pyx_RefNannyFinishContext();
      return NULL;
    }
    __Pyx_GOTREF(__pyx_v_args);
  } else {
    __pyx_v_args = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cls,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_cls)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 1) ? pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, __pyx_v_attrDict, values, used_pos_args, "__new__") < 0)) __PYX_ERR(0, 5069, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_cls = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__new__", 0, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 5069, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_DECREF(__pyx_v_attrDict); __pyx_v_attrDict = 0;
  __Pyx_AddTraceback("cPyparsing.withAttribute.__new__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13withAttribute___new__(__pyx_self, __pyx_v_cls, __pyx_v_args, __pyx_v_attrDict);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_attrDict);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5076
 *         attrs = [(k, v) for k, v in attrs]
 * 
 *         def pa(s, l, tokens):             # <<<<<<<<<<<<<<
 *             for attrName, attrValue in attrs:
 *                 if attrName not in tokens:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13withAttribute_7__new___1pa(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13withAttribute_7__new___1pa = {"pa", (PyCFunction)__pyx_pw_10cPyparsing_13withAttribute_7__new___1pa, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13withAttribute_7__new___1pa(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_s = 0;
  PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_tokens = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pa (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_tokens,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pa", 1, 3, 3, 1); __PYX_ERR(0, 5076, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_tokens)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("pa", 1, 3, 3, 2); __PYX_ERR(0, 5076, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "pa") < 0)) __PYX_ERR(0, 5076, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_tokens = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pa", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 5076, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.withAttribute.__new__.pa", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13withAttribute_7__new___pa(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_tokens);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13withAttribute_7__new___pa(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, PyObject *__pyx_v_tokens) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___new__ *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___new__ *__pyx_outer_scope;
  PyObject *__pyx_v_attrName = NULL;
  PyObject *__pyx_v_attrValue = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  __Pyx_RefNannySetupContext("pa", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___new__ *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":5077
 * 
 *         def pa(s, l, tokens):
 *             for attrName, attrValue in attrs:             # <<<<<<<<<<<<<<
 *                 if attrName not in tokens:
 *                     raise ParseException(s, l, "no matching attribute " + attrName)
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_attrs)) { __Pyx_RaiseClosureNameError("attrs"); __PYX_ERR(0, 5077, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_v_attrs)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_v_attrs)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_v_attrs; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_v_attrs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5077, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5077, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 5077, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5077, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 5077, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5077, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5077, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
      PyObject* sequence = __pyx_t_4;
      #if !CYTHON_COMPILING_IN_PYPY
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 5077, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      #else
      __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5077, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5077, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5077, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_8 = Py_TYPE(__pyx_t_7)->tp_iternext;
      index = 0; __pyx_t_5 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < 0) __PYX_ERR(0, 5077, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 5077, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_attrName, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_attrValue, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "cPyparsing.pyx":5078
 *         def pa(s, l, tokens):
 *             for attrName, attrValue in attrs:
 *                 if attrName not in tokens:             # <<<<<<<<<<<<<<
 *                     raise ParseException(s, l, "no matching attribute " + attrName)
 *                 if attrValue != cls.ANY_VALUE and tokens[attrName] != attrValue:
 */
    __pyx_t_9 = (__Pyx_PySequence_ContainsTF(__pyx_v_attrName, __pyx_v_tokens, Py_NE)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 5078, __pyx_L1_error)
    __pyx_t_10 = (__pyx_t_9 != 0);
    if (__pyx_t_10) {

      /* "cPyparsing.pyx":5079
 *             for attrName, attrValue in attrs:
 *                 if attrName not in tokens:
 *                     raise ParseException(s, l, "no matching attribute " + attrName)             # <<<<<<<<<<<<<<
 *                 if attrValue != cls.ANY_VALUE and tokens[attrName] != attrValue:
 *                     raise ParseException(s, l, "attribute '%s' has value '%s', must be '%s'" %
 */
      __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5079, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = PyNumber_Add(__pyx_kp_u_no_matching_attribute, __pyx_v_attrName); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5079, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = NULL;
      __pyx_t_11 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_11 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_v_s, __pyx_v_l, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5079, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_v_s, __pyx_v_l, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5079, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(3+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5079, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__pyx_t_7) {
          __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_7); __pyx_t_7 = NULL;
        }
        __Pyx_INCREF(__pyx_v_s);
        __Pyx_GIVEREF(__pyx_v_s);
        PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_v_s);
        __Pyx_INCREF(__pyx_v_l);
        __Pyx_GIVEREF(__pyx_v_l);
        PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_v_l);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_12, 2+__pyx_t_11, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_12, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5079, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(0, 5079, __pyx_L1_error)

      /* "cPyparsing.pyx":5078
 *         def pa(s, l, tokens):
 *             for attrName, attrValue in attrs:
 *                 if attrName not in tokens:             # <<<<<<<<<<<<<<
 *                     raise ParseException(s, l, "no matching attribute " + attrName)
 *                 if attrValue != cls.ANY_VALUE and tokens[attrName] != attrValue:
 */
    }

    /* "cPyparsing.pyx":5080
 *                 if attrName not in tokens:
 *                     raise ParseException(s, l, "no matching attribute " + attrName)
 *                 if attrValue != cls.ANY_VALUE and tokens[attrName] != attrValue:             # <<<<<<<<<<<<<<
 *                     raise ParseException(s, l, "attribute '%s' has value '%s', must be '%s'" %
 *                                          (attrName, tokens[attrName], attrValue))
 */
    if (unlikely(!__pyx_cur_scope->__pyx_v_cls)) { __Pyx_RaiseClosureNameError("cls"); __PYX_ERR(0, 5080, __pyx_L1_error) }
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_cls, __pyx_n_s_ANY_VALUE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5080, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = PyObject_RichCompare(__pyx_v_attrValue, __pyx_t_4, Py_NE); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5080, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 5080, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (__pyx_t_9) {
    } else {
      __pyx_t_10 = __pyx_t_9;
      goto __pyx_L9_bool_binop_done;
    }
    __pyx_t_6 = PyObject_GetItem(__pyx_v_tokens, __pyx_v_attrName); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5080, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_6, __pyx_v_attrValue, Py_NE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5080, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 5080, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_10 = __pyx_t_9;
    __pyx_L9_bool_binop_done:;
    if (__pyx_t_10) {

      /* "cPyparsing.pyx":5081
 *                     raise ParseException(s, l, "no matching attribute " + attrName)
 *                 if attrValue != cls.ANY_VALUE and tokens[attrName] != attrValue:
 *                     raise ParseException(s, l, "attribute '%s' has value '%s', must be '%s'" %             # <<<<<<<<<<<<<<
 *                                          (attrName, tokens[attrName], attrValue))
 *         return pa
 */
      __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5081, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);

      /* "cPyparsing.pyx":5082
 *                 if attrValue != cls.ANY_VALUE and tokens[attrName] != attrValue:
 *                     raise ParseException(s, l, "attribute '%s' has value '%s', must be '%s'" %
 *                                          (attrName, tokens[attrName], attrValue))             # <<<<<<<<<<<<<<
 *         return pa
 * 
 */
      __pyx_t_12 = PyObject_GetItem(__pyx_v_tokens, __pyx_v_attrName); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5082, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5082, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_attrName);
      __Pyx_GIVEREF(__pyx_v_attrName);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_attrName);
      __Pyx_GIVEREF(__pyx_t_12);
      PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_12);
      __Pyx_INCREF(__pyx_v_attrValue);
      __Pyx_GIVEREF(__pyx_v_attrValue);
      PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_attrValue);
      __pyx_t_12 = 0;

      /* "cPyparsing.pyx":5081
 *                     raise ParseException(s, l, "no matching attribute " + attrName)
 *                 if attrValue != cls.ANY_VALUE and tokens[attrName] != attrValue:
 *                     raise ParseException(s, l, "attribute '%s' has value '%s', must be '%s'" %             # <<<<<<<<<<<<<<
 *                                          (attrName, tokens[attrName], attrValue))
 *         return pa
 */
      __pyx_t_12 = PyUnicode_Format(__pyx_kp_u_attribute_s_has_value_s_must_be, __pyx_t_5); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5081, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      __pyx_t_11 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_11 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_v_s, __pyx_v_l, __pyx_t_12};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5081, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_v_s, __pyx_v_l, __pyx_t_12};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5081, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(3+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5081, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__pyx_t_5) {
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
        }
        __Pyx_INCREF(__pyx_v_s);
        __Pyx_GIVEREF(__pyx_v_s);
        PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_11, __pyx_v_s);
        __Pyx_INCREF(__pyx_v_l);
        __Pyx_GIVEREF(__pyx_v_l);
        PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_11, __pyx_v_l);
        __Pyx_GIVEREF(__pyx_t_12);
        PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_11, __pyx_t_12);
        __pyx_t_12 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5081, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(0, 5081, __pyx_L1_error)

      /* "cPyparsing.pyx":5080
 *                 if attrName not in tokens:
 *                     raise ParseException(s, l, "no matching attribute " + attrName)
 *                 if attrValue != cls.ANY_VALUE and tokens[attrName] != attrValue:             # <<<<<<<<<<<<<<
 *                     raise ParseException(s, l, "attribute '%s' has value '%s', must be '%s'" %
 *                                          (attrName, tokens[attrName], attrValue))
 */
    }

    /* "cPyparsing.pyx":5077
 * 
 *         def pa(s, l, tokens):
 *             for attrName, attrValue in attrs:             # <<<<<<<<<<<<<<
 *                 if attrName not in tokens:
 *                     raise ParseException(s, l, "no matching attribute " + attrName)
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5076
 *         attrs = [(k, v) for k, v in attrs]
 * 
 *         def pa(s, l, tokens):             # <<<<<<<<<<<<<<
 *             for attrName, attrValue in attrs:
 *                 if attrName not in tokens:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("cPyparsing.withAttribute.__new__.pa", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_attrName);
  __Pyx_XDECREF(__pyx_v_attrValue);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5069
 *     ANY_VALUE = object()
 * 
 *     def __new__(cls, *args, **attrDict):             # <<<<<<<<<<<<<<
 *         if args:
 *             attrs = args[:]
 */

static PyObject *__pyx_pf_10cPyparsing_13withAttribute___new__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_args, PyObject *__pyx_v_attrDict) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___new__ *__pyx_cur_scope;
  PyObject *__pyx_v_pa = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *(*__pyx_t_10)(PyObject *);
  __Pyx_RefNannySetupContext("__new__", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___new__ *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_74___new__(__pyx_ptype_10cPyparsing___pyx_scope_struct_74___new__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___new__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 5069, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_cls = __pyx_v_cls;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_cls);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_cls);

  /* "cPyparsing.pyx":5070
 * 
 *     def __new__(cls, *args, **attrDict):
 *         if args:             # <<<<<<<<<<<<<<
 *             attrs = args[:]
 *         else:
 */
  __pyx_t_1 = (__pyx_v_args != Py_None) && (PyTuple_GET_SIZE(__pyx_v_args) != 0);
  if (__pyx_t_1) {

    /* "cPyparsing.pyx":5071
 *     def __new__(cls, *args, **attrDict):
 *         if args:
 *             attrs = args[:]             # <<<<<<<<<<<<<<
 *         else:
 *             attrs = attrDict.items()
 */
    __pyx_t_2 = __Pyx_PyTuple_GetSlice(__pyx_v_args, 0, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5071, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_cur_scope->__pyx_v_attrs = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "cPyparsing.pyx":5070
 * 
 *     def __new__(cls, *args, **attrDict):
 *         if args:             # <<<<<<<<<<<<<<
 *             attrs = args[:]
 *         else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":5073
 *             attrs = args[:]
 *         else:
 *             attrs = attrDict.items()             # <<<<<<<<<<<<<<
 *         attrs = [(k, v) for k, v in attrs]
 * 
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyDict_Items(__pyx_v_attrDict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5073, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_cur_scope->__pyx_v_attrs = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":5074
 *         else:
 *             attrs = attrDict.items()
 *         attrs = [(k, v) for k, v in attrs]             # <<<<<<<<<<<<<<
 * 
 *         def pa(s, l, tokens):
 */
  { /* enter inner scope */
    PyObject *__pyx_9genexpr48__pyx_v_k = NULL;
    PyObject *__pyx_9genexpr48__pyx_v_v = NULL;
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5074, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_v_attrs)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_v_attrs)) {
      __pyx_t_3 = __pyx_cur_scope->__pyx_v_attrs; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
      __pyx_t_5 = NULL;
    } else {
      __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_cur_scope->__pyx_v_attrs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5074, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5074, __pyx_L6_error)
    }
    for (;;) {
      if (likely(!__pyx_t_5)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_3)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_6); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 5074, __pyx_L6_error)
          #else
          __pyx_t_6 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5074, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
        } else {
          if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_6); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 5074, __pyx_L6_error)
          #else
          __pyx_t_6 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5074, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
        }
      } else {
        __pyx_t_6 = __pyx_t_5(__pyx_t_3);
        if (unlikely(!__pyx_t_6)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 5074, __pyx_L6_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_6);
      }
      if ((likely(PyTuple_CheckExact(__pyx_t_6))) || (PyList_CheckExact(__pyx_t_6))) {
        PyObject* sequence = __pyx_t_6;
        #if !CYTHON_COMPILING_IN_PYPY
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 5074, __pyx_L6_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_7 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_8 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_7 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_8 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        #else
        __pyx_t_7 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5074, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5074, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_8);
        #endif
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_9 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5074, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_10 = Py_TYPE(__pyx_t_9)->tp_iternext;
        index = 0; __pyx_t_7 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_7)) goto __pyx_L9_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_7);
        index = 1; __pyx_t_8 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_8)) goto __pyx_L9_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_8);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_10(__pyx_t_9), 2) < 0) __PYX_ERR(0, 5074, __pyx_L6_error)
        __pyx_t_10 = NULL;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L10_unpacking_done;
        __pyx_L9_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_10 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 5074, __pyx_L6_error)
        __pyx_L10_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_9genexpr48__pyx_v_k, __pyx_t_7);
      __pyx_t_7 = 0;
      __Pyx_XDECREF_SET(__pyx_9genexpr48__pyx_v_v, __pyx_t_8);
      __pyx_t_8 = 0;
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5074, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_9genexpr48__pyx_v_k);
      __Pyx_GIVEREF(__pyx_9genexpr48__pyx_v_k);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_9genexpr48__pyx_v_k);
      __Pyx_INCREF(__pyx_9genexpr48__pyx_v_v);
      __Pyx_GIVEREF(__pyx_9genexpr48__pyx_v_v);
      PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_9genexpr48__pyx_v_v);
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_6))) __PYX_ERR(0, 5074, __pyx_L6_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_9genexpr48__pyx_v_k);
    __Pyx_XDECREF(__pyx_9genexpr48__pyx_v_v);
    goto __pyx_L11_exit_scope;
    __pyx_L6_error:;
    __Pyx_XDECREF(__pyx_9genexpr48__pyx_v_k);
    __Pyx_XDECREF(__pyx_9genexpr48__pyx_v_v);
    goto __pyx_L1_error;
    __pyx_L11_exit_scope:;
  } /* exit inner scope */
  __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_attrs);
  __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_attrs, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5076
 *         attrs = [(k, v) for k, v in attrs]
 * 
 *         def pa(s, l, tokens):             # <<<<<<<<<<<<<<
 *             for attrName, attrValue in attrs:
 *                 if attrName not in tokens:
 */
  __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13withAttribute_7__new___1pa, 0, __pyx_n_s_withAttribute___new___locals_pa, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__186)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5076, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_pa = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5083
 *                     raise ParseException(s, l, "attribute '%s' has value '%s', must be '%s'" %
 *                                          (attrName, tokens[attrName], attrValue))
 *         return pa             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_pa);
  __pyx_r = __pyx_v_pa;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5069
 *     ANY_VALUE = object()
 * 
 *     def __new__(cls, *args, **attrDict):             # <<<<<<<<<<<<<<
 *         if args:
 *             attrs = args[:]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("cPyparsing.withAttribute.__new__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pa);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5086
 * 
 * 
 * def withClass(classname, namespace=''):             # <<<<<<<<<<<<<<
 *     """
 *     Simplified version of C{L{withAttribute}} when matching on a div class - made
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_63withClass(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_62withClass[] = "\n    Simplified version of C{L{withAttribute}} when matching on a div class - made\n    difficult because C{class} is a reserved word in Python.\n\n    Example::\n        html = '''\n            <div>\n            Some text\n            <div class=\"grid\">1 4 0 1 0</div>\n            <div class=\"graph\">1,3 2,3 1,1</div>\n            <div>this &lt;div&gt; has no class</div>\n            </div>\n\n        '''\n        div,div_end = makeHTMLTags(\"div\")\n        div_grid = div().setParseAction(withClass(\"grid\"))\n\n        grid_expr = div_grid + SkipTo(div | div_end)(\"body\")\n        for grid_header in grid_expr.searchString(html):\n            print(grid_header.body)\n\n        div_any_type = div().setParseAction(withClass(withAttribute.ANY_VALUE))\n        div_expr = div_any_type + SkipTo(div | div_end)(\"body\")\n        for div_header in div_expr.searchString(html):\n            print(div_header.body)\n    prints::\n        1 4 0 1 0\n\n        1 4 0 1 0\n        1,3 2,3 1,1\n    ";
static PyMethodDef __pyx_mdef_10cPyparsing_63withClass = {"withClass", (PyCFunction)__pyx_pw_10cPyparsing_63withClass, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_62withClass};
static PyObject *__pyx_pw_10cPyparsing_63withClass(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_classname = 0;
  PyObject *__pyx_v_namespace = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("withClass (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_classname,&__pyx_n_s_namespace,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)__pyx_kp_u__9);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_classname)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_namespace);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "withClass") < 0)) __PYX_ERR(0, 5086, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_classname = values[0];
    __pyx_v_namespace = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("withClass", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 5086, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.withClass", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_62withClass(__pyx_self, __pyx_v_classname, __pyx_v_namespace);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_62withClass(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_classname, PyObject *__pyx_v_namespace) {
  PyObject *__pyx_v_classattr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("withClass", 0);

  /* "cPyparsing.pyx":5118
 *         1,3 2,3 1,1
 *     """
 *     classattr = "%s:class" % namespace if namespace else "class"             # <<<<<<<<<<<<<<
 *     return withAttribute(**{classattr: classname})
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_namespace); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 5118, __pyx_L1_error)
  if (__pyx_t_2) {
    __pyx_t_3 = PyUnicode_Format(__pyx_kp_u_s_class, __pyx_v_namespace); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5118, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {
    __Pyx_INCREF(__pyx_n_u_class_2);
    __pyx_t_1 = __pyx_n_u_class_2;
  }
  __pyx_v_classattr = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5119
 *     """
 *     classattr = "%s:class" % namespace if namespace else "class"
 *     return withAttribute(**{classattr: classname})             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_withAttribute); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (unlikely(PyDict_Contains(__pyx_t_3, __pyx_v_classattr))) {
    __Pyx_RaiseDoubleKeywordsError("function", __pyx_v_classattr); __PYX_ERR(0, 5119, __pyx_L1_error)
  } else {
    if (PyDict_SetItem(__pyx_t_3, __pyx_v_classattr, __pyx_v_classname) < 0) __PYX_ERR(0, 5119, __pyx_L1_error)
  }
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5086
 * 
 * 
 * def withClass(classname, namespace=''):             # <<<<<<<<<<<<<<
 *     """
 *     Simplified version of C{L{withAttribute}} when matching on a div class - made
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cPyparsing.withClass", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_classattr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5127
 * 
 * 
 * def infixNotation(baseExpr, opList, lpar=Suppress('('), rpar=Suppress(')')):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for constructing grammars of expressions made up of
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_65infixNotation(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_64infixNotation[] = "\n    Helper method for constructing grammars of expressions made up of\n    operators working in a precedence hierarchy.  Operators may be unary or\n    binary, left- or right-associative.  Parse actions can also be attached\n    to operator expressions. The generated parser will also recognize the use\n    of parentheses to override operator precedences (see example below).\n\n    Note: if you define a deep operator list, you may see performance issues\n    when using infixNotation. See L{ParserElement.enablePackrat} for a\n    mechanism to potentially improve your parser performance.\n\n    Parameters:\n     - baseExpr - expression representing the most basic element for the nested\n     - opList - list of tuples, one for each operator precedence level in the\n      expression grammar; each tuple is of the form\n      (opExpr, numTerms, rightLeftAssoc, parseAction), where:\n       - opExpr is the pyparsing expression for the operator;\n          may also be a string, which will be converted to a Literal;\n          if numTerms is 3, opExpr is a tuple of two expressions, for the\n          two operators separating the 3 terms\n       - numTerms is the number of terms for this operator (must\n          be 1, 2, or 3)\n       - rightLeftAssoc is the indicator whether the operator is\n          right or left associative, using the pyparsing-defined\n          constants C{opAssoc.RIGHT} and C{opAssoc.LEFT}.\n       - parseAction is the parse action to be associated with\n          expressions matching this operator expression (the\n          parse action tuple member may be omitted); if the parse action\n          is passed a tuple or list of functions, this is equivalent to\n          calling C{setParseAction(*fn)} (L{ParserElement.setParseAction})\n     - lpar - expression for matching left-parentheses (default=C{Suppress('(')})\n     - rpar - expression for matching right-parentheses (default=C{Suppress(')')})\n\n    Example::\n        # simple example of four-func""tion arithmetic with ints and variable names\n        integer = pyparsing_common.signed_integer\n        varname = pyparsing_common.identifier\n\n        arith_expr = infixNotation(integer | varname,\n            [\n            ('-', 1, opAssoc.RIGHT),\n            (oneOf('* /'), 2, opAssoc.LEFT),\n            (oneOf('+ -'), 2, opAssoc.LEFT),\n            ])\n\n        arith_expr.runTests('''\n            5+3*6\n            (5+3)*6\n            -2--11\n            ''', fullDump=False)\n    prints::\n        5+3*6\n        [[5, '+', [3, '*', 6]]]\n\n        (5+3)*6\n        [[[5, '+', 3], '*', 6]]\n\n        -2--11\n        [[['-', 2], '-', ['-', 11]]]\n    ";
static PyMethodDef __pyx_mdef_10cPyparsing_65infixNotation = {"infixNotation", (PyCFunction)__pyx_pw_10cPyparsing_65infixNotation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_64infixNotation};
static PyObject *__pyx_pw_10cPyparsing_65infixNotation(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_baseExpr = 0;
  PyObject *__pyx_v_opList = 0;
  PyObject *__pyx_v_lpar = 0;
  PyObject *__pyx_v_rpar = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("infixNotation (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_baseExpr,&__pyx_n_s_opList,&__pyx_n_s_lpar,&__pyx_n_s_rpar,0};
    PyObject* values[4] = {0,0,0,0};
    values[2] = __pyx_k__187;
    values[3] = __pyx_k__188;
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_baseExpr)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_opList)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("infixNotation", 0, 2, 4, 1); __PYX_ERR(0, 5127, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_lpar);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_rpar);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "infixNotation") < 0)) __PYX_ERR(0, 5127, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_baseExpr = values[0];
    __pyx_v_opList = values[1];
    __pyx_v_lpar = values[2];
    __pyx_v_rpar = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("infixNotation", 0, 2, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 5127, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.infixNotation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_64infixNotation(__pyx_self, __pyx_v_baseExpr, __pyx_v_opList, __pyx_v_lpar, __pyx_v_rpar);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_64infixNotation(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_baseExpr, PyObject *__pyx_v_opList, PyObject *__pyx_v_lpar, PyObject *__pyx_v_rpar) {
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_v_lastExpr = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_operDef = NULL;
  PyObject *__pyx_v_opExpr = NULL;
  PyObject *__pyx_v_arity = NULL;
  PyObject *__pyx_v_rightLeftAssoc = NULL;
  PyObject *__pyx_v_pa = NULL;
  PyObject *__pyx_v_termName = NULL;
  PyObject *__pyx_v_opExpr1 = NULL;
  PyObject *__pyx_v_opExpr2 = NULL;
  PyObject *__pyx_v_thisExpr = NULL;
  PyObject *__pyx_v_matchExpr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *(*__pyx_t_11)(PyObject *);
  int __pyx_t_12;
  int __pyx_t_13;
  int __pyx_t_14;
  Py_ssize_t __pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  __Pyx_RefNannySetupContext("infixNotation", 0);

  /* "cPyparsing.pyx":5188
 *         [[['-', 2], '-', ['-', 11]]]
 *     """
 *     ret = Forward()             # <<<<<<<<<<<<<<
 *     lastExpr = baseExpr | (lpar + ret + rpar)
 *     for i, operDef in enumerate(opList):
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Forward); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5188, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5188, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_ret = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5189
 *     """
 *     ret = Forward()
 *     lastExpr = baseExpr | (lpar + ret + rpar)             # <<<<<<<<<<<<<<
 *     for i, operDef in enumerate(opList):
 *         opExpr, arity, rightLeftAssoc, pa = (operDef + (None,))[:4]
 */
  __pyx_t_1 = PyNumber_Add(__pyx_v_lpar, __pyx_v_ret); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_v_rpar); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Or(__pyx_v_baseExpr, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_lastExpr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5190
 *     ret = Forward()
 *     lastExpr = baseExpr | (lpar + ret + rpar)
 *     for i, operDef in enumerate(opList):             # <<<<<<<<<<<<<<
 *         opExpr, arity, rightLeftAssoc, pa = (operDef + (None,))[:4]
 *         termName = "%s term" % opExpr if arity < 3 else "%s%s term" % opExpr
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_t_1 = __pyx_int_0;
  if (likely(PyList_CheckExact(__pyx_v_opList)) || PyTuple_CheckExact(__pyx_v_opList)) {
    __pyx_t_2 = __pyx_v_opList; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_opList); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5190, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 5190, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5190, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 5190, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5190, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5190, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_operDef, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_1);
    __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_t_1, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5191
 *     lastExpr = baseExpr | (lpar + ret + rpar)
 *     for i, operDef in enumerate(opList):
 *         opExpr, arity, rightLeftAssoc, pa = (operDef + (None,))[:4]             # <<<<<<<<<<<<<<
 *         termName = "%s term" % opExpr if arity < 3 else "%s%s term" % opExpr
 *         if arity == 3:
 */
    __pyx_t_3 = PyNumber_Add(__pyx_v_operDef, __pyx_tuple__189); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5191, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyObject_GetSlice(__pyx_t_3, 0, 4, NULL, NULL, &__pyx_slice__190, 0, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5191, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if ((likely(PyTuple_CheckExact(__pyx_t_6))) || (PyList_CheckExact(__pyx_t_6))) {
      PyObject* sequence = __pyx_t_6;
      #if !CYTHON_COMPILING_IN_PYPY
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 4)) {
        if (size > 4) __Pyx_RaiseTooManyValuesError(4);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 5191, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
        __pyx_t_8 = PyTuple_GET_ITEM(sequence, 2); 
        __pyx_t_9 = PyTuple_GET_ITEM(sequence, 3); 
      } else {
        __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
        __pyx_t_8 = PyList_GET_ITEM(sequence, 2); 
        __pyx_t_9 = PyList_GET_ITEM(sequence, 3); 
      }
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_9);
      #else
      {
        Py_ssize_t i;
        PyObject** temps[4] = {&__pyx_t_3,&__pyx_t_7,&__pyx_t_8,&__pyx_t_9};
        for (i=0; i < 4; i++) {
          PyObject* item = PySequence_ITEM(sequence, i); if (unlikely(!item)) __PYX_ERR(0, 5191, __pyx_L1_error)
          __Pyx_GOTREF(item);
          *(temps[i]) = item;
        }
      }
      #endif
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else {
      Py_ssize_t index = -1;
      PyObject** temps[4] = {&__pyx_t_3,&__pyx_t_7,&__pyx_t_8,&__pyx_t_9};
      __pyx_t_10 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5191, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_11 = Py_TYPE(__pyx_t_10)->tp_iternext;
      for (index=0; index < 4; index++) {
        PyObject* item = __pyx_t_11(__pyx_t_10); if (unlikely(!item)) goto __pyx_L5_unpacking_failed;
        __Pyx_GOTREF(item);
        *(temps[index]) = item;
      }
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_11(__pyx_t_10), 4) < 0) __PYX_ERR(0, 5191, __pyx_L1_error)
      __pyx_t_11 = NULL;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_11 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 5191, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_opExpr, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_arity, __pyx_t_7);
    __pyx_t_7 = 0;
    __Pyx_XDECREF_SET(__pyx_v_rightLeftAssoc, __pyx_t_8);
    __pyx_t_8 = 0;
    __Pyx_XDECREF_SET(__pyx_v_pa, __pyx_t_9);
    __pyx_t_9 = 0;

    /* "cPyparsing.pyx":5192
 *     for i, operDef in enumerate(opList):
 *         opExpr, arity, rightLeftAssoc, pa = (operDef + (None,))[:4]
 *         termName = "%s term" % opExpr if arity < 3 else "%s%s term" % opExpr             # <<<<<<<<<<<<<<
 *         if arity == 3:
 *             if opExpr is None or len(opExpr) != 2:
 */
    __pyx_t_9 = PyObject_RichCompare(__pyx_v_arity, __pyx_int_3, Py_LT); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5192, __pyx_L1_error)
    __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 5192, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (__pyx_t_12) {
      __pyx_t_9 = PyUnicode_Format(__pyx_kp_u_s_term, __pyx_v_opExpr); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5192, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_6 = __pyx_t_9;
      __pyx_t_9 = 0;
    } else {
      __pyx_t_9 = PyUnicode_Format(__pyx_kp_u_s_s_term, __pyx_v_opExpr); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5192, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_6 = __pyx_t_9;
      __pyx_t_9 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_termName, ((PyObject*)__pyx_t_6));
    __pyx_t_6 = 0;

    /* "cPyparsing.pyx":5193
 *         opExpr, arity, rightLeftAssoc, pa = (operDef + (None,))[:4]
 *         termName = "%s term" % opExpr if arity < 3 else "%s%s term" % opExpr
 *         if arity == 3:             # <<<<<<<<<<<<<<
 *             if opExpr is None or len(opExpr) != 2:
 *                 raise ValueError("if numterms=3, opExpr must be a tuple or list of two expressions")
 */
    __pyx_t_6 = __Pyx_PyInt_EqObjC(__pyx_v_arity, __pyx_int_3, 3, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5193, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 5193, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (__pyx_t_12) {

      /* "cPyparsing.pyx":5194
 *         termName = "%s term" % opExpr if arity < 3 else "%s%s term" % opExpr
 *         if arity == 3:
 *             if opExpr is None or len(opExpr) != 2:             # <<<<<<<<<<<<<<
 *                 raise ValueError("if numterms=3, opExpr must be a tuple or list of two expressions")
 *             opExpr1, opExpr2 = opExpr
 */
      __pyx_t_13 = (__pyx_v_opExpr == Py_None);
      __pyx_t_14 = (__pyx_t_13 != 0);
      if (!__pyx_t_14) {
      } else {
        __pyx_t_12 = __pyx_t_14;
        goto __pyx_L9_bool_binop_done;
      }
      __pyx_t_15 = PyObject_Length(__pyx_v_opExpr); if (unlikely(__pyx_t_15 == -1)) __PYX_ERR(0, 5194, __pyx_L1_error)
      __pyx_t_14 = ((__pyx_t_15 != 2) != 0);
      __pyx_t_12 = __pyx_t_14;
      __pyx_L9_bool_binop_done:;
      if (__pyx_t_12) {

        /* "cPyparsing.pyx":5195
 *         if arity == 3:
 *             if opExpr is None or len(opExpr) != 2:
 *                 raise ValueError("if numterms=3, opExpr must be a tuple or list of two expressions")             # <<<<<<<<<<<<<<
 *             opExpr1, opExpr2 = opExpr
 *         thisExpr = Forward().setName(termName)
 */
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__191, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5195, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __PYX_ERR(0, 5195, __pyx_L1_error)

        /* "cPyparsing.pyx":5194
 *         termName = "%s term" % opExpr if arity < 3 else "%s%s term" % opExpr
 *         if arity == 3:
 *             if opExpr is None or len(opExpr) != 2:             # <<<<<<<<<<<<<<
 *                 raise ValueError("if numterms=3, opExpr must be a tuple or list of two expressions")
 *             opExpr1, opExpr2 = opExpr
 */
      }

      /* "cPyparsing.pyx":5196
 *             if opExpr is None or len(opExpr) != 2:
 *                 raise ValueError("if numterms=3, opExpr must be a tuple or list of two expressions")
 *             opExpr1, opExpr2 = opExpr             # <<<<<<<<<<<<<<
 *         thisExpr = Forward().setName(termName)
 *         if rightLeftAssoc == opAssoc.LEFT:
 */
      if ((likely(PyTuple_CheckExact(__pyx_v_opExpr))) || (PyList_CheckExact(__pyx_v_opExpr))) {
        PyObject* sequence = __pyx_v_opExpr;
        #if !CYTHON_COMPILING_IN_PYPY
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 5196, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_9 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_6 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_9 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_9);
        #else
        __pyx_t_6 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5196, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_9 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5196, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        #endif
      } else {
        Py_ssize_t index = -1;
        __pyx_t_8 = PyObject_GetIter(__pyx_v_opExpr); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5196, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_11 = Py_TYPE(__pyx_t_8)->tp_iternext;
        index = 0; __pyx_t_6 = __pyx_t_11(__pyx_t_8); if (unlikely(!__pyx_t_6)) goto __pyx_L11_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_6);
        index = 1; __pyx_t_9 = __pyx_t_11(__pyx_t_8); if (unlikely(!__pyx_t_9)) goto __pyx_L11_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_9);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_11(__pyx_t_8), 2) < 0) __PYX_ERR(0, 5196, __pyx_L1_error)
        __pyx_t_11 = NULL;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L12_unpacking_done;
        __pyx_L11_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_11 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 5196, __pyx_L1_error)
        __pyx_L12_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_opExpr1, __pyx_t_6);
      __pyx_t_6 = 0;
      __Pyx_XDECREF_SET(__pyx_v_opExpr2, __pyx_t_9);
      __pyx_t_9 = 0;

      /* "cPyparsing.pyx":5193
 *         opExpr, arity, rightLeftAssoc, pa = (operDef + (None,))[:4]
 *         termName = "%s term" % opExpr if arity < 3 else "%s%s term" % opExpr
 *         if arity == 3:             # <<<<<<<<<<<<<<
 *             if opExpr is None or len(opExpr) != 2:
 *                 raise ValueError("if numterms=3, opExpr must be a tuple or list of two expressions")
 */
    }

    /* "cPyparsing.pyx":5197
 *                 raise ValueError("if numterms=3, opExpr must be a tuple or list of two expressions")
 *             opExpr1, opExpr2 = opExpr
 *         thisExpr = Forward().setName(termName)             # <<<<<<<<<<<<<<
 *         if rightLeftAssoc == opAssoc.LEFT:
 *             if arity == 1:
 */
    __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_Forward); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    if (__pyx_t_7) {
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5197, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else {
      __pyx_t_6 = __Pyx_PyObject_CallNoArg(__pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5197, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_setName); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_v_termName); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5197, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_termName};
        __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5197, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_9);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_termName};
        __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5197, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_9);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5197, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_v_termName);
        __Pyx_GIVEREF(__pyx_v_termName);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_termName);
        __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_7, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5197, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF_SET(__pyx_v_thisExpr, __pyx_t_9);
    __pyx_t_9 = 0;

    /* "cPyparsing.pyx":5198
 *             opExpr1, opExpr2 = opExpr
 *         thisExpr = Forward().setName(termName)
 *         if rightLeftAssoc == opAssoc.LEFT:             # <<<<<<<<<<<<<<
 *             if arity == 1:
 *                 matchExpr = FollowedBy(lastExpr + opExpr) + Group(lastExpr + OneOrMore(opExpr))
 */
    __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_opAssoc); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5198, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_LEFT); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5198, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = PyObject_RichCompare(__pyx_v_rightLeftAssoc, __pyx_t_8, Py_EQ); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5198, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 5198, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (__pyx_t_12) {

      /* "cPyparsing.pyx":5199
 *         thisExpr = Forward().setName(termName)
 *         if rightLeftAssoc == opAssoc.LEFT:
 *             if arity == 1:             # <<<<<<<<<<<<<<
 *                 matchExpr = FollowedBy(lastExpr + opExpr) + Group(lastExpr + OneOrMore(opExpr))
 *             elif arity == 2:
 */
      __pyx_t_9 = __Pyx_PyInt_EqObjC(__pyx_v_arity, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5199, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 5199, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (__pyx_t_12) {

        /* "cPyparsing.pyx":5200
 *         if rightLeftAssoc == opAssoc.LEFT:
 *             if arity == 1:
 *                 matchExpr = FollowedBy(lastExpr + opExpr) + Group(lastExpr + OneOrMore(opExpr))             # <<<<<<<<<<<<<<
 *             elif arity == 2:
 *                 if opExpr is not None:
 */
        __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_FollowedBy); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5200, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_7 = PyNumber_Add(__pyx_v_lastExpr, __pyx_v_opExpr); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5200, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_6 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
          }
        }
        if (!__pyx_t_6) {
          __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_7); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5200, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_9);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_8)) {
            PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_7};
            __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5200, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
            PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_7};
            __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5200, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          } else
          #endif
          {
            __pyx_t_3 = PyTuple_New(1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5200, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_6); __pyx_t_6 = NULL;
            __Pyx_GIVEREF(__pyx_t_7);
            PyTuple_SET_ITEM(__pyx_t_3, 0+1, __pyx_t_7);
            __pyx_t_7 = 0;
            __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_3, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5200, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5200, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5200, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_10 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
          }
        }
        if (!__pyx_t_10) {
          __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_opExpr); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5200, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_6)) {
            PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_v_opExpr};
            __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5200, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_GOTREF(__pyx_t_7);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
            PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_v_opExpr};
            __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5200, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_GOTREF(__pyx_t_7);
          } else
          #endif
          {
            __pyx_t_16 = PyTuple_New(1+1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 5200, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_16);
            __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_t_10); __pyx_t_10 = NULL;
            __Pyx_INCREF(__pyx_v_opExpr);
            __Pyx_GIVEREF(__pyx_v_opExpr);
            PyTuple_SET_ITEM(__pyx_t_16, 0+1, __pyx_v_opExpr);
            __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_16, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5200, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = PyNumber_Add(__pyx_v_lastExpr, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5200, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        if (!__pyx_t_7) {
          __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5200, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_8);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_3)) {
            PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_6};
            __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5200, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
            PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_6};
            __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5200, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          } else
          #endif
          {
            __pyx_t_16 = PyTuple_New(1+1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 5200, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_16);
            __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_t_7); __pyx_t_7 = NULL;
            __Pyx_GIVEREF(__pyx_t_6);
            PyTuple_SET_ITEM(__pyx_t_16, 0+1, __pyx_t_6);
            __pyx_t_6 = 0;
            __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_16, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5200, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = PyNumber_Add(__pyx_t_9, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5200, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF_SET(__pyx_v_matchExpr, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "cPyparsing.pyx":5199
 *         thisExpr = Forward().setName(termName)
 *         if rightLeftAssoc == opAssoc.LEFT:
 *             if arity == 1:             # <<<<<<<<<<<<<<
 *                 matchExpr = FollowedBy(lastExpr + opExpr) + Group(lastExpr + OneOrMore(opExpr))
 *             elif arity == 2:
 */
        goto __pyx_L14;
      }

      /* "cPyparsing.pyx":5201
 *             if arity == 1:
 *                 matchExpr = FollowedBy(lastExpr + opExpr) + Group(lastExpr + OneOrMore(opExpr))
 *             elif arity == 2:             # <<<<<<<<<<<<<<
 *                 if opExpr is not None:
 *                     matchExpr = FollowedBy(lastExpr + opExpr + lastExpr) + Group(lastExpr + OneOrMore(opExpr + lastExpr))
 */
      __pyx_t_3 = __Pyx_PyInt_EqObjC(__pyx_v_arity, __pyx_int_2, 2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5201, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 5201, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_12) {

        /* "cPyparsing.pyx":5202
 *                 matchExpr = FollowedBy(lastExpr + opExpr) + Group(lastExpr + OneOrMore(opExpr))
 *             elif arity == 2:
 *                 if opExpr is not None:             # <<<<<<<<<<<<<<
 *                     matchExpr = FollowedBy(lastExpr + opExpr + lastExpr) + Group(lastExpr + OneOrMore(opExpr + lastExpr))
 *                 else:
 */
        __pyx_t_12 = (__pyx_v_opExpr != Py_None);
        __pyx_t_14 = (__pyx_t_12 != 0);
        if (__pyx_t_14) {

          /* "cPyparsing.pyx":5203
 *             elif arity == 2:
 *                 if opExpr is not None:
 *                     matchExpr = FollowedBy(lastExpr + opExpr + lastExpr) + Group(lastExpr + OneOrMore(opExpr + lastExpr))             # <<<<<<<<<<<<<<
 *                 else:
 *                     matchExpr = FollowedBy(lastExpr + lastExpr) + Group(lastExpr + OneOrMore(lastExpr))
 */
          __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_FollowedBy); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5203, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_9 = PyNumber_Add(__pyx_v_lastExpr, __pyx_v_opExpr); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5203, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_16 = PyNumber_Add(__pyx_t_9, __pyx_v_lastExpr); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 5203, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_16);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_9 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
            __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
            if (likely(__pyx_t_9)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
              __Pyx_INCREF(__pyx_t_9);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_8, function);
            }
          }
          if (!__pyx_t_9) {
            __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_16); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5203, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            __Pyx_GOTREF(__pyx_t_3);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_8)) {
              PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_16};
              __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5203, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_GOTREF(__pyx_t_3);
              __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
              PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_16};
              __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5203, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_GOTREF(__pyx_t_3);
              __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            } else
            #endif
            {
              __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5203, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_9); __pyx_t_9 = NULL;
              __Pyx_GIVEREF(__pyx_t_16);
              PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_16);
              __pyx_t_16 = 0;
              __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5203, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_3);
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5203, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5203, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_7 = PyNumber_Add(__pyx_v_opExpr, __pyx_v_lastExpr); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5203, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_10 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
            __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
            if (likely(__pyx_t_10)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
              __Pyx_INCREF(__pyx_t_10);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_9, function);
            }
          }
          if (!__pyx_t_10) {
            __pyx_t_16 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_7); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 5203, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_GOTREF(__pyx_t_16);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_7};
              __pyx_t_16 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 5203, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_GOTREF(__pyx_t_16);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_7};
              __pyx_t_16 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 5203, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_GOTREF(__pyx_t_16);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            } else
            #endif
            {
              __pyx_t_17 = PyTuple_New(1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5203, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_17);
              __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_t_10); __pyx_t_10 = NULL;
              __Pyx_GIVEREF(__pyx_t_7);
              PyTuple_SET_ITEM(__pyx_t_17, 0+1, __pyx_t_7);
              __pyx_t_7 = 0;
              __pyx_t_16 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_17, NULL); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 5203, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_16);
              __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_9 = PyNumber_Add(__pyx_v_lastExpr, __pyx_t_16); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5203, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __pyx_t_16 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_6);
            if (likely(__pyx_t_16)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
              __Pyx_INCREF(__pyx_t_16);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_6, function);
            }
          }
          if (!__pyx_t_16) {
            __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5203, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_GOTREF(__pyx_t_8);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_6)) {
              PyObject *__pyx_temp[2] = {__pyx_t_16, __pyx_t_9};
              __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5203, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
              PyObject *__pyx_temp[2] = {__pyx_t_16, __pyx_t_9};
              __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5203, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            } else
            #endif
            {
              __pyx_t_17 = PyTuple_New(1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5203, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_17);
              __Pyx_GIVEREF(__pyx_t_16); PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_t_16); __pyx_t_16 = NULL;
              __Pyx_GIVEREF(__pyx_t_9);
              PyTuple_SET_ITEM(__pyx_t_17, 0+1, __pyx_t_9);
              __pyx_t_9 = 0;
              __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_17, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5203, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = PyNumber_Add(__pyx_t_3, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5203, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF_SET(__pyx_v_matchExpr, __pyx_t_6);
          __pyx_t_6 = 0;

          /* "cPyparsing.pyx":5202
 *                 matchExpr = FollowedBy(lastExpr + opExpr) + Group(lastExpr + OneOrMore(opExpr))
 *             elif arity == 2:
 *                 if opExpr is not None:             # <<<<<<<<<<<<<<
 *                     matchExpr = FollowedBy(lastExpr + opExpr + lastExpr) + Group(lastExpr + OneOrMore(opExpr + lastExpr))
 *                 else:
 */
          goto __pyx_L15;
        }

        /* "cPyparsing.pyx":5205
 *                     matchExpr = FollowedBy(lastExpr + opExpr + lastExpr) + Group(lastExpr + OneOrMore(opExpr + lastExpr))
 *                 else:
 *                     matchExpr = FollowedBy(lastExpr + lastExpr) + Group(lastExpr + OneOrMore(lastExpr))             # <<<<<<<<<<<<<<
 *             elif arity == 3:
 *                 matchExpr = FollowedBy(lastExpr + opExpr1 + lastExpr + opExpr2 + lastExpr) + \
 */
        /*else*/ {
          __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_FollowedBy); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5205, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_3 = PyNumber_Add(__pyx_v_lastExpr, __pyx_v_lastExpr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5205, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_17 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
            __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_8);
            if (likely(__pyx_t_17)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
              __Pyx_INCREF(__pyx_t_17);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_8, function);
            }
          }
          if (!__pyx_t_17) {
            __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5205, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_GOTREF(__pyx_t_6);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_8)) {
              PyObject *__pyx_temp[2] = {__pyx_t_17, __pyx_t_3};
              __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5205, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
              PyObject *__pyx_temp[2] = {__pyx_t_17, __pyx_t_3};
              __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5205, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            } else
            #endif
            {
              __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5205, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_GIVEREF(__pyx_t_17); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_17); __pyx_t_17 = NULL;
              __Pyx_GIVEREF(__pyx_t_3);
              PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_3);
              __pyx_t_3 = 0;
              __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_9, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5205, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5205, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_17 = __Pyx_GetModuleGlobalName(__pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5205, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_17);
          __pyx_t_16 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_17))) {
            __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_17);
            if (likely(__pyx_t_16)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
              __Pyx_INCREF(__pyx_t_16);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_17, function);
            }
          }
          if (!__pyx_t_16) {
            __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_v_lastExpr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5205, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_17)) {
              PyObject *__pyx_temp[2] = {__pyx_t_16, __pyx_v_lastExpr};
              __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_17, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5205, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
              __Pyx_GOTREF(__pyx_t_3);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_17)) {
              PyObject *__pyx_temp[2] = {__pyx_t_16, __pyx_v_lastExpr};
              __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_17, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5205, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
              __Pyx_GOTREF(__pyx_t_3);
            } else
            #endif
            {
              __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5205, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_GIVEREF(__pyx_t_16); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_16); __pyx_t_16 = NULL;
              __Pyx_INCREF(__pyx_v_lastExpr);
              __Pyx_GIVEREF(__pyx_v_lastExpr);
              PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_lastExpr);
              __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_17, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5205, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_3);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          __pyx_t_17 = PyNumber_Add(__pyx_v_lastExpr, __pyx_t_3); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5205, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_17);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
            __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_9);
            if (likely(__pyx_t_3)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
              __Pyx_INCREF(__pyx_t_3);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_9, function);
            }
          }
          if (!__pyx_t_3) {
            __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_17); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5205, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
            __Pyx_GOTREF(__pyx_t_8);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_17};
              __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5205, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_17};
              __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5205, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
            } else
            #endif
            {
              __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5205, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_3); __pyx_t_3 = NULL;
              __Pyx_GIVEREF(__pyx_t_17);
              PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_17);
              __pyx_t_17 = 0;
              __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_7, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5205, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_9 = PyNumber_Add(__pyx_t_6, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5205, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF_SET(__pyx_v_matchExpr, __pyx_t_9);
          __pyx_t_9 = 0;
        }
        __pyx_L15:;

        /* "cPyparsing.pyx":5201
 *             if arity == 1:
 *                 matchExpr = FollowedBy(lastExpr + opExpr) + Group(lastExpr + OneOrMore(opExpr))
 *             elif arity == 2:             # <<<<<<<<<<<<<<
 *                 if opExpr is not None:
 *                     matchExpr = FollowedBy(lastExpr + opExpr + lastExpr) + Group(lastExpr + OneOrMore(opExpr + lastExpr))
 */
        goto __pyx_L14;
      }

      /* "cPyparsing.pyx":5206
 *                 else:
 *                     matchExpr = FollowedBy(lastExpr + lastExpr) + Group(lastExpr + OneOrMore(lastExpr))
 *             elif arity == 3:             # <<<<<<<<<<<<<<
 *                 matchExpr = FollowedBy(lastExpr + opExpr1 + lastExpr + opExpr2 + lastExpr) + \
 *                     Group(lastExpr + opExpr1 + lastExpr + opExpr2 + lastExpr)
 */
      __pyx_t_9 = __Pyx_PyInt_EqObjC(__pyx_v_arity, __pyx_int_3, 3, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5206, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 5206, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (__pyx_t_14) {

        /* "cPyparsing.pyx":5207
 *                     matchExpr = FollowedBy(lastExpr + lastExpr) + Group(lastExpr + OneOrMore(lastExpr))
 *             elif arity == 3:
 *                 matchExpr = FollowedBy(lastExpr + opExpr1 + lastExpr + opExpr2 + lastExpr) + \             # <<<<<<<<<<<<<<
 *                     Group(lastExpr + opExpr1 + lastExpr + opExpr2 + lastExpr)
 *             else:
 */
        __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_FollowedBy); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5207, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (unlikely(!__pyx_v_opExpr1)) { __Pyx_RaiseUnboundLocalError("opExpr1"); __PYX_ERR(0, 5207, __pyx_L1_error) }
        __pyx_t_6 = PyNumber_Add(__pyx_v_lastExpr, __pyx_v_opExpr1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5207, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = PyNumber_Add(__pyx_t_6, __pyx_v_lastExpr); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5207, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_v_opExpr2)) { __Pyx_RaiseUnboundLocalError("opExpr2"); __PYX_ERR(0, 5207, __pyx_L1_error) }
        __pyx_t_6 = PyNumber_Add(__pyx_t_7, __pyx_v_opExpr2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5207, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = PyNumber_Add(__pyx_t_6, __pyx_v_lastExpr); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5207, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
          }
        }
        if (!__pyx_t_6) {
          __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_7); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5207, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_9);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_8)) {
            PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_7};
            __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5207, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
            PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_7};
            __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5207, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          } else
          #endif
          {
            __pyx_t_17 = PyTuple_New(1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5207, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_17);
            __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_t_6); __pyx_t_6 = NULL;
            __Pyx_GIVEREF(__pyx_t_7);
            PyTuple_SET_ITEM(__pyx_t_17, 0+1, __pyx_t_7);
            __pyx_t_7 = 0;
            __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_17, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5207, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "cPyparsing.pyx":5208
 *             elif arity == 3:
 *                 matchExpr = FollowedBy(lastExpr + opExpr1 + lastExpr + opExpr2 + lastExpr) + \
 *                     Group(lastExpr + opExpr1 + lastExpr + opExpr2 + lastExpr)             # <<<<<<<<<<<<<<
 *             else:
 *                 raise ValueError("operator must be unary (1), binary (2), or ternary (3)")
 */
        __pyx_t_17 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5208, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_17);
        if (unlikely(!__pyx_v_opExpr1)) { __Pyx_RaiseUnboundLocalError("opExpr1"); __PYX_ERR(0, 5208, __pyx_L1_error) }
        __pyx_t_7 = PyNumber_Add(__pyx_v_lastExpr, __pyx_v_opExpr1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5208, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_6 = PyNumber_Add(__pyx_t_7, __pyx_v_lastExpr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5208, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_v_opExpr2)) { __Pyx_RaiseUnboundLocalError("opExpr2"); __PYX_ERR(0, 5208, __pyx_L1_error) }
        __pyx_t_7 = PyNumber_Add(__pyx_t_6, __pyx_v_opExpr2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5208, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = PyNumber_Add(__pyx_t_7, __pyx_v_lastExpr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5208, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_17))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_17);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_17, function);
          }
        }
        if (!__pyx_t_7) {
          __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5208, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_8);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_17)) {
            PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_6};
            __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_17, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5208, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_17)) {
            PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_6};
            __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_17, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5208, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          } else
          #endif
          {
            __pyx_t_3 = PyTuple_New(1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5208, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_7); __pyx_t_7 = NULL;
            __Pyx_GIVEREF(__pyx_t_6);
            PyTuple_SET_ITEM(__pyx_t_3, 0+1, __pyx_t_6);
            __pyx_t_6 = 0;
            __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_17, __pyx_t_3, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5208, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

        /* "cPyparsing.pyx":5207
 *                     matchExpr = FollowedBy(lastExpr + lastExpr) + Group(lastExpr + OneOrMore(lastExpr))
 *             elif arity == 3:
 *                 matchExpr = FollowedBy(lastExpr + opExpr1 + lastExpr + opExpr2 + lastExpr) + \             # <<<<<<<<<<<<<<
 *                     Group(lastExpr + opExpr1 + lastExpr + opExpr2 + lastExpr)
 *             else:
 */
        __pyx_t_17 = PyNumber_Add(__pyx_t_9, __pyx_t_8); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5207, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_17);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF_SET(__pyx_v_matchExpr, __pyx_t_17);
        __pyx_t_17 = 0;

        /* "cPyparsing.pyx":5206
 *                 else:
 *                     matchExpr = FollowedBy(lastExpr + lastExpr) + Group(lastExpr + OneOrMore(lastExpr))
 *             elif arity == 3:             # <<<<<<<<<<<<<<
 *                 matchExpr = FollowedBy(lastExpr + opExpr1 + lastExpr + opExpr2 + lastExpr) + \
 *                     Group(lastExpr + opExpr1 + lastExpr + opExpr2 + lastExpr)
 */
        goto __pyx_L14;
      }

      /* "cPyparsing.pyx":5210
 *                     Group(lastExpr + opExpr1 + lastExpr + opExpr2 + lastExpr)
 *             else:
 *                 raise ValueError("operator must be unary (1), binary (2), or ternary (3)")             # <<<<<<<<<<<<<<
 *         elif rightLeftAssoc == opAssoc.RIGHT:
 *             if arity == 1:
 */
      /*else*/ {
        __pyx_t_17 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__192, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5210, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_17);
        __Pyx_Raise(__pyx_t_17, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
        __PYX_ERR(0, 5210, __pyx_L1_error)
      }
      __pyx_L14:;

      /* "cPyparsing.pyx":5198
 *             opExpr1, opExpr2 = opExpr
 *         thisExpr = Forward().setName(termName)
 *         if rightLeftAssoc == opAssoc.LEFT:             # <<<<<<<<<<<<<<
 *             if arity == 1:
 *                 matchExpr = FollowedBy(lastExpr + opExpr) + Group(lastExpr + OneOrMore(opExpr))
 */
      goto __pyx_L13;
    }

    /* "cPyparsing.pyx":5211
 *             else:
 *                 raise ValueError("operator must be unary (1), binary (2), or ternary (3)")
 *         elif rightLeftAssoc == opAssoc.RIGHT:             # <<<<<<<<<<<<<<
 *             if arity == 1:
 *                 # try to avoid LR with this extra test
 */
    __pyx_t_17 = __Pyx_GetModuleGlobalName(__pyx_n_s_opAssoc); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_RIGHT); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    __pyx_t_17 = PyObject_RichCompare(__pyx_v_rightLeftAssoc, __pyx_t_8, Py_EQ); __Pyx_XGOTREF(__pyx_t_17); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5211, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_17); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 5211, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    if (__pyx_t_14) {

      /* "cPyparsing.pyx":5212
 *                 raise ValueError("operator must be unary (1), binary (2), or ternary (3)")
 *         elif rightLeftAssoc == opAssoc.RIGHT:
 *             if arity == 1:             # <<<<<<<<<<<<<<
 *                 # try to avoid LR with this extra test
 *                 if not isinstance(opExpr, Optional):
 */
      __pyx_t_17 = __Pyx_PyInt_EqObjC(__pyx_v_arity, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5212, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_17); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 5212, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      if (__pyx_t_14) {

        /* "cPyparsing.pyx":5214
 *             if arity == 1:
 *                 # try to avoid LR with this extra test
 *                 if not isinstance(opExpr, Optional):             # <<<<<<<<<<<<<<
 *                     opExpr = Optional(opExpr)
 *                 matchExpr = FollowedBy(opExpr.expr + thisExpr) + Group(opExpr + thisExpr)
 */
        __pyx_t_17 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5214, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_17);
        __pyx_t_14 = PyObject_IsInstance(__pyx_v_opExpr, __pyx_t_17); if (unlikely(__pyx_t_14 == -1)) __PYX_ERR(0, 5214, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
        __pyx_t_12 = ((!(__pyx_t_14 != 0)) != 0);
        if (__pyx_t_12) {

          /* "cPyparsing.pyx":5215
 *                 # try to avoid LR with this extra test
 *                 if not isinstance(opExpr, Optional):
 *                     opExpr = Optional(opExpr)             # <<<<<<<<<<<<<<
 *                 matchExpr = FollowedBy(opExpr.expr + thisExpr) + Group(opExpr + thisExpr)
 *             elif arity == 2:
 */
          __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5215, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_9 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
            __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
            if (likely(__pyx_t_9)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
              __Pyx_INCREF(__pyx_t_9);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_8, function);
            }
          }
          if (!__pyx_t_9) {
            __pyx_t_17 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_v_opExpr); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5215, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_17);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_8)) {
              PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_v_opExpr};
              __pyx_t_17 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5215, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_GOTREF(__pyx_t_17);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
              PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_v_opExpr};
              __pyx_t_17 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5215, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_GOTREF(__pyx_t_17);
            } else
            #endif
            {
              __pyx_t_3 = PyTuple_New(1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5215, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_3);
              __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_9); __pyx_t_9 = NULL;
              __Pyx_INCREF(__pyx_v_opExpr);
              __Pyx_GIVEREF(__pyx_v_opExpr);
              PyTuple_SET_ITEM(__pyx_t_3, 0+1, __pyx_v_opExpr);
              __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_3, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5215, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_17);
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF_SET(__pyx_v_opExpr, __pyx_t_17);
          __pyx_t_17 = 0;

          /* "cPyparsing.pyx":5214
 *             if arity == 1:
 *                 # try to avoid LR with this extra test
 *                 if not isinstance(opExpr, Optional):             # <<<<<<<<<<<<<<
 *                     opExpr = Optional(opExpr)
 *                 matchExpr = FollowedBy(opExpr.expr + thisExpr) + Group(opExpr + thisExpr)
 */
        }

        /* "cPyparsing.pyx":5216
 *                 if not isinstance(opExpr, Optional):
 *                     opExpr = Optional(opExpr)
 *                 matchExpr = FollowedBy(opExpr.expr + thisExpr) + Group(opExpr + thisExpr)             # <<<<<<<<<<<<<<
 *             elif arity == 2:
 *                 if opExpr is not None:
 */
        __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_FollowedBy); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5216, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_opExpr, __pyx_n_s_expr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5216, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_9 = PyNumber_Add(__pyx_t_3, __pyx_v_thisExpr); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5216, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
          }
        }
        if (!__pyx_t_3) {
          __pyx_t_17 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5216, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_GOTREF(__pyx_t_17);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_8)) {
            PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_9};
            __pyx_t_17 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5216, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_GOTREF(__pyx_t_17);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
            PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_9};
            __pyx_t_17 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5216, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_GOTREF(__pyx_t_17);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          } else
          #endif
          {
            __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5216, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_3); __pyx_t_3 = NULL;
            __Pyx_GIVEREF(__pyx_t_9);
            PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_9);
            __pyx_t_9 = 0;
            __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_6, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5216, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_17);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5216, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_9 = PyNumber_Add(__pyx_v_opExpr, __pyx_v_thisExpr); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5216, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_3 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
          }
        }
        if (!__pyx_t_3) {
          __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5216, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_GOTREF(__pyx_t_8);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_6)) {
            PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_9};
            __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5216, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
            PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_9};
            __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5216, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          } else
          #endif
          {
            __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5216, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_3); __pyx_t_3 = NULL;
            __Pyx_GIVEREF(__pyx_t_9);
            PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_9);
            __pyx_t_9 = 0;
            __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5216, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = PyNumber_Add(__pyx_t_17, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5216, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF_SET(__pyx_v_matchExpr, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "cPyparsing.pyx":5212
 *                 raise ValueError("operator must be unary (1), binary (2), or ternary (3)")
 *         elif rightLeftAssoc == opAssoc.RIGHT:
 *             if arity == 1:             # <<<<<<<<<<<<<<
 *                 # try to avoid LR with this extra test
 *                 if not isinstance(opExpr, Optional):
 */
        goto __pyx_L16;
      }

      /* "cPyparsing.pyx":5217
 *                     opExpr = Optional(opExpr)
 *                 matchExpr = FollowedBy(opExpr.expr + thisExpr) + Group(opExpr + thisExpr)
 *             elif arity == 2:             # <<<<<<<<<<<<<<
 *                 if opExpr is not None:
 *                     matchExpr = FollowedBy(lastExpr + opExpr + thisExpr) + Group(lastExpr + OneOrMore(opExpr + thisExpr))
 */
      __pyx_t_6 = __Pyx_PyInt_EqObjC(__pyx_v_arity, __pyx_int_2, 2, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5217, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 5217, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (__pyx_t_12) {

        /* "cPyparsing.pyx":5218
 *                 matchExpr = FollowedBy(opExpr.expr + thisExpr) + Group(opExpr + thisExpr)
 *             elif arity == 2:
 *                 if opExpr is not None:             # <<<<<<<<<<<<<<
 *                     matchExpr = FollowedBy(lastExpr + opExpr + thisExpr) + Group(lastExpr + OneOrMore(opExpr + thisExpr))
 *                 else:
 */
        __pyx_t_12 = (__pyx_v_opExpr != Py_None);
        __pyx_t_14 = (__pyx_t_12 != 0);
        if (__pyx_t_14) {

          /* "cPyparsing.pyx":5219
 *             elif arity == 2:
 *                 if opExpr is not None:
 *                     matchExpr = FollowedBy(lastExpr + opExpr + thisExpr) + Group(lastExpr + OneOrMore(opExpr + thisExpr))             # <<<<<<<<<<<<<<
 *                 else:
 *                     matchExpr = FollowedBy(lastExpr + thisExpr) + Group(lastExpr + OneOrMore(thisExpr))
 */
          __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_FollowedBy); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5219, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_17 = PyNumber_Add(__pyx_v_lastExpr, __pyx_v_opExpr); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5219, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_17);
          __pyx_t_7 = PyNumber_Add(__pyx_t_17, __pyx_v_thisExpr); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5219, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          __pyx_t_17 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
            __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_8);
            if (likely(__pyx_t_17)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
              __Pyx_INCREF(__pyx_t_17);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_8, function);
            }
          }
          if (!__pyx_t_17) {
            __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5219, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_GOTREF(__pyx_t_6);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_8)) {
              PyObject *__pyx_temp[2] = {__pyx_t_17, __pyx_t_7};
              __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5219, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
              PyObject *__pyx_temp[2] = {__pyx_t_17, __pyx_t_7};
              __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5219, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            } else
            #endif
            {
              __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5219, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_GIVEREF(__pyx_t_17); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_17); __pyx_t_17 = NULL;
              __Pyx_GIVEREF(__pyx_t_7);
              PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_7);
              __pyx_t_7 = 0;
              __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_9, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5219, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5219, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_17 = __Pyx_GetModuleGlobalName(__pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5219, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_17);
          __pyx_t_3 = PyNumber_Add(__pyx_v_opExpr, __pyx_v_thisExpr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5219, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_16 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_17))) {
            __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_17);
            if (likely(__pyx_t_16)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
              __Pyx_INCREF(__pyx_t_16);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_17, function);
            }
          }
          if (!__pyx_t_16) {
            __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5219, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_GOTREF(__pyx_t_7);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_17)) {
              PyObject *__pyx_temp[2] = {__pyx_t_16, __pyx_t_3};
              __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_17, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5219, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_17)) {
              PyObject *__pyx_temp[2] = {__pyx_t_16, __pyx_t_3};
              __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_17, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5219, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            } else
            #endif
            {
              __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5219, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_GIVEREF(__pyx_t_16); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_16); __pyx_t_16 = NULL;
              __Pyx_GIVEREF(__pyx_t_3);
              PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_3);
              __pyx_t_3 = 0;
              __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_17, __pyx_t_10, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5219, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          __pyx_t_17 = PyNumber_Add(__pyx_v_lastExpr, __pyx_t_7); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5219, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_17);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_7 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
            __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
            if (likely(__pyx_t_7)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
              __Pyx_INCREF(__pyx_t_7);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_9, function);
            }
          }
          if (!__pyx_t_7) {
            __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_17); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5219, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
            __Pyx_GOTREF(__pyx_t_8);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_17};
              __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5219, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_17};
              __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5219, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
            } else
            #endif
            {
              __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5219, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_7); __pyx_t_7 = NULL;
              __Pyx_GIVEREF(__pyx_t_17);
              PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_17);
              __pyx_t_17 = 0;
              __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_10, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5219, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_9 = PyNumber_Add(__pyx_t_6, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5219, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF_SET(__pyx_v_matchExpr, __pyx_t_9);
          __pyx_t_9 = 0;

          /* "cPyparsing.pyx":5218
 *                 matchExpr = FollowedBy(opExpr.expr + thisExpr) + Group(opExpr + thisExpr)
 *             elif arity == 2:
 *                 if opExpr is not None:             # <<<<<<<<<<<<<<
 *                     matchExpr = FollowedBy(lastExpr + opExpr + thisExpr) + Group(lastExpr + OneOrMore(opExpr + thisExpr))
 *                 else:
 */
          goto __pyx_L18;
        }

        /* "cPyparsing.pyx":5221
 *                     matchExpr = FollowedBy(lastExpr + opExpr + thisExpr) + Group(lastExpr + OneOrMore(opExpr + thisExpr))
 *                 else:
 *                     matchExpr = FollowedBy(lastExpr + thisExpr) + Group(lastExpr + OneOrMore(thisExpr))             # <<<<<<<<<<<<<<
 *             elif arity == 3:
 *                 matchExpr = FollowedBy(lastExpr + opExpr1 + thisExpr + opExpr2 + thisExpr) + \
 */
        /*else*/ {
          __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_FollowedBy); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5221, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_6 = PyNumber_Add(__pyx_v_lastExpr, __pyx_v_thisExpr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5221, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_10 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
            __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_8);
            if (likely(__pyx_t_10)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
              __Pyx_INCREF(__pyx_t_10);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_8, function);
            }
          }
          if (!__pyx_t_10) {
            __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5221, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_GOTREF(__pyx_t_9);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_8)) {
              PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_6};
              __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5221, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
              PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_6};
              __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5221, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            } else
            #endif
            {
              __pyx_t_17 = PyTuple_New(1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5221, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_17);
              __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_t_10); __pyx_t_10 = NULL;
              __Pyx_GIVEREF(__pyx_t_6);
              PyTuple_SET_ITEM(__pyx_t_17, 0+1, __pyx_t_6);
              __pyx_t_6 = 0;
              __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_17, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5221, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_17 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5221, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_17);
          __pyx_t_10 = __Pyx_GetModuleGlobalName(__pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5221, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_7 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
            __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_10);
            if (likely(__pyx_t_7)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
              __Pyx_INCREF(__pyx_t_7);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_10, function);
            }
          }
          if (!__pyx_t_7) {
            __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_v_thisExpr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5221, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_10)) {
              PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_thisExpr};
              __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5221, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_GOTREF(__pyx_t_6);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
              PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_thisExpr};
              __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5221, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_GOTREF(__pyx_t_6);
            } else
            #endif
            {
              __pyx_t_3 = PyTuple_New(1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5221, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_3);
              __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_7); __pyx_t_7 = NULL;
              __Pyx_INCREF(__pyx_v_thisExpr);
              __Pyx_GIVEREF(__pyx_v_thisExpr);
              PyTuple_SET_ITEM(__pyx_t_3, 0+1, __pyx_v_thisExpr);
              __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_3, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5221, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_10 = PyNumber_Add(__pyx_v_lastExpr, __pyx_t_6); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5221, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_17))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_17);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_17, function);
            }
          }
          if (!__pyx_t_6) {
            __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_t_10); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5221, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_GOTREF(__pyx_t_8);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_17)) {
              PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_10};
              __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_17, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5221, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_17)) {
              PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_10};
              __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_17, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5221, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            } else
            #endif
            {
              __pyx_t_3 = PyTuple_New(1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5221, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_3);
              __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_6); __pyx_t_6 = NULL;
              __Pyx_GIVEREF(__pyx_t_10);
              PyTuple_SET_ITEM(__pyx_t_3, 0+1, __pyx_t_10);
              __pyx_t_10 = 0;
              __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_17, __pyx_t_3, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5221, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          __pyx_t_17 = PyNumber_Add(__pyx_t_9, __pyx_t_8); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5221, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_17);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF_SET(__pyx_v_matchExpr, __pyx_t_17);
          __pyx_t_17 = 0;
        }
        __pyx_L18:;

        /* "cPyparsing.pyx":5217
 *                     opExpr = Optional(opExpr)
 *                 matchExpr = FollowedBy(opExpr.expr + thisExpr) + Group(opExpr + thisExpr)
 *             elif arity == 2:             # <<<<<<<<<<<<<<
 *                 if opExpr is not None:
 *                     matchExpr = FollowedBy(lastExpr + opExpr + thisExpr) + Group(lastExpr + OneOrMore(opExpr + thisExpr))
 */
        goto __pyx_L16;
      }

      /* "cPyparsing.pyx":5222
 *                 else:
 *                     matchExpr = FollowedBy(lastExpr + thisExpr) + Group(lastExpr + OneOrMore(thisExpr))
 *             elif arity == 3:             # <<<<<<<<<<<<<<
 *                 matchExpr = FollowedBy(lastExpr + opExpr1 + thisExpr + opExpr2 + thisExpr) + \
 *                     Group(lastExpr + opExpr1 + thisExpr + opExpr2 + thisExpr)
 */
      __pyx_t_17 = __Pyx_PyInt_EqObjC(__pyx_v_arity, __pyx_int_3, 3, 0); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5222, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_17); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 5222, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      if (__pyx_t_14) {

        /* "cPyparsing.pyx":5223
 *                     matchExpr = FollowedBy(lastExpr + thisExpr) + Group(lastExpr + OneOrMore(thisExpr))
 *             elif arity == 3:
 *                 matchExpr = FollowedBy(lastExpr + opExpr1 + thisExpr + opExpr2 + thisExpr) + \             # <<<<<<<<<<<<<<
 *                     Group(lastExpr + opExpr1 + thisExpr + opExpr2 + thisExpr)
 *             else:
 */
        __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_FollowedBy); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5223, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (unlikely(!__pyx_v_opExpr1)) { __Pyx_RaiseUnboundLocalError("opExpr1"); __PYX_ERR(0, 5223, __pyx_L1_error) }
        __pyx_t_9 = PyNumber_Add(__pyx_v_lastExpr, __pyx_v_opExpr1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5223, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_3 = PyNumber_Add(__pyx_t_9, __pyx_v_thisExpr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5223, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_v_opExpr2)) { __Pyx_RaiseUnboundLocalError("opExpr2"); __PYX_ERR(0, 5223, __pyx_L1_error) }
        __pyx_t_9 = PyNumber_Add(__pyx_t_3, __pyx_v_opExpr2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5223, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = PyNumber_Add(__pyx_t_9, __pyx_v_thisExpr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5223, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_9 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
          }
        }
        if (!__pyx_t_9) {
          __pyx_t_17 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_3); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5223, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_GOTREF(__pyx_t_17);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_8)) {
            PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_3};
            __pyx_t_17 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5223, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_GOTREF(__pyx_t_17);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
            PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_3};
            __pyx_t_17 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5223, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_GOTREF(__pyx_t_17);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          } else
          #endif
          {
            __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5223, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_9); __pyx_t_9 = NULL;
            __Pyx_GIVEREF(__pyx_t_3);
            PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_3);
            __pyx_t_3 = 0;
            __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_10, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5223, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_17);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "cPyparsing.pyx":5224
 *             elif arity == 3:
 *                 matchExpr = FollowedBy(lastExpr + opExpr1 + thisExpr + opExpr2 + thisExpr) + \
 *                     Group(lastExpr + opExpr1 + thisExpr + opExpr2 + thisExpr)             # <<<<<<<<<<<<<<
 *             else:
 *                 raise ValueError("operator must be unary (1), binary (2), or ternary (3)")
 */
        __pyx_t_10 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5224, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (unlikely(!__pyx_v_opExpr1)) { __Pyx_RaiseUnboundLocalError("opExpr1"); __PYX_ERR(0, 5224, __pyx_L1_error) }
        __pyx_t_3 = PyNumber_Add(__pyx_v_lastExpr, __pyx_v_opExpr1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5224, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_9 = PyNumber_Add(__pyx_t_3, __pyx_v_thisExpr); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5224, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_v_opExpr2)) { __Pyx_RaiseUnboundLocalError("opExpr2"); __PYX_ERR(0, 5224, __pyx_L1_error) }
        __pyx_t_3 = PyNumber_Add(__pyx_t_9, __pyx_v_opExpr2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5224, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_9 = PyNumber_Add(__pyx_t_3, __pyx_v_thisExpr); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5224, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_10);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_10, function);
          }
        }
        if (!__pyx_t_3) {
          __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5224, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_GOTREF(__pyx_t_8);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_10)) {
            PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_9};
            __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5224, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
            PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_9};
            __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5224, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          } else
          #endif
          {
            __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5224, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_3); __pyx_t_3 = NULL;
            __Pyx_GIVEREF(__pyx_t_9);
            PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_9);
            __pyx_t_9 = 0;
            __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_6, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5224, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

        /* "cPyparsing.pyx":5223
 *                     matchExpr = FollowedBy(lastExpr + thisExpr) + Group(lastExpr + OneOrMore(thisExpr))
 *             elif arity == 3:
 *                 matchExpr = FollowedBy(lastExpr + opExpr1 + thisExpr + opExpr2 + thisExpr) + \             # <<<<<<<<<<<<<<
 *                     Group(lastExpr + opExpr1 + thisExpr + opExpr2 + thisExpr)
 *             else:
 */
        __pyx_t_10 = PyNumber_Add(__pyx_t_17, __pyx_t_8); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5223, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF_SET(__pyx_v_matchExpr, __pyx_t_10);
        __pyx_t_10 = 0;

        /* "cPyparsing.pyx":5222
 *                 else:
 *                     matchExpr = FollowedBy(lastExpr + thisExpr) + Group(lastExpr + OneOrMore(thisExpr))
 *             elif arity == 3:             # <<<<<<<<<<<<<<
 *                 matchExpr = FollowedBy(lastExpr + opExpr1 + thisExpr + opExpr2 + thisExpr) + \
 *                     Group(lastExpr + opExpr1 + thisExpr + opExpr2 + thisExpr)
 */
        goto __pyx_L16;
      }

      /* "cPyparsing.pyx":5226
 *                     Group(lastExpr + opExpr1 + thisExpr + opExpr2 + thisExpr)
 *             else:
 *                 raise ValueError("operator must be unary (1), binary (2), or ternary (3)")             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError("operator must indicate right or left associativity")
 */
      /*else*/ {
        __pyx_t_10 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__193, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5226, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_Raise(__pyx_t_10, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __PYX_ERR(0, 5226, __pyx_L1_error)
      }
      __pyx_L16:;

      /* "cPyparsing.pyx":5211
 *             else:
 *                 raise ValueError("operator must be unary (1), binary (2), or ternary (3)")
 *         elif rightLeftAssoc == opAssoc.RIGHT:             # <<<<<<<<<<<<<<
 *             if arity == 1:
 *                 # try to avoid LR with this extra test
 */
      goto __pyx_L13;
    }

    /* "cPyparsing.pyx":5228
 *                 raise ValueError("operator must be unary (1), binary (2), or ternary (3)")
 *         else:
 *             raise ValueError("operator must indicate right or left associativity")             # <<<<<<<<<<<<<<
 *         if pa:
 *             if isinstance(pa, (tuple, list)):
 */
    /*else*/ {
      __pyx_t_10 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__194, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5228, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_Raise(__pyx_t_10, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __PYX_ERR(0, 5228, __pyx_L1_error)
    }
    __pyx_L13:;

    /* "cPyparsing.pyx":5229
 *         else:
 *             raise ValueError("operator must indicate right or left associativity")
 *         if pa:             # <<<<<<<<<<<<<<
 *             if isinstance(pa, (tuple, list)):
 *                 matchExpr.setParseAction(*pa)
 */
    __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_v_pa); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 5229, __pyx_L1_error)
    if (__pyx_t_14) {

      /* "cPyparsing.pyx":5230
 *             raise ValueError("operator must indicate right or left associativity")
 *         if pa:
 *             if isinstance(pa, (tuple, list)):             # <<<<<<<<<<<<<<
 *                 matchExpr.setParseAction(*pa)
 *             else:
 */
      __pyx_t_12 = PyTuple_Check(__pyx_v_pa); 
      __pyx_t_13 = (__pyx_t_12 != 0);
      if (!__pyx_t_13) {
      } else {
        __pyx_t_14 = __pyx_t_13;
        goto __pyx_L21_bool_binop_done;
      }
      __pyx_t_13 = PyList_Check(__pyx_v_pa); 
      __pyx_t_12 = (__pyx_t_13 != 0);
      __pyx_t_14 = __pyx_t_12;
      __pyx_L21_bool_binop_done:;
      __pyx_t_12 = (__pyx_t_14 != 0);
      if (__pyx_t_12) {

        /* "cPyparsing.pyx":5231
 *         if pa:
 *             if isinstance(pa, (tuple, list)):
 *                 matchExpr.setParseAction(*pa)             # <<<<<<<<<<<<<<
 *             else:
 *                 matchExpr.setParseAction(pa)
 */
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_matchExpr, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5231, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_8 = PySequence_Tuple(__pyx_v_pa); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5231, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_8, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5231, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_17);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

        /* "cPyparsing.pyx":5230
 *             raise ValueError("operator must indicate right or left associativity")
 *         if pa:
 *             if isinstance(pa, (tuple, list)):             # <<<<<<<<<<<<<<
 *                 matchExpr.setParseAction(*pa)
 *             else:
 */
        goto __pyx_L20;
      }

      /* "cPyparsing.pyx":5233
 *                 matchExpr.setParseAction(*pa)
 *             else:
 *                 matchExpr.setParseAction(pa)             # <<<<<<<<<<<<<<
 *         thisExpr <<= (matchExpr.setName(termName) | lastExpr)
 *         lastExpr = thisExpr
 */
      /*else*/ {
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_matchExpr, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5233, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_10 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
          }
        }
        if (!__pyx_t_10) {
          __pyx_t_17 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_v_pa); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5233, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_17);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_8)) {
            PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_v_pa};
            __pyx_t_17 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5233, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_GOTREF(__pyx_t_17);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
            PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_v_pa};
            __pyx_t_17 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5233, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_GOTREF(__pyx_t_17);
          } else
          #endif
          {
            __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5233, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_10); __pyx_t_10 = NULL;
            __Pyx_INCREF(__pyx_v_pa);
            __Pyx_GIVEREF(__pyx_v_pa);
            PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_pa);
            __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_6, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5233, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_17);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      }
      __pyx_L20:;

      /* "cPyparsing.pyx":5229
 *         else:
 *             raise ValueError("operator must indicate right or left associativity")
 *         if pa:             # <<<<<<<<<<<<<<
 *             if isinstance(pa, (tuple, list)):
 *                 matchExpr.setParseAction(*pa)
 */
    }

    /* "cPyparsing.pyx":5234
 *             else:
 *                 matchExpr.setParseAction(pa)
 *         thisExpr <<= (matchExpr.setName(termName) | lastExpr)             # <<<<<<<<<<<<<<
 *         lastExpr = thisExpr
 *     ret <<= lastExpr
 */
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_matchExpr, __pyx_n_s_setName); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5234, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_17 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_v_termName); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5234, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_termName};
        __pyx_t_17 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5234, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_17);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_termName};
        __pyx_t_17 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5234, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_17);
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5234, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_v_termName);
        __Pyx_GIVEREF(__pyx_v_termName);
        PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_v_termName);
        __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_10, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5234, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_17);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = PyNumber_Or(__pyx_t_17, __pyx_v_lastExpr); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5234, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    __pyx_t_17 = PyNumber_InPlaceLshift(__pyx_v_thisExpr, __pyx_t_8); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5234, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF_SET(__pyx_v_thisExpr, __pyx_t_17);
    __pyx_t_17 = 0;

    /* "cPyparsing.pyx":5235
 *                 matchExpr.setParseAction(pa)
 *         thisExpr <<= (matchExpr.setName(termName) | lastExpr)
 *         lastExpr = thisExpr             # <<<<<<<<<<<<<<
 *     ret <<= lastExpr
 *     return ret
 */
    __Pyx_INCREF(__pyx_v_thisExpr);
    __Pyx_DECREF_SET(__pyx_v_lastExpr, __pyx_v_thisExpr);

    /* "cPyparsing.pyx":5190
 *     ret = Forward()
 *     lastExpr = baseExpr | (lpar + ret + rpar)
 *     for i, operDef in enumerate(opList):             # <<<<<<<<<<<<<<
 *         opExpr, arity, rightLeftAssoc, pa = (operDef + (None,))[:4]
 *         termName = "%s term" % opExpr if arity < 3 else "%s%s term" % opExpr
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5236
 *         thisExpr <<= (matchExpr.setName(termName) | lastExpr)
 *         lastExpr = thisExpr
 *     ret <<= lastExpr             # <<<<<<<<<<<<<<
 *     return ret
 * 
 */
  __pyx_t_1 = PyNumber_InPlaceLshift(__pyx_v_ret, __pyx_v_lastExpr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF_SET(__pyx_v_ret, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5237
 *         lastExpr = thisExpr
 *     ret <<= lastExpr
 *     return ret             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ret);
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5127
 * 
 * 
 * def infixNotation(baseExpr, opList, lpar=Suppress('('), rpar=Suppress(')')):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for constructing grammars of expressions made up of
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_AddTraceback("cPyparsing.infixNotation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_lastExpr);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_operDef);
  __Pyx_XDECREF(__pyx_v_opExpr);
  __Pyx_XDECREF(__pyx_v_arity);
  __Pyx_XDECREF(__pyx_v_rightLeftAssoc);
  __Pyx_XDECREF(__pyx_v_pa);
  __Pyx_XDECREF(__pyx_v_termName);
  __Pyx_XDECREF(__pyx_v_opExpr1);
  __Pyx_XDECREF(__pyx_v_opExpr2);
  __Pyx_XDECREF(__pyx_v_thisExpr);
  __Pyx_XDECREF(__pyx_v_matchExpr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5250
 * 
 * 
 * def nestedExpr(opener="(", closer=")", content=None, ignoreExpr=quotedString.copy()):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for defining nested lists enclosed in opening and closing
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_67nestedExpr(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_66nestedExpr[] = "\n    Helper method for defining nested lists enclosed in opening and closing\n    delimiters (\"(\" and \")\" are the default).\n\n    Parameters:\n     - opener - opening character for a nested list (default=C{\"(\"}); can also be a pyparsing expression\n     - closer - closing character for a nested list (default=C{\")\"}); can also be a pyparsing expression\n     - content - expression for items within the nested lists (default=C{None})\n     - ignoreExpr - expression for ignoring opening and closing delimiters (default=C{quotedString})\n\n    If an expression is not provided for the content argument, the nested\n    expression will capture all whitespace-delimited content between delimiters\n    as a list of separate values.\n\n    Use the C{ignoreExpr} argument to define expressions that may contain\n    opening or closing characters that should not be treated as opening\n    or closing characters for nesting, such as quotedString or a comment\n    expression.  Specify multiple expressions using an C{L{Or}} or C{L{MatchFirst}}.\n    The default is L{quotedString}, but if no expressions are to be ignored,\n    then pass C{None} for this argument.\n\n    Example::\n        data_type = oneOf(\"void int short long char float double\")\n        decl_data_type = Combine(data_type + Optional(Word('*')))\n        ident = Word(alphas+'_', alphanums+'_')\n        number = pyparsing_common.number\n        arg = Group(decl_data_type + ident)\n        LPAR,RPAR = map(Suppress, \"()\")\n\n        code_body = nestedExpr('{', '}', ignoreExpr=(quotedString | cStyleComment))\n\n        c_function = (decl_data_type(\"type\")\n                      + ident(\"name\")\n                      + LPAR + Optional(delimitedList(arg), [])(\"args\") + RPAR\n                      + code_body(\"body\"))\n        c_function.ignore(cStyleComment)\n\n        source_code = '''\n            int is_odd(int x) {\n                return (x%2);\n            }\n\n            int dec_to_hex(char hchar)"" {\n                if (hchar >= '0' && hchar <= '9') {\n                    return (ord(hchar)-ord('0'));\n                } else {\n                    return (10+ord(hchar)-ord('A'));\n                }\n            }\n        '''\n        for func in c_function.searchString(source_code):\n            print(\"%(name)s (%(type)s) args: %(args)s\" % func)\n\n    prints::\n        is_odd (int) args: [['int', 'x']]\n        dec_to_hex (int) args: [['char', 'hchar']]\n    ";
static PyMethodDef __pyx_mdef_10cPyparsing_67nestedExpr = {"nestedExpr", (PyCFunction)__pyx_pw_10cPyparsing_67nestedExpr, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_66nestedExpr};
static PyObject *__pyx_pw_10cPyparsing_67nestedExpr(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_opener = 0;
  PyObject *__pyx_v_closer = 0;
  PyObject *__pyx_v_content = 0;
  PyObject *__pyx_v_ignoreExpr = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nestedExpr (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_opener,&__pyx_n_s_closer,&__pyx_n_s_content,&__pyx_n_s_ignoreExpr,0};
    PyObject* values[4] = {0,0,0,0};
    values[0] = ((PyObject *)__pyx_kp_u__195);
    values[1] = ((PyObject *)__pyx_kp_u__94);
    values[2] = ((PyObject *)Py_None);
    values[3] = __pyx_k__196;
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_opener);
          if (value) { values[0] = value; kw_args--; }
        }
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_closer);
          if (value) { values[1] = value; kw_args--; }
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_content);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_ignoreExpr);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "nestedExpr") < 0)) __PYX_ERR(0, 5250, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_opener = values[0];
    __pyx_v_closer = values[1];
    __pyx_v_content = values[2];
    __pyx_v_ignoreExpr = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("nestedExpr", 0, 0, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 5250, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.nestedExpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_66nestedExpr(__pyx_self, __pyx_v_opener, __pyx_v_closer, __pyx_v_content, __pyx_v_ignoreExpr);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5316
 *                     content = (Combine(OneOrMore(~ignoreExpr +
 *                                                  CharsNotIn(opener + closer + ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 *                                        ).setParseAction(lambda t: t[0].strip()))             # <<<<<<<<<<<<<<
 *                 else:
 *                     content = (empty.copy() + CharsNotIn(opener + closer + ParserElement.DEFAULT_WHITE_CHARS
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10nestedExpr_lambda51(PyObject *__pyx_self, PyObject *__pyx_v_t); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10nestedExpr_lambda51 = {"lambda51", (PyCFunction)__pyx_pw_10cPyparsing_10nestedExpr_lambda51, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_10nestedExpr_lambda51(PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda51 (wrapper)", 0);
  __pyx_r = __pyx_lambda_funcdef_lambda51(__pyx_self, ((PyObject *)__pyx_v_t));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda51(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("lambda51", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_strip); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5316, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5316, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.nestedExpr.lambda51", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5319
 *                 else:
 *                     content = (empty.copy() + CharsNotIn(opener + closer + ParserElement.DEFAULT_WHITE_CHARS
 *                                                          ).setParseAction(lambda t: t[0].strip()))             # <<<<<<<<<<<<<<
 *             else:
 *                 if ignoreExpr is not None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10nestedExpr_1lambda52(PyObject *__pyx_self, PyObject *__pyx_v_t); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10nestedExpr_1lambda52 = {"lambda52", (PyCFunction)__pyx_pw_10cPyparsing_10nestedExpr_1lambda52, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_10nestedExpr_1lambda52(PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda52 (wrapper)", 0);
  __pyx_r = __pyx_lambda_funcdef_lambda52(__pyx_self, ((PyObject *)__pyx_v_t));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda52(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("lambda52", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_strip); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5319, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5319, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.nestedExpr.lambda52", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5325
 *                                                  ~Literal(opener) + ~Literal(closer) +
 *                                                  CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 *                                        ).setParseAction(lambda t: t[0].strip()))             # <<<<<<<<<<<<<<
 *                 else:
 *                     content = (Combine(OneOrMore(~Literal(opener) + ~Literal(closer) +
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10nestedExpr_2lambda53(PyObject *__pyx_self, PyObject *__pyx_v_t); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10nestedExpr_2lambda53 = {"lambda53", (PyCFunction)__pyx_pw_10cPyparsing_10nestedExpr_2lambda53, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_10nestedExpr_2lambda53(PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda53 (wrapper)", 0);
  __pyx_r = __pyx_lambda_funcdef_lambda53(__pyx_self, ((PyObject *)__pyx_v_t));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda53(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("lambda53", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_strip); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5325, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5325, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.nestedExpr.lambda53", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5329
 *                     content = (Combine(OneOrMore(~Literal(opener) + ~Literal(closer) +
 *                                                  CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 *                                        ).setParseAction(lambda t: t[0].strip()))             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError("opening and closing arguments must be strings if no content expression is given")
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_10nestedExpr_3lambda54(PyObject *__pyx_self, PyObject *__pyx_v_t); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_10nestedExpr_3lambda54 = {"lambda54", (PyCFunction)__pyx_pw_10cPyparsing_10nestedExpr_3lambda54, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_10nestedExpr_3lambda54(PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda54 (wrapper)", 0);
  __pyx_r = __pyx_lambda_funcdef_lambda54(__pyx_self, ((PyObject *)__pyx_v_t));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda54(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("lambda54", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_strip); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5329, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5329, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.nestedExpr.lambda54", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5250
 * 
 * 
 * def nestedExpr(opener="(", closer=")", content=None, ignoreExpr=quotedString.copy()):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for defining nested lists enclosed in opening and closing
 */

static PyObject *__pyx_pf_10cPyparsing_66nestedExpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_opener, PyObject *__pyx_v_closer, PyObject *__pyx_v_content, PyObject *__pyx_v_ignoreExpr) {
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  __Pyx_RefNannySetupContext("nestedExpr", 0);
  __Pyx_INCREF(__pyx_v_content);

  /* "cPyparsing.pyx":5308
 *         dec_to_hex (int) args: [['char', 'hchar']]
 *     """
 *     if opener == closer:             # <<<<<<<<<<<<<<
 *         raise ValueError("opening and closing strings cannot be the same")
 *     if content is None:
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_opener, __pyx_v_closer, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5308, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 5308, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":5309
 *     """
 *     if opener == closer:
 *         raise ValueError("opening and closing strings cannot be the same")             # <<<<<<<<<<<<<<
 *     if content is None:
 *         if isinstance(opener, basestring) and isinstance(closer, basestring):
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__197, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5309, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 5309, __pyx_L1_error)

    /* "cPyparsing.pyx":5308
 *         dec_to_hex (int) args: [['char', 'hchar']]
 *     """
 *     if opener == closer:             # <<<<<<<<<<<<<<
 *         raise ValueError("opening and closing strings cannot be the same")
 *     if content is None:
 */
  }

  /* "cPyparsing.pyx":5310
 *     if opener == closer:
 *         raise ValueError("opening and closing strings cannot be the same")
 *     if content is None:             # <<<<<<<<<<<<<<
 *         if isinstance(opener, basestring) and isinstance(closer, basestring):
 *             if len(opener) == 1 and len(closer) == 1:
 */
  __pyx_t_2 = (__pyx_v_content == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "cPyparsing.pyx":5311
 *         raise ValueError("opening and closing strings cannot be the same")
 *     if content is None:
 *         if isinstance(opener, basestring) and isinstance(closer, basestring):             # <<<<<<<<<<<<<<
 *             if len(opener) == 1 and len(closer) == 1:
 *                 if ignoreExpr is not None:
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5311, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_IsInstance(__pyx_v_opener, __pyx_t_1); if (unlikely(__pyx_t_2 == -1)) __PYX_ERR(0, 5311, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_4 = (__pyx_t_2 != 0);
    if (__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_basestring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5311, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyObject_IsInstance(__pyx_v_closer, __pyx_t_1); if (unlikely(__pyx_t_4 == -1)) __PYX_ERR(0, 5311, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = (__pyx_t_4 != 0);
    __pyx_t_3 = __pyx_t_2;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_3) {

      /* "cPyparsing.pyx":5312
 *     if content is None:
 *         if isinstance(opener, basestring) and isinstance(closer, basestring):
 *             if len(opener) == 1 and len(closer) == 1:             # <<<<<<<<<<<<<<
 *                 if ignoreExpr is not None:
 *                     content = (Combine(OneOrMore(~ignoreExpr +
 */
      __pyx_t_5 = PyObject_Length(__pyx_v_opener); if (unlikely(__pyx_t_5 == -1)) __PYX_ERR(0, 5312, __pyx_L1_error)
      __pyx_t_2 = ((__pyx_t_5 == 1) != 0);
      if (__pyx_t_2) {
      } else {
        __pyx_t_3 = __pyx_t_2;
        goto __pyx_L9_bool_binop_done;
      }
      __pyx_t_5 = PyObject_Length(__pyx_v_closer); if (unlikely(__pyx_t_5 == -1)) __PYX_ERR(0, 5312, __pyx_L1_error)
      __pyx_t_2 = ((__pyx_t_5 == 1) != 0);
      __pyx_t_3 = __pyx_t_2;
      __pyx_L9_bool_binop_done:;
      if (__pyx_t_3) {

        /* "cPyparsing.pyx":5313
 *         if isinstance(opener, basestring) and isinstance(closer, basestring):
 *             if len(opener) == 1 and len(closer) == 1:
 *                 if ignoreExpr is not None:             # <<<<<<<<<<<<<<
 *                     content = (Combine(OneOrMore(~ignoreExpr +
 *                                                  CharsNotIn(opener + closer + ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 */
        __pyx_t_3 = (__pyx_v_ignoreExpr != Py_None);
        __pyx_t_2 = (__pyx_t_3 != 0);
        if (__pyx_t_2) {

          /* "cPyparsing.pyx":5314
 *             if len(opener) == 1 and len(closer) == 1:
 *                 if ignoreExpr is not None:
 *                     content = (Combine(OneOrMore(~ignoreExpr +             # <<<<<<<<<<<<<<
 *                                                  CharsNotIn(opener + closer + ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 *                                        ).setParseAction(lambda t: t[0].strip()))
 */
          __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_Combine); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5314, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5314, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_10 = PyNumber_Invert(__pyx_v_ignoreExpr); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5314, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);

          /* "cPyparsing.pyx":5315
 *                 if ignoreExpr is not None:
 *                     content = (Combine(OneOrMore(~ignoreExpr +
 *                                                  CharsNotIn(opener + closer + ParserElement.DEFAULT_WHITE_CHARS, exact=1))             # <<<<<<<<<<<<<<
 *                                        ).setParseAction(lambda t: t[0].strip()))
 *                 else:
 */
          __pyx_t_11 = __Pyx_GetModuleGlobalName(__pyx_n_s_CharsNotIn); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 5315, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_12 = PyNumber_Add(__pyx_v_opener, __pyx_v_closer); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5315, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5315, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_DEFAULT_WHITE_CHARS); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5315, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_13 = PyNumber_Add(__pyx_t_12, __pyx_t_14); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5315, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_14 = PyTuple_New(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5315, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_GIVEREF(__pyx_t_13);
          PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_13);
          __pyx_t_13 = 0;
          __pyx_t_13 = PyDict_New(); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5315, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_exact, __pyx_int_1) < 0) __PYX_ERR(0, 5315, __pyx_L1_error)
          __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_14, __pyx_t_13); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5315, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

          /* "cPyparsing.pyx":5314
 *             if len(opener) == 1 and len(closer) == 1:
 *                 if ignoreExpr is not None:
 *                     content = (Combine(OneOrMore(~ignoreExpr +             # <<<<<<<<<<<<<<
 *                                                  CharsNotIn(opener + closer + ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 *                                        ).setParseAction(lambda t: t[0].strip()))
 */
          __pyx_t_13 = PyNumber_Add(__pyx_t_10, __pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5314, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_9);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_9, function);
            }
          }
          if (!__pyx_t_12) {
            __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_13); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5314, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_GOTREF(__pyx_t_8);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_13};
              __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5314, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_13};
              __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5314, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            } else
            #endif
            {
              __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5314, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_12); __pyx_t_12 = NULL;
              __Pyx_GIVEREF(__pyx_t_13);
              PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_13);
              __pyx_t_13 = 0;
              __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_10, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5314, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_9 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
            if (likely(__pyx_t_9)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
              __Pyx_INCREF(__pyx_t_9);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_7, function);
            }
          }
          if (!__pyx_t_9) {
            __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5314, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_GOTREF(__pyx_t_6);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_7)) {
              PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_8};
              __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5314, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
              PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_8};
              __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5314, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            } else
            #endif
            {
              __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5314, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_9); __pyx_t_9 = NULL;
              __Pyx_GIVEREF(__pyx_t_8);
              PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_8);
              __pyx_t_8 = 0;
              __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5314, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

          /* "cPyparsing.pyx":5316
 *                     content = (Combine(OneOrMore(~ignoreExpr +
 *                                                  CharsNotIn(opener + closer + ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 *                                        ).setParseAction(lambda t: t[0].strip()))             # <<<<<<<<<<<<<<
 *                 else:
 *                     content = (empty.copy() + CharsNotIn(opener + closer + ParserElement.DEFAULT_WHITE_CHARS
 */
          __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5316, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10nestedExpr_lambda51, 0, __pyx_n_s_nestedExpr_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5316, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_10 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
            if (likely(__pyx_t_10)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
              __Pyx_INCREF(__pyx_t_10);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_7, function);
            }
          }
          if (!__pyx_t_10) {
            __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5316, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_GOTREF(__pyx_t_1);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_7)) {
              PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_6};
              __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5316, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
              PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_6};
              __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5316, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            } else
            #endif
            {
              __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5316, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_10); __pyx_t_10 = NULL;
              __Pyx_GIVEREF(__pyx_t_6);
              PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_6);
              __pyx_t_6 = 0;
              __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5316, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF_SET(__pyx_v_content, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "cPyparsing.pyx":5313
 *         if isinstance(opener, basestring) and isinstance(closer, basestring):
 *             if len(opener) == 1 and len(closer) == 1:
 *                 if ignoreExpr is not None:             # <<<<<<<<<<<<<<
 *                     content = (Combine(OneOrMore(~ignoreExpr +
 *                                                  CharsNotIn(opener + closer + ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 */
          goto __pyx_L11;
        }

        /* "cPyparsing.pyx":5318
 *                                        ).setParseAction(lambda t: t[0].strip()))
 *                 else:
 *                     content = (empty.copy() + CharsNotIn(opener + closer + ParserElement.DEFAULT_WHITE_CHARS             # <<<<<<<<<<<<<<
 *                                                          ).setParseAction(lambda t: t[0].strip()))
 *             else:
 */
        /*else*/ {
          __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_empty); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5318, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_copy); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5318, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_7 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
            __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_8);
            if (likely(__pyx_t_7)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
              __Pyx_INCREF(__pyx_t_7);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_8, function);
            }
          }
          if (__pyx_t_7) {
            __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5318, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          } else {
            __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5318, __pyx_L1_error)
          }
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "cPyparsing.pyx":5319
 *                 else:
 *                     content = (empty.copy() + CharsNotIn(opener + closer + ParserElement.DEFAULT_WHITE_CHARS
 *                                                          ).setParseAction(lambda t: t[0].strip()))             # <<<<<<<<<<<<<<
 *             else:
 *                 if ignoreExpr is not None:
 */
          __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_CharsNotIn); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5318, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);

          /* "cPyparsing.pyx":5318
 *                                        ).setParseAction(lambda t: t[0].strip()))
 *                 else:
 *                     content = (empty.copy() + CharsNotIn(opener + closer + ParserElement.DEFAULT_WHITE_CHARS             # <<<<<<<<<<<<<<
 *                                                          ).setParseAction(lambda t: t[0].strip()))
 *             else:
 */
          __pyx_t_10 = PyNumber_Add(__pyx_v_opener, __pyx_v_closer); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5318, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5318, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_DEFAULT_WHITE_CHARS); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5318, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_9 = PyNumber_Add(__pyx_t_10, __pyx_t_13); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5318, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_13 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_6);
            if (likely(__pyx_t_13)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
              __Pyx_INCREF(__pyx_t_13);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_6, function);
            }
          }
          if (!__pyx_t_13) {
            __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5318, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_GOTREF(__pyx_t_7);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_6)) {
              PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_9};
              __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5318, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
              PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_9};
              __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5318, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            } else
            #endif
            {
              __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5318, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_13); __pyx_t_13 = NULL;
              __Pyx_GIVEREF(__pyx_t_9);
              PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_9);
              __pyx_t_9 = 0;
              __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_10, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5318, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

          /* "cPyparsing.pyx":5319
 *                 else:
 *                     content = (empty.copy() + CharsNotIn(opener + closer + ParserElement.DEFAULT_WHITE_CHARS
 *                                                          ).setParseAction(lambda t: t[0].strip()))             # <<<<<<<<<<<<<<
 *             else:
 *                 if ignoreExpr is not None:
 */
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5319, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10nestedExpr_1lambda52, 0, __pyx_n_s_nestedExpr_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5319, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_10 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
            if (likely(__pyx_t_10)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
              __Pyx_INCREF(__pyx_t_10);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_6, function);
            }
          }
          if (!__pyx_t_10) {
            __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5319, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_GOTREF(__pyx_t_8);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_6)) {
              PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_7};
              __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5319, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
              PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_7};
              __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5319, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            } else
            #endif
            {
              __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5319, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_10); __pyx_t_10 = NULL;
              __Pyx_GIVEREF(__pyx_t_7);
              PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_7);
              __pyx_t_7 = 0;
              __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_9, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5319, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

          /* "cPyparsing.pyx":5318
 *                                        ).setParseAction(lambda t: t[0].strip()))
 *                 else:
 *                     content = (empty.copy() + CharsNotIn(opener + closer + ParserElement.DEFAULT_WHITE_CHARS             # <<<<<<<<<<<<<<
 *                                                          ).setParseAction(lambda t: t[0].strip()))
 *             else:
 */
          __pyx_t_6 = PyNumber_Add(__pyx_t_1, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5318, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF_SET(__pyx_v_content, __pyx_t_6);
          __pyx_t_6 = 0;
        }
        __pyx_L11:;

        /* "cPyparsing.pyx":5312
 *     if content is None:
 *         if isinstance(opener, basestring) and isinstance(closer, basestring):
 *             if len(opener) == 1 and len(closer) == 1:             # <<<<<<<<<<<<<<
 *                 if ignoreExpr is not None:
 *                     content = (Combine(OneOrMore(~ignoreExpr +
 */
        goto __pyx_L8;
      }

      /* "cPyparsing.pyx":5321
 *                                                          ).setParseAction(lambda t: t[0].strip()))
 *             else:
 *                 if ignoreExpr is not None:             # <<<<<<<<<<<<<<
 *                     content = (Combine(OneOrMore(~ignoreExpr +
 *                                                  ~Literal(opener) + ~Literal(closer) +
 */
      /*else*/ {
        __pyx_t_2 = (__pyx_v_ignoreExpr != Py_None);
        __pyx_t_3 = (__pyx_t_2 != 0);
        if (__pyx_t_3) {

          /* "cPyparsing.pyx":5322
 *             else:
 *                 if ignoreExpr is not None:
 *                     content = (Combine(OneOrMore(~ignoreExpr +             # <<<<<<<<<<<<<<
 *                                                  ~Literal(opener) + ~Literal(closer) +
 *                                                  CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 */
          __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Combine); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5322, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5322, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_10 = PyNumber_Invert(__pyx_v_ignoreExpr); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5322, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);

          /* "cPyparsing.pyx":5323
 *                 if ignoreExpr is not None:
 *                     content = (Combine(OneOrMore(~ignoreExpr +
 *                                                  ~Literal(opener) + ~Literal(closer) +             # <<<<<<<<<<<<<<
 *                                                  CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 *                                        ).setParseAction(lambda t: t[0].strip()))
 */
          __pyx_t_12 = __Pyx_GetModuleGlobalName(__pyx_n_s_Literal); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5323, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_14 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
            __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_12);
            if (likely(__pyx_t_14)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
              __Pyx_INCREF(__pyx_t_14);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_12, function);
            }
          }
          if (!__pyx_t_14) {
            __pyx_t_13 = __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_v_opener); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5323, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_13);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[2] = {__pyx_t_14, __pyx_v_opener};
              __pyx_t_13 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5323, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_GOTREF(__pyx_t_13);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[2] = {__pyx_t_14, __pyx_v_opener};
              __pyx_t_13 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5323, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_GOTREF(__pyx_t_13);
            } else
            #endif
            {
              __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 5323, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_11);
              __Pyx_GIVEREF(__pyx_t_14); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_14); __pyx_t_14 = NULL;
              __Pyx_INCREF(__pyx_v_opener);
              __Pyx_GIVEREF(__pyx_v_opener);
              PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_v_opener);
              __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_11, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5323, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_13);
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = PyNumber_Invert(__pyx_t_13); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5323, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

          /* "cPyparsing.pyx":5322
 *             else:
 *                 if ignoreExpr is not None:
 *                     content = (Combine(OneOrMore(~ignoreExpr +             # <<<<<<<<<<<<<<
 *                                                  ~Literal(opener) + ~Literal(closer) +
 *                                                  CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 */
          __pyx_t_13 = PyNumber_Add(__pyx_t_10, __pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5322, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

          /* "cPyparsing.pyx":5323
 *                 if ignoreExpr is not None:
 *                     content = (Combine(OneOrMore(~ignoreExpr +
 *                                                  ~Literal(opener) + ~Literal(closer) +             # <<<<<<<<<<<<<<
 *                                                  CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 *                                        ).setParseAction(lambda t: t[0].strip()))
 */
          __pyx_t_10 = __Pyx_GetModuleGlobalName(__pyx_n_s_Literal); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5323, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_11 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
            __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
            if (likely(__pyx_t_11)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
              __Pyx_INCREF(__pyx_t_11);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_10, function);
            }
          }
          if (!__pyx_t_11) {
            __pyx_t_12 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_v_closer); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5323, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_10)) {
              PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_v_closer};
              __pyx_t_12 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5323, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_GOTREF(__pyx_t_12);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
              PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_v_closer};
              __pyx_t_12 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5323, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_GOTREF(__pyx_t_12);
            } else
            #endif
            {
              __pyx_t_14 = PyTuple_New(1+1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5323, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_14);
              __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_11); __pyx_t_11 = NULL;
              __Pyx_INCREF(__pyx_v_closer);
              __Pyx_GIVEREF(__pyx_v_closer);
              PyTuple_SET_ITEM(__pyx_t_14, 0+1, __pyx_v_closer);
              __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_14, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5323, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_10 = PyNumber_Invert(__pyx_t_12); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5323, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = PyNumber_Add(__pyx_t_13, __pyx_t_10); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5323, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

          /* "cPyparsing.pyx":5324
 *                     content = (Combine(OneOrMore(~ignoreExpr +
 *                                                  ~Literal(opener) + ~Literal(closer) +
 *                                                  CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))             # <<<<<<<<<<<<<<
 *                                        ).setParseAction(lambda t: t[0].strip()))
 *                 else:
 */
          __pyx_t_10 = __Pyx_GetModuleGlobalName(__pyx_n_s_CharsNotIn); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5324, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5324, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_DEFAULT_WHITE_CHARS); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5324, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5324, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_GIVEREF(__pyx_t_14);
          PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_14);
          __pyx_t_14 = 0;
          __pyx_t_14 = PyDict_New(); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5324, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_exact, __pyx_int_1) < 0) __PYX_ERR(0, 5324, __pyx_L1_error)
          __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, __pyx_t_14); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 5324, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

          /* "cPyparsing.pyx":5323
 *                 if ignoreExpr is not None:
 *                     content = (Combine(OneOrMore(~ignoreExpr +
 *                                                  ~Literal(opener) + ~Literal(closer) +             # <<<<<<<<<<<<<<
 *                                                  CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 *                                        ).setParseAction(lambda t: t[0].strip()))
 */
          __pyx_t_14 = PyNumber_Add(__pyx_t_12, __pyx_t_11); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5323, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_11 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_7);
            if (likely(__pyx_t_11)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
              __Pyx_INCREF(__pyx_t_11);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_7, function);
            }
          }
          if (!__pyx_t_11) {
            __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_14); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5322, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_GOTREF(__pyx_t_9);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_7)) {
              PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_t_14};
              __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5322, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
              PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_t_14};
              __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5322, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            } else
            #endif
            {
              __pyx_t_12 = PyTuple_New(1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5322, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_11); __pyx_t_11 = NULL;
              __Pyx_GIVEREF(__pyx_t_14);
              PyTuple_SET_ITEM(__pyx_t_12, 0+1, __pyx_t_14);
              __pyx_t_14 = 0;
              __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_12, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5322, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_7 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_7)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_7);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
            }
          }
          if (!__pyx_t_7) {
            __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5322, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_GOTREF(__pyx_t_8);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_9};
              __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5322, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_9};
              __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5322, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            } else
            #endif
            {
              __pyx_t_12 = PyTuple_New(1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5322, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_7); __pyx_t_7 = NULL;
              __Pyx_GIVEREF(__pyx_t_9);
              PyTuple_SET_ITEM(__pyx_t_12, 0+1, __pyx_t_9);
              __pyx_t_9 = 0;
              __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_12, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5322, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "cPyparsing.pyx":5325
 *                                                  ~Literal(opener) + ~Literal(closer) +
 *                                                  CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 *                                        ).setParseAction(lambda t: t[0].strip()))             # <<<<<<<<<<<<<<
 *                 else:
 *                     content = (Combine(OneOrMore(~Literal(opener) + ~Literal(closer) +
 */
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5325, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_8 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10nestedExpr_2lambda53, 0, __pyx_n_s_nestedExpr_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5325, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_12 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
            }
          }
          if (!__pyx_t_12) {
            __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5325, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_GOTREF(__pyx_t_6);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_8};
              __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5325, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_8};
              __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5325, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            } else
            #endif
            {
              __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5325, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_12); __pyx_t_12 = NULL;
              __Pyx_GIVEREF(__pyx_t_8);
              PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_8);
              __pyx_t_8 = 0;
              __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_9, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5325, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF_SET(__pyx_v_content, __pyx_t_6);
          __pyx_t_6 = 0;

          /* "cPyparsing.pyx":5321
 *                                                          ).setParseAction(lambda t: t[0].strip()))
 *             else:
 *                 if ignoreExpr is not None:             # <<<<<<<<<<<<<<
 *                     content = (Combine(OneOrMore(~ignoreExpr +
 *                                                  ~Literal(opener) + ~Literal(closer) +
 */
          goto __pyx_L12;
        }

        /* "cPyparsing.pyx":5329
 *                     content = (Combine(OneOrMore(~Literal(opener) + ~Literal(closer) +
 *                                                  CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 *                                        ).setParseAction(lambda t: t[0].strip()))             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError("opening and closing arguments must be strings if no content expression is given")
 */
        /*else*/ {

          /* "cPyparsing.pyx":5327
 *                                        ).setParseAction(lambda t: t[0].strip()))
 *                 else:
 *                     content = (Combine(OneOrMore(~Literal(opener) + ~Literal(closer) +             # <<<<<<<<<<<<<<
 *                                                  CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 *                                        ).setParseAction(lambda t: t[0].strip()))
 */
          __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_Combine); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5327, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_12 = __Pyx_GetModuleGlobalName(__pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5327, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_14 = __Pyx_GetModuleGlobalName(__pyx_n_s_Literal); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5327, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __pyx_t_11 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_14))) {
            __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_14);
            if (likely(__pyx_t_11)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
              __Pyx_INCREF(__pyx_t_11);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_14, function);
            }
          }
          if (!__pyx_t_11) {
            __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_v_opener); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5327, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_14)) {
              PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_v_opener};
              __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_14, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5327, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_GOTREF(__pyx_t_7);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_14)) {
              PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_v_opener};
              __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_14, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5327, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_GOTREF(__pyx_t_7);
            } else
            #endif
            {
              __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5327, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_13);
              __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
              __Pyx_INCREF(__pyx_v_opener);
              __Pyx_GIVEREF(__pyx_v_opener);
              PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_v_opener);
              __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_t_13, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5327, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_14 = PyNumber_Invert(__pyx_t_7); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5327, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_Literal); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5327, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_11 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
            __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_13);
            if (likely(__pyx_t_11)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
              __Pyx_INCREF(__pyx_t_11);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_13, function);
            }
          }
          if (!__pyx_t_11) {
            __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_v_closer); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5327, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_13)) {
              PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_v_closer};
              __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5327, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_GOTREF(__pyx_t_7);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_13)) {
              PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_v_closer};
              __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5327, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_GOTREF(__pyx_t_7);
            } else
            #endif
            {
              __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5327, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_11); __pyx_t_11 = NULL;
              __Pyx_INCREF(__pyx_v_closer);
              __Pyx_GIVEREF(__pyx_v_closer);
              PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_v_closer);
              __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_10, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5327, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_13 = PyNumber_Invert(__pyx_t_7); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5327, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_7 = PyNumber_Add(__pyx_t_14, __pyx_t_13); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5327, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

          /* "cPyparsing.pyx":5328
 *                 else:
 *                     content = (Combine(OneOrMore(~Literal(opener) + ~Literal(closer) +
 *                                                  CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))             # <<<<<<<<<<<<<<
 *                                        ).setParseAction(lambda t: t[0].strip()))
 *         else:
 */
          __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_CharsNotIn); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5328, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_14 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5328, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_DEFAULT_WHITE_CHARS); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5328, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_14 = PyTuple_New(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5328, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_GIVEREF(__pyx_t_10);
          PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_10);
          __pyx_t_10 = 0;
          __pyx_t_10 = PyDict_New(); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5328, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_exact, __pyx_int_1) < 0) __PYX_ERR(0, 5328, __pyx_L1_error)
          __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_14, __pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 5328, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

          /* "cPyparsing.pyx":5327
 *                                        ).setParseAction(lambda t: t[0].strip()))
 *                 else:
 *                     content = (Combine(OneOrMore(~Literal(opener) + ~Literal(closer) +             # <<<<<<<<<<<<<<
 *                                                  CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 *                                        ).setParseAction(lambda t: t[0].strip()))
 */
          __pyx_t_10 = PyNumber_Add(__pyx_t_7, __pyx_t_11); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5327, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_11 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
            __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_12);
            if (likely(__pyx_t_11)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
              __Pyx_INCREF(__pyx_t_11);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_12, function);
            }
          }
          if (!__pyx_t_11) {
            __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_10); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5327, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_GOTREF(__pyx_t_8);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_t_10};
              __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5327, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_t_10};
              __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5327, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            } else
            #endif
            {
              __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5327, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_11); __pyx_t_11 = NULL;
              __Pyx_GIVEREF(__pyx_t_10);
              PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_10);
              __pyx_t_10 = 0;
              __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_7, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5327, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_9);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_9, function);
            }
          }
          if (!__pyx_t_12) {
            __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5327, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_GOTREF(__pyx_t_1);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_8};
              __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5327, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_8};
              __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5327, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            } else
            #endif
            {
              __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5327, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_12); __pyx_t_12 = NULL;
              __Pyx_GIVEREF(__pyx_t_8);
              PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_8);
              __pyx_t_8 = 0;
              __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5327, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

          /* "cPyparsing.pyx":5329
 *                     content = (Combine(OneOrMore(~Literal(opener) + ~Literal(closer) +
 *                                                  CharsNotIn(ParserElement.DEFAULT_WHITE_CHARS, exact=1))
 *                                        ).setParseAction(lambda t: t[0].strip()))             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError("opening and closing arguments must be strings if no content expression is given")
 */
          __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5329, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10nestedExpr_3lambda54, 0, __pyx_n_s_nestedExpr_locals_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5329, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_7 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
            __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
            if (likely(__pyx_t_7)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
              __Pyx_INCREF(__pyx_t_7);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_9, function);
            }
          }
          if (!__pyx_t_7) {
            __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5329, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_GOTREF(__pyx_t_6);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_1};
              __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5329, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_1};
              __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5329, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            } else
            #endif
            {
              __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5329, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_7); __pyx_t_7 = NULL;
              __Pyx_GIVEREF(__pyx_t_1);
              PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_1);
              __pyx_t_1 = 0;
              __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_8, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5329, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF_SET(__pyx_v_content, __pyx_t_6);
          __pyx_t_6 = 0;
        }
        __pyx_L12:;
      }
      __pyx_L8:;

      /* "cPyparsing.pyx":5311
 *         raise ValueError("opening and closing strings cannot be the same")
 *     if content is None:
 *         if isinstance(opener, basestring) and isinstance(closer, basestring):             # <<<<<<<<<<<<<<
 *             if len(opener) == 1 and len(closer) == 1:
 *                 if ignoreExpr is not None:
 */
      goto __pyx_L5;
    }

    /* "cPyparsing.pyx":5331
 *                                        ).setParseAction(lambda t: t[0].strip()))
 *         else:
 *             raise ValueError("opening and closing arguments must be strings if no content expression is given")             # <<<<<<<<<<<<<<
 *     ret = Forward()
 *     if ignoreExpr is not None:
 */
    /*else*/ {
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__198, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5331, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(0, 5331, __pyx_L1_error)
    }
    __pyx_L5:;

    /* "cPyparsing.pyx":5310
 *     if opener == closer:
 *         raise ValueError("opening and closing strings cannot be the same")
 *     if content is None:             # <<<<<<<<<<<<<<
 *         if isinstance(opener, basestring) and isinstance(closer, basestring):
 *             if len(opener) == 1 and len(closer) == 1:
 */
  }

  /* "cPyparsing.pyx":5332
 *         else:
 *             raise ValueError("opening and closing arguments must be strings if no content expression is given")
 *     ret = Forward()             # <<<<<<<<<<<<<<
 *     if ignoreExpr is not None:
 *         ret <<= Group(Suppress(opener) + ZeroOrMore(ignoreExpr | ret | content) + Suppress(closer))
 */
  __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_Forward); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  if (__pyx_t_8) {
    __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5332, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  } else {
    __pyx_t_6 = __Pyx_PyObject_CallNoArg(__pyx_t_9); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5332, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_v_ret = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "cPyparsing.pyx":5333
 *             raise ValueError("opening and closing arguments must be strings if no content expression is given")
 *     ret = Forward()
 *     if ignoreExpr is not None:             # <<<<<<<<<<<<<<
 *         ret <<= Group(Suppress(opener) + ZeroOrMore(ignoreExpr | ret | content) + Suppress(closer))
 *     else:
 */
  __pyx_t_3 = (__pyx_v_ignoreExpr != Py_None);
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {

    /* "cPyparsing.pyx":5334
 *     ret = Forward()
 *     if ignoreExpr is not None:
 *         ret <<= Group(Suppress(opener) + ZeroOrMore(ignoreExpr | ret | content) + Suppress(closer))             # <<<<<<<<<<<<<<
 *     else:
 *         ret <<= Group(Suppress(opener) + ZeroOrMore(ret | content) + Suppress(closer))
 */
    __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5334, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Suppress); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5334, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (!__pyx_t_7) {
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_opener); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5334, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_opener};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5334, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_8);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_opener};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5334, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_8);
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5334, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_7); __pyx_t_7 = NULL;
        __Pyx_INCREF(__pyx_v_opener);
        __Pyx_GIVEREF(__pyx_v_opener);
        PyTuple_SET_ITEM(__pyx_t_12, 0+1, __pyx_v_opener);
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_12, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5334, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_12 = __Pyx_GetModuleGlobalName(__pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5334, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_7 = PyNumber_Or(__pyx_v_ignoreExpr, __pyx_v_ret); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5334, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_10 = PyNumber_Or(__pyx_t_7, __pyx_v_content); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5334, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_12);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_12, function);
      }
    }
    if (!__pyx_t_7) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5334, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_12)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_10};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5334, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_10};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5334, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 5334, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_7); __pyx_t_7 = NULL;
        __Pyx_GIVEREF(__pyx_t_10);
        PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_t_10);
        __pyx_t_10 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5334, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_12 = PyNumber_Add(__pyx_t_8, __pyx_t_1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5334, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_Suppress); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5334, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_11 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    if (!__pyx_t_11) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_v_closer); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5334, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_v_closer};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5334, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_v_closer};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5334, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5334, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_11); __pyx_t_11 = NULL;
        __Pyx_INCREF(__pyx_v_closer);
        __Pyx_GIVEREF(__pyx_v_closer);
        PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_v_closer);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_10, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5334, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = PyNumber_Add(__pyx_t_12, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5334, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
      }
    }
    if (!__pyx_t_1) {
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5334, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_6);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_8};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5334, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_8};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5334, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5334, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_1); __pyx_t_1 = NULL;
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_12, 0+1, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_12, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5334, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = PyNumber_InPlaceLshift(__pyx_v_ret, __pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5334, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF_SET(__pyx_v_ret, __pyx_t_9);
    __pyx_t_9 = 0;

    /* "cPyparsing.pyx":5333
 *             raise ValueError("opening and closing arguments must be strings if no content expression is given")
 *     ret = Forward()
 *     if ignoreExpr is not None:             # <<<<<<<<<<<<<<
 *         ret <<= Group(Suppress(opener) + ZeroOrMore(ignoreExpr | ret | content) + Suppress(closer))
 *     else:
 */
    goto __pyx_L13;
  }

  /* "cPyparsing.pyx":5336
 *         ret <<= Group(Suppress(opener) + ZeroOrMore(ignoreExpr | ret | content) + Suppress(closer))
 *     else:
 *         ret <<= Group(Suppress(opener) + ZeroOrMore(ret | content) + Suppress(closer))             # <<<<<<<<<<<<<<
 *     ret.setName('nested %s%s expression' % (opener, closer))
 *     return ret
 */
  /*else*/ {
    __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5336, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_Suppress); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5336, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    if (!__pyx_t_1) {
      __pyx_t_12 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_v_opener); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5336, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_v_opener};
        __pyx_t_12 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5336, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_12);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_v_opener};
        __pyx_t_12 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5336, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_12);
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5336, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_1); __pyx_t_1 = NULL;
        __Pyx_INCREF(__pyx_v_opener);
        __Pyx_GIVEREF(__pyx_v_opener);
        PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_v_opener);
        __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_10, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5336, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_10 = __Pyx_GetModuleGlobalName(__pyx_n_s_ZeroOrMore); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5336, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_1 = PyNumber_Or(__pyx_v_ret, __pyx_v_content); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5336, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_11 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
      }
    }
    if (!__pyx_t_11) {
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5336, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_8);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_t_1};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5336, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_t_1};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5336, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5336, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_11); __pyx_t_11 = NULL;
        __Pyx_GIVEREF(__pyx_t_1);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_1);
        __pyx_t_1 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_7, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5336, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = PyNumber_Add(__pyx_t_12, __pyx_t_8); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5336, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_12 = __Pyx_GetModuleGlobalName(__pyx_n_s_Suppress); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5336, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_12);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_12, function);
      }
    }
    if (!__pyx_t_7) {
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_v_closer); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5336, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_12)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_closer};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5336, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_8);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_closer};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5336, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_8);
      } else
      #endif
      {
        __pyx_t_1 = PyTuple_New(1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5336, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_7); __pyx_t_7 = NULL;
        __Pyx_INCREF(__pyx_v_closer);
        __Pyx_GIVEREF(__pyx_v_closer);
        PyTuple_SET_ITEM(__pyx_t_1, 0+1, __pyx_v_closer);
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_1, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5336, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_12 = PyNumber_Add(__pyx_t_10, __pyx_t_8); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5336, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    if (!__pyx_t_8) {
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_12); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5336, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_GOTREF(__pyx_t_9);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_12};
        __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5336, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_12};
        __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5336, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5336, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
        __Pyx_GIVEREF(__pyx_t_12);
        PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_12);
        __pyx_t_12 = 0;
        __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_10, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5336, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyNumber_InPlaceLshift(__pyx_v_ret, __pyx_t_9); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5336, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF_SET(__pyx_v_ret, __pyx_t_6);
    __pyx_t_6 = 0;
  }
  __pyx_L13:;

  /* "cPyparsing.pyx":5337
 *     else:
 *         ret <<= Group(Suppress(opener) + ZeroOrMore(ret | content) + Suppress(closer))
 *     ret.setName('nested %s%s expression' % (opener, closer))             # <<<<<<<<<<<<<<
 *     return ret
 * 
 */
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_ret, __pyx_n_s_setName); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_INCREF(__pyx_v_opener);
  __Pyx_GIVEREF(__pyx_v_opener);
  PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_v_opener);
  __Pyx_INCREF(__pyx_v_closer);
  __Pyx_GIVEREF(__pyx_v_closer);
  PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_v_closer);
  __pyx_t_12 = PyUnicode_Format(__pyx_kp_u_nested_s_s_expression, __pyx_t_10); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  if (!__pyx_t_10) {
    __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5337, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_GOTREF(__pyx_t_6);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_12};
      __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5337, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_12};
      __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5337, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    } else
    #endif
    {
      __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5337, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_10); __pyx_t_10 = NULL;
      __Pyx_GIVEREF(__pyx_t_12);
      PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_12);
      __pyx_t_12 = 0;
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_8, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5337, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "cPyparsing.pyx":5338
 *         ret <<= Group(Suppress(opener) + ZeroOrMore(ret | content) + Suppress(closer))
 *     ret.setName('nested %s%s expression' % (opener, closer))
 *     return ret             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ret);
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5250
 * 
 * 
 * def nestedExpr(opener="(", closer=")", content=None, ignoreExpr=quotedString.copy()):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for defining nested lists enclosed in opening and closing
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("cPyparsing.nestedExpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_content);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5341
 * 
 * 
 * def indentedBlock(blockStatementExpr, indentStack, indent=True):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for defining space-delimited indentation blocks, such as
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_69indentedBlock(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_68indentedBlock[] = "\n    Helper method for defining space-delimited indentation blocks, such as\n    those used to define block statements in Python source code.\n\n    Parameters:\n     - blockStatementExpr - expression defining syntax of statement that\n            is repeated within the indented block\n     - indentStack - list created by caller to manage indentation stack\n            (multiple statementWithIndentedBlock expressions within a single grammar\n            should share a common indentStack)\n     - indent - boolean indicating whether block must be indented beyond the\n            the current level; set to False for block of left-most statements\n            (default=C{True})\n\n    A valid block must contain at least one C{blockStatement}.\n\n    Example::\n        data = '''\n        def A(z):\n          A1\n          B = 100\n          G = A2\n          A2\n          A3\n        B\n        def BB(a,b,c):\n          BB1\n          def BBA():\n            bba1\n            bba2\n            bba3\n        C\n        D\n        def spam(x,y):\n             def eggs(z):\n                 pass\n        '''\n\n\n        indentStack = [1]\n        stmt = Forward()\n\n        identifier = Word(alphas, alphanums)\n        funcDecl = (\"def\" + identifier + Group( \"(\" + Optional( delimitedList(identifier) ) + \")\" ) + \":\")\n        func_body = indentedBlock(stmt, indentStack)\n        funcDef = Group( funcDecl + func_body )\n\n        rvalue = Forward()\n        funcCall = Group(identifier + \"(\" + Optional(delimitedList(rvalue)) + \")\")\n        rvalue << (funcCall | identifier | Word(nums))\n        assignment = Group(identifier + \"=\" + rvalue)\n        stmt << ( funcDef | assignment | identifier )\n\n        module_body = OneOrMore(stmt)\n\n        parseTree = module_body.parseString(data)\n        parseTree.pprint()\n    prints::\n        [['def',\n          'A',\n          ['(', 'z', ')'],\n          ':',\n          [['A1'], [['B', '=', '100']], [['G', '=', 'A2']""], ['A2'], ['A3']]],\n         'B',\n         ['def',\n          'BB',\n          ['(', 'a', 'b', 'c', ')'],\n          ':',\n          [['BB1'], [['def', 'BBA', ['(', ')'], ':', [['bba1'], ['bba2'], ['bba3']]]]]],\n         'C',\n         'D',\n         ['def',\n          'spam',\n          ['(', 'x', 'y', ')'],\n          ':',\n          [[['def', 'eggs', ['(', 'z', ')'], ':', [['pass']]]]]]]\n    ";
static PyMethodDef __pyx_mdef_10cPyparsing_69indentedBlock = {"indentedBlock", (PyCFunction)__pyx_pw_10cPyparsing_69indentedBlock, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_68indentedBlock};
static PyObject *__pyx_pw_10cPyparsing_69indentedBlock(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_blockStatementExpr = 0;
  PyObject *__pyx_v_indentStack = 0;
  PyObject *__pyx_v_indent = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("indentedBlock (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_blockStatementExpr,&__pyx_n_s_indentStack,&__pyx_n_s_indent,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)Py_True);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_blockStatementExpr)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_indentStack)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("indentedBlock", 0, 2, 3, 1); __PYX_ERR(0, 5341, __pyx_L3_error)
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_indent);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "indentedBlock") < 0)) __PYX_ERR(0, 5341, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_blockStatementExpr = values[0];
    __pyx_v_indentStack = values[1];
    __pyx_v_indent = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("indentedBlock", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 5341, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.indentedBlock", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_68indentedBlock(__pyx_self, __pyx_v_blockStatementExpr, __pyx_v_indentStack, __pyx_v_indent);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5419
 *           [[['def', 'eggs', ['(', 'z', ')'], ':', [['pass']]]]]]]
 *     """
 *     def checkPeerIndent(s, l, t):             # <<<<<<<<<<<<<<
 *         if l >= len(s):
 *             return
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13indentedBlock_1checkPeerIndent(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13indentedBlock_1checkPeerIndent = {"checkPeerIndent", (PyCFunction)__pyx_pw_10cPyparsing_13indentedBlock_1checkPeerIndent, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13indentedBlock_1checkPeerIndent(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_s = 0;
  PyObject *__pyx_v_l = 0;
  CYTHON_UNUSED PyObject *__pyx_v_t = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("checkPeerIndent (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("checkPeerIndent", 1, 3, 3, 1); __PYX_ERR(0, 5419, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("checkPeerIndent", 1, 3, 3, 2); __PYX_ERR(0, 5419, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "checkPeerIndent") < 0)) __PYX_ERR(0, 5419, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("checkPeerIndent", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 5419, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.indentedBlock.checkPeerIndent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13indentedBlock_checkPeerIndent(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13indentedBlock_checkPeerIndent(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, CYTHON_UNUSED PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock *__pyx_outer_scope;
  PyObject *__pyx_v_curCol = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("checkPeerIndent", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":5420
 *     """
 *     def checkPeerIndent(s, l, t):
 *         if l >= len(s):             # <<<<<<<<<<<<<<
 *             return
 *         curCol = col(l, s)
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_s); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 5420, __pyx_L1_error)
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5420, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_l, __pyx_t_2, Py_GE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5420, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 5420, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":5421
 *     def checkPeerIndent(s, l, t):
 *         if l >= len(s):
 *             return             # <<<<<<<<<<<<<<
 *         curCol = col(l, s)
 *         if curCol != indentStack[-1]:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "cPyparsing.pyx":5420
 *     """
 *     def checkPeerIndent(s, l, t):
 *         if l >= len(s):             # <<<<<<<<<<<<<<
 *             return
 *         curCol = col(l, s)
 */
  }

  /* "cPyparsing.pyx":5422
 *         if l >= len(s):
 *             return
 *         curCol = col(l, s)             # <<<<<<<<<<<<<<
 *         if curCol != indentStack[-1]:
 *             if curCol > indentStack[-1]:
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_col); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_l, __pyx_v_s};
    __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5422, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_l, __pyx_v_s};
    __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5422, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else
  #endif
  {
    __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5422, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__pyx_t_5) {
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
    }
    __Pyx_INCREF(__pyx_v_l);
    __Pyx_GIVEREF(__pyx_v_l);
    PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_l);
    __Pyx_INCREF(__pyx_v_s);
    __Pyx_GIVEREF(__pyx_v_s);
    PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_v_s);
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5422, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_curCol = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5423
 *             return
 *         curCol = col(l, s)
 *         if curCol != indentStack[-1]:             # <<<<<<<<<<<<<<
 *             if curCol > indentStack[-1]:
 *                 raise ParseFatalException(s, l, "illegal nesting")
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_indentStack)) { __Pyx_RaiseClosureNameError("indentStack"); __PYX_ERR(0, 5423, __pyx_L1_error) }
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_indentStack, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_curCol, __pyx_t_3, Py_NE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5423, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 5423, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":5424
 *         curCol = col(l, s)
 *         if curCol != indentStack[-1]:
 *             if curCol > indentStack[-1]:             # <<<<<<<<<<<<<<
 *                 raise ParseFatalException(s, l, "illegal nesting")
 *             raise ParseException(s, l, "not a peer entry")
 */
    if (unlikely(!__pyx_cur_scope->__pyx_v_indentStack)) { __Pyx_RaiseClosureNameError("indentStack"); __PYX_ERR(0, 5424, __pyx_L1_error) }
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_indentStack, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5424, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_curCol, __pyx_t_2, Py_GT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5424, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 5424, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_4) {

      /* "cPyparsing.pyx":5425
 *         if curCol != indentStack[-1]:
 *             if curCol > indentStack[-1]:
 *                 raise ParseFatalException(s, l, "illegal nesting")             # <<<<<<<<<<<<<<
 *             raise ParseException(s, l, "not a peer entry")
 * 
 */
      __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseFatalException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5425, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = NULL;
      __pyx_t_6 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_6 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_v_s, __pyx_v_l, __pyx_kp_u_illegal_nesting};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5425, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_v_s, __pyx_v_l, __pyx_kp_u_illegal_nesting};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5425, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      {
        __pyx_t_5 = PyTuple_New(3+__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5425, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        if (__pyx_t_7) {
          __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7); __pyx_t_7 = NULL;
        }
        __Pyx_INCREF(__pyx_v_s);
        __Pyx_GIVEREF(__pyx_v_s);
        PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_6, __pyx_v_s);
        __Pyx_INCREF(__pyx_v_l);
        __Pyx_GIVEREF(__pyx_v_l);
        PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_6, __pyx_v_l);
        __Pyx_INCREF(__pyx_kp_u_illegal_nesting);
        __Pyx_GIVEREF(__pyx_kp_u_illegal_nesting);
        PyTuple_SET_ITEM(__pyx_t_5, 2+__pyx_t_6, __pyx_kp_u_illegal_nesting);
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5425, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 5425, __pyx_L1_error)

      /* "cPyparsing.pyx":5424
 *         curCol = col(l, s)
 *         if curCol != indentStack[-1]:
 *             if curCol > indentStack[-1]:             # <<<<<<<<<<<<<<
 *                 raise ParseFatalException(s, l, "illegal nesting")
 *             raise ParseException(s, l, "not a peer entry")
 */
    }

    /* "cPyparsing.pyx":5426
 *             if curCol > indentStack[-1]:
 *                 raise ParseFatalException(s, l, "illegal nesting")
 *             raise ParseException(s, l, "not a peer entry")             # <<<<<<<<<<<<<<
 * 
 *     def checkSubIndent(s, l, t):
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5426, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_6 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_v_s, __pyx_v_l, __pyx_kp_u_not_a_peer_entry};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5426, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_v_s, __pyx_v_l, __pyx_kp_u_not_a_peer_entry};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5426, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(3+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5426, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__pyx_t_5) {
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
      }
      __Pyx_INCREF(__pyx_v_s);
      __Pyx_GIVEREF(__pyx_v_s);
      PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_s);
      __Pyx_INCREF(__pyx_v_l);
      __Pyx_GIVEREF(__pyx_v_l);
      PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_v_l);
      __Pyx_INCREF(__pyx_kp_u_not_a_peer_entry);
      __Pyx_GIVEREF(__pyx_kp_u_not_a_peer_entry);
      PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_6, __pyx_kp_u_not_a_peer_entry);
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5426, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 5426, __pyx_L1_error)

    /* "cPyparsing.pyx":5423
 *             return
 *         curCol = col(l, s)
 *         if curCol != indentStack[-1]:             # <<<<<<<<<<<<<<
 *             if curCol > indentStack[-1]:
 *                 raise ParseFatalException(s, l, "illegal nesting")
 */
  }

  /* "cPyparsing.pyx":5419
 *           [[['def', 'eggs', ['(', 'z', ')'], ':', [['pass']]]]]]]
 *     """
 *     def checkPeerIndent(s, l, t):             # <<<<<<<<<<<<<<
 *         if l >= len(s):
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.indentedBlock.checkPeerIndent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_curCol);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5428
 *             raise ParseException(s, l, "not a peer entry")
 * 
 *     def checkSubIndent(s, l, t):             # <<<<<<<<<<<<<<
 *         curCol = col(l, s)
 *         if curCol > indentStack[-1]:
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13indentedBlock_3checkSubIndent(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13indentedBlock_3checkSubIndent = {"checkSubIndent", (PyCFunction)__pyx_pw_10cPyparsing_13indentedBlock_3checkSubIndent, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13indentedBlock_3checkSubIndent(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_s = 0;
  PyObject *__pyx_v_l = 0;
  CYTHON_UNUSED PyObject *__pyx_v_t = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("checkSubIndent (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("checkSubIndent", 1, 3, 3, 1); __PYX_ERR(0, 5428, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("checkSubIndent", 1, 3, 3, 2); __PYX_ERR(0, 5428, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "checkSubIndent") < 0)) __PYX_ERR(0, 5428, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("checkSubIndent", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 5428, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.indentedBlock.checkSubIndent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13indentedBlock_2checkSubIndent(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13indentedBlock_2checkSubIndent(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, CYTHON_UNUSED PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock *__pyx_outer_scope;
  PyObject *__pyx_v_curCol = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("checkSubIndent", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":5429
 * 
 *     def checkSubIndent(s, l, t):
 *         curCol = col(l, s)             # <<<<<<<<<<<<<<
 *         if curCol > indentStack[-1]:
 *             indentStack.append(curCol)
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_col); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_l, __pyx_v_s};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5429, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_l, __pyx_v_s};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5429, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5429, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_l);
    __Pyx_GIVEREF(__pyx_v_l);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_l);
    __Pyx_INCREF(__pyx_v_s);
    __Pyx_GIVEREF(__pyx_v_s);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_s);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5429, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_curCol = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5430
 *     def checkSubIndent(s, l, t):
 *         curCol = col(l, s)
 *         if curCol > indentStack[-1]:             # <<<<<<<<<<<<<<
 *             indentStack.append(curCol)
 *         else:
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_indentStack)) { __Pyx_RaiseClosureNameError("indentStack"); __PYX_ERR(0, 5430, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_indentStack, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_curCol, __pyx_t_1, Py_GT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5430, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 5430, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_6) {

    /* "cPyparsing.pyx":5431
 *         curCol = col(l, s)
 *         if curCol > indentStack[-1]:
 *             indentStack.append(curCol)             # <<<<<<<<<<<<<<
 *         else:
 *             raise ParseException(s, l, "not a subentry")
 */
    if (unlikely(!__pyx_cur_scope->__pyx_v_indentStack)) { __Pyx_RaiseClosureNameError("indentStack"); __PYX_ERR(0, 5431, __pyx_L1_error) }
    __pyx_t_7 = __Pyx_PyObject_Append(__pyx_cur_scope->__pyx_v_indentStack, __pyx_v_curCol); if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 5431, __pyx_L1_error)

    /* "cPyparsing.pyx":5430
 *     def checkSubIndent(s, l, t):
 *         curCol = col(l, s)
 *         if curCol > indentStack[-1]:             # <<<<<<<<<<<<<<
 *             indentStack.append(curCol)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":5433
 *             indentStack.append(curCol)
 *         else:
 *             raise ParseException(s, l, "not a subentry")             # <<<<<<<<<<<<<<
 * 
 *     def checkUnindent(s, l, t):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5433, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = NULL;
    __pyx_t_4 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_v_s, __pyx_v_l, __pyx_kp_u_not_a_subentry};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_4, 3+__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5433, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_v_s, __pyx_v_l, __pyx_kp_u_not_a_subentry};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_4, 3+__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5433, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    {
      __pyx_t_3 = PyTuple_New(3+__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5433, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (__pyx_t_5) {
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5); __pyx_t_5 = NULL;
      }
      __Pyx_INCREF(__pyx_v_s);
      __Pyx_GIVEREF(__pyx_v_s);
      PyTuple_SET_ITEM(__pyx_t_3, 0+__pyx_t_4, __pyx_v_s);
      __Pyx_INCREF(__pyx_v_l);
      __Pyx_GIVEREF(__pyx_v_l);
      PyTuple_SET_ITEM(__pyx_t_3, 1+__pyx_t_4, __pyx_v_l);
      __Pyx_INCREF(__pyx_kp_u_not_a_subentry);
      __Pyx_GIVEREF(__pyx_kp_u_not_a_subentry);
      PyTuple_SET_ITEM(__pyx_t_3, 2+__pyx_t_4, __pyx_kp_u_not_a_subentry);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5433, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 5433, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":5428
 *             raise ParseException(s, l, "not a peer entry")
 * 
 *     def checkSubIndent(s, l, t):             # <<<<<<<<<<<<<<
 *         curCol = col(l, s)
 *         if curCol > indentStack[-1]:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.indentedBlock.checkSubIndent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_curCol);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5435
 *             raise ParseException(s, l, "not a subentry")
 * 
 *     def checkUnindent(s, l, t):             # <<<<<<<<<<<<<<
 *         if l >= len(s):
 *             return
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_13indentedBlock_5checkUnindent(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_13indentedBlock_5checkUnindent = {"checkUnindent", (PyCFunction)__pyx_pw_10cPyparsing_13indentedBlock_5checkUnindent, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_13indentedBlock_5checkUnindent(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_s = 0;
  PyObject *__pyx_v_l = 0;
  CYTHON_UNUSED PyObject *__pyx_v_t = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("checkUnindent (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("checkUnindent", 1, 3, 3, 1); __PYX_ERR(0, 5435, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("checkUnindent", 1, 3, 3, 2); __PYX_ERR(0, 5435, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "checkUnindent") < 0)) __PYX_ERR(0, 5435, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("checkUnindent", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 5435, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.indentedBlock.checkUnindent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_13indentedBlock_4checkUnindent(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_13indentedBlock_4checkUnindent(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, CYTHON_UNUSED PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock *__pyx_outer_scope;
  PyObject *__pyx_v_curCol = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  __Pyx_RefNannySetupContext("checkUnindent", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":5436
 * 
 *     def checkUnindent(s, l, t):
 *         if l >= len(s):             # <<<<<<<<<<<<<<
 *             return
 *         curCol = col(l, s)
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_s); if (unlikely(__pyx_t_1 == -1)) __PYX_ERR(0, 5436, __pyx_L1_error)
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_l, __pyx_t_2, Py_GE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5436, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 5436, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_4) {

    /* "cPyparsing.pyx":5437
 *     def checkUnindent(s, l, t):
 *         if l >= len(s):
 *             return             # <<<<<<<<<<<<<<
 *         curCol = col(l, s)
 *         if not(indentStack and curCol < indentStack[-1] and curCol <= indentStack[-2]):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "cPyparsing.pyx":5436
 * 
 *     def checkUnindent(s, l, t):
 *         if l >= len(s):             # <<<<<<<<<<<<<<
 *             return
 *         curCol = col(l, s)
 */
  }

  /* "cPyparsing.pyx":5438
 *         if l >= len(s):
 *             return
 *         curCol = col(l, s)             # <<<<<<<<<<<<<<
 *         if not(indentStack and curCol < indentStack[-1] and curCol <= indentStack[-2]):
 *             raise ParseException(s, l, "not an unindent")
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_col); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_l, __pyx_v_s};
    __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5438, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_l, __pyx_v_s};
    __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5438, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else
  #endif
  {
    __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5438, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__pyx_t_5) {
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
    }
    __Pyx_INCREF(__pyx_v_l);
    __Pyx_GIVEREF(__pyx_v_l);
    PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_l);
    __Pyx_INCREF(__pyx_v_s);
    __Pyx_GIVEREF(__pyx_v_s);
    PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_v_s);
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5438, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_curCol = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5439
 *             return
 *         curCol = col(l, s)
 *         if not(indentStack and curCol < indentStack[-1] and curCol <= indentStack[-2]):             # <<<<<<<<<<<<<<
 *             raise ParseException(s, l, "not an unindent")
 *         indentStack.pop()
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_indentStack)) { __Pyx_RaiseClosureNameError("indentStack"); __PYX_ERR(0, 5439, __pyx_L1_error) }
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_indentStack); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 5439, __pyx_L1_error)
  if (__pyx_t_8) {
  } else {
    __pyx_t_4 = __pyx_t_8;
    goto __pyx_L5_bool_binop_done;
  }
  if (unlikely(!__pyx_cur_scope->__pyx_v_indentStack)) { __Pyx_RaiseClosureNameError("indentStack"); __PYX_ERR(0, 5439, __pyx_L1_error) }
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_indentStack, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_curCol, __pyx_t_3, Py_LT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5439, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 5439, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_8) {
  } else {
    __pyx_t_4 = __pyx_t_8;
    goto __pyx_L5_bool_binop_done;
  }
  if (unlikely(!__pyx_cur_scope->__pyx_v_indentStack)) { __Pyx_RaiseClosureNameError("indentStack"); __PYX_ERR(0, 5439, __pyx_L1_error) }
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_indentStack, -2L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_curCol, __pyx_t_2, Py_LE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5439, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 5439, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_4 = __pyx_t_8;
  __pyx_L5_bool_binop_done:;
  __pyx_t_8 = ((!__pyx_t_4) != 0);
  if (__pyx_t_8) {

    /* "cPyparsing.pyx":5440
 *         curCol = col(l, s)
 *         if not(indentStack and curCol < indentStack[-1] and curCol <= indentStack[-2]):
 *             raise ParseException(s, l, "not an unindent")             # <<<<<<<<<<<<<<
 *         indentStack.pop()
 * 
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5440, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_6 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_v_s, __pyx_v_l, __pyx_kp_u_not_an_unindent};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5440, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_v_s, __pyx_v_l, __pyx_kp_u_not_an_unindent};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5440, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(3+__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5440, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__pyx_t_7) {
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7); __pyx_t_7 = NULL;
      }
      __Pyx_INCREF(__pyx_v_s);
      __Pyx_GIVEREF(__pyx_v_s);
      PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_6, __pyx_v_s);
      __Pyx_INCREF(__pyx_v_l);
      __Pyx_GIVEREF(__pyx_v_l);
      PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_6, __pyx_v_l);
      __Pyx_INCREF(__pyx_kp_u_not_an_unindent);
      __Pyx_GIVEREF(__pyx_kp_u_not_an_unindent);
      PyTuple_SET_ITEM(__pyx_t_5, 2+__pyx_t_6, __pyx_kp_u_not_an_unindent);
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5440, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 5440, __pyx_L1_error)

    /* "cPyparsing.pyx":5439
 *             return
 *         curCol = col(l, s)
 *         if not(indentStack and curCol < indentStack[-1] and curCol <= indentStack[-2]):             # <<<<<<<<<<<<<<
 *             raise ParseException(s, l, "not an unindent")
 *         indentStack.pop()
 */
  }

  /* "cPyparsing.pyx":5441
 *         if not(indentStack and curCol < indentStack[-1] and curCol <= indentStack[-2]):
 *             raise ParseException(s, l, "not an unindent")
 *         indentStack.pop()             # <<<<<<<<<<<<<<
 * 
 *     NL = OneOrMore(LineEnd().setWhitespaceChars("\t ").suppress())
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_indentStack)) { __Pyx_RaiseClosureNameError("indentStack"); __PYX_ERR(0, 5441, __pyx_L1_error) }
  __pyx_t_3 = __Pyx_PyObject_Pop(__pyx_cur_scope->__pyx_v_indentStack); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5441, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5435
 *             raise ParseException(s, l, "not a subentry")
 * 
 *     def checkUnindent(s, l, t):             # <<<<<<<<<<<<<<
 *         if l >= len(s):
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cPyparsing.indentedBlock.checkUnindent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_curCol);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5341
 * 
 * 
 * def indentedBlock(blockStatementExpr, indentStack, indent=True):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for defining space-delimited indentation blocks, such as
 */

static PyObject *__pyx_pf_10cPyparsing_68indentedBlock(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_blockStatementExpr, PyObject *__pyx_v_indentStack, PyObject *__pyx_v_indent) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock *__pyx_cur_scope;
  PyObject *__pyx_v_checkPeerIndent = 0;
  PyObject *__pyx_v_checkSubIndent = 0;
  PyObject *__pyx_v_checkUnindent = 0;
  PyObject *__pyx_v_NL = NULL;
  PyObject *__pyx_v_INDENT = NULL;
  PyObject *__pyx_v_PEER = NULL;
  PyObject *__pyx_v_UNDENT = NULL;
  PyObject *__pyx_v_smExpr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  __Pyx_RefNannySetupContext("indentedBlock", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_75_indentedBlock(__pyx_ptype_10cPyparsing___pyx_scope_struct_75_indentedBlock, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 5341, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_indentStack = __pyx_v_indentStack;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_indentStack);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_indentStack);

  /* "cPyparsing.pyx":5419
 *           [[['def', 'eggs', ['(', 'z', ')'], ':', [['pass']]]]]]]
 *     """
 *     def checkPeerIndent(s, l, t):             # <<<<<<<<<<<<<<
 *         if l >= len(s):
 *             return
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13indentedBlock_1checkPeerIndent, 0, __pyx_n_s_indentedBlock_locals_checkPeerIn, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__200)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_checkPeerIndent = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5428
 *             raise ParseException(s, l, "not a peer entry")
 * 
 *     def checkSubIndent(s, l, t):             # <<<<<<<<<<<<<<
 *         curCol = col(l, s)
 *         if curCol > indentStack[-1]:
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13indentedBlock_3checkSubIndent, 0, __pyx_n_s_indentedBlock_locals_checkSubInd, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__202)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5428, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_checkSubIndent = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5435
 *             raise ParseException(s, l, "not a subentry")
 * 
 *     def checkUnindent(s, l, t):             # <<<<<<<<<<<<<<
 *         if l >= len(s):
 *             return
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13indentedBlock_5checkUnindent, 0, __pyx_n_s_indentedBlock_locals_checkUninde, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__204)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_checkUnindent = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5443
 *         indentStack.pop()
 * 
 *     NL = OneOrMore(LineEnd().setWhitespaceChars("\t ").suppress())             # <<<<<<<<<<<<<<
 *     INDENT = (Empty() + Empty().setParseAction(checkSubIndent)).setName('INDENT')
 *     PEER = Empty().setParseAction(checkPeerIndent).setName('')
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_LineEnd); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (__pyx_t_6) {
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5443, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else {
    __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5443, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_setWhitespaceChars); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__206, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_suppress); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5443, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5443, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_5) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5443, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5443, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5443, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5443, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5); __pyx_t_5 = NULL;
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5443, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_NL = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5444
 * 
 *     NL = OneOrMore(LineEnd().setWhitespaceChars("\t ").suppress())
 *     INDENT = (Empty() + Empty().setParseAction(checkSubIndent)).setName('INDENT')             # <<<<<<<<<<<<<<
 *     PEER = Empty().setParseAction(checkPeerIndent).setName('')
 *     UNDENT = Empty().setParseAction(checkUnindent).setName('UNINDENT')
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Empty); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5444, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5444, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_Empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5444, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5444, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_checkSubIndent); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5444, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_checkSubIndent};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5444, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_checkSubIndent};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5444, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5444, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_INCREF(__pyx_v_checkSubIndent);
      __Pyx_GIVEREF(__pyx_v_checkSubIndent);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_checkSubIndent);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5444, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_setName); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__207, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_INDENT = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5445
 *     NL = OneOrMore(LineEnd().setWhitespaceChars("\t ").suppress())
 *     INDENT = (Empty() + Empty().setParseAction(checkSubIndent)).setName('INDENT')
 *     PEER = Empty().setParseAction(checkPeerIndent).setName('')             # <<<<<<<<<<<<<<
 *     UNDENT = Empty().setParseAction(checkUnindent).setName('UNINDENT')
 *     if indent:
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Empty); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5445, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5445, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_checkPeerIndent); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5445, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_checkPeerIndent};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5445, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_checkPeerIndent};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5445, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5445, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_checkPeerIndent);
      __Pyx_GIVEREF(__pyx_v_checkPeerIndent);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_checkPeerIndent);
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5445, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_setName); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__208, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_PEER = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5446
 *     INDENT = (Empty() + Empty().setParseAction(checkSubIndent)).setName('INDENT')
 *     PEER = Empty().setParseAction(checkPeerIndent).setName('')
 *     UNDENT = Empty().setParseAction(checkUnindent).setName('UNINDENT')             # <<<<<<<<<<<<<<
 *     if indent:
 *         smExpr = Group(Optional(NL) +
 */
  __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_Empty); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5446, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5446, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (!__pyx_t_1) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_checkUnindent); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5446, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_v_checkUnindent};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5446, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_v_checkUnindent};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5446, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else
    #endif
    {
      __pyx_t_2 = PyTuple_New(1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5446, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1); __pyx_t_1 = NULL;
      __Pyx_INCREF(__pyx_v_checkUnindent);
      __Pyx_GIVEREF(__pyx_v_checkUnindent);
      PyTuple_SET_ITEM(__pyx_t_2, 0+1, __pyx_v_checkUnindent);
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5446, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_setName); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__209, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_UNDENT = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5447
 *     PEER = Empty().setParseAction(checkPeerIndent).setName('')
 *     UNDENT = Empty().setParseAction(checkUnindent).setName('UNINDENT')
 *     if indent:             # <<<<<<<<<<<<<<
 *         smExpr = Group(Optional(NL) +
 *                        #~ FollowedBy(blockStatementExpr) +
 */
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_v_indent); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 5447, __pyx_L1_error)
  if (__pyx_t_7) {

    /* "cPyparsing.pyx":5448
 *     UNDENT = Empty().setParseAction(checkUnindent).setName('UNINDENT')
 *     if indent:
 *         smExpr = Group(Optional(NL) +             # <<<<<<<<<<<<<<
 *                        #~ FollowedBy(blockStatementExpr) +
 *                        INDENT + (OneOrMore(PEER + Group(blockStatementExpr) + Optional(NL))) + UNDENT)
 */
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5448, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5448, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_NL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5448, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_NL};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5448, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_NL};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5448, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5448, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_NL);
        __Pyx_GIVEREF(__pyx_v_NL);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_NL);
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5448, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5450
 *         smExpr = Group(Optional(NL) +
 *                        #~ FollowedBy(blockStatementExpr) +
 *                        INDENT + (OneOrMore(PEER + Group(blockStatementExpr) + Optional(NL))) + UNDENT)             # <<<<<<<<<<<<<<
 *     else:
 *         smExpr = Group(Optional(NL) +
 */
    __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_v_INDENT); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5448, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5450, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5450, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    if (!__pyx_t_9) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_v_blockStatementExpr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5450, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_v_blockStatementExpr};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5450, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_v_blockStatementExpr};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5450, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5450, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_9); __pyx_t_9 = NULL;
        __Pyx_INCREF(__pyx_v_blockStatementExpr);
        __Pyx_GIVEREF(__pyx_v_blockStatementExpr);
        PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_v_blockStatementExpr);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_10, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5450, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = PyNumber_Add(__pyx_v_PEER, __pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5450, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_10 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5450, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
      }
    }
    if (!__pyx_t_9) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_v_NL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5450, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_v_NL};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5450, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_v_NL};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5450, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 5450, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        __Pyx_INCREF(__pyx_v_NL);
        __Pyx_GIVEREF(__pyx_v_NL);
        PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_v_NL);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_11, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5450, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = PyNumber_Add(__pyx_t_8, __pyx_t_4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5450, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_10); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5450, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_10};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5450, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_10};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5450, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5450, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_GIVEREF(__pyx_t_10);
        PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_10);
        __pyx_t_10 = 0;
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_8, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5450, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5450, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Add(__pyx_t_6, __pyx_v_UNDENT); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5450, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5448, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_2};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5448, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_2};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5448, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else
      #endif
      {
        __pyx_t_1 = PyTuple_New(1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5448, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_GIVEREF(__pyx_t_2);
        PyTuple_SET_ITEM(__pyx_t_1, 0+1, __pyx_t_2);
        __pyx_t_2 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_1, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5448, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_smExpr = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "cPyparsing.pyx":5447
 *     PEER = Empty().setParseAction(checkPeerIndent).setName('')
 *     UNDENT = Empty().setParseAction(checkUnindent).setName('UNINDENT')
 *     if indent:             # <<<<<<<<<<<<<<
 *         smExpr = Group(Optional(NL) +
 *                        #~ FollowedBy(blockStatementExpr) +
 */
    goto __pyx_L3;
  }

  /* "cPyparsing.pyx":5452
 *                        INDENT + (OneOrMore(PEER + Group(blockStatementExpr) + Optional(NL))) + UNDENT)
 *     else:
 *         smExpr = Group(Optional(NL) +             # <<<<<<<<<<<<<<
 *                        (OneOrMore(PEER + Group(blockStatementExpr) + Optional(NL))))
 *     blockStatementExpr.ignore(_bslash + LineEnd())
 */
  /*else*/ {
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5452, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5452, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_NL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5452, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_NL};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5452, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_NL};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5452, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5452, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_v_NL);
        __Pyx_GIVEREF(__pyx_v_NL);
        PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_v_NL);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5452, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":5453
 *     else:
 *         smExpr = Group(Optional(NL) +
 *                        (OneOrMore(PEER + Group(blockStatementExpr) + Optional(NL))))             # <<<<<<<<<<<<<<
 *     blockStatementExpr.ignore(_bslash + LineEnd())
 *     return smExpr.setName('indented block')
 */
    __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5453, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_10 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5453, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_v_blockStatementExpr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5453, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_blockStatementExpr};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5453, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_blockStatementExpr};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5453, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 5453, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_blockStatementExpr);
        __Pyx_GIVEREF(__pyx_v_blockStatementExpr);
        PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_v_blockStatementExpr);
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5453, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = PyNumber_Add(__pyx_v_PEER, __pyx_t_6); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5453, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_11 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 5453, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_11))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_11);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_11, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_v_NL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5453, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_11)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_NL};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5453, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_11)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_NL};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5453, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5453, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_NL);
        __Pyx_GIVEREF(__pyx_v_NL);
        PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_v_NL);
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_9, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5453, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_11 = PyNumber_Add(__pyx_t_10, __pyx_t_6); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 5453, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_11); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5453, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_11};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5453, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_11};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5453, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5453, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_GIVEREF(__pyx_t_11);
        PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_11);
        __pyx_t_11 = 0;
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_10, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5453, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":5452
 *                        INDENT + (OneOrMore(PEER + Group(blockStatementExpr) + Optional(NL))) + UNDENT)
 *     else:
 *         smExpr = Group(Optional(NL) +             # <<<<<<<<<<<<<<
 *                        (OneOrMore(PEER + Group(blockStatementExpr) + Optional(NL))))
 *     blockStatementExpr.ignore(_bslash + LineEnd())
 */
    __pyx_t_8 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5452, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_2) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5452, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_8};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5452, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_8};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5452, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_1 = PyTuple_New(1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5452, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2); __pyx_t_2 = NULL;
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_1, 0+1, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_1, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5452, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_smExpr = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "cPyparsing.pyx":5454
 *         smExpr = Group(Optional(NL) +
 *                        (OneOrMore(PEER + Group(blockStatementExpr) + Optional(NL))))
 *     blockStatementExpr.ignore(_bslash + LineEnd())             # <<<<<<<<<<<<<<
 *     return smExpr.setName('indented block')
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_blockStatementExpr, __pyx_n_s_ignore); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_bslash); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_LineEnd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_10) {
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_10); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5454, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  } else {
    __pyx_t_8 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5454, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (!__pyx_t_8) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5454, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_2};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5454, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_2};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5454, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_1 = PyTuple_New(1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5454, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_8); __pyx_t_8 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_1, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_1, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5454, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cPyparsing.pyx":5455
 *                        (OneOrMore(PEER + Group(blockStatementExpr) + Optional(NL))))
 *     blockStatementExpr.ignore(_bslash + LineEnd())
 *     return smExpr.setName('indented block')             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_smExpr, __pyx_n_s_setName); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__210, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5341
 * 
 * 
 * def indentedBlock(blockStatementExpr, indentStack, indent=True):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for defining space-delimited indentation blocks, such as
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("cPyparsing.indentedBlock", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_checkPeerIndent);
  __Pyx_XDECREF(__pyx_v_checkSubIndent);
  __Pyx_XDECREF(__pyx_v_checkUnindent);
  __Pyx_XDECREF(__pyx_v_NL);
  __Pyx_XDECREF(__pyx_v_INDENT);
  __Pyx_XDECREF(__pyx_v_PEER);
  __Pyx_XDECREF(__pyx_v_UNDENT);
  __Pyx_XDECREF(__pyx_v_smExpr);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5466
 * 
 * 
 * def replaceHTMLEntity(t):             # <<<<<<<<<<<<<<
 *     """Helper parser action to replace common HTML entities with their special characters"""
 *     return _htmlEntityMap.get(t.entity)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_71replaceHTMLEntity(PyObject *__pyx_self, PyObject *__pyx_v_t); /*proto*/
static char __pyx_doc_10cPyparsing_70replaceHTMLEntity[] = "Helper parser action to replace common HTML entities with their special characters";
static PyMethodDef __pyx_mdef_10cPyparsing_71replaceHTMLEntity = {"replaceHTMLEntity", (PyCFunction)__pyx_pw_10cPyparsing_71replaceHTMLEntity, METH_O, __pyx_doc_10cPyparsing_70replaceHTMLEntity};
static PyObject *__pyx_pw_10cPyparsing_71replaceHTMLEntity(PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("replaceHTMLEntity (wrapper)", 0);
  __pyx_r = __pyx_pf_10cPyparsing_70replaceHTMLEntity(__pyx_self, ((PyObject *)__pyx_v_t));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_70replaceHTMLEntity(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("replaceHTMLEntity", 0);

  /* "cPyparsing.pyx":5468
 * def replaceHTMLEntity(t):
 *     """Helper parser action to replace common HTML entities with their special characters"""
 *     return _htmlEntityMap.get(t.entity)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_htmlEntityMap); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_get); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_entity); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5468, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5468, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5468, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5468, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5468, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5466
 * 
 * 
 * def replaceHTMLEntity(t):             # <<<<<<<<<<<<<<
 *     """Helper parser action to replace common HTML entities with their special characters"""
 *     return _htmlEntityMap.get(t.entity)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.replaceHTMLEntity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5658
 *     fraction = (signed_integer().setParseAction(convertToFloat) + '/' + signed_integer().setParseAction(convertToFloat)).setName("fraction")
 *     """fractional expression of an integer divided by an integer, returns a float"""
 *     fraction.addParseAction(lambda t: t[0] / t[-1])             # <<<<<<<<<<<<<<
 * 
 *     mixed_integer = (fraction | signed_integer + Optional(Optional('-').suppress() + fraction)).setName("fraction or mixed integer-fraction")
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_6lambda55(PyObject *__pyx_self, PyObject *__pyx_v_t); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_16pyparsing_common_6lambda55 = {"lambda55", (PyCFunction)__pyx_pw_10cPyparsing_16pyparsing_common_6lambda55, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_6lambda55(PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda55 (wrapper)", 0);
  __pyx_r = __pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda55(__pyx_self, ((PyObject *)__pyx_v_t));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda55(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("lambda55", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_t, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyNumber_Divide(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.lambda55", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5686
 *     _full_ipv6_address = (_ipv6_part + (':' + _ipv6_part) * 7).setName("full IPv6 address")
 *     _short_ipv6_address = (Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6)) + "::" + Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))).setName("short IPv6 address")
 *     _short_ipv6_address.addCondition(lambda t: sum(1 for tt in t if pyparsing_common._ipv6_part.matches(tt)) < 8)             # <<<<<<<<<<<<<<
 *     _mixed_ipv6_address = ("::ffff:" + ipv4_address).setName("mixed IPv6 address")
 *     ipv6_address = Combine((_full_ipv6_address | _mixed_ipv6_address | _short_ipv6_address).setName("IPv6 address")).setName("IPv6 address")
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_7lambda56(PyObject *__pyx_self, PyObject *__pyx_v_t); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_16pyparsing_common_7lambda56 = {"lambda56", (PyCFunction)__pyx_pw_10cPyparsing_16pyparsing_common_7lambda56, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_7lambda56(PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda56 (wrapper)", 0);
  __pyx_r = __pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56(__pyx_self, ((PyObject *)__pyx_v_t));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_10cPyparsing_16pyparsing_common_8lambda56_2generator35(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

static PyObject *__pyx_pf_10cPyparsing_16pyparsing_common_8lambda56_genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_77_genexpr(__pyx_ptype_10cPyparsing___pyx_scope_struct_77_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 5686, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56 *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_10cPyparsing_16pyparsing_common_8lambda56_2generator35, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_pyparsing_common_lambda_locals_g, __pyx_n_s_cPyparsing); if (unlikely(!gen)) __PYX_ERR(0, 5686, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.lambda56.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_10cPyparsing_16pyparsing_common_8lambda56_2generator35(__pyx_CoroutineObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr *__pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L7_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 5686, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_t)) { __Pyx_RaiseClosureNameError("t"); __PYX_ERR(0, 5686, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_t)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_t)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_outer_scope->__pyx_v_t; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_t); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5686, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5686, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 5686, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5686, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 5686, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5686, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5686, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_tt);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_tt, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_pyparsing_common); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5686, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_ipv6_part); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5686, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_matches); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5686, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_cur_scope->__pyx_v_tt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5686, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_tt};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5686, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_tt};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5686, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5686, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_tt);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_tt);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_cur_scope->__pyx_v_tt);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5686, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 5686, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_8) {
      __Pyx_INCREF(__pyx_int_1);
      __pyx_r = __pyx_int_1;
      __Pyx_XGIVEREF(__pyx_t_1);
      __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
      __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
      __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 1;
      return __pyx_r;
      __pyx_L7_resume_from_yield:;
      __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
      __pyx_cur_scope->__pyx_t_0 = 0;
      __Pyx_XGOTREF(__pyx_t_1);
      __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
      __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 5686, __pyx_L1_error)
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56 *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("lambda56", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56 *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56(__pyx_ptype_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56 *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 5686, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_t = __pyx_v_t;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_t);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_t);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_pf_10cPyparsing_16pyparsing_common_8lambda56_genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_sum, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_int_8, Py_LT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5686, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.lambda56", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5769
 *     """Predefined expression of 1 or more printable words or quoted strings, separated by commas."""
 * 
 *     upcaseTokens = staticmethod(tokenMap(lambda t: _ustr(t).upper()))             # <<<<<<<<<<<<<<
 *     """Parse action to convert tokens to upper case."""
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_8lambda58(PyObject *__pyx_self, PyObject *__pyx_v_t); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_16pyparsing_common_8lambda58 = {"lambda58", (PyCFunction)__pyx_pw_10cPyparsing_16pyparsing_common_8lambda58, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_8lambda58(PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda58 (wrapper)", 0);
  __pyx_r = __pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda58(__pyx_self, ((PyObject *)__pyx_v_t));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda58(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("lambda58", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_t); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5769, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_t};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5769, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_t};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5769, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5769, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_INCREF(__pyx_v_t);
      __Pyx_GIVEREF(__pyx_v_t);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_t);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5769, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_upper); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5769, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5769, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.lambda58", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5772
 *     """Parse action to convert tokens to upper case."""
 * 
 *     downcaseTokens = staticmethod(tokenMap(lambda t: _ustr(t).lower()))             # <<<<<<<<<<<<<<
 *     """Parse action to convert tokens to lower case."""
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_9lambda59(PyObject *__pyx_self, PyObject *__pyx_v_t); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_16pyparsing_common_9lambda59 = {"lambda59", (PyCFunction)__pyx_pw_10cPyparsing_16pyparsing_common_9lambda59, METH_O, 0};
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_9lambda59(PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda59 (wrapper)", 0);
  __pyx_r = __pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda59(__pyx_self, ((PyObject *)__pyx_v_t));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda59(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("lambda59", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ustr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5772, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_t); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5772, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_t};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5772, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_t};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5772, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5772, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_INCREF(__pyx_v_t);
      __Pyx_GIVEREF(__pyx_v_t);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_t);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5772, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_lower); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5772, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5772, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5772, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.lambda59", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5695
 * 
 *     @staticmethod
 *     def convertToDate(fmt="%Y-%m-%d"):             # <<<<<<<<<<<<<<
 *         """
 *         Helper to create a parse action for converting parsed date string to Python datetime.date
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_1convertToDate(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_16pyparsing_common_convertToDate[] = "\n        Helper to create a parse action for converting parsed date string to Python datetime.date\n\n        Params -\n         - fmt - format to be passed to datetime.strptime (default=C{\"%Y-%m-%d\"})\n\n        Example::\n            date_expr = pyparsing_common.iso8601_date.copy()\n            date_expr.setParseAction(pyparsing_common.convertToDate())\n            print(date_expr.parseString(\"1999-12-31\"))\n        prints::\n            [datetime.date(1999, 12, 31)]\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_16pyparsing_common_1convertToDate = {"convertToDate", (PyCFunction)__pyx_pw_10cPyparsing_16pyparsing_common_1convertToDate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_16pyparsing_common_convertToDate};
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_1convertToDate(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_fmt = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("convertToDate (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_fmt,0};
    PyObject* values[1] = {0};
    values[0] = ((PyObject *)((PyObject*)__pyx_kp_u_Y_m_d));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_fmt);
          if (value) { values[0] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "convertToDate") < 0)) __PYX_ERR(0, 5695, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_fmt = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("convertToDate", 0, 0, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 5695, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.convertToDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_16pyparsing_common_convertToDate(__pyx_self, __pyx_v_fmt);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5709
 *             [datetime.date(1999, 12, 31)]
 *         """
 *         def cvt_fn(s, l, t):             # <<<<<<<<<<<<<<
 *             try:
 *                 return datetime.strptime(t[0], fmt).date()
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_13convertToDate_1cvt_fn(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_16pyparsing_common_13convertToDate_1cvt_fn = {"cvt_fn", (PyCFunction)__pyx_pw_10cPyparsing_16pyparsing_common_13convertToDate_1cvt_fn, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_13convertToDate_1cvt_fn(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_s = 0;
  PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cvt_fn (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("cvt_fn", 1, 3, 3, 1); __PYX_ERR(0, 5709, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("cvt_fn", 1, 3, 3, 2); __PYX_ERR(0, 5709, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "cvt_fn") < 0)) __PYX_ERR(0, 5709, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("cvt_fn", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 5709, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.convertToDate.cvt_fn", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_16pyparsing_common_13convertToDate_cvt_fn(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_16pyparsing_common_13convertToDate_cvt_fn(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_convertToDate *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_convertToDate *__pyx_outer_scope;
  PyObject *__pyx_v_ve = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  char const *__pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  __Pyx_RefNannySetupContext("cvt_fn", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_convertToDate *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":5710
 *         """
 *         def cvt_fn(s, l, t):
 *             try:             # <<<<<<<<<<<<<<
 *                 return datetime.strptime(t[0], fmt).date()
 *             except ValueError as ve:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":5711
 *         def cvt_fn(s, l, t):
 *             try:
 *                 return datetime.strptime(t[0], fmt).date()             # <<<<<<<<<<<<<<
 *             except ValueError as ve:
 *                 raise ParseException(s, l, str(ve))
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_datetime); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5711, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_strptime); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5711, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5711, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (unlikely(!__pyx_cur_scope->__pyx_v_fmt)) { __Pyx_RaiseClosureNameError("fmt"); __PYX_ERR(0, 5711, __pyx_L3_error) }
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_t_6, __pyx_cur_scope->__pyx_v_fmt};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5711, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_t_6, __pyx_cur_scope->__pyx_v_fmt};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5711, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5711, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_8) {
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
        }
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_t_6);
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_fmt);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_fmt);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_cur_scope->__pyx_v_fmt);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5711, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_date); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5711, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      if (__pyx_t_5) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5711, __pyx_L3_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else {
        __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5711, __pyx_L3_error)
      }
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":5710
 *         """
 *         def cvt_fn(s, l, t):
 *             try:             # <<<<<<<<<<<<<<
 *                 return datetime.strptime(t[0], fmt).date()
 *             except ValueError as ve:
 */
    }
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":5712
 *             try:
 *                 return datetime.strptime(t[0], fmt).date()
 *             except ValueError as ve:             # <<<<<<<<<<<<<<
 *                 raise ParseException(s, l, str(ve))
 *         return cvt_fn
 */
    __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError);
    if (__pyx_t_9) {
      __Pyx_AddTraceback("cPyparsing.pyparsing_common.convertToDate.cvt_fn", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 5712, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_v_ve = __pyx_t_7;
      /*try:*/ {

        /* "cPyparsing.pyx":5713
 *                 return datetime.strptime(t[0], fmt).date()
 *             except ValueError as ve:
 *                 raise ParseException(s, l, str(ve))             # <<<<<<<<<<<<<<
 *         return cvt_fn
 * 
 */
        __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5713, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_11 = __Pyx_GetModuleGlobalName(__pyx_n_s_str); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 5713, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_12 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_11))) {
          __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
          if (likely(__pyx_t_12)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
            __Pyx_INCREF(__pyx_t_12);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_11, function);
          }
        }
        if (!__pyx_t_12) {
          __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_v_ve); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5713, __pyx_L16_error)
          __Pyx_GOTREF(__pyx_t_8);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_11)) {
            PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_v_ve};
            __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5713, __pyx_L16_error)
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_GOTREF(__pyx_t_8);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_11)) {
            PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_v_ve};
            __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5713, __pyx_L16_error)
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_GOTREF(__pyx_t_8);
          } else
          #endif
          {
            __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5713, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_12); __pyx_t_12 = NULL;
            __Pyx_INCREF(__pyx_v_ve);
            __Pyx_GIVEREF(__pyx_v_ve);
            PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_v_ve);
            __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5713, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_11 = NULL;
        __pyx_t_9 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_11)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_11);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
            __pyx_t_9 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[4] = {__pyx_t_11, __pyx_v_s, __pyx_v_l, __pyx_t_8};
          __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_9, 3+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5713, __pyx_L16_error)
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[4] = {__pyx_t_11, __pyx_v_s, __pyx_v_l, __pyx_t_8};
          __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_9, 3+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5713, __pyx_L16_error)
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        } else
        #endif
        {
          __pyx_t_13 = PyTuple_New(3+__pyx_t_9); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5713, __pyx_L16_error)
          __Pyx_GOTREF(__pyx_t_13);
          if (__pyx_t_11) {
            __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
          }
          __Pyx_INCREF(__pyx_v_s);
          __Pyx_GIVEREF(__pyx_v_s);
          PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_9, __pyx_v_s);
          __Pyx_INCREF(__pyx_v_l);
          __Pyx_GIVEREF(__pyx_v_l);
          PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_9, __pyx_v_l);
          __Pyx_GIVEREF(__pyx_t_8);
          PyTuple_SET_ITEM(__pyx_t_13, 2+__pyx_t_9, __pyx_t_8);
          __pyx_t_8 = 0;
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_13, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5713, __pyx_L16_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        }
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_Raise(__pyx_t_10, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __PYX_ERR(0, 5713, __pyx_L16_error)
      }

      /* "cPyparsing.pyx":5712
 *             try:
 *                 return datetime.strptime(t[0], fmt).date()
 *             except ValueError as ve:             # <<<<<<<<<<<<<<
 *                 raise ParseException(s, l, str(ve))
 *         return cvt_fn
 */
      /*finally:*/ {
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __pyx_L16_error:;
          __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
          __Pyx_PyThreadState_assign
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18) < 0)) __Pyx_ErrFetch(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __pyx_t_9 = __pyx_lineno; __pyx_t_14 = __pyx_clineno; __pyx_t_15 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_ve);
            __pyx_v_ve = NULL;
          }
          __Pyx_PyThreadState_assign
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
          }
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_ErrRestore(__pyx_t_16, __pyx_t_17, __pyx_t_18);
          __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
          __pyx_lineno = __pyx_t_9; __pyx_clineno = __pyx_t_14; __pyx_filename = __pyx_t_15;
          goto __pyx_L5_except_error;
        }
      }
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cPyparsing.pyx":5710
 *         """
 *         def cvt_fn(s, l, t):
 *             try:             # <<<<<<<<<<<<<<
 *                 return datetime.strptime(t[0], fmt).date()
 *             except ValueError as ve:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":5709
 *             [datetime.date(1999, 12, 31)]
 *         """
 *         def cvt_fn(s, l, t):             # <<<<<<<<<<<<<<
 *             try:
 *                 return datetime.strptime(t[0], fmt).date()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.convertToDate.cvt_fn", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ve);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5695
 * 
 *     @staticmethod
 *     def convertToDate(fmt="%Y-%m-%d"):             # <<<<<<<<<<<<<<
 *         """
 *         Helper to create a parse action for converting parsed date string to Python datetime.date
 */

static PyObject *__pyx_pf_10cPyparsing_16pyparsing_common_convertToDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_fmt) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_convertToDate *__pyx_cur_scope;
  PyObject *__pyx_v_cvt_fn = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("convertToDate", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_convertToDate *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_78_convertToDate(__pyx_ptype_10cPyparsing___pyx_scope_struct_78_convertToDate, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_convertToDate *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 5695, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_fmt = __pyx_v_fmt;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_fmt);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_fmt);

  /* "cPyparsing.pyx":5709
 *             [datetime.date(1999, 12, 31)]
 *         """
 *         def cvt_fn(s, l, t):             # <<<<<<<<<<<<<<
 *             try:
 *                 return datetime.strptime(t[0], fmt).date()
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_16pyparsing_common_13convertToDate_1cvt_fn, 0, __pyx_n_s_pyparsing_common_convertToDate_l, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__212)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cvt_fn = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5714
 *             except ValueError as ve:
 *                 raise ParseException(s, l, str(ve))
 *         return cvt_fn             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cvt_fn);
  __pyx_r = __pyx_v_cvt_fn;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5695
 * 
 *     @staticmethod
 *     def convertToDate(fmt="%Y-%m-%d"):             # <<<<<<<<<<<<<<
 *         """
 *         Helper to create a parse action for converting parsed date string to Python datetime.date
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.convertToDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cvt_fn);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5717
 * 
 *     @staticmethod
 *     def convertToDatetime(fmt="%Y-%m-%dT%H:%M:%S.%f"):             # <<<<<<<<<<<<<<
 *         """
 *         Helper to create a parse action for converting parsed datetime string to Python datetime.datetime
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_3convertToDatetime(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_16pyparsing_common_2convertToDatetime[] = "\n        Helper to create a parse action for converting parsed datetime string to Python datetime.datetime\n\n        Params -\n         - fmt - format to be passed to datetime.strptime (default=C{\"%Y-%m-%dT%H:%M:%S.%f\"})\n\n        Example::\n            dt_expr = pyparsing_common.iso8601_datetime.copy()\n            dt_expr.setParseAction(pyparsing_common.convertToDatetime())\n            print(dt_expr.parseString(\"1999-12-31T23:59:59.999\"))\n        prints::\n            [datetime.datetime(1999, 12, 31, 23, 59, 59, 999000)]\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_16pyparsing_common_3convertToDatetime = {"convertToDatetime", (PyCFunction)__pyx_pw_10cPyparsing_16pyparsing_common_3convertToDatetime, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_16pyparsing_common_2convertToDatetime};
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_3convertToDatetime(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_fmt = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("convertToDatetime (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_fmt,0};
    PyObject* values[1] = {0};
    values[0] = ((PyObject *)((PyObject*)__pyx_kp_u_Y_m_dT_H_M_S_f));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_fmt);
          if (value) { values[0] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "convertToDatetime") < 0)) __PYX_ERR(0, 5717, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_fmt = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("convertToDatetime", 0, 0, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 5717, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.convertToDatetime", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_16pyparsing_common_2convertToDatetime(__pyx_self, __pyx_v_fmt);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5731
 *             [datetime.datetime(1999, 12, 31, 23, 59, 59, 999000)]
 *         """
 *         def cvt_fn(s, l, t):             # <<<<<<<<<<<<<<
 *             try:
 *                 return datetime.strptime(t[0], fmt)
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_17convertToDatetime_1cvt_fn(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_10cPyparsing_16pyparsing_common_17convertToDatetime_1cvt_fn = {"cvt_fn", (PyCFunction)__pyx_pw_10cPyparsing_16pyparsing_common_17convertToDatetime_1cvt_fn, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_17convertToDatetime_1cvt_fn(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_s = 0;
  PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_t = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cvt_fn (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_t,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("cvt_fn", 1, 3, 3, 1); __PYX_ERR(0, 5731, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("cvt_fn", 1, 3, 3, 2); __PYX_ERR(0, 5731, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "cvt_fn") < 0)) __PYX_ERR(0, 5731, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_t = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("cvt_fn", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 5731, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.convertToDatetime.cvt_fn", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_16pyparsing_common_17convertToDatetime_cvt_fn(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_t);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_16pyparsing_common_17convertToDatetime_cvt_fn(PyObject *__pyx_self, PyObject *__pyx_v_s, PyObject *__pyx_v_l, PyObject *__pyx_v_t) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_convertToDatetime *__pyx_cur_scope;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_convertToDatetime *__pyx_outer_scope;
  PyObject *__pyx_v_ve = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  char const *__pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  __Pyx_RefNannySetupContext("cvt_fn", 0);
  __pyx_outer_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_convertToDatetime *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cPyparsing.pyx":5732
 *         """
 *         def cvt_fn(s, l, t):
 *             try:             # <<<<<<<<<<<<<<
 *                 return datetime.strptime(t[0], fmt)
 *             except ValueError as ve:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":5733
 *         def cvt_fn(s, l, t):
 *             try:
 *                 return datetime.strptime(t[0], fmt)             # <<<<<<<<<<<<<<
 *             except ValueError as ve:
 *                 raise ParseException(s, l, str(ve))
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_datetime); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5733, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strptime); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5733, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5733, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (unlikely(!__pyx_cur_scope->__pyx_v_fmt)) { __Pyx_RaiseClosureNameError("fmt"); __PYX_ERR(0, 5733, __pyx_L3_error) }
      __pyx_t_7 = NULL;
      __pyx_t_8 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_8 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_t_5, __pyx_cur_scope->__pyx_v_fmt};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5733, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_t_5, __pyx_cur_scope->__pyx_v_fmt};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5733, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(2+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5733, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_9);
        if (__pyx_t_7) {
          __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
        }
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_t_5);
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_fmt);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_fmt);
        PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, __pyx_cur_scope->__pyx_v_fmt);
        __pyx_t_5 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_9, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5733, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "cPyparsing.pyx":5732
 *         """
 *         def cvt_fn(s, l, t):
 *             try:             # <<<<<<<<<<<<<<
 *                 return datetime.strptime(t[0], fmt)
 *             except ValueError as ve:
 */
    }
    __pyx_L3_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "cPyparsing.pyx":5734
 *             try:
 *                 return datetime.strptime(t[0], fmt)
 *             except ValueError as ve:             # <<<<<<<<<<<<<<
 *                 raise ParseException(s, l, str(ve))
 *         return cvt_fn
 */
    __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError);
    if (__pyx_t_8) {
      __Pyx_AddTraceback("cPyparsing.pyparsing_common.convertToDatetime.cvt_fn", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_9) < 0) __PYX_ERR(0, 5734, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_6);
      __pyx_v_ve = __pyx_t_6;
      /*try:*/ {

        /* "cPyparsing.pyx":5735
 *                 return datetime.strptime(t[0], fmt)
 *             except ValueError as ve:
 *                 raise ParseException(s, l, str(ve))             # <<<<<<<<<<<<<<
 *         return cvt_fn
 * 
 */
        __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseException); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5735, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_11 = __Pyx_GetModuleGlobalName(__pyx_n_s_str); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 5735, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_12 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_11))) {
          __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
          if (likely(__pyx_t_12)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
            __Pyx_INCREF(__pyx_t_12);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_11, function);
          }
        }
        if (!__pyx_t_12) {
          __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_v_ve); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5735, __pyx_L16_error)
          __Pyx_GOTREF(__pyx_t_10);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_11)) {
            PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_v_ve};
            __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5735, __pyx_L16_error)
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_GOTREF(__pyx_t_10);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_11)) {
            PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_v_ve};
            __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5735, __pyx_L16_error)
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_GOTREF(__pyx_t_10);
          } else
          #endif
          {
            __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5735, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_12); __pyx_t_12 = NULL;
            __Pyx_INCREF(__pyx_v_ve);
            __Pyx_GIVEREF(__pyx_v_ve);
            PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_v_ve);
            __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_13, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5735, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_11 = NULL;
        __pyx_t_8 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_11)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_11);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
            __pyx_t_8 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_7)) {
          PyObject *__pyx_temp[4] = {__pyx_t_11, __pyx_v_s, __pyx_v_l, __pyx_t_10};
          __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_8, 3+__pyx_t_8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5735, __pyx_L16_error)
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
          PyObject *__pyx_temp[4] = {__pyx_t_11, __pyx_v_s, __pyx_v_l, __pyx_t_10};
          __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_8, 3+__pyx_t_8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5735, __pyx_L16_error)
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        } else
        #endif
        {
          __pyx_t_13 = PyTuple_New(3+__pyx_t_8); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5735, __pyx_L16_error)
          __Pyx_GOTREF(__pyx_t_13);
          if (__pyx_t_11) {
            __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
          }
          __Pyx_INCREF(__pyx_v_s);
          __Pyx_GIVEREF(__pyx_v_s);
          PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_8, __pyx_v_s);
          __Pyx_INCREF(__pyx_v_l);
          __Pyx_GIVEREF(__pyx_v_l);
          PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_8, __pyx_v_l);
          __Pyx_GIVEREF(__pyx_t_10);
          PyTuple_SET_ITEM(__pyx_t_13, 2+__pyx_t_8, __pyx_t_10);
          __pyx_t_10 = 0;
          __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_13, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5735, __pyx_L16_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_Raise(__pyx_t_5, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __PYX_ERR(0, 5735, __pyx_L16_error)
      }

      /* "cPyparsing.pyx":5734
 *             try:
 *                 return datetime.strptime(t[0], fmt)
 *             except ValueError as ve:             # <<<<<<<<<<<<<<
 *                 raise ParseException(s, l, str(ve))
 *         return cvt_fn
 */
      /*finally:*/ {
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __pyx_L16_error:;
          __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
          __Pyx_PyThreadState_assign
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18) < 0)) __Pyx_ErrFetch(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __pyx_t_8 = __pyx_lineno; __pyx_t_14 = __pyx_clineno; __pyx_t_15 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_ve);
            __pyx_v_ve = NULL;
          }
          __Pyx_PyThreadState_assign
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
          }
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_ErrRestore(__pyx_t_16, __pyx_t_17, __pyx_t_18);
          __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
          __pyx_lineno = __pyx_t_8; __pyx_clineno = __pyx_t_14; __pyx_filename = __pyx_t_15;
          goto __pyx_L5_except_error;
        }
      }
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "cPyparsing.pyx":5732
 *         """
 *         def cvt_fn(s, l, t):
 *             try:             # <<<<<<<<<<<<<<
 *                 return datetime.strptime(t[0], fmt)
 *             except ValueError as ve:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "cPyparsing.pyx":5731
 *             [datetime.datetime(1999, 12, 31, 23, 59, 59, 999000)]
 *         """
 *         def cvt_fn(s, l, t):             # <<<<<<<<<<<<<<
 *             try:
 *                 return datetime.strptime(t[0], fmt)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.convertToDatetime.cvt_fn", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ve);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5717
 * 
 *     @staticmethod
 *     def convertToDatetime(fmt="%Y-%m-%dT%H:%M:%S.%f"):             # <<<<<<<<<<<<<<
 *         """
 *         Helper to create a parse action for converting parsed datetime string to Python datetime.datetime
 */

static PyObject *__pyx_pf_10cPyparsing_16pyparsing_common_2convertToDatetime(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_fmt) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_convertToDatetime *__pyx_cur_scope;
  PyObject *__pyx_v_cvt_fn = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("convertToDatetime", 0);
  __pyx_cur_scope = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_convertToDatetime *)__pyx_tp_new_10cPyparsing___pyx_scope_struct_79_convertToDatetime(__pyx_ptype_10cPyparsing___pyx_scope_struct_79_convertToDatetime, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_convertToDatetime *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 5717, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_fmt = __pyx_v_fmt;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_fmt);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_fmt);

  /* "cPyparsing.pyx":5731
 *             [datetime.datetime(1999, 12, 31, 23, 59, 59, 999000)]
 *         """
 *         def cvt_fn(s, l, t):             # <<<<<<<<<<<<<<
 *             try:
 *                 return datetime.strptime(t[0], fmt)
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_16pyparsing_common_17convertToDatetime_1cvt_fn, 0, __pyx_n_s_pyparsing_common_convertToDateti, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__214)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cvt_fn = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5736
 *             except ValueError as ve:
 *                 raise ParseException(s, l, str(ve))
 *         return cvt_fn             # <<<<<<<<<<<<<<
 * 
 *     iso8601_date = Regex(r'(?P<year>\d{4})(?:-(?P<month>\d\d)(?:-(?P<day>\d\d))?)?').setName("ISO8601 date")
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cvt_fn);
  __pyx_r = __pyx_v_cvt_fn;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5717
 * 
 *     @staticmethod
 *     def convertToDatetime(fmt="%Y-%m-%dT%H:%M:%S.%f"):             # <<<<<<<<<<<<<<
 *         """
 *         Helper to create a parse action for converting parsed datetime string to Python datetime.datetime
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.convertToDatetime", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cvt_fn);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cPyparsing.pyx":5750
 * 
 *     @staticmethod
 *     def stripHTMLTags(s, l, tokens):             # <<<<<<<<<<<<<<
 *         """
 *         Parse action to remove HTML tags from web page HTML source
 */

/* Python wrapper */
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_5stripHTMLTags(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_10cPyparsing_16pyparsing_common_4stripHTMLTags[] = "\n        Parse action to remove HTML tags from web page HTML source\n\n        Example::\n            # strip HTML links from normal text\n            text = '<td>More info at the <a href=\"http://pyparsing.wikispaces.com\">pyparsing</a> wiki page</td>'\n            td,td_end = makeHTMLTags(\"TD\")\n            table_text = td + SkipTo(td_end).setParseAction(pyparsing_common.stripHTMLTags)(\"body\") + td_end\n\n            print(table_text.parseString(text).body) # -> 'More info at the pyparsing wiki page'\n        ";
static PyMethodDef __pyx_mdef_10cPyparsing_16pyparsing_common_5stripHTMLTags = {"stripHTMLTags", (PyCFunction)__pyx_pw_10cPyparsing_16pyparsing_common_5stripHTMLTags, METH_VARARGS|METH_KEYWORDS, __pyx_doc_10cPyparsing_16pyparsing_common_4stripHTMLTags};
static PyObject *__pyx_pw_10cPyparsing_16pyparsing_common_5stripHTMLTags(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_tokens = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stripHTMLTags (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,&__pyx_n_s_l,&__pyx_n_s_tokens,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_s)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_l)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("stripHTMLTags", 1, 3, 3, 1); __PYX_ERR(0, 5750, __pyx_L3_error)
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_tokens)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("stripHTMLTags", 1, 3, 3, 2); __PYX_ERR(0, 5750, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "stripHTMLTags") < 0)) __PYX_ERR(0, 5750, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_s = values[0];
    __pyx_v_l = values[1];
    __pyx_v_tokens = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("stripHTMLTags", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 5750, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.stripHTMLTags", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_10cPyparsing_16pyparsing_common_4stripHTMLTags(__pyx_self, __pyx_v_s, __pyx_v_l, __pyx_v_tokens);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_10cPyparsing_16pyparsing_common_4stripHTMLTags(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_s, CYTHON_UNUSED PyObject *__pyx_v_l, PyObject *__pyx_v_tokens) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("stripHTMLTags", 0);

  /* "cPyparsing.pyx":5762
 *             print(table_text.parseString(text).body) # -> 'More info at the pyparsing wiki page'
 *         """
 *         return pyparsing_common._html_stripper.transformString(tokens[0])             # <<<<<<<<<<<<<<
 * 
 *     _commasepitem = Combine(OneOrMore(~Literal(",") + ~LineEnd() + Word(printables, excludeChars=',')
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_pyparsing_common); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_html_stripper); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_transformString); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_tokens, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5762, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5762, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5762, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5762, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5762, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cPyparsing.pyx":5750
 * 
 *     @staticmethod
 *     def stripHTMLTags(s, l, tokens):             # <<<<<<<<<<<<<<
 *         """
 *         Parse action to remove HTML tags from web page HTML source
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cPyparsing.pyparsing_common.stripHTMLTags", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct__genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct__genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct__genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct__genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct__genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct__genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct__genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_y);
  Py_CLEAR(p->__pyx_t_0);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct__genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct__genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct__genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct__genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr *)o;
  if (p->__pyx_v_y) {
    e = (*v)(p->__pyx_v_y, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct__genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr *)o;
  tmp = ((PyObject*)p->__pyx_v_y);
  p->__pyx_v_y = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_t_0);
  p->__pyx_t_0 = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct__genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct__genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct__genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct__genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct__genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct__genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct__genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_1_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_1_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_1_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_1_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_1_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_1_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_1_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_s);
  Py_CLEAR(p->__pyx_t_0);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_1_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_1_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_1_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_1_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr *)o;
  if (p->__pyx_v_s) {
    e = (*v)(p->__pyx_v_s, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_1_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_v_s);
  p->__pyx_v_s = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_t_0);
  p->__pyx_t_0 = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_1_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_1_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_1_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_1_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_1_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_1_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_1_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_2_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_2_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_2_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_2_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_2_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_2_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_2_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_c);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_2_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_2_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_2_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_2_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr *)o;
  if (p->__pyx_v_c) {
    e = (*v)(p->__pyx_v_c, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_2_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_v_c);
  p->__pyx_v_c = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_2_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_2_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_2_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_2_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_2_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_2_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_2_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_3__itervalues *__pyx_freelist_10cPyparsing___pyx_scope_struct_3__itervalues[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_3__itervalues = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_3__itervalues(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_3__itervalues > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_3__itervalues)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_3__itervalues[--__pyx_freecount_10cPyparsing___pyx_scope_struct_3__itervalues];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_3__itervalues));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_3__itervalues(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_3__itervalues *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_3__itervalues *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_3__itervalues < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_3__itervalues)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_3__itervalues[__pyx_freecount_10cPyparsing___pyx_scope_struct_3__itervalues++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_3__itervalues *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_3__itervalues(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_3__itervalues *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_3__itervalues *)o;
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_3__itervalues(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_3__itervalues *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_3__itervalues *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_3__itervalues = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_3__itervalues", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_3__itervalues), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_3__itervalues, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_3__itervalues, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_3__itervalues, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_3__itervalues, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_4_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_4_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_4_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_4_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_4_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_4_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_4_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_k);
  Py_CLEAR(p->__pyx_t_0);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_4_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_4_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_4_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_4_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_k) {
    e = (*v)(p->__pyx_v_k, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_4_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_3__itervalues *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_k);
  p->__pyx_v_k = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_t_0);
  p->__pyx_t_0 = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_4_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_4_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_4_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_4_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_4_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_4_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_4_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__iteritems *__pyx_freelist_10cPyparsing___pyx_scope_struct_5__iteritems[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_5__iteritems = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_5__iteritems(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_5__iteritems > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__iteritems)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_5__iteritems[--__pyx_freecount_10cPyparsing___pyx_scope_struct_5__iteritems];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__iteritems));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_5__iteritems(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__iteritems *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__iteritems *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_5__iteritems < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__iteritems)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_5__iteritems[__pyx_freecount_10cPyparsing___pyx_scope_struct_5__iteritems++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__iteritems *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_5__iteritems(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__iteritems *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__iteritems *)o;
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_5__iteritems(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__iteritems *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__iteritems *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_5__iteritems = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_5__iteritems", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__iteritems), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_5__iteritems, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_5__iteritems, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_5__iteritems, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_5__iteritems, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_6_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_6_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_6_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_6_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_6_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_6_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_6_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_k);
  Py_CLEAR(p->__pyx_t_0);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_6_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_6_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_6_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_6_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_k) {
    e = (*v)(p->__pyx_v_k, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_6_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_5__iteritems *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_k);
  p->__pyx_v_k = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_t_0);
  p->__pyx_t_0 = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_6_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_6_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_6_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_6_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_6_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_6_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_6_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_7___iadd__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_7___iadd__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_7___iadd__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_7___iadd__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_7___iadd__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_7___iadd__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_7___iadd__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_7___iadd__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_7___iadd__));
    (void) PyObject_INIT(o, t);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_7___iadd__(PyObject *o) {
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_7___iadd__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_7___iadd__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_7___iadd__[__pyx_freecount_10cPyparsing___pyx_scope_struct_7___iadd__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_7___iadd__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_7___iadd__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_7___iadd__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_7___iadd__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_7___iadd__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_7___iadd__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_8___str__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_8___str__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_8___str__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_8___str__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_8___str__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_8___str__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_8___str__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_8___str__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_8___str__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_8___str__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_8___str__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_8___str__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_8___str__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_8___str__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_8___str__[__pyx_freecount_10cPyparsing___pyx_scope_struct_8___str__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_8___str__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_8___str__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_8___str__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_8___str__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_8___str__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_8___str__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_8___str__ *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_8___str__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_8___str__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_8___str__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_8___str__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_8___str__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_8___str__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_8___str__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_9_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_9_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_9_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_9_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_9_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_9_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_9_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_9_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_9_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_9_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_9_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_9_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_i);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_9_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_9_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_9_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_9_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_9_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_9_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_9_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_9_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_i) {
    e = (*v)(p->__pyx_v_i, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_9_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_9_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_9_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_8___str__ *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_i);
  p->__pyx_v_i = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_9_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_9_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_9_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_9_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_9_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_9_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_9_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_asDict *__pyx_freelist_10cPyparsing___pyx_scope_struct_10_asDict[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_10_asDict = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_10_asDict(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_10_asDict > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_asDict)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_10_asDict[--__pyx_freecount_10cPyparsing___pyx_scope_struct_10_asDict];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_asDict));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_10_asDict(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_asDict *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_asDict *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_item_fn);
  Py_CLEAR(p->__pyx_v_toItem);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_10_asDict < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_asDict)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_10_asDict[__pyx_freecount_10cPyparsing___pyx_scope_struct_10_asDict++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_asDict *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_10_asDict(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_asDict *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_asDict *)o;
  if (p->__pyx_v_item_fn) {
    e = (*v)(p->__pyx_v_item_fn, a); if (e) return e;
  }
  if (p->__pyx_v_toItem) {
    e = (*v)(p->__pyx_v_toItem, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_10_asDict(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_asDict *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_asDict *)o;
  tmp = ((PyObject*)p->__pyx_v_item_fn);
  p->__pyx_v_item_fn = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_toItem);
  p->__pyx_v_toItem = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_10_asDict = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_10_asDict", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_asDict), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_10_asDict, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_10_asDict, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_10_asDict, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_10_asDict, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_11_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_11_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_11_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_11_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_11_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_11_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_11_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_k);
  Py_CLEAR(p->__pyx_v_v);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_11_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_11_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_11_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_11_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_k) {
    e = (*v)(p->__pyx_v_k, a); if (e) return e;
  }
  if (p->__pyx_v_v) {
    e = (*v)(p->__pyx_v_v, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_11_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_10_asDict *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_k);
  p->__pyx_v_k = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_v);
  p->__pyx_v_v = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_11_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_11_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_11_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_11_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_11_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_11_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_11_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_asXML *__pyx_freelist_10cPyparsing___pyx_scope_struct_12_asXML[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_12_asXML = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_12_asXML(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_12_asXML > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_asXML)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_12_asXML[--__pyx_freecount_10cPyparsing___pyx_scope_struct_12_asXML];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_asXML));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_12_asXML(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_asXML *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_asXML *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_12_asXML < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_asXML)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_12_asXML[__pyx_freecount_10cPyparsing___pyx_scope_struct_12_asXML++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_asXML *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_12_asXML(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_asXML *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_asXML *)o;
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_12_asXML(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_asXML *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_asXML *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_12_asXML = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_12_asXML", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_asXML), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_12_asXML, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_12_asXML, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_12_asXML, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_12_asXML, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_13_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_13_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_13_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_13_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_13_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_13_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_13_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_k);
  Py_CLEAR(p->__pyx_v_v);
  Py_CLEAR(p->__pyx_v_vlist);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_13_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_13_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_13_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_13_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_k) {
    e = (*v)(p->__pyx_v_k, a); if (e) return e;
  }
  if (p->__pyx_v_v) {
    e = (*v)(p->__pyx_v_v, a); if (e) return e;
  }
  if (p->__pyx_v_vlist) {
    e = (*v)(p->__pyx_v_vlist, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_13_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_12_asXML *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_k);
  p->__pyx_v_k = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_v);
  p->__pyx_v_v = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_vlist);
  p->__pyx_v_vlist = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_13_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_13_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_13_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_13_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_13_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_13_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_13_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_dump *__pyx_freelist_10cPyparsing___pyx_scope_struct_14_dump[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_14_dump = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_14_dump(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_14_dump > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_dump)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_14_dump[--__pyx_freecount_10cPyparsing___pyx_scope_struct_14_dump];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_dump));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_14_dump(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_dump *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_dump *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_14_dump < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_dump)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_14_dump[__pyx_freecount_10cPyparsing___pyx_scope_struct_14_dump++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_dump *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_14_dump(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_dump *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_dump *)o;
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_14_dump(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_dump *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_dump *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_14_dump = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_14_dump", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_dump), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_14_dump, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_14_dump, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_14_dump, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_14_dump, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_15_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_15_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_15_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_15_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_15_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_15_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_15_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_k);
  Py_CLEAR(p->__pyx_v_v);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_15_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_15_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_15_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_15_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_k) {
    e = (*v)(p->__pyx_v_k, a); if (e) return e;
  }
  if (p->__pyx_v_v) {
    e = (*v)(p->__pyx_v_v, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_15_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_dump *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_k);
  p->__pyx_v_k = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_v);
  p->__pyx_v_v = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_15_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_15_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_15_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_15_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_15_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_15_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_15_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_16_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_16_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_16_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_16_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_16_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_16_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_16_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_16_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_16_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_16_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_16_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_16_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_vv);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_16_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_16_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_16_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_16_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_16_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_16_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_16_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_16_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_vv) {
    e = (*v)(p->__pyx_v_vv, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_16_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_16_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_16_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_14_dump *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_vv);
  p->__pyx_v_vv = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_16_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_16_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_16_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_16_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_16_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_16_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_16_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_17__trim_arity *__pyx_freelist_10cPyparsing___pyx_scope_struct_17__trim_arity[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_17__trim_arity = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_17__trim_arity(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_17__trim_arity > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_17__trim_arity)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_17__trim_arity[--__pyx_freecount_10cPyparsing___pyx_scope_struct_17__trim_arity];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_17__trim_arity));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_17__trim_arity(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_17__trim_arity *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_17__trim_arity *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_extract_tb);
  Py_CLEAR(p->__pyx_v_func);
  Py_CLEAR(p->__pyx_v_limit);
  Py_CLEAR(p->__pyx_v_maxargs);
  Py_CLEAR(p->__pyx_v_tb_info_synth);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_17__trim_arity < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_17__trim_arity)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_17__trim_arity[__pyx_freecount_10cPyparsing___pyx_scope_struct_17__trim_arity++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_17__trim_arity *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_17__trim_arity(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_17__trim_arity *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_17__trim_arity *)o;
  if (p->__pyx_v_extract_tb) {
    e = (*v)(p->__pyx_v_extract_tb, a); if (e) return e;
  }
  if (p->__pyx_v_func) {
    e = (*v)(p->__pyx_v_func, a); if (e) return e;
  }
  if (p->__pyx_v_limit) {
    e = (*v)(p->__pyx_v_limit, a); if (e) return e;
  }
  if (p->__pyx_v_maxargs) {
    e = (*v)(p->__pyx_v_maxargs, a); if (e) return e;
  }
  if (p->__pyx_v_tb_info_synth) {
    e = (*v)(p->__pyx_v_tb_info_synth, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_17__trim_arity(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_17__trim_arity *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_17__trim_arity *)o;
  tmp = ((PyObject*)p->__pyx_v_extract_tb);
  p->__pyx_v_extract_tb = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_func);
  p->__pyx_v_func = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_limit);
  p->__pyx_v_limit = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_maxargs);
  p->__pyx_v_maxargs = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_tb_info_synth);
  p->__pyx_v_tb_info_synth = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_17__trim_arity = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_17__trim_arity", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_17__trim_arity), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_17__trim_arity, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_17__trim_arity, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_17__trim_arity, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_17__trim_arity, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_setBreak *__pyx_freelist_10cPyparsing___pyx_scope_struct_18_setBreak[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_18_setBreak = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_18_setBreak(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_18_setBreak > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_setBreak)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_18_setBreak[--__pyx_freecount_10cPyparsing___pyx_scope_struct_18_setBreak];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_setBreak));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_18_setBreak(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_setBreak *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_setBreak *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v__parseMethod);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_18_setBreak < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_setBreak)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_18_setBreak[__pyx_freecount_10cPyparsing___pyx_scope_struct_18_setBreak++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_setBreak *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_18_setBreak(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_setBreak *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_setBreak *)o;
  if (p->__pyx_v__parseMethod) {
    e = (*v)(p->__pyx_v__parseMethod, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_18_setBreak(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_setBreak *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_setBreak *)o;
  tmp = ((PyObject*)p->__pyx_v__parseMethod);
  p->__pyx_v__parseMethod = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_18_setBreak = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_18_setBreak", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_18_setBreak), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_18_setBreak, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_18_setBreak, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_18_setBreak, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_18_setBreak, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_addCondition *__pyx_freelist_10cPyparsing___pyx_scope_struct_19_addCondition[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_19_addCondition = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_19_addCondition(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_19_addCondition > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_addCondition)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_19_addCondition[--__pyx_freecount_10cPyparsing___pyx_scope_struct_19_addCondition];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_addCondition));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_19_addCondition(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_addCondition *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_addCondition *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_exc_type);
  Py_CLEAR(p->__pyx_v_fn);
  Py_CLEAR(p->__pyx_v_msg);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_19_addCondition < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_addCondition)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_19_addCondition[__pyx_freecount_10cPyparsing___pyx_scope_struct_19_addCondition++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_addCondition *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_19_addCondition(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_addCondition *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_addCondition *)o;
  if (p->__pyx_v_exc_type) {
    e = (*v)(p->__pyx_v_exc_type, a); if (e) return e;
  }
  if (p->__pyx_v_fn) {
    e = (*v)(p->__pyx_v_fn, a); if (e) return e;
  }
  if (p->__pyx_v_msg) {
    e = (*v)(p->__pyx_v_msg, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_19_addCondition(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_addCondition *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_addCondition *)o;
  tmp = ((PyObject*)p->__pyx_v_exc_type);
  p->__pyx_v_exc_type = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_fn);
  p->__pyx_v_fn = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_msg);
  p->__pyx_v_msg = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_19_addCondition = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_19_addCondition", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_19_addCondition), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_19_addCondition, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_19_addCondition, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_19_addCondition, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_19_addCondition, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_20___init__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_20___init__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_20___init__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_20___init__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_20___init__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_20___init__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_20___init__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_cache);
  Py_CLEAR(p->__pyx_v_not_in_cache);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_20___init__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_20___init__[__pyx_freecount_10cPyparsing___pyx_scope_struct_20___init__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_20___init__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__ *)o;
  if (p->__pyx_v_cache) {
    e = (*v)(p->__pyx_v_cache, a); if (e) return e;
  }
  if (p->__pyx_v_not_in_cache) {
    e = (*v)(p->__pyx_v_not_in_cache, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_20___init__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__ *)o;
  tmp = ((PyObject*)p->__pyx_v_cache);
  p->__pyx_v_cache = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_not_in_cache);
  p->__pyx_v_not_in_cache = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_20___init__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_20___init__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_20___init__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_20___init__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_20___init__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_20___init__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_20___init__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_21___init__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_21___init__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_21___init__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_21___init__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_21___init__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_21___init__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_21___init__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_cache);
  Py_CLEAR(p->__pyx_v_not_in_cache);
  Py_CLEAR(p->__pyx_v_size);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_21___init__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_21___init__[__pyx_freecount_10cPyparsing___pyx_scope_struct_21___init__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_21___init__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__ *)o;
  if (p->__pyx_v_cache) {
    e = (*v)(p->__pyx_v_cache, a); if (e) return e;
  }
  if (p->__pyx_v_not_in_cache) {
    e = (*v)(p->__pyx_v_not_in_cache, a); if (e) return e;
  }
  if (p->__pyx_v_size) {
    e = (*v)(p->__pyx_v_size, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_21___init__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__ *)o;
  tmp = ((PyObject*)p->__pyx_v_cache);
  p->__pyx_v_cache = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_not_in_cache);
  p->__pyx_v_not_in_cache = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_size);
  p->__pyx_v_size = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_21___init__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_21___init__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_21___init__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_21___init__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_21___init__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_21___init__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_21___init__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_22___init__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_22___init__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_22___init__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_22___init__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_22___init__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_22___init__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_22___init__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_cache);
  Py_CLEAR(p->__pyx_v_key_fifo);
  Py_CLEAR(p->__pyx_v_not_in_cache);
  Py_CLEAR(p->__pyx_v_size);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_22___init__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_22___init__[__pyx_freecount_10cPyparsing___pyx_scope_struct_22___init__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_22___init__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__ *)o;
  if (p->__pyx_v_cache) {
    e = (*v)(p->__pyx_v_cache, a); if (e) return e;
  }
  if (p->__pyx_v_key_fifo) {
    e = (*v)(p->__pyx_v_key_fifo, a); if (e) return e;
  }
  if (p->__pyx_v_not_in_cache) {
    e = (*v)(p->__pyx_v_not_in_cache, a); if (e) return e;
  }
  if (p->__pyx_v_size) {
    e = (*v)(p->__pyx_v_size, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_22___init__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__ *)o;
  tmp = ((PyObject*)p->__pyx_v_cache);
  p->__pyx_v_cache = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_key_fifo);
  p->__pyx_v_key_fifo = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_not_in_cache);
  p->__pyx_v_not_in_cache = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_size);
  p->__pyx_v_size = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_22___init__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_22___init__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_22___init__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_22___init__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_22___init__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_22___init__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_22___init__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_23_scanString *__pyx_freelist_10cPyparsing___pyx_scope_struct_23_scanString[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_23_scanString = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_23_scanString(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_23_scanString > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_23_scanString)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_23_scanString[--__pyx_freecount_10cPyparsing___pyx_scope_struct_23_scanString];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_23_scanString));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_23_scanString(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_23_scanString *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_23_scanString *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_e);
  Py_CLEAR(p->__pyx_v_exc);
  Py_CLEAR(p->__pyx_v_instring);
  Py_CLEAR(p->__pyx_v_loc);
  Py_CLEAR(p->__pyx_v_maxMatches);
  Py_CLEAR(p->__pyx_v_nextLoc);
  Py_CLEAR(p->__pyx_v_nextloc);
  Py_CLEAR(p->__pyx_v_overlap);
  Py_CLEAR(p->__pyx_v_parseFn);
  Py_CLEAR(p->__pyx_v_preloc);
  Py_CLEAR(p->__pyx_v_preparseFn);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_tokens);
  Py_CLEAR(p->__pyx_t_0);
  Py_CLEAR(p->__pyx_t_1);
  Py_CLEAR(p->__pyx_t_2);
  Py_CLEAR(p->__pyx_t_3);
  Py_CLEAR(p->__pyx_t_4);
  Py_CLEAR(p->__pyx_t_5);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_23_scanString < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_23_scanString)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_23_scanString[__pyx_freecount_10cPyparsing___pyx_scope_struct_23_scanString++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_23_scanString *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_23_scanString(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_23_scanString *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_23_scanString *)o;
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  if (p->__pyx_v_exc) {
    e = (*v)(p->__pyx_v_exc, a); if (e) return e;
  }
  if (p->__pyx_v_instring) {
    e = (*v)(p->__pyx_v_instring, a); if (e) return e;
  }
  if (p->__pyx_v_loc) {
    e = (*v)(p->__pyx_v_loc, a); if (e) return e;
  }
  if (p->__pyx_v_maxMatches) {
    e = (*v)(p->__pyx_v_maxMatches, a); if (e) return e;
  }
  if (p->__pyx_v_nextLoc) {
    e = (*v)(p->__pyx_v_nextLoc, a); if (e) return e;
  }
  if (p->__pyx_v_nextloc) {
    e = (*v)(p->__pyx_v_nextloc, a); if (e) return e;
  }
  if (p->__pyx_v_overlap) {
    e = (*v)(p->__pyx_v_overlap, a); if (e) return e;
  }
  if (p->__pyx_v_parseFn) {
    e = (*v)(p->__pyx_v_parseFn, a); if (e) return e;
  }
  if (p->__pyx_v_preloc) {
    e = (*v)(p->__pyx_v_preloc, a); if (e) return e;
  }
  if (p->__pyx_v_preparseFn) {
    e = (*v)(p->__pyx_v_preparseFn, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  if (p->__pyx_v_tokens) {
    e = (*v)(p->__pyx_v_tokens, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  if (p->__pyx_t_1) {
    e = (*v)(p->__pyx_t_1, a); if (e) return e;
  }
  if (p->__pyx_t_2) {
    e = (*v)(p->__pyx_t_2, a); if (e) return e;
  }
  if (p->__pyx_t_3) {
    e = (*v)(p->__pyx_t_3, a); if (e) return e;
  }
  if (p->__pyx_t_4) {
    e = (*v)(p->__pyx_t_4, a); if (e) return e;
  }
  if (p->__pyx_t_5) {
    e = (*v)(p->__pyx_t_5, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_23_scanString(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_23_scanString *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_23_scanString *)o;
  tmp = ((PyObject*)p->__pyx_v_e);
  p->__pyx_v_e = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_exc);
  p->__pyx_v_exc = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_instring);
  p->__pyx_v_instring = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_loc);
  p->__pyx_v_loc = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_maxMatches);
  p->__pyx_v_maxMatches = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_nextLoc);
  p->__pyx_v_nextLoc = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_nextloc);
  p->__pyx_v_nextloc = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_overlap);
  p->__pyx_v_overlap = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_parseFn);
  p->__pyx_v_parseFn = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_preloc);
  p->__pyx_v_preloc = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_preparseFn);
  p->__pyx_v_preparseFn = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_tokens);
  p->__pyx_v_tokens = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_t_0);
  p->__pyx_t_0 = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_t_1);
  p->__pyx_t_1 = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_t_2);
  p->__pyx_t_2 = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_t_3);
  p->__pyx_t_3 = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_t_4);
  p->__pyx_t_4 = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_t_5);
  p->__pyx_t_5 = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_23_scanString = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_23_scanString", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_23_scanString), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_23_scanString, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_23_scanString, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_23_scanString, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_23_scanString, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_24_split *__pyx_freelist_10cPyparsing___pyx_scope_struct_24_split[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_24_split = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_24_split(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_24_split > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_24_split)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_24_split[--__pyx_freecount_10cPyparsing___pyx_scope_struct_24_split];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_24_split));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_24_split(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_24_split *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_24_split *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_e);
  Py_CLEAR(p->__pyx_v_includeSeparators);
  Py_CLEAR(p->__pyx_v_instring);
  Py_CLEAR(p->__pyx_v_last);
  Py_CLEAR(p->__pyx_v_maxsplit);
  Py_CLEAR(p->__pyx_v_s);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_t);
  Py_CLEAR(p->__pyx_t_0);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_24_split < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_24_split)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_24_split[__pyx_freecount_10cPyparsing___pyx_scope_struct_24_split++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_24_split *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_24_split(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_24_split *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_24_split *)o;
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  if (p->__pyx_v_includeSeparators) {
    e = (*v)(p->__pyx_v_includeSeparators, a); if (e) return e;
  }
  if (p->__pyx_v_instring) {
    e = (*v)(p->__pyx_v_instring, a); if (e) return e;
  }
  if (p->__pyx_v_last) {
    e = (*v)(p->__pyx_v_last, a); if (e) return e;
  }
  if (p->__pyx_v_maxsplit) {
    e = (*v)(p->__pyx_v_maxsplit, a); if (e) return e;
  }
  if (p->__pyx_v_s) {
    e = (*v)(p->__pyx_v_s, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  if (p->__pyx_v_t) {
    e = (*v)(p->__pyx_v_t, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_24_split(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_24_split *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_24_split *)o;
  tmp = ((PyObject*)p->__pyx_v_e);
  p->__pyx_v_e = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_includeSeparators);
  p->__pyx_v_includeSeparators = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_instring);
  p->__pyx_v_instring = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_last);
  p->__pyx_v_last = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_maxsplit);
  p->__pyx_v_maxsplit = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_s);
  p->__pyx_v_s = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_t);
  p->__pyx_v_t = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_t_0);
  p->__pyx_t_0 = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_24_split = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_24_split", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_24_split), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_24_split, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_24_split, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_24_split, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_24_split, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_25___mul__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_25___mul__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_25___mul__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_25___mul__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_25___mul__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_25___mul__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_25___mul__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_25___mul__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_25___mul__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_25___mul__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_25___mul__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_25___mul__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_makeOptionalList);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_25___mul__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_25___mul__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_25___mul__[__pyx_freecount_10cPyparsing___pyx_scope_struct_25___mul__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_25___mul__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_25___mul__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_25___mul__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_25___mul__ *)o;
  if (p->__pyx_v_makeOptionalList) {
    e = (*v)(p->__pyx_v_makeOptionalList, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_25___mul__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_25___mul__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_25___mul__ *)o;
  tmp = ((PyObject*)p->__pyx_v_makeOptionalList);
  p->__pyx_v_makeOptionalList = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_25___mul__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_25___mul__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_25___mul__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_25___mul__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_25___mul__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_25___mul__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_25___mul__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_26___init__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_26___init__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_26___init__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_26___init__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_26___init__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_26___init__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_26___init__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_26___init__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_26___init__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_26___init__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_26___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_26___init__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_bodyChars);
  Py_CLEAR(p->__pyx_v_excludeChars);
  Py_CLEAR(p->__pyx_v_initChars);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_26___init__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_26___init__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_26___init__[__pyx_freecount_10cPyparsing___pyx_scope_struct_26___init__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_26___init__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_26___init__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_26___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_26___init__ *)o;
  if (p->__pyx_v_bodyChars) {
    e = (*v)(p->__pyx_v_bodyChars, a); if (e) return e;
  }
  if (p->__pyx_v_excludeChars) {
    e = (*v)(p->__pyx_v_excludeChars, a); if (e) return e;
  }
  if (p->__pyx_v_initChars) {
    e = (*v)(p->__pyx_v_initChars, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_26___init__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_26___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_26___init__ *)o;
  tmp = ((PyObject*)p->__pyx_v_bodyChars);
  p->__pyx_v_bodyChars = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_excludeChars);
  p->__pyx_v_excludeChars = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_initChars);
  p->__pyx_v_initChars = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_26___init__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_26___init__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_26___init__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_26___init__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_26___init__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_26___init__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_26___init__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_27_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_27_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_27_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_27_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_27_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_27_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_27_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_c);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_27_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_27_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_27_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_27_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_c) {
    e = (*v)(p->__pyx_v_c, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_27_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_26___init__ *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_c);
  p->__pyx_v_c = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_27_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_27_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_27_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_27_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_27_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_27_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_27_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_28_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_28_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_28_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_28_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_28_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_28_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_28_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_28_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_28_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_28_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_28_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_28_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_c);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_28_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_28_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_28_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_28_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_28_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_28_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_28_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_28_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_c) {
    e = (*v)(p->__pyx_v_c, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_28_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_28_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_28_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_26___init__ *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_c);
  p->__pyx_v_c = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_28_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_28_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_28_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_28_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_28_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_28_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_28_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_29___init__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_29___init__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_29___init__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_29___init__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_29___init__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_29___init__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_29___init__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_29___init__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_29___init__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_29___init__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_29___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_29___init__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_29___init__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_29___init__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_29___init__[__pyx_freecount_10cPyparsing___pyx_scope_struct_29___init__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_29___init__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_29___init__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_29___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_29___init__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_29___init__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_29___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_29___init__ *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_29___init__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_29___init__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_29___init__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_29___init__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_29___init__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_29___init__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_29___init__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_30_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_30_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_30_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_30_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_30_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_30_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_30_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_30_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_30_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_30_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_30_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_30_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_i);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_30_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_30_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_30_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_30_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_30_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_30_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_30_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_30_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_i) {
    e = (*v)(p->__pyx_v_i, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_30_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_30_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_30_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_29___init__ *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_i);
  p->__pyx_v_i = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_30_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_30_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_30_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_30_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_30_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_30_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_30_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_31___init__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_31___init__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_31___init__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_31___init__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_31___init__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_31___init__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_31___init__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_31___init__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_31___init__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_31___init__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_31___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_31___init__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_31___init__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_31___init__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_31___init__[__pyx_freecount_10cPyparsing___pyx_scope_struct_31___init__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_31___init__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_31___init__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_31___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_31___init__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_31___init__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_31___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_31___init__ *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_31___init__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_31___init__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_31___init__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_31___init__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_31___init__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_31___init__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_31___init__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_32_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_32_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_32_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_32_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_32_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_32_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_32_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_c);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_32_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_32_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_32_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_32_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_c) {
    e = (*v)(p->__pyx_v_c, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_32_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_31___init__ *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_c);
  p->__pyx_v_c = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_32_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_32_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_32_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_32_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_32_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_32_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_32_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_33_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_33_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_33_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_33_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_33_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_33_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_33_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_33_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_33_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_33_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_33_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_33_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_c);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_33_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_33_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_33_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_33_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_33_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_33_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_33_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_33_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_c) {
    e = (*v)(p->__pyx_v_c, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_33_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_33_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_33_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_31___init__ *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_c);
  p->__pyx_v_c = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_33_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_33_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_33_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_33_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_33_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_33_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_33_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_34___init__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_34___init__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_34___init__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_34___init__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_34___init__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_34___init__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_34___init__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_34___init__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_34___init__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_34___init__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_34___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_34___init__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_exprs);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_34___init__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_34___init__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_34___init__[__pyx_freecount_10cPyparsing___pyx_scope_struct_34___init__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_34___init__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_34___init__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_34___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_34___init__ *)o;
  if (p->__pyx_v_exprs) {
    e = (*v)(p->__pyx_v_exprs, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_34___init__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_34___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_34___init__ *)o;
  tmp = ((PyObject*)p->__pyx_v_exprs);
  p->__pyx_v_exprs = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_34___init__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_34___init__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_34___init__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_34___init__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_34___init__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_34___init__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_34___init__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_35_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_35_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_35_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_35_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_35_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_35_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_35_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_expr);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_35_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_35_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_35_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_35_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_expr) {
    e = (*v)(p->__pyx_v_expr, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_35_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_34___init__ *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_expr);
  p->__pyx_v_expr = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_35_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_35_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_35_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_35_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_35_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_35_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_35_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_36___init__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_36___init__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_36___init__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_36___init__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_36___init__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_36___init__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_36___init__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_36___init__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_36___init__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_36___init__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_36___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_36___init__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_36___init__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_36___init__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_36___init__[__pyx_freecount_10cPyparsing___pyx_scope_struct_36___init__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_36___init__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_36___init__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_36___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_36___init__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_36___init__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_36___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_36___init__ *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_36___init__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_36___init__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_36___init__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_36___init__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_36___init__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_36___init__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_36___init__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_37_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_37_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_37_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_37_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_37_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_37_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_37_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_e);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_37_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_37_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_37_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_37_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_37_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_36___init__ *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_e);
  p->__pyx_v_e = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_37_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_37_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_37_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_37_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_37_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_37_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_37_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_38___str__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_38___str__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_38___str__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_38___str__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_38___str__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_38___str__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_38___str__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_38___str__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_38___str__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_38___str__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_38___str__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_38___str__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_38___str__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_38___str__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_38___str__[__pyx_freecount_10cPyparsing___pyx_scope_struct_38___str__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_38___str__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_38___str__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_38___str__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_38___str__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_38___str__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_38___str__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_38___str__ *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_38___str__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_38___str__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_38___str__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_38___str__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_38___str__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_38___str__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_38___str__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_39_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_39_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_39_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_39_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_39_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_39_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_39_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_e);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_39_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_39_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_39_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_39_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_39_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_38___str__ *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_e);
  p->__pyx_v_e = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_39_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_39_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_39_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_39_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_39_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_39_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_39_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_40___init__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_40___init__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_40___init__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_40___init__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_40___init__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_40___init__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_40___init__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_40___init__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_40___init__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_40___init__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_40___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_40___init__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_40___init__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_40___init__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_40___init__[__pyx_freecount_10cPyparsing___pyx_scope_struct_40___init__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_40___init__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_40___init__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_40___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_40___init__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_40___init__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_40___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_40___init__ *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_40___init__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_40___init__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_40___init__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_40___init__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_40___init__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_40___init__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_40___init__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_41_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_41_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_41_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_41_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_41_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_41_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_41_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_e);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_41_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_41_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_41_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_41_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_41_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_40___init__ *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_e);
  p->__pyx_v_e = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_41_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_41_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_41_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_41_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_41_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_41_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_41_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_42___str__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_42___str__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_42___str__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_42___str__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_42___str__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_42___str__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_42___str__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_42___str__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_42___str__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_42___str__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_42___str__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_42___str__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_42___str__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_42___str__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_42___str__[__pyx_freecount_10cPyparsing___pyx_scope_struct_42___str__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_42___str__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_42___str__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_42___str__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_42___str__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_42___str__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_42___str__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_42___str__ *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_42___str__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_42___str__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_42___str__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_42___str__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_42___str__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_42___str__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_42___str__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_43_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_43_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_43_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_43_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_43_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_43_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_43_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_e);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_43_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_43_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_43_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_43_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_43_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_42___str__ *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_e);
  p->__pyx_v_e = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_43_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_43_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_43_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_43_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_43_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_43_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_43_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_44___init__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_44___init__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_44___init__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_44___init__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_44___init__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_44___init__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_44___init__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_44___init__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_44___init__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_44___init__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_44___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_44___init__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_44___init__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_44___init__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_44___init__[__pyx_freecount_10cPyparsing___pyx_scope_struct_44___init__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_44___init__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_44___init__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_44___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_44___init__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_44___init__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_44___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_44___init__ *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_44___init__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_44___init__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_44___init__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_44___init__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_44___init__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_44___init__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_44___init__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_45_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_45_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_45_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_45_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_45_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_45_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_45_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_e);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_45_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_45_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_45_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_45_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_45_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_44___init__ *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_e);
  p->__pyx_v_e = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_45_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_45_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_45_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_45_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_45_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_45_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_45_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_46___str__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_46___str__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_46___str__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_46___str__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_46___str__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_46___str__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_46___str__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_46___str__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_46___str__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_46___str__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_46___str__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_46___str__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_46___str__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_46___str__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_46___str__[__pyx_freecount_10cPyparsing___pyx_scope_struct_46___str__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_46___str__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_46___str__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_46___str__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_46___str__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_46___str__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_46___str__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_46___str__ *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_46___str__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_46___str__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_46___str__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_46___str__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_46___str__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_46___str__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_46___str__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_47_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_47_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_47_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_47_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_47_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_47_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_47_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_e);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_47_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_47_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_47_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_47_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_47_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_46___str__ *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_e);
  p->__pyx_v_e = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_47_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_47_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_47_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_47_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_47_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_47_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_47_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_48___init__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_48___init__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_48___init__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_48___init__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_48___init__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_48___init__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_48___init__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_48___init__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_48___init__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_48___init__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_48___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_48___init__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_48___init__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_48___init__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_48___init__[__pyx_freecount_10cPyparsing___pyx_scope_struct_48___init__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_48___init__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_48___init__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_48___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_48___init__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_48___init__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_48___init__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_48___init__ *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_48___init__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_48___init__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_48___init__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_48___init__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_48___init__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_48___init__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_48___init__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_49_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_49_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_49_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_49_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_49_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_49_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_49_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_e);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_49_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_49_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_49_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_49_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_49_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_48___init__ *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_e);
  p->__pyx_v_e = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_49_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_49_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_49_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_49_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_49_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_49_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_49_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_parseImpl *__pyx_freelist_10cPyparsing___pyx_scope_struct_50_parseImpl[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_50_parseImpl = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_50_parseImpl(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_50_parseImpl > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_parseImpl)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_50_parseImpl[--__pyx_freecount_10cPyparsing___pyx_scope_struct_50_parseImpl];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_parseImpl));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_50_parseImpl(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_parseImpl *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_parseImpl *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_tmpReqd);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_50_parseImpl < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_parseImpl)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_50_parseImpl[__pyx_freecount_10cPyparsing___pyx_scope_struct_50_parseImpl++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_parseImpl *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_50_parseImpl(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_parseImpl *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_parseImpl *)o;
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  if (p->__pyx_v_tmpReqd) {
    e = (*v)(p->__pyx_v_tmpReqd, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_50_parseImpl(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_parseImpl *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_parseImpl *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_tmpReqd);
  p->__pyx_v_tmpReqd = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_50_parseImpl = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_50_parseImpl", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_parseImpl), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_50_parseImpl, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_50_parseImpl, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_50_parseImpl, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_50_parseImpl, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_51_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_51_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_51_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_51_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_51_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_51_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_51_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_e);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_51_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_51_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_51_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_51_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_51_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_parseImpl *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_e);
  p->__pyx_v_e = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_51_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_51_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_51_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_51_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_51_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_51_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_51_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_52_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_52_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_52_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_52_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_52_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_52_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_52_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_e);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_52_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_52_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_52_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_52_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_52_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_50_parseImpl *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_e);
  p->__pyx_v_e = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_52_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_52_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_52_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_52_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_52_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_52_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_52_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_53___str__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_53___str__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_53___str__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_53___str__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_53___str__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_53___str__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_53___str__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_53___str__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_53___str__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_53___str__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_53___str__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_53___str__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_53___str__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_53___str__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_53___str__[__pyx_freecount_10cPyparsing___pyx_scope_struct_53___str__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_53___str__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_53___str__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_53___str__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_53___str__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_53___str__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_53___str__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_53___str__ *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_53___str__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_53___str__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_53___str__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_53___str__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_53___str__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_53___str__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_53___str__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_54_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_54_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_54_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_54_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_54_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_54_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_54_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_e);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_54_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_54_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_54_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_54_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_54_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_53___str__ *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_e);
  p->__pyx_v_e = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_54_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_54_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_54_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_54_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_54_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_54_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_54_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_traceParseAction *__pyx_freelist_10cPyparsing___pyx_scope_struct_55_traceParseAction[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_55_traceParseAction = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_55_traceParseAction(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_55_traceParseAction > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_traceParseAction)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_55_traceParseAction[--__pyx_freecount_10cPyparsing___pyx_scope_struct_55_traceParseAction];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_traceParseAction));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_55_traceParseAction(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_traceParseAction *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_traceParseAction *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_f);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_55_traceParseAction < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_traceParseAction)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_55_traceParseAction[__pyx_freecount_10cPyparsing___pyx_scope_struct_55_traceParseAction++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_traceParseAction *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_55_traceParseAction(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_traceParseAction *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_traceParseAction *)o;
  if (p->__pyx_v_f) {
    e = (*v)(p->__pyx_v_f, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_55_traceParseAction(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_traceParseAction *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_traceParseAction *)o;
  tmp = ((PyObject*)p->__pyx_v_f);
  p->__pyx_v_f = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_55_traceParseAction = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_55_traceParseAction", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_55_traceParseAction), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_55_traceParseAction, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_55_traceParseAction, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_55_traceParseAction, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_55_traceParseAction, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_countedArray *__pyx_freelist_10cPyparsing___pyx_scope_struct_56_countedArray[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_56_countedArray = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_56_countedArray(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_56_countedArray > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_countedArray)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_56_countedArray[--__pyx_freecount_10cPyparsing___pyx_scope_struct_56_countedArray];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_countedArray));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_56_countedArray(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_countedArray *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_countedArray *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_arrayExpr);
  Py_CLEAR(p->__pyx_v_expr);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_56_countedArray < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_countedArray)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_56_countedArray[__pyx_freecount_10cPyparsing___pyx_scope_struct_56_countedArray++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_countedArray *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_56_countedArray(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_countedArray *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_countedArray *)o;
  if (p->__pyx_v_arrayExpr) {
    e = (*v)(p->__pyx_v_arrayExpr, a); if (e) return e;
  }
  if (p->__pyx_v_expr) {
    e = (*v)(p->__pyx_v_expr, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_56_countedArray(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_countedArray *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_countedArray *)o;
  tmp = ((PyObject*)p->__pyx_v_arrayExpr);
  p->__pyx_v_arrayExpr = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_expr);
  p->__pyx_v_expr = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_56_countedArray = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_56_countedArray", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_56_countedArray), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_56_countedArray, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_56_countedArray, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_56_countedArray, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_56_countedArray, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral *__pyx_freelist_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral[--__pyx_freecount_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_rep);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral[__pyx_freecount_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral *)o;
  if (p->__pyx_v_rep) {
    e = (*v)(p->__pyx_v_rep, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral *)o;
  tmp = ((PyObject*)p->__pyx_v_rep);
  p->__pyx_v_rep = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_57_matchPreviousLiteral", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater *__pyx_freelist_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater[--__pyx_freecount_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_tflat);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater[__pyx_freecount_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_tflat) {
    e = (*v)(p->__pyx_v_tflat, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_tflat);
  p->__pyx_v_tflat = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_58_copyTokenToRepeater", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_59_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_59_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_59_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_59_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_59_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_59_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_59_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_tt);
  Py_CLEAR(p->__pyx_t_0);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_59_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_59_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_59_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_59_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_tt) {
    e = (*v)(p->__pyx_v_tt, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_59_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_tt);
  p->__pyx_v_tt = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_t_0);
  p->__pyx_t_0 = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_59_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_59_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_59_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_59_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_59_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_59_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_59_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_rep);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr *)o;
  if (p->__pyx_v_rep) {
    e = (*v)(p->__pyx_v_rep, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr *)o;
  tmp = ((PyObject*)p->__pyx_v_rep);
  p->__pyx_v_rep = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_60_matchPreviousExpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater *__pyx_freelist_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater[--__pyx_freecount_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_matchTokens);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater[__pyx_freecount_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_matchTokens) {
    e = (*v)(p->__pyx_v_matchTokens, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_matchTokens);
  p->__pyx_v_matchTokens = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_61_copyTokenToRepeater", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf *__pyx_freelist_10cPyparsing___pyx_scope_struct_62_oneOf[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_62_oneOf = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_62_oneOf(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_62_oneOf > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_62_oneOf[--__pyx_freecount_10cPyparsing___pyx_scope_struct_62_oneOf];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_62_oneOf(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_parseElementClass);
  Py_CLEAR(p->__pyx_v_symbols);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_62_oneOf < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_62_oneOf[__pyx_freecount_10cPyparsing___pyx_scope_struct_62_oneOf++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_62_oneOf(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf *)o;
  if (p->__pyx_v_parseElementClass) {
    e = (*v)(p->__pyx_v_parseElementClass, a); if (e) return e;
  }
  if (p->__pyx_v_symbols) {
    e = (*v)(p->__pyx_v_symbols, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_62_oneOf(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf *)o;
  tmp = ((PyObject*)p->__pyx_v_parseElementClass);
  p->__pyx_v_parseElementClass = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_symbols);
  p->__pyx_v_symbols = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_62_oneOf = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_62_oneOf", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_62_oneOf, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_62_oneOf, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_62_oneOf, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_62_oneOf, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_63_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_63_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_63_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_63_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_63_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_63_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_63_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_sym);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_63_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_63_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_63_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_63_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_sym) {
    e = (*v)(p->__pyx_v_sym, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_63_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_sym);
  p->__pyx_v_sym = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_63_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_63_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_63_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_63_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_63_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_63_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_63_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_64_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_64_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_64_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_64_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_64_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_64_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_64_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_sym);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_64_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_64_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_64_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_64_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_sym) {
    e = (*v)(p->__pyx_v_sym, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_64_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_sym);
  p->__pyx_v_sym = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_64_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_64_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_64_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_64_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_64_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_64_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_64_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_65_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_65_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_65_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_65_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_65_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_65_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_65_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_sym);
  Py_CLEAR(p->__pyx_t_0);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_65_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_65_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_65_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_65_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_sym) {
    e = (*v)(p->__pyx_v_sym, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_65_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_62_oneOf *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_sym);
  p->__pyx_v_sym = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_t_0);
  p->__pyx_t_0 = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_65_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_65_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_65_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_65_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_65_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_65_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_65_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_srange *__pyx_freelist_10cPyparsing___pyx_scope_struct_66_srange[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_66_srange = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_66_srange(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_66_srange > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_srange)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_66_srange[--__pyx_freecount_10cPyparsing___pyx_scope_struct_66_srange];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_srange));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_66_srange(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_srange *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_srange *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v__expanded);
  Py_CLEAR(p->__pyx_v_s);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_66_srange < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_srange)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_66_srange[__pyx_freecount_10cPyparsing___pyx_scope_struct_66_srange++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_srange *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_66_srange(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_srange *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_srange *)o;
  if (p->__pyx_v__expanded) {
    e = (*v)(p->__pyx_v__expanded, a); if (e) return e;
  }
  if (p->__pyx_v_s) {
    e = (*v)(p->__pyx_v_s, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_66_srange(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_srange *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_srange *)o;
  tmp = ((PyObject*)p->__pyx_v__expanded);
  p->__pyx_v__expanded = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_s);
  p->__pyx_v_s = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_66_srange = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_66_srange", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_srange), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_66_srange, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_66_srange, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_66_srange, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_66_srange, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_67__expanded *__pyx_freelist_10cPyparsing___pyx_scope_struct_67__expanded[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_67__expanded = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_67__expanded(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_67__expanded > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_67__expanded)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_67__expanded[--__pyx_freecount_10cPyparsing___pyx_scope_struct_67__expanded];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_67__expanded));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_67__expanded(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_67__expanded *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_67__expanded *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_p);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_67__expanded < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_67__expanded)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_67__expanded[__pyx_freecount_10cPyparsing___pyx_scope_struct_67__expanded++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_67__expanded *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_67__expanded(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_67__expanded *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_67__expanded *)o;
  if (p->__pyx_v_p) {
    e = (*v)(p->__pyx_v_p, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_67__expanded(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_67__expanded *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_67__expanded *)o;
  tmp = ((PyObject*)p->__pyx_v_p);
  p->__pyx_v_p = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_67__expanded = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_67__expanded", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_67__expanded), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_67__expanded, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_67__expanded, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_67__expanded, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_67__expanded, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_68_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_68_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_68_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_68_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_68_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_68_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_68_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_68_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_68_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_68_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_68_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_68_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_c);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_68_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_68_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_68_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_68_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_68_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_68_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_68_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_68_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_c) {
    e = (*v)(p->__pyx_v_c, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_68_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_68_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_68_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_67__expanded *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_c);
  p->__pyx_v_c = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_68_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_68_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_68_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_68_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_68_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_68_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_68_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_69_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_69_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_69_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_69_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_69_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_69_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_69_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_69_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_69_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_69_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_69_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_69_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_part);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_69_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_69_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_69_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_69_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_69_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_69_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_69_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_69_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_part) {
    e = (*v)(p->__pyx_v_part, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_69_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_69_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_69_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_66_srange *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_part);
  p->__pyx_v_part = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_69_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_69_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_69_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_69_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_69_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_69_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_69_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol *__pyx_freelist_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol[--__pyx_freecount_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_n);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol[__pyx_freecount_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol *)o;
  if (p->__pyx_v_n) {
    e = (*v)(p->__pyx_v_n, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol *)o;
  tmp = ((PyObject*)p->__pyx_v_n);
  p->__pyx_v_n = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_70_matchOnlyAtCol", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_replaceWith *__pyx_freelist_10cPyparsing___pyx_scope_struct_71_replaceWith[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_71_replaceWith = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_71_replaceWith(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_71_replaceWith > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_replaceWith)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_71_replaceWith[--__pyx_freecount_10cPyparsing___pyx_scope_struct_71_replaceWith];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_replaceWith));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_71_replaceWith(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_replaceWith *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_replaceWith *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_replStr);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_71_replaceWith < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_replaceWith)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_71_replaceWith[__pyx_freecount_10cPyparsing___pyx_scope_struct_71_replaceWith++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_replaceWith *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_71_replaceWith(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_replaceWith *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_replaceWith *)o;
  if (p->__pyx_v_replStr) {
    e = (*v)(p->__pyx_v_replStr, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_71_replaceWith(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_replaceWith *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_replaceWith *)o;
  tmp = ((PyObject*)p->__pyx_v_replStr);
  p->__pyx_v_replStr = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_71_replaceWith = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_71_replaceWith", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_71_replaceWith), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_71_replaceWith, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_71_replaceWith, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_71_replaceWith, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_71_replaceWith, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_tokenMap *__pyx_freelist_10cPyparsing___pyx_scope_struct_72_tokenMap[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_72_tokenMap = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_72_tokenMap(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_72_tokenMap > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_tokenMap)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_72_tokenMap[--__pyx_freecount_10cPyparsing___pyx_scope_struct_72_tokenMap];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_tokenMap));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_72_tokenMap(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_tokenMap *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_tokenMap *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_args);
  Py_CLEAR(p->__pyx_v_func);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_72_tokenMap < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_tokenMap)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_72_tokenMap[__pyx_freecount_10cPyparsing___pyx_scope_struct_72_tokenMap++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_tokenMap *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_72_tokenMap(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_tokenMap *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_tokenMap *)o;
  if (p->__pyx_v_args) {
    e = (*v)(p->__pyx_v_args, a); if (e) return e;
  }
  if (p->__pyx_v_func) {
    e = (*v)(p->__pyx_v_func, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_72_tokenMap(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_tokenMap *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_tokenMap *)o;
  tmp = ((PyObject*)p->__pyx_v_args);
  p->__pyx_v_args = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_func);
  p->__pyx_v_func = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_72_tokenMap = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_72_tokenMap", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_72_tokenMap), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_72_tokenMap, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_72_tokenMap, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_72_tokenMap, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_72_tokenMap, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_73_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_73_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_73_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_73_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_73_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_73_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_73_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_c);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_73_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_73_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_73_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_73_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_genexpr *)o;
  if (p->__pyx_v_c) {
    e = (*v)(p->__pyx_v_c, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_73_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_v_c);
  p->__pyx_v_c = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_73_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_73_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_73_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_73_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_73_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_73_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_73_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___new__ *__pyx_freelist_10cPyparsing___pyx_scope_struct_74___new__[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_74___new__ = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_74___new__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_74___new__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___new__)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_74___new__[--__pyx_freecount_10cPyparsing___pyx_scope_struct_74___new__];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___new__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_74___new__(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___new__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___new__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_attrs);
  Py_CLEAR(p->__pyx_v_cls);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_74___new__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___new__)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_74___new__[__pyx_freecount_10cPyparsing___pyx_scope_struct_74___new__++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___new__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_74___new__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___new__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___new__ *)o;
  if (p->__pyx_v_attrs) {
    e = (*v)(p->__pyx_v_attrs, a); if (e) return e;
  }
  if (p->__pyx_v_cls) {
    e = (*v)(p->__pyx_v_cls, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_74___new__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___new__ *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___new__ *)o;
  tmp = ((PyObject*)p->__pyx_v_attrs);
  p->__pyx_v_attrs = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_cls);
  p->__pyx_v_cls = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_74___new__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_74___new__", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_74___new__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_74___new__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_74___new__, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_74___new__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_74___new__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock *__pyx_freelist_10cPyparsing___pyx_scope_struct_75_indentedBlock[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_75_indentedBlock = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_75_indentedBlock(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_75_indentedBlock > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_75_indentedBlock[--__pyx_freecount_10cPyparsing___pyx_scope_struct_75_indentedBlock];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_75_indentedBlock(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_indentStack);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_75_indentedBlock < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_75_indentedBlock[__pyx_freecount_10cPyparsing___pyx_scope_struct_75_indentedBlock++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_75_indentedBlock(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock *)o;
  if (p->__pyx_v_indentStack) {
    e = (*v)(p->__pyx_v_indentStack, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_75_indentedBlock(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock *)o;
  tmp = ((PyObject*)p->__pyx_v_indentStack);
  p->__pyx_v_indentStack = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_75_indentedBlock = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_75_indentedBlock", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_75_indentedBlock), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_75_indentedBlock, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_75_indentedBlock, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_75_indentedBlock, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_75_indentedBlock, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56 *__pyx_freelist_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56 = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56 > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56[--__pyx_freecount_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56 *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56 *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_t);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56 < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56[__pyx_freecount_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56 *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56 *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56 *)o;
  if (p->__pyx_v_t) {
    e = (*v)(p->__pyx_v_t, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56 *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56 *)o;
  tmp = ((PyObject*)p->__pyx_v_t);
  p->__pyx_v_t = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56 = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr *__pyx_freelist_10cPyparsing___pyx_scope_struct_77_genexpr[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_77_genexpr = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_77_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_77_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_77_genexpr[--__pyx_freecount_10cPyparsing___pyx_scope_struct_77_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_77_genexpr(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_tt);
  Py_CLEAR(p->__pyx_t_0);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_77_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_77_genexpr[__pyx_freecount_10cPyparsing___pyx_scope_struct_77_genexpr++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_77_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject*)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_tt) {
    e = (*v)(p->__pyx_v_tt, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_77_genexpr(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr *)o;
  tmp = ((PyObject*)p->__pyx_outer_scope);
  p->__pyx_outer_scope = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56 *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_tt);
  p->__pyx_v_tt = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_t_0);
  p->__pyx_t_0 = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_77_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_77_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_77_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_77_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_77_genexpr, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_77_genexpr, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_77_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_convertToDate *__pyx_freelist_10cPyparsing___pyx_scope_struct_78_convertToDate[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_78_convertToDate = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_78_convertToDate(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_78_convertToDate > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_convertToDate)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_78_convertToDate[--__pyx_freecount_10cPyparsing___pyx_scope_struct_78_convertToDate];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_convertToDate));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_78_convertToDate(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_convertToDate *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_convertToDate *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_fmt);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_78_convertToDate < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_convertToDate)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_78_convertToDate[__pyx_freecount_10cPyparsing___pyx_scope_struct_78_convertToDate++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_convertToDate *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_78_convertToDate(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_convertToDate *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_convertToDate *)o;
  if (p->__pyx_v_fmt) {
    e = (*v)(p->__pyx_v_fmt, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_78_convertToDate(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_convertToDate *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_convertToDate *)o;
  tmp = ((PyObject*)p->__pyx_v_fmt);
  p->__pyx_v_fmt = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_78_convertToDate = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_78_convertToDate", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_78_convertToDate), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_78_convertToDate, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_78_convertToDate, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_78_convertToDate, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_78_convertToDate, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_convertToDatetime *__pyx_freelist_10cPyparsing___pyx_scope_struct_79_convertToDatetime[8];
static int __pyx_freecount_10cPyparsing___pyx_scope_struct_79_convertToDatetime = 0;

static PyObject *__pyx_tp_new_10cPyparsing___pyx_scope_struct_79_convertToDatetime(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_10cPyparsing___pyx_scope_struct_79_convertToDatetime > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_convertToDatetime)))) {
    o = (PyObject*)__pyx_freelist_10cPyparsing___pyx_scope_struct_79_convertToDatetime[--__pyx_freecount_10cPyparsing___pyx_scope_struct_79_convertToDatetime];
    memset(o, 0, sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_convertToDatetime));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_79_convertToDatetime(PyObject *o) {
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_convertToDatetime *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_convertToDatetime *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_fmt);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_10cPyparsing___pyx_scope_struct_79_convertToDatetime < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_convertToDatetime)))) {
    __pyx_freelist_10cPyparsing___pyx_scope_struct_79_convertToDatetime[__pyx_freecount_10cPyparsing___pyx_scope_struct_79_convertToDatetime++] = ((struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_convertToDatetime *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_79_convertToDatetime(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_convertToDatetime *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_convertToDatetime *)o;
  if (p->__pyx_v_fmt) {
    e = (*v)(p->__pyx_v_fmt, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_10cPyparsing___pyx_scope_struct_79_convertToDatetime(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_convertToDatetime *p = (struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_convertToDatetime *)o;
  tmp = ((PyObject*)p->__pyx_v_fmt);
  p->__pyx_v_fmt = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_10cPyparsing___pyx_scope_struct_79_convertToDatetime = {
  PyVarObject_HEAD_INIT(0, 0)
  "cPyparsing.__pyx_scope_struct_79_convertToDatetime", /*tp_name*/
  sizeof(struct __pyx_obj_10cPyparsing___pyx_scope_struct_79_convertToDatetime), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_10cPyparsing___pyx_scope_struct_79_convertToDatetime, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_10cPyparsing___pyx_scope_struct_79_convertToDatetime, /*tp_traverse*/
  __pyx_tp_clear_10cPyparsing___pyx_scope_struct_79_convertToDatetime, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_10cPyparsing___pyx_scope_struct_79_convertToDatetime, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
static struct PyModuleDef __pyx_moduledef = {
  #if PY_VERSION_HEX < 0x03020000
    { PyObject_HEAD_INIT(NULL) NULL, 0, NULL },
  #else
    PyModuleDef_HEAD_INIT,
  #endif
    "cPyparsing",
    __pyx_k_cPyparsing_is_an_alternative_im, /* m_doc */
    -1, /* m_size */
    __pyx_methods /* m_methods */,
    NULL, /* m_reload */
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_u_0123456789, __pyx_k_0123456789, sizeof(__pyx_k_0123456789), 0, 1, 0, 0},
  {&__pyx_kp_u_0_0_7, __pyx_k_0_0_7, sizeof(__pyx_k_0_0_7), 0, 1, 0, 0},
  {&__pyx_kp_u_0_9a_fA_F_1_4, __pyx_k_0_9a_fA_F_1_4, sizeof(__pyx_k_0_9a_fA_F_1_4), 0, 1, 0, 0},
  {&__pyx_kp_u_0_9a_fA_F_2_0_9a_fA_F_2_1_0_9a, __pyx_k_0_9a_fA_F_2_0_9a_fA_F_2_1_0_9a, sizeof(__pyx_k_0_9a_fA_F_2_0_9a_fA_F_2_1_0_9a), 0, 1, 0, 0},
  {&__pyx_kp_u_0_9a_fA_F_8_0_9a_fA_F_4_3_0_9a, __pyx_k_0_9a_fA_F_8_0_9a_fA_F_4_3_0_9a, sizeof(__pyx_k_0_9a_fA_F_8_0_9a_fA_F_4_3_0_9a), 0, 1, 0, 0},
  {&__pyx_kp_u_0_xX_0_9a_fA_F, __pyx_k_0_xX_0_9a_fA_F, sizeof(__pyx_k_0_xX_0_9a_fA_F), 0, 1, 0, 0},
  {&__pyx_kp_u_0x, __pyx_k_0x, sizeof(__pyx_k_0x), 0, 1, 0, 0},
  {&__pyx_kp_u_0xa1_0xbf_0xd7_0xf7, __pyx_k_0xa1_0xbf_0xd7_0xf7, sizeof(__pyx_k_0xa1_0xbf_0xd7_0xf7), 0, 1, 0, 0},
  {&__pyx_kp_u_0xc0_0xd6_0xd8_0xf6_0xf8_0xff, __pyx_k_0xc0_0xd6_0xd8_0xf6_0xf8_0xff, sizeof(__pyx_k_0xc0_0xd6_0xd8_0xf6_0xf8_0xff), 0, 1, 0, 0},
  {&__pyx_kp_u_100_100_100_3_14159_6_02e23_1e, __pyx_k_100_100_100_3_14159_6_02e23_1e, sizeof(__pyx_k_100_100_100_3_14159_6_02e23_1e), 0, 1, 0, 0},
  {&__pyx_kp_u_100_FF, __pyx_k_100_FF, sizeof(__pyx_k_100_FF), 0, 1, 0, 0},
  {&__pyx_kp_u_12345678_1234_5678_1234_5678123, __pyx_k_12345678_1234_5678_1234_5678123, sizeof(__pyx_k_12345678_1234_5678_1234_5678123), 0, 1, 0, 0},
  {&__pyx_kp_u_25_0_5_2_0_4_0_9_1_0_9_1_2_25_0, __pyx_k_25_0_5_2_0_4_0_9_1_0_9_1_2_25_0, sizeof(__pyx_k_25_0_5_2_0_4_0_9_1_0_9_1_2_25_0), 0, 1, 0, 0},
  {&__pyx_kp_u_2_2_0, __pyx_k_2_2_0, sizeof(__pyx_k_2_2_0), 0, 1, 0, 0},
  {&__pyx_n_u_ABCDEFabcdef, __pyx_k_ABCDEFabcdef, sizeof(__pyx_k_ABCDEFabcdef), 0, 1, 0, 1},
  {&__pyx_n_s_ANY_VALUE, __pyx_k_ANY_VALUE, sizeof(__pyx_k_ANY_VALUE), 0, 0, 1, 1},
  {&__pyx_kp_u_A_Z, __pyx_k_A_Z, sizeof(__pyx_k_A_Z), 0, 1, 0, 0},
  {&__pyx_kp_s_A_token_that_will_never_match, __pyx_k_A_token_that_will_never_match, sizeof(__pyx_k_A_token_that_will_never_match), 0, 0, 1, 0},
  {&__pyx_kp_s_A_variation_on_L_Literal_which, __pyx_k_A_variation_on_L_Literal_which, sizeof(__pyx_k_A_variation_on_L_Literal_which), 0, 0, 1, 0},
  {&__pyx_kp_s_Abstract_C_ParserElement_subcla, __pyx_k_Abstract_C_ParserElement_subcla, sizeof(__pyx_k_Abstract_C_ParserElement_subcla), 0, 0, 1, 0},
  {&__pyx_kp_s_Abstract_base_level_parser_eleme, __pyx_k_Abstract_base_level_parser_eleme, sizeof(__pyx_k_Abstract_base_level_parser_eleme), 0, 0, 1, 0},
  {&__pyx_kp_s_Abstract_subclass_of_C_ParseExp, __pyx_k_Abstract_subclass_of_C_ParseExp, sizeof(__pyx_k_Abstract_subclass_of_C_ParseExp), 0, 0, 1, 0},
  {&__pyx_kp_s_Abstract_subclass_of_C_ParserEl, __pyx_k_Abstract_subclass_of_C_ParserEl, sizeof(__pyx_k_Abstract_subclass_of_C_ParserEl), 0, 0, 1, 0},
  {&__pyx_kp_s_Abstract_subclass_of_ParserElem, __pyx_k_Abstract_subclass_of_ParserElem, sizeof(__pyx_k_Abstract_subclass_of_ParserElem), 0, 0, 1, 0},
  {&__pyx_kp_s_An_empty_token_will_always_matc, __pyx_k_An_empty_token_will_always_matc, sizeof(__pyx_k_An_empty_token_will_always_matc), 0, 0, 1, 0},
  {&__pyx_n_s_And, __pyx_k_And, sizeof(__pyx_k_And), 0, 0, 1, 1},
  {&__pyx_n_u_And, __pyx_k_And, sizeof(__pyx_k_And), 0, 1, 0, 1},
  {&__pyx_n_s_And__ErrorStop, __pyx_k_And__ErrorStop, sizeof(__pyx_k_And__ErrorStop), 0, 0, 1, 1},
  {&__pyx_n_s_And__ErrorStop___init, __pyx_k_And__ErrorStop___init, sizeof(__pyx_k_And__ErrorStop___init), 0, 0, 1, 1},
  {&__pyx_n_s_And___iadd, __pyx_k_And___iadd, sizeof(__pyx_k_And___iadd), 0, 0, 1, 1},
  {&__pyx_n_s_And___init, __pyx_k_And___init, sizeof(__pyx_k_And___init), 0, 0, 1, 1},
  {&__pyx_n_s_And___init___locals_genexpr, __pyx_k_And___init___locals_genexpr, sizeof(__pyx_k_And___init___locals_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_And___str, __pyx_k_And___str, sizeof(__pyx_k_And___str), 0, 0, 1, 1},
  {&__pyx_n_s_And___str___locals_genexpr, __pyx_k_And___str___locals_genexpr, sizeof(__pyx_k_And___str___locals_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_And_checkRecursion, __pyx_k_And_checkRecursion, sizeof(__pyx_k_And_checkRecursion), 0, 0, 1, 1},
  {&__pyx_n_s_And_parseImpl, __pyx_k_And_parseImpl, sizeof(__pyx_k_And_parseImpl), 0, 0, 1, 1},
  {&__pyx_n_s_AttributeError, __pyx_k_AttributeError, sizeof(__pyx_k_AttributeError), 0, 0, 1, 1},
  {&__pyx_kp_u_CR, __pyx_k_CR, sizeof(__pyx_k_CR), 0, 1, 0, 0},
  {&__pyx_kp_u_C_style_comment, __pyx_k_C_style_comment, sizeof(__pyx_k_C_style_comment), 0, 1, 0, 0},
  {&__pyx_kp_u_C_style_comment_2, __pyx_k_C_style_comment_2, sizeof(__pyx_k_C_style_comment_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Cannot_combine_element_of_type_s, __pyx_k_Cannot_combine_element_of_type_s, sizeof(__pyx_k_Cannot_combine_element_of_type_s), 0, 1, 0, 0},
  {&__pyx_n_s_CaselessKeyword, __pyx_k_CaselessKeyword, sizeof(__pyx_k_CaselessKeyword), 0, 0, 1, 1},
  {&__pyx_n_u_CaselessKeyword, __pyx_k_CaselessKeyword, sizeof(__pyx_k_CaselessKeyword), 0, 1, 0, 1},
  {&__pyx_n_s_CaselessKeyword___init, __pyx_k_CaselessKeyword___init, sizeof(__pyx_k_CaselessKeyword___init), 0, 0, 1, 1},
  {&__pyx_n_s_CaselessKeyword_parseImpl, __pyx_k_CaselessKeyword_parseImpl, sizeof(__pyx_k_CaselessKeyword_parseImpl), 0, 0, 1, 1},
  {&__pyx_n_s_CaselessLiteral, __pyx_k_CaselessLiteral, sizeof(__pyx_k_CaselessLiteral), 0, 0, 1, 1},
  {&__pyx_n_u_CaselessLiteral, __pyx_k_CaselessLiteral, sizeof(__pyx_k_CaselessLiteral), 0, 1, 0, 1},
  {&__pyx_n_s_CaselessLiteral___init, __pyx_k_CaselessLiteral___init, sizeof(__pyx_k_CaselessLiteral___init), 0, 0, 1, 1},
  {&__pyx_n_s_CaselessLiteral_parseImpl, __pyx_k_CaselessLiteral_parseImpl, sizeof(__pyx_k_CaselessLiteral_parseImpl), 0, 0, 1, 1},
  {&__pyx_kp_s_Caseless_version_of_L_Keyword_E, __pyx_k_Caseless_version_of_L_Keyword_E, sizeof(__pyx_k_Caseless_version_of_L_Keyword_E), 0, 0, 1, 0},
  {&__pyx_n_s_CharsNotIn, __pyx_k_CharsNotIn, sizeof(__pyx_k_CharsNotIn), 0, 0, 1, 1},
  {&__pyx_n_u_CharsNotIn, __pyx_k_CharsNotIn, sizeof(__pyx_k_CharsNotIn), 0, 1, 0, 1},
  {&__pyx_n_s_CharsNotIn___init, __pyx_k_CharsNotIn___init, sizeof(__pyx_k_CharsNotIn___init), 0, 0, 1, 1},
  {&__pyx_n_s_CharsNotIn___str, __pyx_k_CharsNotIn___str, sizeof(__pyx_k_CharsNotIn___str), 0, 0, 1, 1},
  {&__pyx_n_s_CharsNotIn_parseImpl, __pyx_k_CharsNotIn_parseImpl, sizeof(__pyx_k_CharsNotIn_parseImpl), 0, 0, 1, 1},
  {&__pyx_n_s_CloseMatch, __pyx_k_CloseMatch, sizeof(__pyx_k_CloseMatch), 0, 0, 1, 1},
  {&__pyx_n_u_CloseMatch, __pyx_k_CloseMatch, sizeof(__pyx_k_CloseMatch), 0, 1, 0, 1},
  {&__pyx_n_s_CloseMatch___init, __pyx_k_CloseMatch___init, sizeof(__pyx_k_CloseMatch___init), 0, 0, 1, 1},
  {&__pyx_n_s_CloseMatch_parseImpl, __pyx_k_CloseMatch_parseImpl, sizeof(__pyx_k_CloseMatch_parseImpl), 0, 0, 1, 1},
  {&__pyx_n_s_Combine, __pyx_k_Combine, sizeof(__pyx_k_Combine), 0, 0, 1, 1},
  {&__pyx_n_u_Combine, __pyx_k_Combine, sizeof(__pyx_k_Combine), 0, 1, 0, 1},
  {&__pyx_n_s_Combine___init, __pyx_k_Combine___init, sizeof(__pyx_k_Combine___init), 0, 0, 1, 1},
  {&__pyx_n_s_Combine_ignore, __pyx_k_Combine_ignore, sizeof(__pyx_k_Combine_ignore), 0, 0, 1, 1},
  {&__pyx_n_s_Combine_postParse, __pyx_k_Combine_postParse, sizeof(__pyx_k_Combine_postParse), 0, 0, 1, 1},
  {&__pyx_n_s_Constants, __pyx_k_Constants, sizeof(__pyx_k_Constants), 0, 0, 1, 1},
  {&__pyx_kp_s_Converter_for_ignoring_the_resu, __pyx_k_Converter_for_ignoring_the_resu, sizeof(__pyx_k_Converter_for_ignoring_the_resu), 0, 0, 1, 0},
  {&__pyx_kp_s_Converter_to_concatenate_all_ma, __pyx_k_Converter_to_concatenate_all_ma, sizeof(__pyx_k_Converter_to_concatenate_all_ma), 0, 0, 1, 0},
  {&__pyx_kp_s_Converter_to_return_a_repetitiv, __pyx_k_Converter_to_return_a_repetitiv, sizeof(__pyx_k_Converter_to_return_a_repetitiv), 0, 0, 1, 0},
  {&__pyx_kp_s_Converter_to_return_the_matched, __pyx_k_Converter_to_return_the_matched, sizeof(__pyx_k_Converter_to_return_the_matched), 0, 0, 1, 0},
  {&__pyx_n_s_DEFAULT_KEYWORD_CHARS, __pyx_k_DEFAULT_KEYWORD_CHARS, sizeof(__pyx_k_DEFAULT_KEYWORD_CHARS), 0, 0, 1, 1},
  {&__pyx_n_s_DEFAULT_WHITE_CHARS, __pyx_k_DEFAULT_WHITE_CHARS, sizeof(__pyx_k_DEFAULT_WHITE_CHARS), 0, 0, 1, 1},
  {&__pyx_n_s_DOTALL, __pyx_k_DOTALL, sizeof(__pyx_k_DOTALL), 0, 0, 1, 1},
  {&__pyx_n_s_Dict, __pyx_k_Dict, sizeof(__pyx_k_Dict), 0, 0, 1, 1},
  {&__pyx_n_u_Dict, __pyx_k_Dict, sizeof(__pyx_k_Dict), 0, 1, 0, 1},
  {&__pyx_n_s_Dict___init, __pyx_k_Dict___init, sizeof(__pyx_k_Dict___init), 0, 0, 1, 1},
  {&__pyx_n_s_Dict_postParse, __pyx_k_Dict_postParse, sizeof(__pyx_k_Dict_postParse), 0, 0, 1, 1},
  {&__pyx_n_s_Each, __pyx_k_Each, sizeof(__pyx_k_Each), 0, 0, 1, 1},
  {&__pyx_n_u_Each, __pyx_k_Each, sizeof(__pyx_k_Each), 0, 1, 0, 1},
  {&__pyx_n_s_Each___init, __pyx_k_Each___init, sizeof(__pyx_k_Each___init), 0, 0, 1, 1},
  {&__pyx_n_s_Each___init___locals_genexpr, __pyx_k_Each___init___locals_genexpr, sizeof(__pyx_k_Each___init___locals_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_Each___str, __pyx_k_Each___str, sizeof(__pyx_k_Each___str), 0, 0, 1, 1},
  {&__pyx_n_s_Each___str___locals_genexpr, __pyx_k_Each___str___locals_genexpr, sizeof(__pyx_k_Each___str___locals_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_Each_checkRecursion, __pyx_k_Each_checkRecursion, sizeof(__pyx_k_Each_checkRecursion), 0, 0, 1, 1},
  {&__pyx_n_s_Each_parseImpl, __pyx_k_Each_parseImpl, sizeof(__pyx_k_Each_parseImpl), 0, 0, 1, 1},
  {&__pyx_n_s_Each_parseImpl_locals_genexpr, __pyx_k_Each_parseImpl_locals_genexpr, sizeof(__pyx_k_Each_parseImpl_locals_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_Empty, __pyx_k_Empty, sizeof(__pyx_k_Empty), 0, 0, 1, 1},
  {&__pyx_n_u_Empty, __pyx_k_Empty, sizeof(__pyx_k_Empty), 0, 1, 0, 1},
  {&__pyx_n_s_Empty___init, __pyx_k_Empty___init, sizeof(__pyx_k_Empty___init), 0, 0, 1, 1},
  {&__pyx_n_s_ErrorStop, __pyx_k_ErrorStop, sizeof(__pyx_k_ErrorStop), 0, 0, 1, 1},
  {&__pyx_kp_u_Exception_creating_Regex_for_one, __pyx_k_Exception_creating_Regex_for_one, sizeof(__pyx_k_Exception_creating_Regex_for_one), 0, 1, 0, 0},
  {&__pyx_kp_u_Exception_raised, __pyx_k_Exception_raised, sizeof(__pyx_k_Exception_raised), 0, 1, 0, 0},
  {&__pyx_kp_s_Exception_thrown_when_parse_exp, __pyx_k_Exception_thrown_when_parse_exp, sizeof(__pyx_k_Exception_thrown_when_parse_exp), 0, 0, 1, 0},
  {&__pyx_kp_u_Expected, __pyx_k_Expected, sizeof(__pyx_k_Expected), 0, 1, 0, 0},
  {&__pyx_kp_u_Expected_end_of_line, __pyx_k_Expected_end_of_line, sizeof(__pyx_k_Expected_end_of_line), 0, 1, 0, 0},
  {&__pyx_kp_u_Expected_end_of_text, __pyx_k_Expected_end_of_text, sizeof(__pyx_k_Expected_end_of_text), 0, 1, 0, 0},
  {&__pyx_kp_u_Expected_r_with_up_to_d_mismatch, __pyx_k_Expected_r_with_up_to_d_mismatch, sizeof(__pyx_k_Expected_r_with_up_to_d_mismatch), 0, 1, 0, 0},
  {&__pyx_kp_u_Expected_start_of_line, __pyx_k_Expected_start_of_line, sizeof(__pyx_k_Expected_start_of_line), 0, 1, 0, 0},
  {&__pyx_kp_u_Expected_start_of_text, __pyx_k_Expected_start_of_text, sizeof(__pyx_k_Expected_start_of_text), 0, 1, 0, 0},
  {&__pyx_kp_u_FAIL, __pyx_k_FAIL, sizeof(__pyx_k_FAIL), 0, 1, 0, 0},
  {&__pyx_kp_u_FAIL_EXCEPTION, __pyx_k_FAIL_EXCEPTION, sizeof(__pyx_k_FAIL_EXCEPTION), 0, 1, 0, 0},
  {&__pyx_kp_u_FATAL, __pyx_k_FATAL, sizeof(__pyx_k_FATAL), 0, 1, 0, 0},
  {&__pyx_kp_u_FF, __pyx_k_FF, sizeof(__pyx_k_FF), 0, 1, 0, 0},
  {&__pyx_n_s_FILE_NAME, __pyx_k_FILE_NAME, sizeof(__pyx_k_FILE_NAME), 0, 0, 1, 1},
  {&__pyx_n_s_FifoCache, __pyx_k_FifoCache, sizeof(__pyx_k_FifoCache), 0, 0, 1, 1},
  {&__pyx_n_s_FollowedBy, __pyx_k_FollowedBy, sizeof(__pyx_k_FollowedBy), 0, 0, 1, 1},
  {&__pyx_n_u_FollowedBy, __pyx_k_FollowedBy, sizeof(__pyx_k_FollowedBy), 0, 1, 0, 1},
  {&__pyx_n_s_FollowedBy___init, __pyx_k_FollowedBy___init, sizeof(__pyx_k_FollowedBy___init), 0, 0, 1, 1},
  {&__pyx_n_s_FollowedBy_parseImpl, __pyx_k_FollowedBy_parseImpl, sizeof(__pyx_k_FollowedBy_parseImpl), 0, 0, 1, 1},
  {&__pyx_n_s_Forward, __pyx_k_Forward, sizeof(__pyx_k_Forward), 0, 0, 1, 1},
  {&__pyx_n_u_Forward, __pyx_k_Forward, sizeof(__pyx_k_Forward), 0, 1, 0, 1},
  {&__pyx_n_s_ForwardNoRecurse, __pyx_k_ForwardNoRecurse, sizeof(__pyx_k_ForwardNoRecurse), 0, 0, 1, 1},
  {&__pyx_n_s_ForwardNoRecurse___str, __pyx_k_ForwardNoRecurse___str, sizeof(__pyx_k_ForwardNoRecurse___str), 0, 0, 1, 1},
  {&__pyx_n_s_Forward___ilshift, __pyx_k_Forward___ilshift, sizeof(__pyx_k_Forward___ilshift), 0, 0, 1, 1},
  {&__pyx_n_s_Forward___init, __pyx_k_Forward___init, sizeof(__pyx_k_Forward___init), 0, 0, 1, 1},
  {&__pyx_n_s_Forward___lshift, __pyx_k_Forward___lshift, sizeof(__pyx_k_Forward___lshift), 0, 0, 1, 1},
  {&__pyx_n_s_Forward___str, __pyx_k_Forward___str, sizeof(__pyx_k_Forward___str), 0, 0, 1, 1},
  {&__pyx_n_s_Forward_copy, __pyx_k_Forward_copy, sizeof(__pyx_k_Forward_copy), 0, 0, 1, 1},
  {&__pyx_kp_s_Forward_declaration_of_an_expre, __pyx_k_Forward_declaration_of_an_expre, sizeof(__pyx_k_Forward_declaration_of_an_expre), 0, 0, 1, 0},
  {&__pyx_n_s_Forward_leaveWhitespace, __pyx_k_Forward_leaveWhitespace, sizeof(__pyx_k_Forward_leaveWhitespace), 0, 0, 1, 1},
  {&__pyx_n_s_Forward_streamline, __pyx_k_Forward_streamline, sizeof(__pyx_k_Forward_streamline), 0, 0, 1, 1},
  {&__pyx_n_s_Forward_validate, __pyx_k_Forward_validate, sizeof(__pyx_k_Forward_validate), 0, 0, 1, 1},
  {&__pyx_kp_u_Found_unwanted_token, __pyx_k_Found_unwanted_token, sizeof(__pyx_k_Found_unwanted_token), 0, 1, 0, 0},
  {&__pyx_n_s_GoToColumn, __pyx_k_GoToColumn, sizeof(__pyx_k_GoToColumn), 0, 0, 1, 1},
  {&__pyx_n_u_GoToColumn, __pyx_k_GoToColumn, sizeof(__pyx_k_GoToColumn), 0, 1, 0, 1},
  {&__pyx_n_s_GoToColumn___init, __pyx_k_GoToColumn___init, sizeof(__pyx_k_GoToColumn___init), 0, 0, 1, 1},
  {&__pyx_n_s_GoToColumn_parseImpl, __pyx_k_GoToColumn_parseImpl, sizeof(__pyx_k_GoToColumn_parseImpl), 0, 0, 1, 1},
  {&__pyx_n_s_GoToColumn_preParse, __pyx_k_GoToColumn_preParse, sizeof(__pyx_k_GoToColumn_preParse), 0, 0, 1, 1},
  {&__pyx_n_s_Group, __pyx_k_Group, sizeof(__pyx_k_Group), 0, 0, 1, 1},
  {&__pyx_n_u_Group, __pyx_k_Group, sizeof(__pyx_k_Group), 0, 1, 0, 1},
  {&__pyx_n_s_Group___init, __pyx_k_Group___init, sizeof(__pyx_k_Group___init), 0, 0, 1, 1},
  {&__pyx_n_s_Group_postParse, __pyx_k_Group_postParse, sizeof(__pyx_k_Group_postParse), 0, 0, 1, 1},
  {&__pyx_n_s_HIT, __pyx_k_HIT, sizeof(__pyx_k_HIT), 0, 0, 1, 1},
  {&__pyx_kp_u_HTML_comment, __pyx_k_HTML_comment, sizeof(__pyx_k_HTML_comment), 0, 1, 0, 0},
  {&__pyx_kp_s_Helper_to_create_a_validating_p, __pyx_k_Helper_to_create_a_validating_p, sizeof(__pyx_k_Helper_to_create_a_validating_p), 0, 0, 1, 0},
  {&__pyx_kp_s_Here_are_some_common_low_level, __pyx_k_Here_are_some_common_low_level, sizeof(__pyx_k_Here_are_some_common_low_level), 0, 0, 1, 0},
  {&__pyx_n_s_INDENT, __pyx_k_INDENT, sizeof(__pyx_k_INDENT), 0, 0, 1, 1},
  {&__pyx_n_u_INDENT, __pyx_k_INDENT, sizeof(__pyx_k_INDENT), 0, 1, 0, 1},
  {&__pyx_kp_u_IPv4_address, __pyx_k_IPv4_address, sizeof(__pyx_k_IPv4_address), 0, 1, 0, 0},
  {&__pyx_kp_u_IPv6_address, __pyx_k_IPv6_address, sizeof(__pyx_k_IPv6_address), 0, 1, 0, 0},
  {&__pyx_kp_u_ISO8601_date, __pyx_k_ISO8601_date, sizeof(__pyx_k_ISO8601_date), 0, 1, 0, 0},
  {&__pyx_kp_u_ISO8601_datetime, __pyx_k_ISO8601_datetime, sizeof(__pyx_k_ISO8601_datetime), 0, 1, 0, 0},
  {&__pyx_n_u_ITEM, __pyx_k_ITEM, sizeof(__pyx_k_ITEM), 0, 1, 0, 1},
  {&__pyx_n_s_ImportError, __pyx_k_ImportError, sizeof(__pyx_k_ImportError), 0, 0, 1, 1},
  {&__pyx_n_s_IndexError, __pyx_k_IndexError, sizeof(__pyx_k_IndexError), 0, 0, 1, 1},
  {&__pyx_kp_u_Invalid_argument_to_oneOf_expect, __pyx_k_Invalid_argument_to_oneOf_expect, sizeof(__pyx_k_Invalid_argument_to_oneOf_expect), 0, 1, 0, 0},
  {&__pyx_n_s_Iterable, __pyx_k_Iterable, sizeof(__pyx_k_Iterable), 0, 0, 1, 1},
  {&__pyx_n_s_KeyError, __pyx_k_KeyError, sizeof(__pyx_k_KeyError), 0, 0, 1, 1},
  {&__pyx_n_s_Keyword, __pyx_k_Keyword, sizeof(__pyx_k_Keyword), 0, 0, 1, 1},
  {&__pyx_n_u_Keyword, __pyx_k_Keyword, sizeof(__pyx_k_Keyword), 0, 1, 0, 1},
  {&__pyx_n_s_Keyword___init, __pyx_k_Keyword___init, sizeof(__pyx_k_Keyword___init), 0, 0, 1, 1},
  {&__pyx_n_s_Keyword_copy, __pyx_k_Keyword_copy, sizeof(__pyx_k_Keyword_copy), 0, 0, 1, 1},
  {&__pyx_n_s_Keyword_parseImpl, __pyx_k_Keyword_parseImpl, sizeof(__pyx_k_Keyword_parseImpl), 0, 0, 1, 1},
  {&__pyx_n_s_Keyword_setDefaultKeywordChars, __pyx_k_Keyword_setDefaultKeywordChars, sizeof(__pyx_k_Keyword_setDefaultKeywordChars), 0, 0, 1, 1},
  {&__pyx_n_s_L, __pyx_k_L, sizeof(__pyx_k_L), 0, 0, 1, 1},
  {&__pyx_n_s_LEFT, __pyx_k_LEFT, sizeof(__pyx_k_LEFT), 0, 0, 1, 1},
  {&__pyx_kp_u_LF, __pyx_k_LF, sizeof(__pyx_k_LF), 0, 1, 0, 0},
  {&__pyx_n_s_L_2, __pyx_k_L_2, sizeof(__pyx_k_L_2), 0, 0, 1, 1},
  {&__pyx_n_s_LineEnd, __pyx_k_LineEnd, sizeof(__pyx_k_LineEnd), 0, 0, 1, 1},
  {&__pyx_n_u_LineEnd, __pyx_k_LineEnd, sizeof(__pyx_k_LineEnd), 0, 1, 0, 1},
  {&__pyx_n_s_LineEnd___init, __pyx_k_LineEnd___init, sizeof(__pyx_k_LineEnd___init), 0, 0, 1, 1},
  {&__pyx_n_s_LineEnd_parseImpl, __pyx_k_LineEnd_parseImpl, sizeof(__pyx_k_LineEnd_parseImpl), 0, 0, 1, 1},
  {&__pyx_n_s_LineStart, __pyx_k_LineStart, sizeof(__pyx_k_LineStart), 0, 0, 1, 1},
  {&__pyx_n_u_LineStart, __pyx_k_LineStart, sizeof(__pyx_k_LineStart), 0, 1, 0, 1},
  {&__pyx_n_s_LineStart___init, __pyx_k_LineStart___init, sizeof(__pyx_k_LineStart___init), 0, 0, 1, 1},
  {&__pyx_n_s_LineStart_parseImpl, __pyx_k_LineStart_parseImpl, sizeof(__pyx_k_LineStart_parseImpl), 0, 0, 1, 1},
  {&__pyx_n_s_Literal, __pyx_k_Literal, sizeof(__pyx_k_Literal), 0, 0, 1, 1},
  {&__pyx_n_u_Literal, __pyx_k_Literal, sizeof(__pyx_k_Literal), 0, 1, 0, 1},
  {&__pyx_n_s_Literal___init, __pyx_k_Literal___init, sizeof(__pyx_k_Literal___init), 0, 0, 1, 1},
  {&__pyx_n_s_Literal_parseImpl, __pyx_k_Literal_parseImpl, sizeof(__pyx_k_Literal_parseImpl), 0, 0, 1, 1},
  {&__pyx_kp_s_Lookahead_matching_of_the_given, __pyx_k_Lookahead_matching_of_the_given, sizeof(__pyx_k_Lookahead_matching_of_the_given), 0, 0, 1, 0},
  {&__pyx_kp_s_Lookahead_to_disallow_matching, __pyx_k_Lookahead_to_disallow_matching, sizeof(__pyx_k_Lookahead_to_disallow_matching), 0, 0, 1, 0},
  {&__pyx_kp_u_MAC_address, __pyx_k_MAC_address, sizeof(__pyx_k_MAC_address), 0, 1, 0, 0},
  {&__pyx_n_s_MAX_INT, __pyx_k_MAX_INT, sizeof(__pyx_k_MAX_INT), 0, 0, 1, 1},
  {&__pyx_n_s_MISS, __pyx_k_MISS, sizeof(__pyx_k_MISS), 0, 0, 1, 1},
  {&__pyx_n_s_MULTILINE, __pyx_k_MULTILINE, sizeof(__pyx_k_MULTILINE), 0, 0, 1, 1},
  {&__pyx_kp_u_Match, __pyx_k_Match, sizeof(__pyx_k_Match), 0, 1, 0, 0},
  {&__pyx_n_s_MatchFirst, __pyx_k_MatchFirst, sizeof(__pyx_k_MatchFirst), 0, 0, 1, 1},
  {&__pyx_n_u_MatchFirst, __pyx_k_MatchFirst, sizeof(__pyx_k_MatchFirst), 0, 1, 0, 1},
  {&__pyx_n_s_MatchFirst___init, __pyx_k_MatchFirst___init, sizeof(__pyx_k_MatchFirst___init), 0, 0, 1, 1},
  {&__pyx_n_s_MatchFirst___init___locals_genex, __pyx_k_MatchFirst___init___locals_genex, sizeof(__pyx_k_MatchFirst___init___locals_genex), 0, 0, 1, 1},
  {&__pyx_n_s_MatchFirst___ior, __pyx_k_MatchFirst___ior, sizeof(__pyx_k_MatchFirst___ior), 0, 0, 1, 1},
  {&__pyx_n_s_MatchFirst___str, __pyx_k_MatchFirst___str, sizeof(__pyx_k_MatchFirst___str), 0, 0, 1, 1},
  {&__pyx_n_s_MatchFirst___str___locals_genexp, __pyx_k_MatchFirst___str___locals_genexp, sizeof(__pyx_k_MatchFirst___str___locals_genexp), 0, 0, 1, 1},
  {&__pyx_n_s_MatchFirst_checkRecursion, __pyx_k_MatchFirst_checkRecursion, sizeof(__pyx_k_MatchFirst_checkRecursion), 0, 0, 1, 1},
  {&__pyx_n_s_MatchFirst_parseImpl, __pyx_k_MatchFirst_parseImpl, sizeof(__pyx_k_MatchFirst_parseImpl), 0, 0, 1, 1},
  {&__pyx_kp_u_Matched, __pyx_k_Matched, sizeof(__pyx_k_Matched), 0, 1, 0, 0},
  {&__pyx_kp_s_Matches_if_current_position_is, __pyx_k_Matches_if_current_position_is, sizeof(__pyx_k_Matches_if_current_position_is), 0, 0, 1, 0},
  {&__pyx_kp_s_Matches_if_current_position_is_2, __pyx_k_Matches_if_current_position_is_2, sizeof(__pyx_k_Matches_if_current_position_is_2), 0, 0, 1, 0},
  {&__pyx_kp_s_Matches_if_current_position_is_3, __pyx_k_Matches_if_current_position_is_3, sizeof(__pyx_k_Matches_if_current_position_is_3), 0, 0, 1, 0},
  {&__pyx_kp_s_Matches_if_current_position_is_4, __pyx_k_Matches_if_current_position_is_4, sizeof(__pyx_k_Matches_if_current_position_is_4), 0, 0, 1, 0},
  {&__pyx_kp_s_Matches_if_the_current_position, __pyx_k_Matches_if_the_current_position, sizeof(__pyx_k_Matches_if_the_current_position), 0, 0, 1, 0},
  {&__pyx_kp_s_Matches_if_the_current_position_2, __pyx_k_Matches_if_the_current_position_2, sizeof(__pyx_k_Matches_if_the_current_position_2), 0, 0, 1, 0},
  {&__pyx_n_s_MethodType, __pyx_k_MethodType, sizeof(__pyx_k_MethodType), 0, 0, 1, 1},
  {&__pyx_kp_u_Missing_one_or_more_required_ele, __pyx_k_Missing_one_or_more_required_ele, sizeof(__pyx_k_Missing_one_or_more_required_ele), 0, 1, 0, 0},
  {&__pyx_n_s_MultipleMatch, __pyx_k_MultipleMatch, sizeof(__pyx_k_MultipleMatch), 0, 0, 1, 1},
  {&__pyx_n_s_MultipleMatch___init, __pyx_k_MultipleMatch___init, sizeof(__pyx_k_MultipleMatch___init), 0, 0, 1, 1},
  {&__pyx_n_s_MultipleMatch_parseImpl, __pyx_k_MultipleMatch_parseImpl, sizeof(__pyx_k_MultipleMatch_parseImpl), 0, 0, 1, 1},
  {&__pyx_n_s_MutableMapping, __pyx_k_MutableMapping, sizeof(__pyx_k_MutableMapping), 0, 0, 1, 1},
  {&__pyx_n_s_NL, __pyx_k_NL, sizeof(__pyx_k_NL), 0, 0, 1, 1},
  {&__pyx_n_s_NoMatch, __pyx_k_NoMatch, sizeof(__pyx_k_NoMatch), 0, 0, 1, 1},
  {&__pyx_n_u_NoMatch, __pyx_k_NoMatch, sizeof(__pyx_k_NoMatch), 0, 1, 0, 1},
  {&__pyx_n_s_NoMatch___init, __pyx_k_NoMatch___init, sizeof(__pyx_k_NoMatch___init), 0, 0, 1, 1},
  {&__pyx_n_s_NoMatch_parseImpl, __pyx_k_NoMatch_parseImpl, sizeof(__pyx_k_NoMatch_parseImpl), 0, 0, 1, 1},
  {&__pyx_kp_u_No_match_found_for, __pyx_k_No_match_found_for, sizeof(__pyx_k_No_match_found_for), 0, 1, 0, 0},
  {&__pyx_n_s_NotAny, __pyx_k_NotAny, sizeof(__pyx_k_NotAny), 0, 0, 1, 1},
  {&__pyx_n_u_NotAny, __pyx_k_NotAny, sizeof(__pyx_k_NotAny), 0, 1, 0, 1},
  {&__pyx_n_s_NotAny___init, __pyx_k_NotAny___init, sizeof(__pyx_k_NotAny___init), 0, 0, 1, 1},
  {&__pyx_n_s_NotAny___str, __pyx_k_NotAny___str, sizeof(__pyx_k_NotAny___str), 0, 0, 1, 1},
  {&__pyx_n_s_NotAny_parseImpl, __pyx_k_NotAny_parseImpl, sizeof(__pyx_k_NotAny_parseImpl), 0, 0, 1, 1},
  {&__pyx_kp_u_Not_at_the_end_of_a_word, __pyx_k_Not_at_the_end_of_a_word, sizeof(__pyx_k_Not_at_the_end_of_a_word), 0, 1, 0, 0},
  {&__pyx_kp_u_Not_at_the_start_of_a_word, __pyx_k_Not_at_the_start_of_a_word, sizeof(__pyx_k_Not_at_the_start_of_a_word), 0, 1, 0, 0},
  {&__pyx_n_s_NullToken, __pyx_k_NullToken, sizeof(__pyx_k_NullToken), 0, 0, 1, 1},
  {&__pyx_n_s_NullToken___bool, __pyx_k_NullToken___bool, sizeof(__pyx_k_NullToken___bool), 0, 0, 1, 1},
  {&__pyx_n_s_NullToken___str, __pyx_k_NullToken___str, sizeof(__pyx_k_NullToken___str), 0, 0, 1, 1},
  {&__pyx_n_s_OneOrMore, __pyx_k_OneOrMore, sizeof(__pyx_k_OneOrMore), 0, 0, 1, 1},
  {&__pyx_n_u_OneOrMore, __pyx_k_OneOrMore, sizeof(__pyx_k_OneOrMore), 0, 1, 0, 1},
  {&__pyx_n_s_OneOrMore___str, __pyx_k_OneOrMore___str, sizeof(__pyx_k_OneOrMore___str), 0, 0, 1, 1},
  {&__pyx_n_s_OnlyOnce, __pyx_k_OnlyOnce, sizeof(__pyx_k_OnlyOnce), 0, 0, 1, 1},
  {&__pyx_n_u_OnlyOnce, __pyx_k_OnlyOnce, sizeof(__pyx_k_OnlyOnce), 0, 1, 0, 1},
  {&__pyx_n_s_OnlyOnce___call, __pyx_k_OnlyOnce___call, sizeof(__pyx_k_OnlyOnce___call), 0, 0, 1, 1},
  {&__pyx_n_s_OnlyOnce___init, __pyx_k_OnlyOnce___init, sizeof(__pyx_k_OnlyOnce___init), 0, 0, 1, 1},
  {&__pyx_n_s_OnlyOnce_reset, __pyx_k_OnlyOnce_reset, sizeof(__pyx_k_OnlyOnce_reset), 0, 0, 1, 1},
  {&__pyx_n_s_Optional, __pyx_k_Optional, sizeof(__pyx_k_Optional), 0, 0, 1, 1},
  {&__pyx_n_u_Optional, __pyx_k_Optional, sizeof(__pyx_k_Optional), 0, 1, 0, 1},
  {&__pyx_n_s_Optional___init, __pyx_k_Optional___init, sizeof(__pyx_k_Optional___init), 0, 0, 1, 1},
  {&__pyx_n_s_Optional___str, __pyx_k_Optional___str, sizeof(__pyx_k_Optional___str), 0, 0, 1, 1},
  {&__pyx_kp_s_Optional_matching_of_the_given, __pyx_k_Optional_matching_of_the_given, sizeof(__pyx_k_Optional_matching_of_the_given), 0, 0, 1, 0},
  {&__pyx_n_s_Optional_parseImpl, __pyx_k_Optional_parseImpl, sizeof(__pyx_k_Optional_parseImpl), 0, 0, 1, 1},
  {&__pyx_kp_s_Optional_repetition_of_zero_or, __pyx_k_Optional_repetition_of_zero_or, sizeof(__pyx_k_Optional_repetition_of_zero_or), 0, 0, 1, 0},
  {&__pyx_n_s_Or, __pyx_k_Or, sizeof(__pyx_k_Or), 0, 0, 1, 1},
  {&__pyx_n_u_Or, __pyx_k_Or, sizeof(__pyx_k_Or), 0, 1, 0, 1},
  {&__pyx_n_s_Or___init, __pyx_k_Or___init, sizeof(__pyx_k_Or___init), 0, 0, 1, 1},
  {&__pyx_n_s_Or___init___locals_genexpr, __pyx_k_Or___init___locals_genexpr, sizeof(__pyx_k_Or___init___locals_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_Or___ixor, __pyx_k_Or___ixor, sizeof(__pyx_k_Or___ixor), 0, 0, 1, 1},
  {&__pyx_n_s_Or___str, __pyx_k_Or___str, sizeof(__pyx_k_Or___str), 0, 0, 1, 1},
  {&__pyx_n_s_Or___str___locals_genexpr, __pyx_k_Or___str___locals_genexpr, sizeof(__pyx_k_Or___str___locals_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_Or_checkRecursion, __pyx_k_Or_checkRecursion, sizeof(__pyx_k_Or_checkRecursion), 0, 0, 1, 1},
  {&__pyx_n_s_Or_parseImpl, __pyx_k_Or_parseImpl, sizeof(__pyx_k_Or_parseImpl), 0, 0, 1, 1},
  {&__pyx_n_s_Or_parseImpl_locals_lambda, __pyx_k_Or_parseImpl_locals_lambda, sizeof(__pyx_k_Or_parseImpl_locals_lambda), 0, 0, 1, 1},
  {&__pyx_n_s_OrderedDict, __pyx_k_OrderedDict, sizeof(__pyx_k_OrderedDict), 0, 0, 1, 1},
  {&__pyx_n_s_OrderedDict_2, __pyx_k_OrderedDict_2, sizeof(__pyx_k_OrderedDict_2), 0, 0, 1, 1},
  {&__pyx_n_s_PEER, __pyx_k_PEER, sizeof(__pyx_k_PEER), 0, 0, 1, 1},
  {&__pyx_n_s_PY_3, __pyx_k_PY_3, sizeof(__pyx_k_PY_3), 0, 0, 1, 1},
  {&__pyx_kp_u_P_entity, __pyx_k_P_entity, sizeof(__pyx_k_P_entity), 0, 1, 0, 0},
  {&__pyx_kp_u_P_year_d_4_P_month_d_d_P_day_d, __pyx_k_P_year_d_4_P_month_d_d_P_day_d, sizeof(__pyx_k_P_year_d_4_P_month_d_d_P_day_d), 0, 1, 0, 0},
  {&__pyx_kp_u_P_year_d_4_P_month_d_d_P_day_d_2, __pyx_k_P_year_d_4_P_month_d_d_P_day_d_2, sizeof(__pyx_k_P_year_d_4_P_month_d_d_P_day_d_2), 0, 1, 0, 0},
  {&__pyx_n_s_ParseBaseException, __pyx_k_ParseBaseException, sizeof(__pyx_k_ParseBaseException), 0, 0, 1, 1},
  {&__pyx_n_u_ParseBaseException, __pyx_k_ParseBaseException, sizeof(__pyx_k_ParseBaseException), 0, 1, 0, 1},
  {&__pyx_n_s_ParseBaseException___dir, __pyx_k_ParseBaseException___dir, sizeof(__pyx_k_ParseBaseException___dir), 0, 0, 1, 1},
  {&__pyx_n_s_ParseBaseException___getattr, __pyx_k_ParseBaseException___getattr, sizeof(__pyx_k_ParseBaseException___getattr), 0, 0, 1, 1},
  {&__pyx_n_s_ParseBaseException___init, __pyx_k_ParseBaseException___init, sizeof(__pyx_k_ParseBaseException___init), 0, 0, 1, 1},
  {&__pyx_n_s_ParseBaseException___repr, __pyx_k_ParseBaseException___repr, sizeof(__pyx_k_ParseBaseException___repr), 0, 0, 1, 1},
  {&__pyx_n_s_ParseBaseException___str, __pyx_k_ParseBaseException___str, sizeof(__pyx_k_ParseBaseException___str), 0, 0, 1, 1},
  {&__pyx_n_s_ParseBaseException__from_excepti, __pyx_k_ParseBaseException__from_excepti, sizeof(__pyx_k_ParseBaseException__from_excepti), 0, 0, 1, 1},
  {&__pyx_n_s_ParseBaseException_markInputline, __pyx_k_ParseBaseException_markInputline, sizeof(__pyx_k_ParseBaseException_markInputline), 0, 0, 1, 1},
  {&__pyx_n_s_ParseElementEnhance, __pyx_k_ParseElementEnhance, sizeof(__pyx_k_ParseElementEnhance), 0, 0, 1, 1},
  {&__pyx_n_u_ParseElementEnhance, __pyx_k_ParseElementEnhance, sizeof(__pyx_k_ParseElementEnhance), 0, 1, 0, 1},
  {&__pyx_n_s_ParseElementEnhance___init, __pyx_k_ParseElementEnhance___init, sizeof(__pyx_k_ParseElementEnhance___init), 0, 0, 1, 1},
  {&__pyx_n_s_ParseElementEnhance___str, __pyx_k_ParseElementEnhance___str, sizeof(__pyx_k_ParseElementEnhance___str), 0, 0, 1, 1},
  {&__pyx_n_s_ParseElementEnhance_checkRecursi, __pyx_k_ParseElementEnhance_checkRecursi, sizeof(__pyx_k_ParseElementEnhance_checkRecursi), 0, 0, 1, 1},
  {&__pyx_n_s_ParseElementEnhance_ignore, __pyx_k_ParseElementEnhance_ignore, sizeof(__pyx_k_ParseElementEnhance_ignore), 0, 0, 1, 1},
  {&__pyx_n_s_ParseElementEnhance_leaveWhitesp, __pyx_k_ParseElementEnhance_leaveWhitesp, sizeof(__pyx_k_ParseElementEnhance_leaveWhitesp), 0, 0, 1, 1},
  {&__pyx_n_s_ParseElementEnhance_parseImpl, __pyx_k_ParseElementEnhance_parseImpl, sizeof(__pyx_k_ParseElementEnhance_parseImpl), 0, 0, 1, 1},
  {&__pyx_n_s_ParseElementEnhance_streamline, __pyx_k_ParseElementEnhance_streamline, sizeof(__pyx_k_ParseElementEnhance_streamline), 0, 0, 1, 1},
  {&__pyx_n_s_ParseElementEnhance_validate, __pyx_k_ParseElementEnhance_validate, sizeof(__pyx_k_ParseElementEnhance_validate), 0, 0, 1, 1},
  {&__pyx_n_s_ParseException, __pyx_k_ParseException, sizeof(__pyx_k_ParseException), 0, 0, 1, 1},
  {&__pyx_n_u_ParseException, __pyx_k_ParseException, sizeof(__pyx_k_ParseException), 0, 1, 0, 1},
  {&__pyx_n_s_ParseExpression, __pyx_k_ParseExpression, sizeof(__pyx_k_ParseExpression), 0, 0, 1, 1},
  {&__pyx_n_u_ParseExpression, __pyx_k_ParseExpression, sizeof(__pyx_k_ParseExpression), 0, 1, 0, 1},
  {&__pyx_n_s_ParseExpression___getitem, __pyx_k_ParseExpression___getitem, sizeof(__pyx_k_ParseExpression___getitem), 0, 0, 1, 1},
  {&__pyx_n_s_ParseExpression___init, __pyx_k_ParseExpression___init, sizeof(__pyx_k_ParseExpression___init), 0, 0, 1, 1},
  {&__pyx_n_s_ParseExpression___init___locals, __pyx_k_ParseExpression___init___locals, sizeof(__pyx_k_ParseExpression___init___locals), 0, 0, 1, 1},
  {&__pyx_n_s_ParseExpression___str, __pyx_k_ParseExpression___str, sizeof(__pyx_k_ParseExpression___str), 0, 0, 1, 1},
  {&__pyx_n_s_ParseExpression_append, __pyx_k_ParseExpression_append, sizeof(__pyx_k_ParseExpression_append), 0, 0, 1, 1},
  {&__pyx_n_s_ParseExpression_copy, __pyx_k_ParseExpression_copy, sizeof(__pyx_k_ParseExpression_copy), 0, 0, 1, 1},
  {&__pyx_n_s_ParseExpression_ignore, __pyx_k_ParseExpression_ignore, sizeof(__pyx_k_ParseExpression_ignore), 0, 0, 1, 1},
  {&__pyx_n_s_ParseExpression_leaveWhitespace, __pyx_k_ParseExpression_leaveWhitespace, sizeof(__pyx_k_ParseExpression_leaveWhitespace), 0, 0, 1, 1},
  {&__pyx_n_s_ParseExpression_setResultsName, __pyx_k_ParseExpression_setResultsName, sizeof(__pyx_k_ParseExpression_setResultsName), 0, 0, 1, 1},
  {&__pyx_n_s_ParseExpression_streamline, __pyx_k_ParseExpression_streamline, sizeof(__pyx_k_ParseExpression_streamline), 0, 0, 1, 1},
  {&__pyx_n_s_ParseExpression_validate, __pyx_k_ParseExpression_validate, sizeof(__pyx_k_ParseExpression_validate), 0, 0, 1, 1},
  {&__pyx_n_s_ParseFatalException, __pyx_k_ParseFatalException, sizeof(__pyx_k_ParseFatalException), 0, 0, 1, 1},
  {&__pyx_n_u_ParseFatalException, __pyx_k_ParseFatalException, sizeof(__pyx_k_ParseFatalException), 0, 1, 0, 1},
  {&__pyx_n_s_ParseResults, __pyx_k_ParseResults, sizeof(__pyx_k_ParseResults), 0, 0, 1, 1},
  {&__pyx_n_u_ParseResults, __pyx_k_ParseResults, sizeof(__pyx_k_ParseResults), 0, 1, 0, 1},
  {&__pyx_n_s_ParseResultsWithOffset, __pyx_k_ParseResultsWithOffset, sizeof(__pyx_k_ParseResultsWithOffset), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResultsWithOffset___getite, __pyx_k_ParseResultsWithOffset___getite, sizeof(__pyx_k_ParseResultsWithOffset___getite), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResultsWithOffset___init, __pyx_k_ParseResultsWithOffset___init, sizeof(__pyx_k_ParseResultsWithOffset___init), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResultsWithOffset___repr, __pyx_k_ParseResultsWithOffset___repr, sizeof(__pyx_k_ParseResultsWithOffset___repr), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResultsWithOffset_setOffse, __pyx_k_ParseResultsWithOffset_setOffse, sizeof(__pyx_k_ParseResultsWithOffset_setOffse), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults___add, __pyx_k_ParseResults___add, sizeof(__pyx_k_ParseResults___add), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults___bool, __pyx_k_ParseResults___bool, sizeof(__pyx_k_ParseResults___bool), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults___contains, __pyx_k_ParseResults___contains, sizeof(__pyx_k_ParseResults___contains), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults___delitem, __pyx_k_ParseResults___delitem, sizeof(__pyx_k_ParseResults___delitem), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults___dir, __pyx_k_ParseResults___dir, sizeof(__pyx_k_ParseResults___dir), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults___getattr, __pyx_k_ParseResults___getattr, sizeof(__pyx_k_ParseResults___getattr), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults___getitem, __pyx_k_ParseResults___getitem, sizeof(__pyx_k_ParseResults___getitem), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults___getnewargs, __pyx_k_ParseResults___getnewargs, sizeof(__pyx_k_ParseResults___getnewargs), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults___getstate, __pyx_k_ParseResults___getstate, sizeof(__pyx_k_ParseResults___getstate), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults___iadd, __pyx_k_ParseResults___iadd, sizeof(__pyx_k_ParseResults___iadd), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults___iadd___locals_add, __pyx_k_ParseResults___iadd___locals_add, sizeof(__pyx_k_ParseResults___iadd___locals_add), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults___init, __pyx_k_ParseResults___init, sizeof(__pyx_k_ParseResults___init), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults___iter, __pyx_k_ParseResults___iter, sizeof(__pyx_k_ParseResults___iter), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults___len, __pyx_k_ParseResults___len, sizeof(__pyx_k_ParseResults___len), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults___lookup, __pyx_k_ParseResults___lookup, sizeof(__pyx_k_ParseResults___lookup), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults___new, __pyx_k_ParseResults___new, sizeof(__pyx_k_ParseResults___new), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults___radd, __pyx_k_ParseResults___radd, sizeof(__pyx_k_ParseResults___radd), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults___repr, __pyx_k_ParseResults___repr, sizeof(__pyx_k_ParseResults___repr), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults___reversed, __pyx_k_ParseResults___reversed, sizeof(__pyx_k_ParseResults___reversed), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults___setitem, __pyx_k_ParseResults___setitem, sizeof(__pyx_k_ParseResults___setitem), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults___setstate, __pyx_k_ParseResults___setstate, sizeof(__pyx_k_ParseResults___setstate), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults___str, __pyx_k_ParseResults___str, sizeof(__pyx_k_ParseResults___str), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults___str___locals_gene, __pyx_k_ParseResults___str___locals_gene, sizeof(__pyx_k_ParseResults___str___locals_gene), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults__accumNames, __pyx_k_ParseResults__accumNames, sizeof(__pyx_k_ParseResults__accumNames), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults__asList, __pyx_k_ParseResults__asList, sizeof(__pyx_k_ParseResults__asList), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults__asStringList, __pyx_k_ParseResults__asStringList, sizeof(__pyx_k_ParseResults__asStringList), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults__doinit, __pyx_k_ParseResults__doinit, sizeof(__pyx_k_ParseResults__doinit), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults__iteritems, __pyx_k_ParseResults__iteritems, sizeof(__pyx_k_ParseResults__iteritems), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults__iteritems_locals_g, __pyx_k_ParseResults__iteritems_locals_g, sizeof(__pyx_k_ParseResults__iteritems_locals_g), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults__iterkeys, __pyx_k_ParseResults__iterkeys, sizeof(__pyx_k_ParseResults__iterkeys), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults__itervalues, __pyx_k_ParseResults__itervalues, sizeof(__pyx_k_ParseResults__itervalues), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults__itervalues_locals, __pyx_k_ParseResults__itervalues_locals, sizeof(__pyx_k_ParseResults__itervalues_locals), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults__lookup, __pyx_k_ParseResults__lookup, sizeof(__pyx_k_ParseResults__lookup), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults__modal, __pyx_k_ParseResults__modal, sizeof(__pyx_k_ParseResults__modal), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults__name, __pyx_k_ParseResults__name, sizeof(__pyx_k_ParseResults__name), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults__parent, __pyx_k_ParseResults__parent, sizeof(__pyx_k_ParseResults__parent), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults__tokdict, __pyx_k_ParseResults__tokdict, sizeof(__pyx_k_ParseResults__tokdict), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults__toklist, __pyx_k_ParseResults__toklist, sizeof(__pyx_k_ParseResults__toklist), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults_append, __pyx_k_ParseResults_append, sizeof(__pyx_k_ParseResults_append), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults_asDict, __pyx_k_ParseResults_asDict, sizeof(__pyx_k_ParseResults_asDict), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults_asDict_locals_genex, __pyx_k_ParseResults_asDict_locals_genex, sizeof(__pyx_k_ParseResults_asDict_locals_genex), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults_asDict_locals_toIte, __pyx_k_ParseResults_asDict_locals_toIte, sizeof(__pyx_k_ParseResults_asDict_locals_toIte), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults_asList, __pyx_k_ParseResults_asList, sizeof(__pyx_k_ParseResults_asList), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults_asXML, __pyx_k_ParseResults_asXML, sizeof(__pyx_k_ParseResults_asXML), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults_asXML_locals_genexp, __pyx_k_ParseResults_asXML_locals_genexp, sizeof(__pyx_k_ParseResults_asXML_locals_genexp), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults_clear, __pyx_k_ParseResults_clear, sizeof(__pyx_k_ParseResults_clear), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults_copy, __pyx_k_ParseResults_copy, sizeof(__pyx_k_ParseResults_copy), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults_dump, __pyx_k_ParseResults_dump, sizeof(__pyx_k_ParseResults_dump), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults_dump_locals_genexpr, __pyx_k_ParseResults_dump_locals_genexpr, sizeof(__pyx_k_ParseResults_dump_locals_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults_extend, __pyx_k_ParseResults_extend, sizeof(__pyx_k_ParseResults_extend), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults_get, __pyx_k_ParseResults_get, sizeof(__pyx_k_ParseResults_get), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults_getName, __pyx_k_ParseResults_getName, sizeof(__pyx_k_ParseResults_getName), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults_haskeys, __pyx_k_ParseResults_haskeys, sizeof(__pyx_k_ParseResults_haskeys), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults_insert, __pyx_k_ParseResults_insert, sizeof(__pyx_k_ParseResults_insert), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults_items, __pyx_k_ParseResults_items, sizeof(__pyx_k_ParseResults_items), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults_keys, __pyx_k_ParseResults_keys, sizeof(__pyx_k_ParseResults_keys), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults_pop, __pyx_k_ParseResults_pop, sizeof(__pyx_k_ParseResults_pop), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults_pprint, __pyx_k_ParseResults_pprint, sizeof(__pyx_k_ParseResults_pprint), 0, 0, 1, 1},
  {&__pyx_n_s_ParseResults_values, __pyx_k_ParseResults_values, sizeof(__pyx_k_ParseResults_values), 0, 0, 1, 1},
  {&__pyx_n_s_ParseSyntaxException, __pyx_k_ParseSyntaxException, sizeof(__pyx_k_ParseSyntaxException), 0, 0, 1, 1},
  {&__pyx_n_u_ParseSyntaxException, __pyx_k_ParseSyntaxException, sizeof(__pyx_k_ParseSyntaxException), 0, 1, 0, 1},
  {&__pyx_n_s_ParserElement, __pyx_k_ParserElement, sizeof(__pyx_k_ParserElement), 0, 0, 1, 1},
  {&__pyx_n_u_ParserElement, __pyx_k_ParserElement, sizeof(__pyx_k_ParserElement), 0, 1, 0, 1},
  {&__pyx_n_s_ParserElement__FifoCache, __pyx_k_ParserElement__FifoCache, sizeof(__pyx_k_ParserElement__FifoCache), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement__FifoCache___init, __pyx_k_ParserElement__FifoCache___init, sizeof(__pyx_k_ParserElement__FifoCache___init), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement__FifoCache___init_2, __pyx_k_ParserElement__FifoCache___init_2, sizeof(__pyx_k_ParserElement__FifoCache___init_2), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement__FifoCache___init_3, __pyx_k_ParserElement__FifoCache___init_3, sizeof(__pyx_k_ParserElement__FifoCache___init_3), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement__FifoCache___init_4, __pyx_k_ParserElement__FifoCache___init_4, sizeof(__pyx_k_ParserElement__FifoCache___init_4), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement__FifoCache___init_5, __pyx_k_ParserElement__FifoCache___init_5, sizeof(__pyx_k_ParserElement__FifoCache___init_5), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement__UnboundedCache, __pyx_k_ParserElement__UnboundedCache, sizeof(__pyx_k_ParserElement__UnboundedCache), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement__UnboundedCache_2, __pyx_k_ParserElement__UnboundedCache_2, sizeof(__pyx_k_ParserElement__UnboundedCache_2), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement__UnboundedCache_3, __pyx_k_ParserElement__UnboundedCache_3, sizeof(__pyx_k_ParserElement__UnboundedCache_3), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement__UnboundedCache_4, __pyx_k_ParserElement__UnboundedCache_4, sizeof(__pyx_k_ParserElement__UnboundedCache_4), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement__UnboundedCache_5, __pyx_k_ParserElement__UnboundedCache_5, sizeof(__pyx_k_ParserElement__UnboundedCache_5), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement__UnboundedCache_6, __pyx_k_ParserElement__UnboundedCache_6, sizeof(__pyx_k_ParserElement__UnboundedCache_6), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement___add, __pyx_k_ParserElement___add, sizeof(__pyx_k_ParserElement___add), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement___and, __pyx_k_ParserElement___and, sizeof(__pyx_k_ParserElement___and), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement___call, __pyx_k_ParserElement___call, sizeof(__pyx_k_ParserElement___call), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement___eq, __pyx_k_ParserElement___eq, sizeof(__pyx_k_ParserElement___eq), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement___hash, __pyx_k_ParserElement___hash, sizeof(__pyx_k_ParserElement___hash), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement___init, __pyx_k_ParserElement___init, sizeof(__pyx_k_ParserElement___init), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement___invert, __pyx_k_ParserElement___invert, sizeof(__pyx_k_ParserElement___invert), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement___mul, __pyx_k_ParserElement___mul, sizeof(__pyx_k_ParserElement___mul), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement___mul___locals_mak, __pyx_k_ParserElement___mul___locals_mak, sizeof(__pyx_k_ParserElement___mul___locals_mak), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement___ne, __pyx_k_ParserElement___ne, sizeof(__pyx_k_ParserElement___ne), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement___or, __pyx_k_ParserElement___or, sizeof(__pyx_k_ParserElement___or), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement___radd, __pyx_k_ParserElement___radd, sizeof(__pyx_k_ParserElement___radd), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement___rand, __pyx_k_ParserElement___rand, sizeof(__pyx_k_ParserElement___rand), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement___repr, __pyx_k_ParserElement___repr, sizeof(__pyx_k_ParserElement___repr), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement___req, __pyx_k_ParserElement___req, sizeof(__pyx_k_ParserElement___req), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement___rmul, __pyx_k_ParserElement___rmul, sizeof(__pyx_k_ParserElement___rmul), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement___rne, __pyx_k_ParserElement___rne, sizeof(__pyx_k_ParserElement___rne), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement___ror, __pyx_k_ParserElement___ror, sizeof(__pyx_k_ParserElement___ror), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement___rsub, __pyx_k_ParserElement___rsub, sizeof(__pyx_k_ParserElement___rsub), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement___rxor, __pyx_k_ParserElement___rxor, sizeof(__pyx_k_ParserElement___rxor), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement___str, __pyx_k_ParserElement___str, sizeof(__pyx_k_ParserElement___str), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement___sub, __pyx_k_ParserElement___sub, sizeof(__pyx_k_ParserElement___sub), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement___xor, __pyx_k_ParserElement___xor, sizeof(__pyx_k_ParserElement___xor), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement__parseCache, __pyx_k_ParserElement__parseCache, sizeof(__pyx_k_ParserElement__parseCache), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement__parseNoCache, __pyx_k_ParserElement__parseNoCache, sizeof(__pyx_k_ParserElement__parseNoCache), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement__skipIgnorables, __pyx_k_ParserElement__skipIgnorables, sizeof(__pyx_k_ParserElement__skipIgnorables), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_addCondition, __pyx_k_ParserElement_addCondition, sizeof(__pyx_k_ParserElement_addCondition), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_addCondition_local, __pyx_k_ParserElement_addCondition_local, sizeof(__pyx_k_ParserElement_addCondition_local), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_addParseAction, __pyx_k_ParserElement_addParseAction, sizeof(__pyx_k_ParserElement_addParseAction), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_canParseNext, __pyx_k_ParserElement_canParseNext, sizeof(__pyx_k_ParserElement_canParseNext), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_checkRecursion, __pyx_k_ParserElement_checkRecursion, sizeof(__pyx_k_ParserElement_checkRecursion), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_copy, __pyx_k_ParserElement_copy, sizeof(__pyx_k_ParserElement_copy), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_enablePackrat, __pyx_k_ParserElement_enablePackrat, sizeof(__pyx_k_ParserElement_enablePackrat), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_ignore, __pyx_k_ParserElement_ignore, sizeof(__pyx_k_ParserElement_ignore), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_inlineLiteralsUsin, __pyx_k_ParserElement_inlineLiteralsUsin, sizeof(__pyx_k_ParserElement_inlineLiteralsUsin), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_leaveWhitespace, __pyx_k_ParserElement_leaveWhitespace, sizeof(__pyx_k_ParserElement_leaveWhitespace), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_matches, __pyx_k_ParserElement_matches, sizeof(__pyx_k_ParserElement_matches), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_parseFile, __pyx_k_ParserElement_parseFile, sizeof(__pyx_k_ParserElement_parseFile), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_parseImpl, __pyx_k_ParserElement_parseImpl, sizeof(__pyx_k_ParserElement_parseImpl), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_parseString, __pyx_k_ParserElement_parseString, sizeof(__pyx_k_ParserElement_parseString), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_parseWithTabs, __pyx_k_ParserElement_parseWithTabs, sizeof(__pyx_k_ParserElement_parseWithTabs), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_postParse, __pyx_k_ParserElement_postParse, sizeof(__pyx_k_ParserElement_postParse), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_preParse, __pyx_k_ParserElement_preParse, sizeof(__pyx_k_ParserElement_preParse), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_resetCache, __pyx_k_ParserElement_resetCache, sizeof(__pyx_k_ParserElement_resetCache), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_runTests, __pyx_k_ParserElement_runTests, sizeof(__pyx_k_ParserElement_runTests), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_scanString, __pyx_k_ParserElement_scanString, sizeof(__pyx_k_ParserElement_scanString), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_searchString, __pyx_k_ParserElement_searchString, sizeof(__pyx_k_ParserElement_searchString), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_setBreak, __pyx_k_ParserElement_setBreak, sizeof(__pyx_k_ParserElement_setBreak), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_setBreak_locals_br, __pyx_k_ParserElement_setBreak_locals_br, sizeof(__pyx_k_ParserElement_setBreak_locals_br), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_setDebug, __pyx_k_ParserElement_setDebug, sizeof(__pyx_k_ParserElement_setDebug), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_setDebugActions, __pyx_k_ParserElement_setDebugActions, sizeof(__pyx_k_ParserElement_setDebugActions), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_setDefaultWhitespa, __pyx_k_ParserElement_setDefaultWhitespa, sizeof(__pyx_k_ParserElement_setDefaultWhitespa), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_setFailAction, __pyx_k_ParserElement_setFailAction, sizeof(__pyx_k_ParserElement_setFailAction), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_setName, __pyx_k_ParserElement_setName, sizeof(__pyx_k_ParserElement_setName), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_setParseAction, __pyx_k_ParserElement_setParseAction, sizeof(__pyx_k_ParserElement_setParseAction), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_setResultsName, __pyx_k_ParserElement_setResultsName, sizeof(__pyx_k_ParserElement_setResultsName), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_setWhitespaceChars, __pyx_k_ParserElement_setWhitespaceChars, sizeof(__pyx_k_ParserElement_setWhitespaceChars), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_split, __pyx_k_ParserElement_split, sizeof(__pyx_k_ParserElement_split), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_streamline, __pyx_k_ParserElement_streamline, sizeof(__pyx_k_ParserElement_streamline), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_suppress, __pyx_k_ParserElement_suppress, sizeof(__pyx_k_ParserElement_suppress), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_transformString, __pyx_k_ParserElement_transformString, sizeof(__pyx_k_ParserElement_transformString), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_tryParse, __pyx_k_ParserElement_tryParse, sizeof(__pyx_k_ParserElement_tryParse), 0, 0, 1, 1},
  {&__pyx_n_s_ParserElement_validate, __pyx_k_ParserElement_validate, sizeof(__pyx_k_ParserElement_validate), 0, 0, 1, 1},
  {&__pyx_n_s_PositionToken, __pyx_k_PositionToken, sizeof(__pyx_k_PositionToken), 0, 0, 1, 1},
  {&__pyx_n_s_PositionToken___init, __pyx_k_PositionToken___init, sizeof(__pyx_k_PositionToken___init), 0, 0, 1, 1},
  {&__pyx_kp_u_Python_style_comment, __pyx_k_Python_style_comment, sizeof(__pyx_k_Python_style_comment), 0, 1, 0, 0},
  {&__pyx_n_s_QuotedString, __pyx_k_QuotedString, sizeof(__pyx_k_QuotedString), 0, 0, 1, 1},
  {&__pyx_n_u_QuotedString, __pyx_k_QuotedString, sizeof(__pyx_k_QuotedString), 0, 1, 0, 1},
  {&__pyx_n_s_QuotedString___init, __pyx_k_QuotedString___init, sizeof(__pyx_k_QuotedString___init), 0, 0, 1, 1},
  {&__pyx_n_s_QuotedString___init___locals_gen, __pyx_k_QuotedString___init___locals_gen, sizeof(__pyx_k_QuotedString___init___locals_gen), 0, 0, 1, 1},
  {&__pyx_n_s_QuotedString___str, __pyx_k_QuotedString___str, sizeof(__pyx_k_QuotedString___str), 0, 0, 1, 1},
  {&__pyx_n_s_QuotedString_parseImpl, __pyx_k_QuotedString_parseImpl, sizeof(__pyx_k_QuotedString_parseImpl), 0, 0, 1, 1},
  {&__pyx_n_s_RIGHT, __pyx_k_RIGHT, sizeof(__pyx_k_RIGHT), 0, 0, 1, 1},
  {&__pyx_n_s_RLock, __pyx_k_RLock, sizeof(__pyx_k_RLock), 0, 0, 1, 1},
  {&__pyx_kp_u_Re_s, __pyx_k_Re_s, sizeof(__pyx_k_Re_s), 0, 1, 0, 0},
  {&__pyx_n_s_RecursiveGrammarException, __pyx_k_RecursiveGrammarException, sizeof(__pyx_k_RecursiveGrammarException), 0, 0, 1, 1},
  {&__pyx_n_u_RecursiveGrammarException, __pyx_k_RecursiveGrammarException, sizeof(__pyx_k_RecursiveGrammarException), 0, 1, 0, 1},
  {&__pyx_n_s_RecursiveGrammarException___init, __pyx_k_RecursiveGrammarException___init, sizeof(__pyx_k_RecursiveGrammarException___init), 0, 0, 1, 1},
  {&__pyx_n_s_RecursiveGrammarException___str, __pyx_k_RecursiveGrammarException___str, sizeof(__pyx_k_RecursiveGrammarException___str), 0, 0, 1, 1},
  {&__pyx_kp_u_RecursiveGrammarException_s, __pyx_k_RecursiveGrammarException_s, sizeof(__pyx_k_RecursiveGrammarException_s), 0, 1, 0, 0},
  {&__pyx_n_s_Regex, __pyx_k_Regex, sizeof(__pyx_k_Regex), 0, 0, 1, 1},
  {&__pyx_n_u_Regex, __pyx_k_Regex, sizeof(__pyx_k_Regex), 0, 1, 0, 1},
  {&__pyx_n_s_Regex___init, __pyx_k_Regex___init, sizeof(__pyx_k_Regex___init), 0, 0, 1, 1},
  {&__pyx_n_s_Regex___str, __pyx_k_Regex___str, sizeof(__pyx_k_Regex___str), 0, 0, 1, 1},
  {&__pyx_kp_u_Regex_may_only_be_constructed_wi, __pyx_k_Regex_may_only_be_constructed_wi, sizeof(__pyx_k_Regex_may_only_be_constructed_wi), 0, 1, 0, 0},
  {&__pyx_n_s_Regex_parseImpl, __pyx_k_Regex_parseImpl, sizeof(__pyx_k_Regex_parseImpl), 0, 0, 1, 1},
  {&__pyx_kp_s_Repetition_of_one_or_more_of_th, __pyx_k_Repetition_of_one_or_more_of_th, sizeof(__pyx_k_Repetition_of_one_or_more_of_th), 0, 0, 1, 0},
  {&__pyx_kp_s_Requires_all_given_C_ParseExpre, __pyx_k_Requires_all_given_C_ParseExpre, sizeof(__pyx_k_Requires_all_given_C_ParseExpre), 0, 0, 1, 0},
  {&__pyx_kp_s_Requires_all_given_C_ParseExpre_2, __pyx_k_Requires_all_given_C_ParseExpre_2, sizeof(__pyx_k_Requires_all_given_C_ParseExpre_2), 0, 0, 1, 0},
  {&__pyx_kp_s_Requires_that_at_least_one_C_Pa, __pyx_k_Requires_that_at_least_one_C_Pa, sizeof(__pyx_k_Requires_that_at_least_one_C_Pa), 0, 0, 1, 0},
  {&__pyx_kp_s_Requires_that_at_least_one_C_Pa_2, __pyx_k_Requires_that_at_least_one_C_Pa_2, sizeof(__pyx_k_Requires_that_at_least_one_C_Pa_2), 0, 0, 1, 0},
  {&__pyx_kp_u_SPC, __pyx_k_SPC, sizeof(__pyx_k_SPC), 0, 1, 0, 0},
  {&__pyx_n_s_SkipTo, __pyx_k_SkipTo, sizeof(__pyx_k_SkipTo), 0, 0, 1, 1},
  {&__pyx_n_u_SkipTo, __pyx_k_SkipTo, sizeof(__pyx_k_SkipTo), 0, 1, 0, 1},
  {&__pyx_n_s_SkipTo___init, __pyx_k_SkipTo___init, sizeof(__pyx_k_SkipTo___init), 0, 0, 1, 1},
  {&__pyx_n_s_SkipTo_parseImpl, __pyx_k_SkipTo_parseImpl, sizeof(__pyx_k_SkipTo_parseImpl), 0, 0, 1, 1},
  {&__pyx_kp_s_Special_matching_class_for_matc, __pyx_k_Special_matching_class_for_matc, sizeof(__pyx_k_Special_matching_class_for_matc), 0, 0, 1, 0},
  {&__pyx_n_s_StringEnd, __pyx_k_StringEnd, sizeof(__pyx_k_StringEnd), 0, 0, 1, 1},
  {&__pyx_n_u_StringEnd, __pyx_k_StringEnd, sizeof(__pyx_k_StringEnd), 0, 1, 0, 1},
  {&__pyx_n_s_StringEnd___init, __pyx_k_StringEnd___init, sizeof(__pyx_k_StringEnd___init), 0, 0, 1, 1},
  {&__pyx_n_s_StringEnd_parseImpl, __pyx_k_StringEnd_parseImpl, sizeof(__pyx_k_StringEnd_parseImpl), 0, 0, 1, 1},
  {&__pyx_n_s_StringStart, __pyx_k_StringStart, sizeof(__pyx_k_StringStart), 0, 0, 1, 1},
  {&__pyx_n_u_StringStart, __pyx_k_StringStart, sizeof(__pyx_k_StringStart), 0, 1, 0, 1},
  {&__pyx_n_s_StringStart___init, __pyx_k_StringStart___init, sizeof(__pyx_k_StringStart___init), 0, 0, 1, 1},
  {&__pyx_n_s_StringStart_parseImpl, __pyx_k_StringStart_parseImpl, sizeof(__pyx_k_StringStart_parseImpl), 0, 0, 1, 1},
  {&__pyx_kp_s_Structured_parse_results_to_pro, __pyx_k_Structured_parse_results_to_pro, sizeof(__pyx_k_Structured_parse_results_to_pro), 0, 0, 1, 0},
  {&__pyx_n_s_Suppress, __pyx_k_Suppress, sizeof(__pyx_k_Suppress), 0, 0, 1, 1},
  {&__pyx_n_u_Suppress, __pyx_k_Suppress, sizeof(__pyx_k_Suppress), 0, 1, 0, 1},
  {&__pyx_n_s_Suppress_postParse, __pyx_k_Suppress_postParse, sizeof(__pyx_k_Suppress_postParse), 0, 0, 1, 1},
  {&__pyx_n_s_Suppress_suppress, __pyx_k_Suppress_suppress, sizeof(__pyx_k_Suppress_suppress), 0, 0, 1, 1},
  {&__pyx_n_s_SyntaxError, __pyx_k_SyntaxError, sizeof(__pyx_k_SyntaxError), 0, 0, 1, 1},
  {&__pyx_n_s_SyntaxWarning, __pyx_k_SyntaxWarning, sizeof(__pyx_k_SyntaxWarning), 0, 0, 1, 1},
  {&__pyx_kp_u_TAB, __pyx_k_TAB, sizeof(__pyx_k_TAB), 0, 1, 0, 0},
  {&__pyx_kp_u_Text_not_in_expected_column, __pyx_k_Text_not_in_expected_column, sizeof(__pyx_k_Text_not_in_expected_column), 0, 1, 0, 0},
  {&__pyx_n_s_Token, __pyx_k_Token, sizeof(__pyx_k_Token), 0, 0, 1, 1},
  {&__pyx_n_u_Token, __pyx_k_Token, sizeof(__pyx_k_Token), 0, 1, 0, 1},
  {&__pyx_n_s_TokenConverter, __pyx_k_TokenConverter, sizeof(__pyx_k_TokenConverter), 0, 0, 1, 1},
  {&__pyx_n_u_TokenConverter, __pyx_k_TokenConverter, sizeof(__pyx_k_TokenConverter), 0, 1, 0, 1},
  {&__pyx_n_s_TokenConverter___init, __pyx_k_TokenConverter___init, sizeof(__pyx_k_TokenConverter___init), 0, 0, 1, 1},
  {&__pyx_n_s_Token___init, __pyx_k_Token___init, sizeof(__pyx_k_Token___init), 0, 0, 1, 1},
  {&__pyx_kp_s_Token_for_matching_strings_that, __pyx_k_Token_for_matching_strings_that, sizeof(__pyx_k_Token_for_matching_strings_that), 0, 0, 1, 0},
  {&__pyx_kp_s_Token_for_matching_strings_that_2, __pyx_k_Token_for_matching_strings_that_2, sizeof(__pyx_k_Token_for_matching_strings_that_2), 0, 0, 1, 0},
  {&__pyx_kp_s_Token_for_matching_words_compos, __pyx_k_Token_for_matching_words_compos, sizeof(__pyx_k_Token_for_matching_words_compos), 0, 0, 1, 0},
  {&__pyx_kp_s_Token_for_matching_words_compos_2, __pyx_k_Token_for_matching_words_compos_2, sizeof(__pyx_k_Token_for_matching_words_compos_2), 0, 0, 1, 0},
  {&__pyx_kp_s_Token_for_skipping_over_all_und, __pyx_k_Token_for_skipping_over_all_und, sizeof(__pyx_k_Token_for_skipping_over_all_und), 0, 0, 1, 0},
  {&__pyx_kp_s_Token_to_advance_to_a_specific, __pyx_k_Token_to_advance_to_a_specific, sizeof(__pyx_k_Token_to_advance_to_a_specific), 0, 0, 1, 0},
  {&__pyx_kp_s_Token_to_exactly_match_a_specif, __pyx_k_Token_to_exactly_match_a_specif, sizeof(__pyx_k_Token_to_exactly_match_a_specif), 0, 0, 1, 0},
  {&__pyx_kp_s_Token_to_exactly_match_a_specif_2, __pyx_k_Token_to_exactly_match_a_specif_2, sizeof(__pyx_k_Token_to_exactly_match_a_specif_2), 0, 0, 1, 0},
  {&__pyx_kp_s_Token_to_match_a_specified_stri, __pyx_k_Token_to_match_a_specified_stri, sizeof(__pyx_k_Token_to_match_a_specified_stri), 0, 0, 1, 0},
  {&__pyx_n_s_TypeError, __pyx_k_TypeError, sizeof(__pyx_k_TypeError), 0, 0, 1, 1},
  {&__pyx_n_s_UNDENT, __pyx_k_UNDENT, sizeof(__pyx_k_UNDENT), 0, 0, 1, 1},
  {&__pyx_n_s_UNICODE, __pyx_k_UNICODE, sizeof(__pyx_k_UNICODE), 0, 0, 1, 1},
  {&__pyx_n_u_UNINDENT, __pyx_k_UNINDENT, sizeof(__pyx_k_UNINDENT), 0, 1, 0, 1},
  {&__pyx_n_s_UUID, __pyx_k_UUID, sizeof(__pyx_k_UUID), 0, 0, 1, 1},
  {&__pyx_n_u_UUID, __pyx_k_UUID, sizeof(__pyx_k_UUID), 0, 1, 0, 1},
  {&__pyx_n_s_UnboundedCache, __pyx_k_UnboundedCache, sizeof(__pyx_k_UnboundedCache), 0, 0, 1, 1},
  {&__pyx_kp_u_Unmatchable_token, __pyx_k_Unmatchable_token, sizeof(__pyx_k_Unmatchable_token), 0, 1, 0, 0},
  {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
  {&__pyx_n_s_WRAP_CALL_LINE_NUM, __pyx_k_WRAP_CALL_LINE_NUM, sizeof(__pyx_k_WRAP_CALL_LINE_NUM), 0, 0, 1, 1},
  {&__pyx_kp_u_W_s, __pyx_k_W_s, sizeof(__pyx_k_W_s), 0, 1, 0, 0},
  {&__pyx_kp_u_W_s_2, __pyx_k_W_s_2, sizeof(__pyx_k_W_s_2), 0, 1, 0, 0},
  {&__pyx_kp_u_W_s_3, __pyx_k_W_s_3, sizeof(__pyx_k_W_s_3), 0, 1, 0, 0},
  {&__pyx_kp_u_W_s_s, __pyx_k_W_s_s, sizeof(__pyx_k_W_s_s), 0, 1, 0, 0},
  {&__pyx_n_s_White, __pyx_k_White, sizeof(__pyx_k_White), 0, 0, 1, 1},
  {&__pyx_n_u_White, __pyx_k_White, sizeof(__pyx_k_White), 0, 1, 0, 1},
  {&__pyx_n_s_White___init, __pyx_k_White___init, sizeof(__pyx_k_White___init), 0, 0, 1, 1},
  {&__pyx_n_s_White___init___locals_genexpr, __pyx_k_White___init___locals_genexpr, sizeof(__pyx_k_White___init___locals_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_White_parseImpl, __pyx_k_White_parseImpl, sizeof(__pyx_k_White_parseImpl), 0, 0, 1, 1},
  {&__pyx_n_s_Word, __pyx_k_Word, sizeof(__pyx_k_Word), 0, 0, 1, 1},
  {&__pyx_n_u_Word, __pyx_k_Word, sizeof(__pyx_k_Word), 0, 1, 0, 1},
  {&__pyx_n_s_WordEnd, __pyx_k_WordEnd, sizeof(__pyx_k_WordEnd), 0, 0, 1, 1},
  {&__pyx_n_u_WordEnd, __pyx_k_WordEnd, sizeof(__pyx_k_WordEnd), 0, 1, 0, 1},
  {&__pyx_n_s_WordEnd___init, __pyx_k_WordEnd___init, sizeof(__pyx_k_WordEnd___init), 0, 0, 1, 1},
  {&__pyx_n_s_WordEnd_parseImpl, __pyx_k_WordEnd_parseImpl, sizeof(__pyx_k_WordEnd_parseImpl), 0, 0, 1, 1},
  {&__pyx_n_s_WordStart, __pyx_k_WordStart, sizeof(__pyx_k_WordStart), 0, 0, 1, 1},
  {&__pyx_n_u_WordStart, __pyx_k_WordStart, sizeof(__pyx_k_WordStart), 0, 1, 0, 1},
  {&__pyx_n_s_WordStart___init, __pyx_k_WordStart___init, sizeof(__pyx_k_WordStart___init), 0, 0, 1, 1},
  {&__pyx_n_s_WordStart_parseImpl, __pyx_k_WordStart_parseImpl, sizeof(__pyx_k_WordStart_parseImpl), 0, 0, 1, 1},
  {&__pyx_n_s_Word___init, __pyx_k_Word___init, sizeof(__pyx_k_Word___init), 0, 0, 1, 1},
  {&__pyx_n_s_Word___init___locals_genexpr, __pyx_k_Word___init___locals_genexpr, sizeof(__pyx_k_Word___init___locals_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_Word___str, __pyx_k_Word___str, sizeof(__pyx_k_Word___str), 0, 0, 1, 1},
  {&__pyx_n_s_Word___str___locals_charsAsStr, __pyx_k_Word___str___locals_charsAsStr, sizeof(__pyx_k_Word___str___locals_charsAsStr), 0, 0, 1, 1},
  {&__pyx_n_s_Word_parseImpl, __pyx_k_Word_parseImpl, sizeof(__pyx_k_Word_parseImpl), 0, 0, 1, 1},
  {&__pyx_kp_s_Wrapper_for_parse_actions_to_en, __pyx_k_Wrapper_for_parse_actions_to_en, sizeof(__pyx_k_Wrapper_for_parse_actions_to_en), 0, 0, 1, 0},
  {&__pyx_kp_u_Y_m_d, __pyx_k_Y_m_d, sizeof(__pyx_k_Y_m_d), 0, 1, 0, 0},
  {&__pyx_kp_u_Y_m_dT_H_M_S_f, __pyx_k_Y_m_dT_H_M_S_f, sizeof(__pyx_k_Y_m_dT_H_M_S_f), 0, 1, 0, 0},
  {&__pyx_n_s_ZeroOrMore, __pyx_k_ZeroOrMore, sizeof(__pyx_k_ZeroOrMore), 0, 0, 1, 1},
  {&__pyx_n_u_ZeroOrMore, __pyx_k_ZeroOrMore, sizeof(__pyx_k_ZeroOrMore), 0, 1, 0, 1},
  {&__pyx_n_s_ZeroOrMore___init, __pyx_k_ZeroOrMore___init, sizeof(__pyx_k_ZeroOrMore___init), 0, 0, 1, 1},
  {&__pyx_n_s_ZeroOrMore___str, __pyx_k_ZeroOrMore___str, sizeof(__pyx_k_ZeroOrMore___str), 0, 0, 1, 1},
  {&__pyx_n_s_ZeroOrMore_parseImpl, __pyx_k_ZeroOrMore_parseImpl, sizeof(__pyx_k_ZeroOrMore_parseImpl), 0, 0, 1, 1},
  {&__pyx_kp_u__10, __pyx_k__10, sizeof(__pyx_k__10), 0, 1, 0, 0},
  {&__pyx_kp_u__102, __pyx_k__102, sizeof(__pyx_k__102), 0, 1, 0, 0},
  {&__pyx_kp_u__108, __pyx_k__108, sizeof(__pyx_k__108), 0, 1, 0, 0},
  {&__pyx_kp_u__111, __pyx_k__111, sizeof(__pyx_k__111), 0, 1, 0, 0},
  {&__pyx_kp_u__112, __pyx_k__112, sizeof(__pyx_k__112), 0, 1, 0, 0},
  {&__pyx_kp_u__113, __pyx_k__113, sizeof(__pyx_k__113), 0, 1, 0, 0},
  {&__pyx_kp_u__115, __pyx_k__115, sizeof(__pyx_k__115), 0, 1, 0, 0},
  {&__pyx_kp_u__119, __pyx_k__119, sizeof(__pyx_k__119), 0, 1, 0, 0},
  {&__pyx_kp_u__123, __pyx_k__123, sizeof(__pyx_k__123), 0, 1, 0, 0},
  {&__pyx_kp_u__124, __pyx_k__124, sizeof(__pyx_k__124), 0, 1, 0, 0},
  {&__pyx_kp_u__125, __pyx_k__125, sizeof(__pyx_k__125), 0, 1, 0, 0},
  {&__pyx_kp_u__127, __pyx_k__127, sizeof(__pyx_k__127), 0, 1, 0, 0},
  {&__pyx_kp_u__129, __pyx_k__129, sizeof(__pyx_k__129), 0, 1, 0, 0},
  {&__pyx_kp_u__132, __pyx_k__132, sizeof(__pyx_k__132), 0, 1, 0, 0},
  {&__pyx_kp_u__133, __pyx_k__133, sizeof(__pyx_k__133), 0, 1, 0, 0},
  {&__pyx_kp_u__146, __pyx_k__146, sizeof(__pyx_k__146), 0, 1, 0, 0},
  {&__pyx_kp_u__16, __pyx_k__16, sizeof(__pyx_k__16), 0, 1, 0, 0},
  {&__pyx_kp_u__166, __pyx_k__166, sizeof(__pyx_k__166), 0, 1, 0, 0},
  {&__pyx_kp_u__167, __pyx_k__167, sizeof(__pyx_k__167), 0, 1, 0, 0},
  {&__pyx_kp_u__17, __pyx_k__17, sizeof(__pyx_k__17), 0, 1, 0, 0},
  {&__pyx_kp_u__170, __pyx_k__170, sizeof(__pyx_k__170), 0, 1, 0, 0},
  {&__pyx_kp_u__18, __pyx_k__18, sizeof(__pyx_k__18), 0, 1, 0, 0},
  {&__pyx_kp_u__182, __pyx_k__182, sizeof(__pyx_k__182), 0, 1, 0, 0},
  {&__pyx_kp_u__195, __pyx_k__195, sizeof(__pyx_k__195), 0, 1, 0, 0},
  {&__pyx_kp_u__205, __pyx_k__205, sizeof(__pyx_k__205), 0, 1, 0, 0},
  {&__pyx_kp_u__21, __pyx_k__21, sizeof(__pyx_k__21), 0, 1, 0, 0},
  {&__pyx_kp_u__22, __pyx_k__22, sizeof(__pyx_k__22), 0, 1, 0, 0},
  {&__pyx_kp_u__23, __pyx_k__23, sizeof(__pyx_k__23), 0, 1, 0, 0},
  {&__pyx_kp_u__24, __pyx_k__24, sizeof(__pyx_k__24), 0, 1, 0, 0},
  {&__pyx_kp_u__25, __pyx_k__25, sizeof(__pyx_k__25), 0, 1, 0, 0},
  {&__pyx_kp_u__26, __pyx_k__26, sizeof(__pyx_k__26), 0, 1, 0, 0},
  {&__pyx_kp_u__355, __pyx_k__355, sizeof(__pyx_k__355), 0, 1, 0, 0},
  {&__pyx_kp_u__38, __pyx_k__38, sizeof(__pyx_k__38), 0, 1, 0, 0},
  {&__pyx_kp_u__508, __pyx_k__508, sizeof(__pyx_k__508), 0, 1, 0, 0},
  {&__pyx_kp_u__6, __pyx_k__6, sizeof(__pyx_k__6), 0, 1, 0, 0},
  {&__pyx_n_s__653, __pyx_k__653, sizeof(__pyx_k__653), 0, 0, 1, 1},
  {&__pyx_n_u__653, __pyx_k__653, sizeof(__pyx_k__653), 0, 1, 0, 1},
  {&__pyx_kp_u__7, __pyx_k__7, sizeof(__pyx_k__7), 0, 1, 0, 0},
  {&__pyx_kp_u__8, __pyx_k__8, sizeof(__pyx_k__8), 0, 1, 0, 0},
  {&__pyx_kp_u__82, __pyx_k__82, sizeof(__pyx_k__82), 0, 1, 0, 0},
  {&__pyx_kp_u__823, __pyx_k__823, sizeof(__pyx_k__823), 0, 1, 0, 0},
  {&__pyx_kp_u__826, __pyx_k__826, sizeof(__pyx_k__826), 0, 1, 0, 0},
  {&__pyx_kp_u__84, __pyx_k__84, sizeof(__pyx_k__84), 0, 1, 0, 0},
  {&__pyx_kp_u__85, __pyx_k__85, sizeof(__pyx_k__85), 0, 1, 0, 0},
  {&__pyx_kp_u__857, __pyx_k__857, sizeof(__pyx_k__857), 0, 1, 0, 0},
  {&__pyx_kp_u__860, __pyx_k__860, sizeof(__pyx_k__860), 0, 1, 0, 0},
  {&__pyx_kp_u__873, __pyx_k__873, sizeof(__pyx_k__873), 0, 1, 0, 0},
  {&__pyx_kp_u__875, __pyx_k__875, sizeof(__pyx_k__875), 0, 1, 0, 0},
  {&__pyx_kp_u__876, __pyx_k__876, sizeof(__pyx_k__876), 0, 1, 0, 0},
  {&__pyx_kp_u__88, __pyx_k__88, sizeof(__pyx_k__88), 0, 1, 0, 0},
  {&__pyx_kp_u__880, __pyx_k__880, sizeof(__pyx_k__880), 0, 1, 0, 0},
  {&__pyx_kp_u__882, __pyx_k__882, sizeof(__pyx_k__882), 0, 1, 0, 0},
  {&__pyx_kp_u__886, __pyx_k__886, sizeof(__pyx_k__886), 0, 1, 0, 0},
  {&__pyx_kp_u__893, __pyx_k__893, sizeof(__pyx_k__893), 0, 1, 0, 0},
  {&__pyx_kp_u__896, __pyx_k__896, sizeof(__pyx_k__896), 0, 1, 0, 0},
  {&__pyx_kp_u__9, __pyx_k__9, sizeof(__pyx_k__9), 0, 1, 0, 0},
  {&__pyx_kp_u__92, __pyx_k__92, sizeof(__pyx_k__92), 0, 1, 0, 0},
  {&__pyx_kp_u__921, __pyx_k__921, sizeof(__pyx_k__921), 0, 1, 0, 0},
  {&__pyx_kp_u__93, __pyx_k__93, sizeof(__pyx_k__93), 0, 1, 0, 0},
  {&__pyx_kp_u__94, __pyx_k__94, sizeof(__pyx_k__94), 0, 1, 0, 0},
  {&__pyx_kp_u__95, __pyx_k__95, sizeof(__pyx_k__95), 0, 1, 0, 0},
  {&__pyx_kp_u__96, __pyx_k__96, sizeof(__pyx_k__96), 0, 1, 0, 0},
  {&__pyx_kp_u__97, __pyx_k__97, sizeof(__pyx_k__97), 0, 1, 0, 0},
  {&__pyx_kp_u__98, __pyx_k__98, sizeof(__pyx_k__98), 0, 1, 0, 0},
  {&__pyx_kp_u__99, __pyx_k__99, sizeof(__pyx_k__99), 0, 1, 0, 0},
  {&__pyx_n_s_a, __pyx_k_a, sizeof(__pyx_k_a), 0, 0, 1, 1},
  {&__pyx_n_s_add, __pyx_k_add, sizeof(__pyx_k_add), 0, 0, 1, 1},
  {&__pyx_n_s_addCondition, __pyx_k_addCondition, sizeof(__pyx_k_addCondition), 0, 0, 1, 1},
  {&__pyx_n_s_addParseAction, __pyx_k_addParseAction, sizeof(__pyx_k_addParseAction), 0, 0, 1, 1},
  {&__pyx_n_s_addoffset, __pyx_k_addoffset, sizeof(__pyx_k_addoffset), 0, 0, 1, 1},
  {&__pyx_n_s_adjacent, __pyx_k_adjacent, sizeof(__pyx_k_adjacent), 0, 0, 1, 1},
  {&__pyx_n_s_all, __pyx_k_all, sizeof(__pyx_k_all), 0, 0, 1, 1},
  {&__pyx_n_s_allResults, __pyx_k_allResults, sizeof(__pyx_k_allResults), 0, 0, 1, 1},
  {&__pyx_n_s_all_2, __pyx_k_all_2, sizeof(__pyx_k_all_2), 0, 0, 1, 1},
  {&__pyx_n_s_alphanums, __pyx_k_alphanums, sizeof(__pyx_k_alphanums), 0, 0, 1, 1},
  {&__pyx_n_u_alphanums, __pyx_k_alphanums, sizeof(__pyx_k_alphanums), 0, 1, 0, 1},
  {&__pyx_n_s_alphas, __pyx_k_alphas, sizeof(__pyx_k_alphas), 0, 0, 1, 1},
  {&__pyx_n_u_alphas, __pyx_k_alphas, sizeof(__pyx_k_alphas), 0, 1, 0, 1},
  {&__pyx_n_s_alphas8bit, __pyx_k_alphas8bit, sizeof(__pyx_k_alphas8bit), 0, 0, 1, 1},
  {&__pyx_n_u_alphas8bit, __pyx_k_alphas8bit, sizeof(__pyx_k_alphas8bit), 0, 1, 0, 1},
  {&__pyx_kp_u_amp_gt_lt_quot_apos, __pyx_k_amp_gt_lt_quot_apos, sizeof(__pyx_k_amp_gt_lt_quot_apos), 0, 1, 0, 0},
  {&__pyx_n_s_aname, __pyx_k_aname, sizeof(__pyx_k_aname), 0, 0, 1, 1},
  {&__pyx_n_s_and, __pyx_k_and, sizeof(__pyx_k_and), 0, 0, 1, 1},
  {&__pyx_n_s_any, __pyx_k_any, sizeof(__pyx_k_any), 0, 0, 1, 1},
  {&__pyx_n_s_anyCloseTag, __pyx_k_anyCloseTag, sizeof(__pyx_k_anyCloseTag), 0, 0, 1, 1},
  {&__pyx_n_u_anyCloseTag, __pyx_k_anyCloseTag, sizeof(__pyx_k_anyCloseTag), 0, 1, 0, 1},
  {&__pyx_n_s_anyOpenTag, __pyx_k_anyOpenTag, sizeof(__pyx_k_anyOpenTag), 0, 0, 1, 1},
  {&__pyx_n_u_anyOpenTag, __pyx_k_anyOpenTag, sizeof(__pyx_k_anyOpenTag), 0, 1, 0, 1},
  {&__pyx_kp_u_any_tag, __pyx_k_any_tag, sizeof(__pyx_k_any_tag), 0, 1, 0, 0},
  {&__pyx_n_s_append, __pyx_k_append, sizeof(__pyx_k_append), 0, 0, 1, 1},
  {&__pyx_n_s_args, __pyx_k_args, sizeof(__pyx_k_args), 0, 0, 1, 1},
  {&__pyx_n_s_arity, __pyx_k_arity, sizeof(__pyx_k_arity), 0, 0, 1, 1},
  {&__pyx_n_s_arrayExpr, __pyx_k_arrayExpr, sizeof(__pyx_k_arrayExpr), 0, 0, 1, 1},
  {&__pyx_n_u_arrayLen, __pyx_k_arrayLen, sizeof(__pyx_k_arrayLen), 0, 1, 0, 1},
  {&__pyx_n_s_asDict, __pyx_k_asDict, sizeof(__pyx_k_asDict), 0, 0, 1, 1},
  {&__pyx_n_s_asKeyword, __pyx_k_asKeyword, sizeof(__pyx_k_asKeyword), 0, 0, 1, 1},
  {&__pyx_n_s_asList, __pyx_k_asList, sizeof(__pyx_k_asList), 0, 0, 1, 1},
  {&__pyx_n_s_asString, __pyx_k_asString, sizeof(__pyx_k_asString), 0, 0, 1, 1},
  {&__pyx_n_s_asStringList, __pyx_k_asStringList, sizeof(__pyx_k_asStringList), 0, 0, 1, 1},
  {&__pyx_n_s_asXML, __pyx_k_asXML, sizeof(__pyx_k_asXML), 0, 0, 1, 1},
  {&__pyx_kp_u_as_column_list_and_dotted_table, __pyx_k_as_column_list_and_dotted_table, sizeof(__pyx_k_as_column_list_and_dotted_table), 0, 1, 0, 0},
  {&__pyx_n_s_ascii_lowercase, __pyx_k_ascii_lowercase, sizeof(__pyx_k_ascii_lowercase), 0, 0, 1, 1},
  {&__pyx_n_s_ascii_uppercase, __pyx_k_ascii_uppercase, sizeof(__pyx_k_ascii_uppercase), 0, 0, 1, 1},
  {&__pyx_kp_u_at_loc, __pyx_k_at_loc, sizeof(__pyx_k_at_loc), 0, 1, 0, 0},
  {&__pyx_n_s_attrDict, __pyx_k_attrDict, sizeof(__pyx_k_attrDict), 0, 0, 1, 1},
  {&__pyx_n_s_attrName, __pyx_k_attrName, sizeof(__pyx_k_attrName), 0, 0, 1, 1},
  {&__pyx_n_s_attrValue, __pyx_k_attrValue, sizeof(__pyx_k_attrValue), 0, 0, 1, 1},
  {&__pyx_kp_u_attribute_s_has_value_s_must_be, __pyx_k_attribute_s_has_value_s_must_be, sizeof(__pyx_k_attribute_s_has_value_s_must_be), 0, 1, 0, 0},
  {&__pyx_n_s_attrs, __pyx_k_attrs, sizeof(__pyx_k_attrs), 0, 0, 1, 1},
  {&__pyx_kp_u_b, __pyx_k_b, sizeof(__pyx_k_b), 0, 1, 0, 0},
  {&__pyx_n_s_b_2, __pyx_k_b_2, sizeof(__pyx_k_b_2), 0, 0, 1, 1},
  {&__pyx_n_s_baseExpr, __pyx_k_baseExpr, sizeof(__pyx_k_baseExpr), 0, 0, 1, 1},
  {&__pyx_kp_s_base_exception_class_for_all_par, __pyx_k_base_exception_class_for_all_par, sizeof(__pyx_k_base_exception_class_for_all_par), 0, 0, 1, 0},
  {&__pyx_n_s_basestring, __pyx_k_basestring, sizeof(__pyx_k_basestring), 0, 0, 1, 1},
  {&__pyx_n_s_blockStatementExpr, __pyx_k_blockStatementExpr, sizeof(__pyx_k_blockStatementExpr), 0, 0, 1, 1},
  {&__pyx_n_s_body, __pyx_k_body, sizeof(__pyx_k_body), 0, 0, 1, 1},
  {&__pyx_n_u_body, __pyx_k_body, sizeof(__pyx_k_body), 0, 1, 0, 1},
  {&__pyx_n_s_bodyChars, __pyx_k_bodyChars, sizeof(__pyx_k_bodyChars), 0, 0, 1, 1},
  {&__pyx_n_s_bodyCharsOrig, __pyx_k_bodyCharsOrig, sizeof(__pyx_k_bodyCharsOrig), 0, 0, 1, 1},
  {&__pyx_n_s_bodychars, __pyx_k_bodychars, sizeof(__pyx_k_bodychars), 0, 0, 1, 1},
  {&__pyx_n_s_bool, __pyx_k_bool, sizeof(__pyx_k_bool), 0, 0, 1, 1},
  {&__pyx_n_s_breakFlag, __pyx_k_breakFlag, sizeof(__pyx_k_breakFlag), 0, 0, 1, 1},
  {&__pyx_n_s_breaker, __pyx_k_breaker, sizeof(__pyx_k_breaker), 0, 0, 1, 1},
  {&__pyx_n_s_bslash, __pyx_k_bslash, sizeof(__pyx_k_bslash), 0, 0, 1, 1},
  {&__pyx_n_s_builtin, __pyx_k_builtin, sizeof(__pyx_k_builtin), 0, 0, 1, 1},
  {&__pyx_n_s_c, __pyx_k_c, sizeof(__pyx_k_c), 0, 0, 1, 1},
  {&__pyx_n_s_cPyparsing, __pyx_k_cPyparsing, sizeof(__pyx_k_cPyparsing), 0, 0, 1, 1},
  {&__pyx_kp_u_cPyparsing_pyx, __pyx_k_cPyparsing_pyx, sizeof(__pyx_k_cPyparsing_pyx), 0, 1, 0, 0},
  {&__pyx_n_s_cStyleComment, __pyx_k_cStyleComment, sizeof(__pyx_k_cStyleComment), 0, 0, 1, 1},
  {&__pyx_n_u_cStyleComment, __pyx_k_cStyleComment, sizeof(__pyx_k_cStyleComment), 0, 1, 0, 1},
  {&__pyx_n_s_cache, __pyx_k_cache, sizeof(__pyx_k_cache), 0, 0, 1, 1},
  {&__pyx_n_s_cache_len, __pyx_k_cache_len, sizeof(__pyx_k_cache_len), 0, 0, 1, 1},
  {&__pyx_n_s_cache_size_limit, __pyx_k_cache_size_limit, sizeof(__pyx_k_cache_size_limit), 0, 0, 1, 1},
  {&__pyx_n_s_call, __pyx_k_call, sizeof(__pyx_k_call), 0, 0, 1, 1},
  {&__pyx_n_s_callDuringTry, __pyx_k_callDuringTry, sizeof(__pyx_k_callDuringTry), 0, 0, 1, 1},
  {&__pyx_n_u_callDuringTry, __pyx_k_callDuringTry, sizeof(__pyx_k_callDuringTry), 0, 1, 0, 1},
  {&__pyx_n_s_callPreParse, __pyx_k_callPreParse, sizeof(__pyx_k_callPreParse), 0, 0, 1, 1},
  {&__pyx_n_s_callPreparse, __pyx_k_callPreparse, sizeof(__pyx_k_callPreparse), 0, 0, 1, 1},
  {&__pyx_n_s_callable, __pyx_k_callable, sizeof(__pyx_k_callable), 0, 0, 1, 1},
  {&__pyx_n_s_called, __pyx_k_called, sizeof(__pyx_k_called), 0, 0, 1, 1},
  {&__pyx_n_s_canParseNext, __pyx_k_canParseNext, sizeof(__pyx_k_canParseNext), 0, 0, 1, 1},
  {&__pyx_kp_u_cannot_multiply_ParserElement_an, __pyx_k_cannot_multiply_ParserElement_an, sizeof(__pyx_k_cannot_multiply_ParserElement_an), 0, 1, 0, 0},
  {&__pyx_kp_u_cannot_multiply_ParserElement_an_2, __pyx_k_cannot_multiply_ParserElement_an_2, sizeof(__pyx_k_cannot_multiply_ParserElement_an_2), 0, 1, 0, 0},
  {&__pyx_kp_u_cannot_multiply_ParserElement_by, __pyx_k_cannot_multiply_ParserElement_by, sizeof(__pyx_k_cannot_multiply_ParserElement_by), 0, 1, 0, 0},
  {&__pyx_kp_u_cannot_multiply_ParserElement_by_2, __pyx_k_cannot_multiply_ParserElement_by_2, sizeof(__pyx_k_cannot_multiply_ParserElement_by_2), 0, 1, 0, 0},
  {&__pyx_kp_u_cannot_specify_a_minimum_length, __pyx_k_cannot_specify_a_minimum_length, sizeof(__pyx_k_cannot_specify_a_minimum_length), 0, 1, 0, 0},
  {&__pyx_kp_u_cannot_specify_a_minimum_length_2, __pyx_k_cannot_specify_a_minimum_length_2, sizeof(__pyx_k_cannot_specify_a_minimum_length_2), 0, 1, 0, 0},
  {&__pyx_n_s_caseless, __pyx_k_caseless, sizeof(__pyx_k_caseless), 0, 0, 1, 1},
  {&__pyx_n_s_caselessmatch, __pyx_k_caselessmatch, sizeof(__pyx_k_caselessmatch), 0, 0, 1, 1},
  {&__pyx_n_s_charRange, __pyx_k_charRange, sizeof(__pyx_k_charRange), 0, 0, 1, 1},
  {&__pyx_n_s_chars, __pyx_k_chars, sizeof(__pyx_k_chars), 0, 0, 1, 1},
  {&__pyx_n_s_charsAsStr, __pyx_k_charsAsStr, sizeof(__pyx_k_charsAsStr), 0, 0, 1, 1},
  {&__pyx_n_s_checkPeerIndent, __pyx_k_checkPeerIndent, sizeof(__pyx_k_checkPeerIndent), 0, 0, 1, 1},
  {&__pyx_n_s_checkRecursion, __pyx_k_checkRecursion, sizeof(__pyx_k_checkRecursion), 0, 0, 1, 1},
  {&__pyx_n_s_checkSubIndent, __pyx_k_checkSubIndent, sizeof(__pyx_k_checkSubIndent), 0, 0, 1, 1},
  {&__pyx_n_s_checkUnindent, __pyx_k_checkUnindent, sizeof(__pyx_k_checkUnindent), 0, 0, 1, 1},
  {&__pyx_n_s_check_ender, __pyx_k_check_ender, sizeof(__pyx_k_check_ender), 0, 0, 1, 1},
  {&__pyx_n_s_chr, __pyx_k_chr, sizeof(__pyx_k_chr), 0, 0, 1, 1},
  {&__pyx_n_s_class, __pyx_k_class, sizeof(__pyx_k_class), 0, 0, 1, 1},
  {&__pyx_n_u_class, __pyx_k_class, sizeof(__pyx_k_class), 0, 1, 0, 1},
  {&__pyx_n_u_class_2, __pyx_k_class_2, sizeof(__pyx_k_class_2), 0, 1, 0, 1},
  {&__pyx_n_s_classattr, __pyx_k_classattr, sizeof(__pyx_k_classattr), 0, 0, 1, 1},
  {&__pyx_n_s_classname, __pyx_k_classname, sizeof(__pyx_k_classname), 0, 0, 1, 1},
  {&__pyx_n_s_clear, __pyx_k_clear, sizeof(__pyx_k_clear), 0, 0, 1, 1},
  {&__pyx_n_s_close, __pyx_k_close, sizeof(__pyx_k_close), 0, 0, 1, 1},
  {&__pyx_n_s_closeTag, __pyx_k_closeTag, sizeof(__pyx_k_closeTag), 0, 0, 1, 1},
  {&__pyx_n_s_closer, __pyx_k_closer, sizeof(__pyx_k_closer), 0, 0, 1, 1},
  {&__pyx_n_s_cls, __pyx_k_cls, sizeof(__pyx_k_cls), 0, 0, 1, 1},
  {&__pyx_n_s_col, __pyx_k_col, sizeof(__pyx_k_col), 0, 0, 1, 1},
  {&__pyx_n_u_col, __pyx_k_col, sizeof(__pyx_k_col), 0, 1, 0, 1},
  {&__pyx_n_s_collections, __pyx_k_collections, sizeof(__pyx_k_collections), 0, 0, 1, 1},
  {&__pyx_n_s_colno, __pyx_k_colno, sizeof(__pyx_k_colno), 0, 0, 1, 1},
  {&__pyx_n_s_column, __pyx_k_column, sizeof(__pyx_k_column), 0, 0, 1, 1},
  {&__pyx_n_u_column, __pyx_k_column, sizeof(__pyx_k_column), 0, 1, 0, 1},
  {&__pyx_n_s_columnName, __pyx_k_columnName, sizeof(__pyx_k_columnName), 0, 0, 1, 1},
  {&__pyx_n_s_columnNameList, __pyx_k_columnNameList, sizeof(__pyx_k_columnNameList), 0, 0, 1, 1},
  {&__pyx_n_s_columnSpec, __pyx_k_columnSpec, sizeof(__pyx_k_columnSpec), 0, 0, 1, 1},
  {&__pyx_n_u_columns, __pyx_k_columns, sizeof(__pyx_k_columns), 0, 1, 0, 1},
  {&__pyx_n_s_combine, __pyx_k_combine, sizeof(__pyx_k_combine), 0, 0, 1, 1},
  {&__pyx_n_u_commaItem, __pyx_k_commaItem, sizeof(__pyx_k_commaItem), 0, 1, 0, 1},
  {&__pyx_n_s_commaSeparatedList, __pyx_k_commaSeparatedList, sizeof(__pyx_k_commaSeparatedList), 0, 0, 1, 1},
  {&__pyx_n_u_commaSeparatedList, __pyx_k_commaSeparatedList, sizeof(__pyx_k_commaSeparatedList), 0, 1, 0, 1},
  {&__pyx_kp_u_comma_separated_list, __pyx_k_comma_separated_list, sizeof(__pyx_k_comma_separated_list), 0, 1, 0, 0},
  {&__pyx_n_s_comma_separated_list_2, __pyx_k_comma_separated_list_2, sizeof(__pyx_k_comma_separated_list_2), 0, 0, 1, 1},
  {&__pyx_n_u_command, __pyx_k_command, sizeof(__pyx_k_command), 0, 1, 0, 1},
  {&__pyx_n_s_commasepitem, __pyx_k_commasepitem, sizeof(__pyx_k_commasepitem), 0, 0, 1, 1},
  {&__pyx_n_s_comment, __pyx_k_comment, sizeof(__pyx_k_comment), 0, 0, 1, 1},
  {&__pyx_kp_u_comment_2, __pyx_k_comment_2, sizeof(__pyx_k_comment_2), 0, 1, 0, 0},
  {&__pyx_n_s_comments, __pyx_k_comments, sizeof(__pyx_k_comments), 0, 0, 1, 1},
  {&__pyx_n_s_commonHTMLEntity, __pyx_k_commonHTMLEntity, sizeof(__pyx_k_commonHTMLEntity), 0, 0, 1, 1},
  {&__pyx_n_u_commonHTMLEntity, __pyx_k_commonHTMLEntity, sizeof(__pyx_k_commonHTMLEntity), 0, 1, 0, 1},
  {&__pyx_kp_u_common_HTML_entity, __pyx_k_common_HTML_entity, sizeof(__pyx_k_common_HTML_entity), 0, 1, 0, 0},
  {&__pyx_n_s_compile, __pyx_k_compile, sizeof(__pyx_k_compile), 0, 0, 1, 1},
  {&__pyx_n_s_compiledREtype, __pyx_k_compiledREtype, sizeof(__pyx_k_compiledREtype), 0, 0, 1, 1},
  {&__pyx_n_s_contains, __pyx_k_contains, sizeof(__pyx_k_contains), 0, 0, 1, 1},
  {&__pyx_n_s_content, __pyx_k_content, sizeof(__pyx_k_content), 0, 0, 1, 1},
  {&__pyx_n_s_convertToDate, __pyx_k_convertToDate, sizeof(__pyx_k_convertToDate), 0, 0, 1, 1},
  {&__pyx_n_s_convertToDatetime, __pyx_k_convertToDatetime, sizeof(__pyx_k_convertToDatetime), 0, 0, 1, 1},
  {&__pyx_n_s_convertToFloat, __pyx_k_convertToFloat, sizeof(__pyx_k_convertToFloat), 0, 0, 1, 1},
  {&__pyx_n_s_convertToInteger, __pyx_k_convertToInteger, sizeof(__pyx_k_convertToInteger), 0, 0, 1, 1},
  {&__pyx_n_s_convertWhitespaceEscapes, __pyx_k_convertWhitespaceEscapes, sizeof(__pyx_k_convertWhitespaceEscapes), 0, 0, 1, 1},
  {&__pyx_n_s_copy, __pyx_k_copy, sizeof(__pyx_k_copy), 0, 0, 1, 1},
  {&__pyx_n_s_copyDefaultWhiteChars, __pyx_k_copyDefaultWhiteChars, sizeof(__pyx_k_copyDefaultWhiteChars), 0, 0, 1, 1},
  {&__pyx_n_s_copyTokenToRepeater, __pyx_k_copyTokenToRepeater, sizeof(__pyx_k_copyTokenToRepeater), 0, 0, 1, 1},
  {&__pyx_n_s_count, __pyx_k_count, sizeof(__pyx_k_count), 0, 0, 1, 1},
  {&__pyx_n_s_countFieldParseAction, __pyx_k_countFieldParseAction, sizeof(__pyx_k_countFieldParseAction), 0, 0, 1, 1},
  {&__pyx_n_s_countedArray, __pyx_k_countedArray, sizeof(__pyx_k_countedArray), 0, 0, 1, 1},
  {&__pyx_n_u_countedArray, __pyx_k_countedArray, sizeof(__pyx_k_countedArray), 0, 1, 0, 1},
  {&__pyx_n_s_countedArray_locals_countFieldPa, __pyx_k_countedArray_locals_countFieldPa, sizeof(__pyx_k_countedArray_locals_countFieldPa), 0, 0, 1, 1},
  {&__pyx_n_s_countedArray_locals_lambda, __pyx_k_countedArray_locals_lambda, sizeof(__pyx_k_countedArray_locals_lambda), 0, 0, 1, 1},
  {&__pyx_n_s_cppStyleComment, __pyx_k_cppStyleComment, sizeof(__pyx_k_cppStyleComment), 0, 0, 1, 1},
  {&__pyx_n_u_cppStyleComment, __pyx_k_cppStyleComment, sizeof(__pyx_k_cppStyleComment), 0, 1, 0, 1},
  {&__pyx_n_s_cpy, __pyx_k_cpy, sizeof(__pyx_k_cpy), 0, 0, 1, 1},
  {&__pyx_n_s_cur, __pyx_k_cur, sizeof(__pyx_k_cur), 0, 0, 1, 1},
  {&__pyx_n_s_curCol, __pyx_k_curCol, sizeof(__pyx_k_curCol), 0, 0, 1, 1},
  {&__pyx_n_s_cvt_fn, __pyx_k_cvt_fn, sizeof(__pyx_k_cvt_fn), 0, 0, 1, 1},
  {&__pyx_n_s_d, __pyx_k_d, sizeof(__pyx_k_d), 0, 0, 1, 1},
  {&__pyx_kp_u_d_2, __pyx_k_d_2, sizeof(__pyx_k_d_2), 0, 1, 0, 0},
  {&__pyx_kp_u_d_d, __pyx_k_d_d, sizeof(__pyx_k_d_d), 0, 1, 0, 0},
  {&__pyx_kp_u_d_d_2, __pyx_k_d_d_2, sizeof(__pyx_k_d_d_2), 0, 1, 0, 0},
  {&__pyx_kp_u_d_d_eE_d, __pyx_k_d_d_eE_d, sizeof(__pyx_k_d_d_eE_d), 0, 1, 0, 0},
  {&__pyx_kp_u_d_eE_d_d_eE_d, __pyx_k_d_eE_d_d_eE_d, sizeof(__pyx_k_d_eE_d_d_eE_d), 0, 1, 0, 0},
  {&__pyx_n_s_data, __pyx_k_data, sizeof(__pyx_k_data), 0, 0, 1, 1},
  {&__pyx_n_s_date, __pyx_k_date, sizeof(__pyx_k_date), 0, 0, 1, 1},
  {&__pyx_n_s_datetime, __pyx_k_datetime, sizeof(__pyx_k_datetime), 0, 0, 1, 1},
  {&__pyx_n_s_dblQuotedString, __pyx_k_dblQuotedString, sizeof(__pyx_k_dblQuotedString), 0, 0, 1, 1},
  {&__pyx_n_u_dblQuotedString, __pyx_k_dblQuotedString, sizeof(__pyx_k_dblQuotedString), 0, 1, 0, 1},
  {&__pyx_n_s_dblSlashComment, __pyx_k_dblSlashComment, sizeof(__pyx_k_dblSlashComment), 0, 0, 1, 1},
  {&__pyx_n_u_dblSlashComment, __pyx_k_dblSlashComment, sizeof(__pyx_k_dblSlashComment), 0, 1, 0, 1},
  {&__pyx_n_s_debug, __pyx_k_debug, sizeof(__pyx_k_debug), 0, 0, 1, 1},
  {&__pyx_n_s_debugActions, __pyx_k_debugActions, sizeof(__pyx_k_debugActions), 0, 0, 1, 1},
  {&__pyx_n_s_debugging, __pyx_k_debugging, sizeof(__pyx_k_debugging), 0, 0, 1, 1},
  {&__pyx_n_s_decode, __pyx_k_decode, sizeof(__pyx_k_decode), 0, 0, 1, 1},
  {&__pyx_n_s_default, __pyx_k_default, sizeof(__pyx_k_default), 0, 0, 1, 1},
  {&__pyx_n_u_default, __pyx_k_default, sizeof(__pyx_k_default), 0, 1, 0, 1},
  {&__pyx_n_s_defaultExceptionDebugAction, __pyx_k_defaultExceptionDebugAction, sizeof(__pyx_k_defaultExceptionDebugAction), 0, 0, 1, 1},
  {&__pyx_n_s_defaultStartDebugAction, __pyx_k_defaultStartDebugAction, sizeof(__pyx_k_defaultStartDebugAction), 0, 0, 1, 1},
  {&__pyx_n_s_defaultSuccessDebugAction, __pyx_k_defaultSuccessDebugAction, sizeof(__pyx_k_defaultSuccessDebugAction), 0, 0, 1, 1},
  {&__pyx_n_s_defaultValue, __pyx_k_defaultValue, sizeof(__pyx_k_defaultValue), 0, 0, 1, 1},
  {&__pyx_n_s_defaultvalue, __pyx_k_defaultvalue, sizeof(__pyx_k_defaultvalue), 0, 0, 1, 1},
  {&__pyx_n_s_delim, __pyx_k_delim, sizeof(__pyx_k_delim), 0, 0, 1, 1},
  {&__pyx_n_s_delimitedList, __pyx_k_delimitedList, sizeof(__pyx_k_delimitedList), 0, 0, 1, 1},
  {&__pyx_n_u_delimitedList, __pyx_k_delimitedList, sizeof(__pyx_k_delimitedList), 0, 1, 0, 1},
  {&__pyx_n_s_delitem, __pyx_k_delitem, sizeof(__pyx_k_delitem), 0, 0, 1, 1},
  {&__pyx_n_s_depth, __pyx_k_depth, sizeof(__pyx_k_depth), 0, 0, 1, 1},
  {&__pyx_n_s_deque, __pyx_k_deque, sizeof(__pyx_k_deque), 0, 0, 1, 1},
  {&__pyx_n_s_dictOf, __pyx_k_dictOf, sizeof(__pyx_k_dictOf), 0, 0, 1, 1},
  {&__pyx_n_u_dictOf, __pyx_k_dictOf, sizeof(__pyx_k_dictOf), 0, 1, 0, 1},
  {&__pyx_n_s_dictvalue, __pyx_k_dictvalue, sizeof(__pyx_k_dictvalue), 0, 0, 1, 1},
  {&__pyx_n_s_dir, __pyx_k_dir, sizeof(__pyx_k_dir), 0, 0, 1, 1},
  {&__pyx_n_s_dlName, __pyx_k_dlName, sizeof(__pyx_k_dlName), 0, 0, 1, 1},
  {&__pyx_n_s_doActions, __pyx_k_doActions, sizeof(__pyx_k_doActions), 0, 0, 1, 1},
  {&__pyx_n_s_doc, __pyx_k_doc, sizeof(__pyx_k_doc), 0, 0, 1, 1},
  {&__pyx_n_s_doctag, __pyx_k_doctag, sizeof(__pyx_k_doctag), 0, 0, 1, 1},
  {&__pyx_n_s_downcaseTokens, __pyx_k_downcaseTokens, sizeof(__pyx_k_downcaseTokens), 0, 0, 1, 1},
  {&__pyx_n_u_downcaseTokens, __pyx_k_downcaseTokens, sizeof(__pyx_k_downcaseTokens), 0, 1, 0, 1},
  {&__pyx_n_s_dummy, __pyx_k_dummy, sizeof(__pyx_k_dummy), 0, 0, 1, 1},
  {&__pyx_n_s_dump, __pyx_k_dump, sizeof(__pyx_k_dump), 0, 0, 1, 1},
  {&__pyx_n_s_e, __pyx_k_e, sizeof(__pyx_k_e), 0, 0, 1, 1},
  {&__pyx_n_s_e2, __pyx_k_e2, sizeof(__pyx_k_e2), 0, 0, 1, 1},
  {&__pyx_n_s_elem, __pyx_k_elem, sizeof(__pyx_k_elem), 0, 0, 1, 1},
  {&__pyx_n_s_empty, __pyx_k_empty, sizeof(__pyx_k_empty), 0, 0, 1, 1},
  {&__pyx_n_u_empty, __pyx_k_empty, sizeof(__pyx_k_empty), 0, 1, 0, 1},
  {&__pyx_n_s_enablePackrat, __pyx_k_enablePackrat, sizeof(__pyx_k_enablePackrat), 0, 0, 1, 1},
  {&__pyx_n_s_end, __pyx_k_end, sizeof(__pyx_k_end), 0, 0, 1, 1},
  {&__pyx_n_u_end, __pyx_k_end, sizeof(__pyx_k_end), 0, 1, 0, 1},
  {&__pyx_n_s_endQuoteChar, __pyx_k_endQuoteChar, sizeof(__pyx_k_endQuoteChar), 0, 0, 1, 1},
  {&__pyx_n_s_endQuoteCharLen, __pyx_k_endQuoteCharLen, sizeof(__pyx_k_endQuoteCharLen), 0, 0, 1, 1},
  {&__pyx_kp_u_endQuoteChar_cannot_be_the_empty, __pyx_k_endQuoteChar_cannot_be_the_empty, sizeof(__pyx_k_endQuoteChar_cannot_be_the_empty), 0, 1, 0, 0},
  {&__pyx_n_s_ender, __pyx_k_ender, sizeof(__pyx_k_ender), 0, 0, 1, 1},
  {&__pyx_n_s_endloc, __pyx_k_endloc, sizeof(__pyx_k_endloc), 0, 0, 1, 1},
  {&__pyx_n_s_endlocMarker, __pyx_k_endlocMarker, sizeof(__pyx_k_endlocMarker), 0, 0, 1, 1},
  {&__pyx_n_s_endswith, __pyx_k_endswith, sizeof(__pyx_k_endswith), 0, 0, 1, 1},
  {&__pyx_n_s_enter, __pyx_k_enter, sizeof(__pyx_k_enter), 0, 0, 1, 1},
  {&__pyx_kp_u_entering_s_line_s_d_r, __pyx_k_entering_s_line_s_d_r, sizeof(__pyx_k_entering_s_line_s_d_r), 0, 1, 0, 0},
  {&__pyx_n_s_entity, __pyx_k_entity, sizeof(__pyx_k_entity), 0, 0, 1, 1},
  {&__pyx_n_s_enumerate, __pyx_k_enumerate, sizeof(__pyx_k_enumerate), 0, 0, 1, 1},
  {&__pyx_n_s_eq, __pyx_k_eq, sizeof(__pyx_k_eq), 0, 0, 1, 1},
  {&__pyx_n_s_err, __pyx_k_err, sizeof(__pyx_k_err), 0, 0, 1, 1},
  {&__pyx_n_s_errmsg, __pyx_k_errmsg, sizeof(__pyx_k_errmsg), 0, 0, 1, 1},
  {&__pyx_n_s_error, __pyx_k_error, sizeof(__pyx_k_error), 0, 0, 1, 1},
  {&__pyx_n_s_errorStop, __pyx_k_errorStop, sizeof(__pyx_k_errorStop), 0, 0, 1, 1},
  {&__pyx_n_s_escChar, __pyx_k_escChar, sizeof(__pyx_k_escChar), 0, 0, 1, 1},
  {&__pyx_n_s_escCharReplacePattern, __pyx_k_escCharReplacePattern, sizeof(__pyx_k_escCharReplacePattern), 0, 0, 1, 1},
  {&__pyx_n_s_escQuote, __pyx_k_escQuote, sizeof(__pyx_k_escQuote), 0, 0, 1, 1},
  {&__pyx_n_s_escape, __pyx_k_escape, sizeof(__pyx_k_escape), 0, 0, 1, 1},
  {&__pyx_n_s_escapeRegexRangeChars, __pyx_k_escapeRegexRangeChars, sizeof(__pyx_k_escapeRegexRangeChars), 0, 0, 1, 1},
  {&__pyx_n_s_escapedHexChar, __pyx_k_escapedHexChar, sizeof(__pyx_k_escapedHexChar), 0, 0, 1, 1},
  {&__pyx_n_s_escapedOctChar, __pyx_k_escapedOctChar, sizeof(__pyx_k_escapedOctChar), 0, 0, 1, 1},
  {&__pyx_n_s_escapedPunc, __pyx_k_escapedPunc, sizeof(__pyx_k_escapedPunc), 0, 0, 1, 1},
  {&__pyx_n_s_exact, __pyx_k_exact, sizeof(__pyx_k_exact), 0, 0, 1, 1},
  {&__pyx_n_s_exc, __pyx_k_exc, sizeof(__pyx_k_exc), 0, 0, 1, 1},
  {&__pyx_n_s_exc_info, __pyx_k_exc_info, sizeof(__pyx_k_exc_info), 0, 0, 1, 1},
  {&__pyx_n_s_exc_type, __pyx_k_exc_type, sizeof(__pyx_k_exc_type), 0, 0, 1, 1},
  {&__pyx_n_s_exception, __pyx_k_exception, sizeof(__pyx_k_exception), 0, 0, 1, 1},
  {&__pyx_n_u_exception, __pyx_k_exception, sizeof(__pyx_k_exception), 0, 1, 0, 1},
  {&__pyx_n_s_exceptionAction, __pyx_k_exceptionAction, sizeof(__pyx_k_exceptionAction), 0, 0, 1, 1},
  {&__pyx_kp_s_exception_thrown_by_L_ParserElem, __pyx_k_exception_thrown_by_L_ParserElem, sizeof(__pyx_k_exception_thrown_by_L_ParserElem), 0, 0, 1, 0},
  {&__pyx_n_s_excludeChars, __pyx_k_excludeChars, sizeof(__pyx_k_excludeChars), 0, 0, 1, 1},
  {&__pyx_n_s_exit, __pyx_k_exit, sizeof(__pyx_k_exit), 0, 0, 1, 1},
  {&__pyx_n_s_expanded, __pyx_k_expanded, sizeof(__pyx_k_expanded), 0, 0, 1, 1},
  {&__pyx_n_s_expandtabs, __pyx_k_expandtabs, sizeof(__pyx_k_expandtabs), 0, 0, 1, 1},
  {&__pyx_n_s_expr, __pyx_k_expr, sizeof(__pyx_k_expr), 0, 0, 1, 1},
  {&__pyx_n_s_expr_parse, __pyx_k_expr_parse, sizeof(__pyx_k_expr_parse), 0, 0, 1, 1},
  {&__pyx_n_s_exprs, __pyx_k_exprs, sizeof(__pyx_k_exprs), 0, 0, 1, 1},
  {&__pyx_n_s_exprsFound, __pyx_k_exprsFound, sizeof(__pyx_k_exprsFound), 0, 0, 1, 1},
  {&__pyx_n_s_exprtokens, __pyx_k_exprtokens, sizeof(__pyx_k_exprtokens), 0, 0, 1, 1},
  {&__pyx_n_s_extend, __pyx_k_extend, sizeof(__pyx_k_extend), 0, 0, 1, 1},
  {&__pyx_n_s_extractText, __pyx_k_extractText, sizeof(__pyx_k_extractText), 0, 0, 1, 1},
  {&__pyx_n_s_extract_tb, __pyx_k_extract_tb, sizeof(__pyx_k_extract_tb), 0, 0, 1, 1},
  {&__pyx_kp_u_f, __pyx_k_f, sizeof(__pyx_k_f), 0, 1, 0, 0},
  {&__pyx_n_s_f_2, __pyx_k_f_2, sizeof(__pyx_k_f_2), 0, 0, 1, 1},
  {&__pyx_n_s_failAction, __pyx_k_failAction, sizeof(__pyx_k_failAction), 0, 0, 1, 1},
  {&__pyx_n_s_failOn, __pyx_k_failOn, sizeof(__pyx_k_failOn), 0, 0, 1, 1},
  {&__pyx_n_u_failOn, __pyx_k_failOn, sizeof(__pyx_k_failOn), 0, 1, 0, 1},
  {&__pyx_n_s_failed, __pyx_k_failed, sizeof(__pyx_k_failed), 0, 0, 1, 1},
  {&__pyx_kp_u_failed_user_defined_condition, __pyx_k_failed_user_defined_condition, sizeof(__pyx_k_failed_user_defined_condition), 0, 1, 0, 0},
  {&__pyx_n_s_failureTests, __pyx_k_failureTests, sizeof(__pyx_k_failureTests), 0, 0, 1, 1},
  {&__pyx_n_s_fatal, __pyx_k_fatal, sizeof(__pyx_k_fatal), 0, 0, 1, 1},
  {&__pyx_n_u_fatal, __pyx_k_fatal, sizeof(__pyx_k_fatal), 0, 1, 0, 1},
  {&__pyx_kp_u_ffff, __pyx_k_ffff, sizeof(__pyx_k_ffff), 0, 1, 0, 0},
  {&__pyx_n_s_file_contents, __pyx_k_file_contents, sizeof(__pyx_k_file_contents), 0, 0, 1, 1},
  {&__pyx_n_s_file_or_filename, __pyx_k_file_or_filename, sizeof(__pyx_k_file_or_filename), 0, 0, 1, 1},
  {&__pyx_n_s_filename, __pyx_k_filename, sizeof(__pyx_k_filename), 0, 0, 1, 1},
  {&__pyx_n_s_finalResults, __pyx_k_finalResults, sizeof(__pyx_k_finalResults), 0, 0, 1, 1},
  {&__pyx_n_s_find, __pyx_k_find, sizeof(__pyx_k_find), 0, 0, 1, 1},
  {&__pyx_n_s_firstMatchChar, __pyx_k_firstMatchChar, sizeof(__pyx_k_firstMatchChar), 0, 0, 1, 1},
  {&__pyx_n_s_firstQuoteChar, __pyx_k_firstQuoteChar, sizeof(__pyx_k_firstQuoteChar), 0, 0, 1, 1},
  {&__pyx_n_s_flag, __pyx_k_flag, sizeof(__pyx_k_flag), 0, 0, 1, 1},
  {&__pyx_n_s_flags, __pyx_k_flags, sizeof(__pyx_k_flags), 0, 0, 1, 1},
  {&__pyx_n_s_flatten, __pyx_k_flatten, sizeof(__pyx_k_flatten), 0, 0, 1, 1},
  {&__pyx_n_s_fmt, __pyx_k_fmt, sizeof(__pyx_k_fmt), 0, 0, 1, 1},
  {&__pyx_n_s_fn, __pyx_k_fn, sizeof(__pyx_k_fn), 0, 0, 1, 1},
  {&__pyx_n_s_fname, __pyx_k_fname, sizeof(__pyx_k_fname), 0, 0, 1, 1},
  {&__pyx_n_s_fns, __pyx_k_fns, sizeof(__pyx_k_fns), 0, 0, 1, 1},
  {&__pyx_n_s_fnumber, __pyx_k_fnumber, sizeof(__pyx_k_fnumber), 0, 0, 1, 1},
  {&__pyx_n_u_fnumber, __pyx_k_fnumber, sizeof(__pyx_k_fnumber), 0, 1, 0, 1},
  {&__pyx_n_s_formatted, __pyx_k_formatted, sizeof(__pyx_k_formatted), 0, 0, 1, 1},
  {&__pyx_n_s_foundArity, __pyx_k_foundArity, sizeof(__pyx_k_foundArity), 0, 0, 1, 1},
  {&__pyx_n_s_fraction, __pyx_k_fraction, sizeof(__pyx_k_fraction), 0, 0, 1, 1},
  {&__pyx_n_u_fraction, __pyx_k_fraction, sizeof(__pyx_k_fraction), 0, 1, 0, 1},
  {&__pyx_kp_u_fraction_or_mixed_integer_fracti, __pyx_k_fraction_or_mixed_integer_fracti, sizeof(__pyx_k_fraction_or_mixed_integer_fracti), 0, 1, 0, 0},
  {&__pyx_n_s_frame_summary, __pyx_k_frame_summary, sizeof(__pyx_k_frame_summary), 0, 0, 1, 1},
  {&__pyx_n_s_frames, __pyx_k_frames, sizeof(__pyx_k_frames), 0, 0, 1, 1},
  {&__pyx_n_s_from, __pyx_k_from, sizeof(__pyx_k_from), 0, 0, 1, 1},
  {&__pyx_n_s_fromToken, __pyx_k_fromToken, sizeof(__pyx_k_fromToken), 0, 0, 1, 1},
  {&__pyx_n_u_from_2, __pyx_k_from_2, sizeof(__pyx_k_from_2), 0, 1, 0, 1},
  {&__pyx_n_s_from_exception, __pyx_k_from_exception, sizeof(__pyx_k_from_exception), 0, 0, 1, 1},
  {&__pyx_n_s_from_symbols, __pyx_k_from_symbols, sizeof(__pyx_k_from_symbols), 0, 0, 1, 1},
  {&__pyx_n_s_full, __pyx_k_full, sizeof(__pyx_k_full), 0, 0, 1, 1},
  {&__pyx_n_s_fullDump, __pyx_k_fullDump, sizeof(__pyx_k_fullDump), 0, 0, 1, 1},
  {&__pyx_kp_u_full_IPv6_address, __pyx_k_full_IPv6_address, sizeof(__pyx_k_full_IPv6_address), 0, 1, 0, 0},
  {&__pyx_n_s_full_ipv6_address, __pyx_k_full_ipv6_address, sizeof(__pyx_k_full_ipv6_address), 0, 0, 1, 1},
  {&__pyx_n_s_func, __pyx_k_func, sizeof(__pyx_k_func), 0, 0, 1, 1},
  {&__pyx_n_s_func_name, __pyx_k_func_name, sizeof(__pyx_k_func_name), 0, 0, 1, 1},
  {&__pyx_kp_u_g_1, __pyx_k_g_1, sizeof(__pyx_k_g_1), 0, 1, 0, 0},
  {&__pyx_n_s_generatorType, __pyx_k_generatorType, sizeof(__pyx_k_generatorType), 0, 0, 1, 1},
  {&__pyx_n_s_genexpr, __pyx_k_genexpr, sizeof(__pyx_k_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_get, __pyx_k_get, sizeof(__pyx_k_get), 0, 0, 1, 1},
  {&__pyx_n_s_getName, __pyx_k_getName, sizeof(__pyx_k_getName), 0, 0, 1, 1},
  {&__pyx_n_s_getattr, __pyx_k_getattr, sizeof(__pyx_k_getattr), 0, 0, 1, 1},
  {&__pyx_n_s_getitem, __pyx_k_getitem, sizeof(__pyx_k_getitem), 0, 0, 1, 1},
  {&__pyx_n_s_getnewargs, __pyx_k_getnewargs, sizeof(__pyx_k_getnewargs), 0, 0, 1, 1},
  {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
  {&__pyx_n_s_group, __pyx_k_group, sizeof(__pyx_k_group), 0, 0, 1, 1},
  {&__pyx_n_s_groupdict, __pyx_k_groupdict, sizeof(__pyx_k_groupdict), 0, 0, 1, 1},
  {&__pyx_kp_u_gt_lt_amp_nbsp_quot_apos, __pyx_k_gt_lt_amp_nbsp_quot_apos, sizeof(__pyx_k_gt_lt_amp_nbsp_quot_apos), 0, 1, 0, 0},
  {&__pyx_n_s_hasIgnoreExprs, __pyx_k_hasIgnoreExprs, sizeof(__pyx_k_hasIgnoreExprs), 0, 0, 1, 1},
  {&__pyx_n_s_hash, __pyx_k_hash, sizeof(__pyx_k_hash), 0, 0, 1, 1},
  {&__pyx_n_s_haskeys, __pyx_k_haskeys, sizeof(__pyx_k_haskeys), 0, 0, 1, 1},
  {&__pyx_kp_u_hex_integer, __pyx_k_hex_integer, sizeof(__pyx_k_hex_integer), 0, 1, 0, 0},
  {&__pyx_n_s_hex_integer_2, __pyx_k_hex_integer_2, sizeof(__pyx_k_hex_integer_2), 0, 0, 1, 1},
  {&__pyx_n_u_hex_integer_2, __pyx_k_hex_integer_2, sizeof(__pyx_k_hex_integer_2), 0, 1, 0, 1},
  {&__pyx_n_s_hexnums, __pyx_k_hexnums, sizeof(__pyx_k_hexnums), 0, 0, 1, 1},
  {&__pyx_n_u_hexnums, __pyx_k_hexnums, sizeof(__pyx_k_hexnums), 0, 1, 0, 1},
  {&__pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_k_home_travis_build_evhub_cpypars, sizeof(__pyx_k_home_travis_build_evhub_cpypars), 0, 0, 1, 0},
  {&__pyx_n_s_htmlComment, __pyx_k_htmlComment, sizeof(__pyx_k_htmlComment), 0, 0, 1, 1},
  {&__pyx_n_u_htmlComment, __pyx_k_htmlComment, sizeof(__pyx_k_htmlComment), 0, 1, 0, 1},
  {&__pyx_n_s_htmlEntityMap, __pyx_k_htmlEntityMap, sizeof(__pyx_k_htmlEntityMap), 0, 0, 1, 1},
  {&__pyx_n_s_html_stripper, __pyx_k_html_stripper, sizeof(__pyx_k_html_stripper), 0, 0, 1, 1},
  {&__pyx_n_s_i, __pyx_k_i, sizeof(__pyx_k_i), 0, 0, 1, 1},
  {&__pyx_n_s_iadd, __pyx_k_iadd, sizeof(__pyx_k_iadd), 0, 0, 1, 1},
  {&__pyx_n_s_id, __pyx_k_id, sizeof(__pyx_k_id), 0, 0, 1, 1},
  {&__pyx_n_s_ident, __pyx_k_ident, sizeof(__pyx_k_ident), 0, 0, 1, 1},
  {&__pyx_n_s_identChars, __pyx_k_identChars, sizeof(__pyx_k_identChars), 0, 0, 1, 1},
  {&__pyx_n_s_identifier, __pyx_k_identifier, sizeof(__pyx_k_identifier), 0, 0, 1, 1},
  {&__pyx_n_u_identifier, __pyx_k_identifier, sizeof(__pyx_k_identifier), 0, 1, 0, 1},
  {&__pyx_kp_u_if_numterms_3_opExpr_must_be_a_t, __pyx_k_if_numterms_3_opExpr_must_be_a_t, sizeof(__pyx_k_if_numterms_3_opExpr_must_be_a_t), 0, 1, 0, 0},
  {&__pyx_n_s_ignore, __pyx_k_ignore, sizeof(__pyx_k_ignore), 0, 0, 1, 1},
  {&__pyx_n_u_ignore, __pyx_k_ignore, sizeof(__pyx_k_ignore), 0, 1, 0, 1},
  {&__pyx_n_s_ignoreExpr, __pyx_k_ignoreExpr, sizeof(__pyx_k_ignoreExpr), 0, 0, 1, 1},
  {&__pyx_n_s_ignoreExprs, __pyx_k_ignoreExprs, sizeof(__pyx_k_ignoreExprs), 0, 0, 1, 1},
  {&__pyx_n_s_ikey, __pyx_k_ikey, sizeof(__pyx_k_ikey), 0, 0, 1, 1},
  {&__pyx_kp_u_illegal_nesting, __pyx_k_illegal_nesting, sizeof(__pyx_k_illegal_nesting), 0, 1, 0, 0},
  {&__pyx_n_s_ilshift, __pyx_k_ilshift, sizeof(__pyx_k_ilshift), 0, 0, 1, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_inAccumNames, __pyx_k_inAccumNames, sizeof(__pyx_k_inAccumNames), 0, 0, 1, 1},
  {&__pyx_n_u_include, __pyx_k_include, sizeof(__pyx_k_include), 0, 1, 0, 1},
  {&__pyx_n_s_includeMatch, __pyx_k_includeMatch, sizeof(__pyx_k_includeMatch), 0, 0, 1, 1},
  {&__pyx_n_s_includeSeparators, __pyx_k_includeSeparators, sizeof(__pyx_k_includeSeparators), 0, 0, 1, 1},
  {&__pyx_n_s_indent, __pyx_k_indent, sizeof(__pyx_k_indent), 0, 0, 1, 1},
  {&__pyx_n_s_indentStack, __pyx_k_indentStack, sizeof(__pyx_k_indentStack), 0, 0, 1, 1},
  {&__pyx_n_s_indentedBlock, __pyx_k_indentedBlock, sizeof(__pyx_k_indentedBlock), 0, 0, 1, 1},
  {&__pyx_n_u_indentedBlock, __pyx_k_indentedBlock, sizeof(__pyx_k_indentedBlock), 0, 1, 0, 1},
  {&__pyx_n_s_indentedBlock_locals_checkPeerIn, __pyx_k_indentedBlock_locals_checkPeerIn, sizeof(__pyx_k_indentedBlock_locals_checkPeerIn), 0, 0, 1, 1},
  {&__pyx_n_s_indentedBlock_locals_checkSubInd, __pyx_k_indentedBlock_locals_checkSubInd, sizeof(__pyx_k_indentedBlock_locals_checkSubInd), 0, 0, 1, 1},
  {&__pyx_n_s_indentedBlock_locals_checkUninde, __pyx_k_indentedBlock_locals_checkUninde, sizeof(__pyx_k_indentedBlock_locals_checkUninde), 0, 0, 1, 1},
  {&__pyx_kp_u_indented_block, __pyx_k_indented_block, sizeof(__pyx_k_indented_block), 0, 1, 0, 0},
  {&__pyx_n_s_index, __pyx_k_index, sizeof(__pyx_k_index), 0, 0, 1, 1},
  {&__pyx_n_s_indices, __pyx_k_indices, sizeof(__pyx_k_indices), 0, 0, 1, 1},
  {&__pyx_n_s_infixNotation, __pyx_k_infixNotation, sizeof(__pyx_k_infixNotation), 0, 0, 1, 1},
  {&__pyx_n_u_infixNotation, __pyx_k_infixNotation, sizeof(__pyx_k_infixNotation), 0, 1, 0, 1},
  {&__pyx_n_s_init, __pyx_k_init, sizeof(__pyx_k_init), 0, 0, 1, 1},
  {&__pyx_n_s_initChars, __pyx_k_initChars, sizeof(__pyx_k_initChars), 0, 0, 1, 1},
  {&__pyx_n_s_initCharsOrig, __pyx_k_initCharsOrig, sizeof(__pyx_k_initCharsOrig), 0, 0, 1, 1},
  {&__pyx_n_s_initExprGroups, __pyx_k_initExprGroups, sizeof(__pyx_k_initExprGroups), 0, 0, 1, 1},
  {&__pyx_n_s_inlineLiteralsUsing, __pyx_k_inlineLiteralsUsing, sizeof(__pyx_k_inlineLiteralsUsing), 0, 0, 1, 1},
  {&__pyx_n_s_insStr, __pyx_k_insStr, sizeof(__pyx_k_insStr), 0, 0, 1, 1},
  {&__pyx_n_s_insert, __pyx_k_insert, sizeof(__pyx_k_insert), 0, 0, 1, 1},
  {&__pyx_n_s_instring, __pyx_k_instring, sizeof(__pyx_k_instring), 0, 0, 1, 1},
  {&__pyx_n_s_instrlen, __pyx_k_instrlen, sizeof(__pyx_k_instrlen), 0, 0, 1, 1},
  {&__pyx_n_s_intExpr, __pyx_k_intExpr, sizeof(__pyx_k_intExpr), 0, 0, 1, 1},
  {&__pyx_n_s_integer, __pyx_k_integer, sizeof(__pyx_k_integer), 0, 0, 1, 1},
  {&__pyx_n_u_integer, __pyx_k_integer, sizeof(__pyx_k_integer), 0, 1, 0, 1},
  {&__pyx_kp_u_invalid_pattern_s_passed_to_Rege, __pyx_k_invalid_pattern_s_passed_to_Rege, sizeof(__pyx_k_invalid_pattern_s_passed_to_Rege), 0, 1, 0, 0},
  {&__pyx_n_s_invert, __pyx_k_invert, sizeof(__pyx_k_invert), 0, 0, 1, 1},
  {&__pyx_n_s_ior, __pyx_k_ior, sizeof(__pyx_k_ior), 0, 0, 1, 1},
  {&__pyx_n_s_ipv4_address, __pyx_k_ipv4_address, sizeof(__pyx_k_ipv4_address), 0, 0, 1, 1},
  {&__pyx_n_s_ipv6_address, __pyx_k_ipv6_address, sizeof(__pyx_k_ipv6_address), 0, 0, 1, 1},
  {&__pyx_n_s_ipv6_part, __pyx_k_ipv6_part, sizeof(__pyx_k_ipv6_part), 0, 0, 1, 1},
  {&__pyx_n_s_isequal, __pyx_k_isequal, sizeof(__pyx_k_isequal), 0, 0, 1, 1},
  {&__pyx_n_s_isinstance, __pyx_k_isinstance, sizeof(__pyx_k_isinstance), 0, 0, 1, 1},
  {&__pyx_n_s_iso8601_date, __pyx_k_iso8601_date, sizeof(__pyx_k_iso8601_date), 0, 0, 1, 1},
  {&__pyx_n_s_iso8601_datetime, __pyx_k_iso8601_datetime, sizeof(__pyx_k_iso8601_datetime), 0, 0, 1, 1},
  {&__pyx_n_s_isspace, __pyx_k_isspace, sizeof(__pyx_k_isspace), 0, 0, 1, 1},
  {&__pyx_n_s_item, __pyx_k_item, sizeof(__pyx_k_item), 0, 0, 1, 1},
  {&__pyx_n_s_item_fn, __pyx_k_item_fn, sizeof(__pyx_k_item_fn), 0, 0, 1, 1},
  {&__pyx_n_s_items, __pyx_k_items, sizeof(__pyx_k_items), 0, 0, 1, 1},
  {&__pyx_n_s_itemseq, __pyx_k_itemseq, sizeof(__pyx_k_itemseq), 0, 0, 1, 1},
  {&__pyx_n_s_iter, __pyx_k_iter, sizeof(__pyx_k_iter), 0, 0, 1, 1},
  {&__pyx_n_s_iteritems, __pyx_k_iteritems, sizeof(__pyx_k_iteritems), 0, 0, 1, 1},
  {&__pyx_n_s_iteritems_2, __pyx_k_iteritems_2, sizeof(__pyx_k_iteritems_2), 0, 0, 1, 1},
  {&__pyx_n_s_iterkeys, __pyx_k_iterkeys, sizeof(__pyx_k_iterkeys), 0, 0, 1, 1},
  {&__pyx_n_u_iterkeys, __pyx_k_iterkeys, sizeof(__pyx_k_iterkeys), 0, 1, 0, 1},
  {&__pyx_n_s_iterkeys_2, __pyx_k_iterkeys_2, sizeof(__pyx_k_iterkeys_2), 0, 0, 1, 1},
  {&__pyx_n_s_itervalues, __pyx_k_itervalues, sizeof(__pyx_k_itervalues), 0, 0, 1, 1},
  {&__pyx_n_s_itervalues_2, __pyx_k_itervalues_2, sizeof(__pyx_k_itervalues_2), 0, 0, 1, 1},
  {&__pyx_n_s_ixor, __pyx_k_ixor, sizeof(__pyx_k_ixor), 0, 0, 1, 1},
  {&__pyx_n_s_j, __pyx_k_j, sizeof(__pyx_k_j), 0, 0, 1, 1},
  {&__pyx_n_s_javaStyleComment, __pyx_k_javaStyleComment, sizeof(__pyx_k_javaStyleComment), 0, 0, 1, 1},
  {&__pyx_n_u_javaStyleComment, __pyx_k_javaStyleComment, sizeof(__pyx_k_javaStyleComment), 0, 1, 0, 1},
  {&__pyx_n_s_joinString, __pyx_k_joinString, sizeof(__pyx_k_joinString), 0, 0, 1, 1},
  {&__pyx_kp_s_just_like_L_ParseFatalException, __pyx_k_just_like_L_ParseFatalException, sizeof(__pyx_k_just_like_L_ParseFatalException), 0, 0, 1, 0},
  {&__pyx_n_s_k, __pyx_k_k, sizeof(__pyx_k_k), 0, 0, 1, 1},
  {&__pyx_n_s_keepMatching, __pyx_k_keepMatching, sizeof(__pyx_k_keepMatching), 0, 0, 1, 1},
  {&__pyx_n_s_keepTabs, __pyx_k_keepTabs, sizeof(__pyx_k_keepTabs), 0, 0, 1, 1},
  {&__pyx_n_s_key, __pyx_k_key, sizeof(__pyx_k_key), 0, 0, 1, 1},
  {&__pyx_n_s_key_fifo, __pyx_k_key_fifo, sizeof(__pyx_k_key_fifo), 0, 0, 1, 1},
  {&__pyx_n_s_keys, __pyx_k_keys, sizeof(__pyx_k_keys), 0, 0, 1, 1},
  {&__pyx_n_s_kwargs, __pyx_k_kwargs, sizeof(__pyx_k_kwargs), 0, 0, 1, 1},
  {&__pyx_n_s_l, __pyx_k_l, sizeof(__pyx_k_l), 0, 0, 1, 1},
  {&__pyx_n_s_lambda, __pyx_k_lambda, sizeof(__pyx_k_lambda), 0, 0, 1, 1},
  {&__pyx_n_s_last, __pyx_k_last, sizeof(__pyx_k_last), 0, 0, 1, 1},
  {&__pyx_n_s_lastCR, __pyx_k_lastCR, sizeof(__pyx_k_lastCR), 0, 0, 1, 1},
  {&__pyx_n_s_lastE, __pyx_k_lastE, sizeof(__pyx_k_lastE), 0, 0, 1, 1},
  {&__pyx_n_s_lastExpr, __pyx_k_lastExpr, sizeof(__pyx_k_lastExpr), 0, 0, 1, 1},
  {&__pyx_n_s_leaveWhitespace, __pyx_k_leaveWhitespace, sizeof(__pyx_k_leaveWhitespace), 0, 0, 1, 1},
  {&__pyx_kp_u_leaving_s_exception_s, __pyx_k_leaving_s_exception_s, sizeof(__pyx_k_leaving_s_exception_s), 0, 1, 0, 0},
  {&__pyx_kp_u_leaving_s_ret_r, __pyx_k_leaving_s_ret_r, sizeof(__pyx_k_leaving_s_ret_r), 0, 1, 0, 0},
  {&__pyx_n_s_len, __pyx_k_len, sizeof(__pyx_k_len), 0, 0, 1, 1},
  {&__pyx_kp_u_len_2, __pyx_k_len_2, sizeof(__pyx_k_len_2), 0, 1, 0, 0},
  {&__pyx_n_s_len_3, __pyx_k_len_3, sizeof(__pyx_k_len_3), 0, 0, 1, 1},
  {&__pyx_n_s_limit, __pyx_k_limit, sizeof(__pyx_k_limit), 0, 0, 1, 1},
  {&__pyx_n_s_line, __pyx_k_line, sizeof(__pyx_k_line), 0, 0, 1, 1},
  {&__pyx_n_u_line, __pyx_k_line, sizeof(__pyx_k_line), 0, 1, 0, 1},
  {&__pyx_n_s_lineEnd, __pyx_k_lineEnd, sizeof(__pyx_k_lineEnd), 0, 0, 1, 1},
  {&__pyx_n_u_lineEnd, __pyx_k_lineEnd, sizeof(__pyx_k_lineEnd), 0, 1, 0, 1},
  {&__pyx_n_s_lineStart, __pyx_k_lineStart, sizeof(__pyx_k_lineStart), 0, 0, 1, 1},
  {&__pyx_n_u_lineStart, __pyx_k_lineStart, sizeof(__pyx_k_lineStart), 0, 1, 0, 1},
  {&__pyx_n_s_line_column, __pyx_k_line_column, sizeof(__pyx_k_line_column), 0, 0, 1, 1},
  {&__pyx_n_s_line_str, __pyx_k_line_str, sizeof(__pyx_k_line_str), 0, 0, 1, 1},
  {&__pyx_n_s_lineno, __pyx_k_lineno, sizeof(__pyx_k_lineno), 0, 0, 1, 1},
  {&__pyx_n_u_lineno, __pyx_k_lineno, sizeof(__pyx_k_lineno), 0, 1, 0, 1},
  {&__pyx_kp_u_lineno_col_line, __pyx_k_lineno_col_line, sizeof(__pyx_k_lineno_col_line), 0, 1, 0, 0},
  {&__pyx_n_s_listAllMatches, __pyx_k_listAllMatches, sizeof(__pyx_k_listAllMatches), 0, 0, 1, 1},
  {&__pyx_n_s_literalStringClass, __pyx_k_literalStringClass, sizeof(__pyx_k_literalStringClass), 0, 0, 1, 1},
  {&__pyx_n_s_loc, __pyx_k_loc, sizeof(__pyx_k_loc), 0, 0, 1, 1},
  {&__pyx_n_s_loc2, __pyx_k_loc2, sizeof(__pyx_k_loc2), 0, 0, 1, 1},
  {&__pyx_n_s_locMarker, __pyx_k_locMarker, sizeof(__pyx_k_locMarker), 0, 0, 1, 1},
  {&__pyx_n_s_locatedExpr, __pyx_k_locatedExpr, sizeof(__pyx_k_locatedExpr), 0, 0, 1, 1},
  {&__pyx_n_u_locatedExpr, __pyx_k_locatedExpr, sizeof(__pyx_k_locatedExpr), 0, 1, 0, 1},
  {&__pyx_n_s_locatedExpr_locals_lambda, __pyx_k_locatedExpr_locals_lambda, sizeof(__pyx_k_locatedExpr_locals_lambda), 0, 0, 1, 1},
  {&__pyx_n_s_locator, __pyx_k_locator, sizeof(__pyx_k_locator), 0, 0, 1, 1},
  {&__pyx_n_s_locn, __pyx_k_locn, sizeof(__pyx_k_locn), 0, 0, 1, 1},
  {&__pyx_n_u_locn_end, __pyx_k_locn_end, sizeof(__pyx_k_locn_end), 0, 1, 0, 1},
  {&__pyx_n_u_locn_start, __pyx_k_locn_start, sizeof(__pyx_k_locn_start), 0, 1, 0, 1},
  {&__pyx_n_s_lookup, __pyx_k_lookup, sizeof(__pyx_k_lookup), 0, 0, 1, 1},
  {&__pyx_n_s_lookup_2, __pyx_k_lookup_2, sizeof(__pyx_k_lookup_2), 0, 0, 1, 1},
  {&__pyx_n_s_lower, __pyx_k_lower, sizeof(__pyx_k_lower), 0, 0, 1, 1},
  {&__pyx_n_s_lpar, __pyx_k_lpar, sizeof(__pyx_k_lpar), 0, 0, 1, 1},
  {&__pyx_n_s_lshift, __pyx_k_lshift, sizeof(__pyx_k_lshift), 0, 0, 1, 1},
  {&__pyx_n_s_lstrip, __pyx_k_lstrip, sizeof(__pyx_k_lstrip), 0, 0, 1, 1},
  {&__pyx_n_s_mac_address, __pyx_k_mac_address, sizeof(__pyx_k_mac_address), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_u_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 1, 0, 1},
  {&__pyx_n_s_makeHTMLTags, __pyx_k_makeHTMLTags, sizeof(__pyx_k_makeHTMLTags), 0, 0, 1, 1},
  {&__pyx_n_u_makeHTMLTags, __pyx_k_makeHTMLTags, sizeof(__pyx_k_makeHTMLTags), 0, 1, 0, 1},
  {&__pyx_n_s_makeOptionalList, __pyx_k_makeOptionalList, sizeof(__pyx_k_makeOptionalList), 0, 0, 1, 1},
  {&__pyx_n_s_makeTags, __pyx_k_makeTags, sizeof(__pyx_k_makeTags), 0, 0, 1, 1},
  {&__pyx_n_s_makeTags_locals_genexpr, __pyx_k_makeTags_locals_genexpr, sizeof(__pyx_k_makeTags_locals_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_makeTags_locals_lambda, __pyx_k_makeTags_locals_lambda, sizeof(__pyx_k_makeTags_locals_lambda), 0, 0, 1, 1},
  {&__pyx_n_s_makeXMLTags, __pyx_k_makeXMLTags, sizeof(__pyx_k_makeXMLTags), 0, 0, 1, 1},
  {&__pyx_n_u_makeXMLTags, __pyx_k_makeXMLTags, sizeof(__pyx_k_makeXMLTags), 0, 1, 0, 1},
  {&__pyx_n_s_map, __pyx_k_map, sizeof(__pyx_k_map), 0, 0, 1, 1},
  {&__pyx_n_s_markInputline, __pyx_k_markInputline, sizeof(__pyx_k_markInputline), 0, 0, 1, 1},
  {&__pyx_n_s_markerString, __pyx_k_markerString, sizeof(__pyx_k_markerString), 0, 0, 1, 1},
  {&__pyx_n_s_masks, __pyx_k_masks, sizeof(__pyx_k_masks), 0, 0, 1, 1},
  {&__pyx_n_s_mat, __pyx_k_mat, sizeof(__pyx_k_mat), 0, 0, 1, 1},
  {&__pyx_n_s_match, __pyx_k_match, sizeof(__pyx_k_match), 0, 0, 1, 1},
  {&__pyx_n_s_matchExpr, __pyx_k_matchExpr, sizeof(__pyx_k_matchExpr), 0, 0, 1, 1},
  {&__pyx_n_s_matchLen, __pyx_k_matchLen, sizeof(__pyx_k_matchLen), 0, 0, 1, 1},
  {&__pyx_n_s_matchOnlyAtCol, __pyx_k_matchOnlyAtCol, sizeof(__pyx_k_matchOnlyAtCol), 0, 0, 1, 1},
  {&__pyx_n_u_matchOnlyAtCol, __pyx_k_matchOnlyAtCol, sizeof(__pyx_k_matchOnlyAtCol), 0, 1, 0, 1},
  {&__pyx_n_s_matchOnlyAtCol_locals_verifyCol, __pyx_k_matchOnlyAtCol_locals_verifyCol, sizeof(__pyx_k_matchOnlyAtCol_locals_verifyCol), 0, 0, 1, 1},
  {&__pyx_n_s_matchOrder, __pyx_k_matchOrder, sizeof(__pyx_k_matchOrder), 0, 0, 1, 1},
  {&__pyx_n_s_matchPreviousExpr, __pyx_k_matchPreviousExpr, sizeof(__pyx_k_matchPreviousExpr), 0, 0, 1, 1},
  {&__pyx_n_u_matchPreviousExpr, __pyx_k_matchPreviousExpr, sizeof(__pyx_k_matchPreviousExpr), 0, 1, 0, 1},
  {&__pyx_n_s_matchPreviousExpr_locals_copyTok, __pyx_k_matchPreviousExpr_locals_copyTok, sizeof(__pyx_k_matchPreviousExpr_locals_copyTok), 0, 0, 1, 1},
  {&__pyx_n_s_matchPreviousExpr_locals_copyTok_2, __pyx_k_matchPreviousExpr_locals_copyTok_2, sizeof(__pyx_k_matchPreviousExpr_locals_copyTok_2), 0, 0, 1, 1},
  {&__pyx_n_s_matchPreviousLiteral, __pyx_k_matchPreviousLiteral, sizeof(__pyx_k_matchPreviousLiteral), 0, 0, 1, 1},
  {&__pyx_n_u_matchPreviousLiteral, __pyx_k_matchPreviousLiteral, sizeof(__pyx_k_matchPreviousLiteral), 0, 1, 0, 1},
  {&__pyx_n_s_matchPreviousLiteral_locals_copy, __pyx_k_matchPreviousLiteral_locals_copy, sizeof(__pyx_k_matchPreviousLiteral_locals_copy), 0, 0, 1, 1},
  {&__pyx_n_s_matchPreviousLiteral_locals_copy_2, __pyx_k_matchPreviousLiteral_locals_copy_2, sizeof(__pyx_k_matchPreviousLiteral_locals_copy_2), 0, 0, 1, 1},
  {&__pyx_n_s_matchString, __pyx_k_matchString, sizeof(__pyx_k_matchString), 0, 0, 1, 1},
  {&__pyx_n_s_matchTokens, __pyx_k_matchTokens, sizeof(__pyx_k_matchTokens), 0, 0, 1, 1},
  {&__pyx_n_s_matchWhite, __pyx_k_matchWhite, sizeof(__pyx_k_matchWhite), 0, 0, 1, 1},
  {&__pyx_n_s_match_string, __pyx_k_match_string, sizeof(__pyx_k_match_string), 0, 0, 1, 1},
  {&__pyx_n_s_match_stringloc, __pyx_k_match_stringloc, sizeof(__pyx_k_match_stringloc), 0, 0, 1, 1},
  {&__pyx_kp_u_matched_token_not_at_column_d, __pyx_k_matched_token_not_at_column_d, sizeof(__pyx_k_matched_token_not_at_column_d), 0, 1, 0, 0},
  {&__pyx_n_s_matches, __pyx_k_matches, sizeof(__pyx_k_matches), 0, 0, 1, 1},
  {&__pyx_n_s_max, __pyx_k_max, sizeof(__pyx_k_max), 0, 0, 1, 1},
  {&__pyx_n_s_maxExcLoc, __pyx_k_maxExcLoc, sizeof(__pyx_k_maxExcLoc), 0, 0, 1, 1},
  {&__pyx_n_s_maxException, __pyx_k_maxException, sizeof(__pyx_k_maxException), 0, 0, 1, 1},
  {&__pyx_n_s_maxLen, __pyx_k_maxLen, sizeof(__pyx_k_maxLen), 0, 0, 1, 1},
  {&__pyx_n_s_maxMatches, __pyx_k_maxMatches, sizeof(__pyx_k_maxMatches), 0, 0, 1, 1},
  {&__pyx_n_s_maxMismatches, __pyx_k_maxMismatches, sizeof(__pyx_k_maxMismatches), 0, 0, 1, 1},
  {&__pyx_n_s_maxSpecified, __pyx_k_maxSpecified, sizeof(__pyx_k_maxSpecified), 0, 0, 1, 1},
  {&__pyx_n_s_maxargs, __pyx_k_maxargs, sizeof(__pyx_k_maxargs), 0, 0, 1, 1},
  {&__pyx_n_s_maxlen, __pyx_k_maxlen, sizeof(__pyx_k_maxlen), 0, 0, 1, 1},
  {&__pyx_n_s_maxloc, __pyx_k_maxloc, sizeof(__pyx_k_maxloc), 0, 0, 1, 1},
  {&__pyx_n_s_maxsize, __pyx_k_maxsize, sizeof(__pyx_k_maxsize), 0, 0, 1, 1},
  {&__pyx_n_s_maxsplit, __pyx_k_maxsplit, sizeof(__pyx_k_maxsplit), 0, 0, 1, 1},
  {&__pyx_n_s_mayIndexError, __pyx_k_mayIndexError, sizeof(__pyx_k_mayIndexError), 0, 0, 1, 1},
  {&__pyx_n_s_mayReturnEmpty, __pyx_k_mayReturnEmpty, sizeof(__pyx_k_mayReturnEmpty), 0, 0, 1, 1},
  {&__pyx_n_u_message, __pyx_k_message, sizeof(__pyx_k_message), 0, 1, 0, 1},
  {&__pyx_n_s_metaclass, __pyx_k_metaclass, sizeof(__pyx_k_metaclass), 0, 0, 1, 1},
  {&__pyx_n_s_methodCall, __pyx_k_methodCall, sizeof(__pyx_k_methodCall), 0, 0, 1, 1},
  {&__pyx_n_s_min, __pyx_k_min, sizeof(__pyx_k_min), 0, 0, 1, 1},
  {&__pyx_n_s_minElements, __pyx_k_minElements, sizeof(__pyx_k_minElements), 0, 0, 1, 1},
  {&__pyx_n_s_minLen, __pyx_k_minLen, sizeof(__pyx_k_minLen), 0, 0, 1, 1},
  {&__pyx_n_s_mismatches, __pyx_k_mismatches, sizeof(__pyx_k_mismatches), 0, 0, 1, 1},
  {&__pyx_n_u_mismatches, __pyx_k_mismatches, sizeof(__pyx_k_mismatches), 0, 1, 0, 1},
  {&__pyx_n_s_missing, __pyx_k_missing, sizeof(__pyx_k_missing), 0, 0, 1, 1},
  {&__pyx_kp_u_mixed_IPv6_address, __pyx_k_mixed_IPv6_address, sizeof(__pyx_k_mixed_IPv6_address), 0, 1, 0, 0},
  {&__pyx_n_s_mixed_integer, __pyx_k_mixed_integer, sizeof(__pyx_k_mixed_integer), 0, 0, 1, 1},
  {&__pyx_n_s_mixed_ipv6_address, __pyx_k_mixed_ipv6_address, sizeof(__pyx_k_mixed_ipv6_address), 0, 0, 1, 1},
  {&__pyx_n_s_modal, __pyx_k_modal, sizeof(__pyx_k_modal), 0, 0, 1, 1},
  {&__pyx_n_s_modalResults, __pyx_k_modalResults, sizeof(__pyx_k_modalResults), 0, 0, 1, 1},
  {&__pyx_n_s_module, __pyx_k_module, sizeof(__pyx_k_module), 0, 0, 1, 1},
  {&__pyx_n_s_msg, __pyx_k_msg, sizeof(__pyx_k_msg), 0, 0, 1, 1},
  {&__pyx_n_s_mul, __pyx_k_mul, sizeof(__pyx_k_mul), 0, 0, 1, 1},
  {&__pyx_n_s_multiline, __pyx_k_multiline, sizeof(__pyx_k_multiline), 0, 0, 1, 1},
  {&__pyx_n_s_multioptionals, __pyx_k_multioptionals, sizeof(__pyx_k_multioptionals), 0, 0, 1, 1},
  {&__pyx_n_s_multirequired, __pyx_k_multirequired, sizeof(__pyx_k_multirequired), 0, 0, 1, 1},
  {&__pyx_n_s_mustMatchTheseTokens, __pyx_k_mustMatchTheseTokens, sizeof(__pyx_k_mustMatchTheseTokens), 0, 0, 1, 1},
  {&__pyx_n_s_mylen, __pyx_k_mylen, sizeof(__pyx_k_mylen), 0, 0, 1, 1},
  {&__pyx_n_s_n, __pyx_k_n, sizeof(__pyx_k_n), 0, 0, 1, 1},
  {&__pyx_kp_u_n_2, __pyx_k_n_2, sizeof(__pyx_k_n_2), 0, 1, 0, 0},
  {&__pyx_kp_u_n_n, __pyx_k_n_n, sizeof(__pyx_k_n_n), 0, 1, 0, 0},
  {&__pyx_kp_u_n_r_x_x_0_9a_fA_F, __pyx_k_n_r_x_x_0_9a_fA_F, sizeof(__pyx_k_n_r_x_x_0_9a_fA_F), 0, 1, 0, 0},
  {&__pyx_kp_u_n_r_x_x_0_9a_fA_F_2, __pyx_k_n_r_x_x_0_9a_fA_F_2, sizeof(__pyx_k_n_r_x_x_0_9a_fA_F_2), 0, 1, 0, 0},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_u_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 1, 0, 1},
  {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
  {&__pyx_n_u_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 1, 0, 1},
  {&__pyx_n_s_namedItems, __pyx_k_namedItems, sizeof(__pyx_k_namedItems), 0, 0, 1, 1},
  {&__pyx_n_s_namedItemsOnly, __pyx_k_namedItemsOnly, sizeof(__pyx_k_namedItemsOnly), 0, 0, 1, 1},
  {&__pyx_n_s_namespace, __pyx_k_namespace, sizeof(__pyx_k_namespace), 0, 0, 1, 1},
  {&__pyx_n_s_ne, __pyx_k_ne, sizeof(__pyx_k_ne), 0, 0, 1, 1},
  {&__pyx_n_u_negate, __pyx_k_negate, sizeof(__pyx_k_negate), 0, 1, 0, 1},
  {&__pyx_n_s_nestedExpr, __pyx_k_nestedExpr, sizeof(__pyx_k_nestedExpr), 0, 0, 1, 1},
  {&__pyx_n_u_nestedExpr, __pyx_k_nestedExpr, sizeof(__pyx_k_nestedExpr), 0, 1, 0, 1},
  {&__pyx_n_s_nestedExpr_locals_lambda, __pyx_k_nestedExpr_locals_lambda, sizeof(__pyx_k_nestedExpr_locals_lambda), 0, 0, 1, 1},
  {&__pyx_kp_u_nested_s_s_expression, __pyx_k_nested_s_s_expression, sizeof(__pyx_k_nested_s_s_expression), 0, 1, 0, 0},
  {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
  {&__pyx_n_s_newloc, __pyx_k_newloc, sizeof(__pyx_k_newloc), 0, 0, 1, 1},
  {&__pyx_n_s_newself, __pyx_k_newself, sizeof(__pyx_k_newself), 0, 0, 1, 1},
  {&__pyx_n_s_nextCR, __pyx_k_nextCR, sizeof(__pyx_k_nextCR), 0, 0, 1, 1},
  {&__pyx_n_s_nextLevelIndent, __pyx_k_nextLevelIndent, sizeof(__pyx_k_nextLevelIndent), 0, 0, 1, 1},
  {&__pyx_n_s_nextLoc, __pyx_k_nextLoc, sizeof(__pyx_k_nextLoc), 0, 0, 1, 1},
  {&__pyx_n_s_nextloc, __pyx_k_nextloc, sizeof(__pyx_k_nextloc), 0, 0, 1, 1},
  {&__pyx_n_s_nl, __pyx_k_nl, sizeof(__pyx_k_nl), 0, 0, 1, 1},
  {&__pyx_kp_u_no_defined_alternatives_to_match, __pyx_k_no_defined_alternatives_to_match, sizeof(__pyx_k_no_defined_alternatives_to_match), 0, 1, 0, 0},
  {&__pyx_kp_u_no_matching_attribute, __pyx_k_no_matching_attribute, sizeof(__pyx_k_no_matching_attribute), 0, 1, 0, 0},
  {&__pyx_n_s_nonzero, __pyx_k_nonzero, sizeof(__pyx_k_nonzero), 0, 0, 1, 1},
  {&__pyx_n_s_notChars, __pyx_k_notChars, sizeof(__pyx_k_notChars), 0, 0, 1, 1},
  {&__pyx_kp_u_not_a_peer_entry, __pyx_k_not_a_peer_entry, sizeof(__pyx_k_not_a_peer_entry), 0, 1, 0, 0},
  {&__pyx_kp_u_not_a_subentry, __pyx_k_not_a_subentry, sizeof(__pyx_k_not_a_subentry), 0, 1, 0, 0},
  {&__pyx_kp_u_not_an_unindent, __pyx_k_not_an_unindent, sizeof(__pyx_k_not_an_unindent), 0, 1, 0, 0},
  {&__pyx_n_s_not_ender, __pyx_k_not_ender, sizeof(__pyx_k_not_ender), 0, 0, 1, 1},
  {&__pyx_n_s_not_in_cache, __pyx_k_not_in_cache, sizeof(__pyx_k_not_in_cache), 0, 0, 1, 1},
  {&__pyx_n_s_notchars, __pyx_k_notchars, sizeof(__pyx_k_notchars), 0, 0, 1, 1},
  {&__pyx_n_s_nullDebugAction, __pyx_k_nullDebugAction, sizeof(__pyx_k_nullDebugAction), 0, 0, 1, 1},
  {&__pyx_n_u_nullDebugAction, __pyx_k_nullDebugAction, sizeof(__pyx_k_nullDebugAction), 0, 1, 0, 1},
  {&__pyx_kp_u_null_string_passed_to_Keyword_us, __pyx_k_null_string_passed_to_Keyword_us, sizeof(__pyx_k_null_string_passed_to_Keyword_us), 0, 1, 0, 0},
  {&__pyx_kp_u_null_string_passed_to_Literal_us, __pyx_k_null_string_passed_to_Literal_us, sizeof(__pyx_k_null_string_passed_to_Literal_us), 0, 1, 0, 0},
  {&__pyx_kp_u_null_string_passed_to_Regex_use, __pyx_k_null_string_passed_to_Regex_use, sizeof(__pyx_k_null_string_passed_to_Regex_use), 0, 1, 0, 0},
  {&__pyx_n_s_number, __pyx_k_number, sizeof(__pyx_k_number), 0, 0, 1, 1},
  {&__pyx_n_s_nums, __pyx_k_nums, sizeof(__pyx_k_nums), 0, 0, 1, 1},
  {&__pyx_n_u_nums, __pyx_k_nums, sizeof(__pyx_k_nums), 0, 1, 0, 1},
  {&__pyx_n_s_obj, __pyx_k_obj, sizeof(__pyx_k_obj), 0, 0, 1, 1},
  {&__pyx_n_s_object, __pyx_k_object, sizeof(__pyx_k_object), 0, 0, 1, 1},
  {&__pyx_n_s_occurrences, __pyx_k_occurrences, sizeof(__pyx_k_occurrences), 0, 0, 1, 1},
  {&__pyx_n_s_offset, __pyx_k_offset, sizeof(__pyx_k_offset), 0, 0, 1, 1},
  {&__pyx_n_s_oneOf, __pyx_k_oneOf, sizeof(__pyx_k_oneOf), 0, 0, 1, 1},
  {&__pyx_n_u_oneOf, __pyx_k_oneOf, sizeof(__pyx_k_oneOf), 0, 1, 0, 1},
  {&__pyx_n_s_oneOf_locals_genexpr, __pyx_k_oneOf_locals_genexpr, sizeof(__pyx_k_oneOf_locals_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_oneOf_locals_lambda, __pyx_k_oneOf_locals_lambda, sizeof(__pyx_k_oneOf_locals_lambda), 0, 0, 1, 1},
  {&__pyx_n_s_opAssoc, __pyx_k_opAssoc, sizeof(__pyx_k_opAssoc), 0, 0, 1, 1},
  {&__pyx_n_u_opAssoc, __pyx_k_opAssoc, sizeof(__pyx_k_opAssoc), 0, 1, 0, 1},
  {&__pyx_n_s_opExpr, __pyx_k_opExpr, sizeof(__pyx_k_opExpr), 0, 0, 1, 1},
  {&__pyx_n_s_opExpr1, __pyx_k_opExpr1, sizeof(__pyx_k_opExpr1), 0, 0, 1, 1},
  {&__pyx_n_s_opExpr2, __pyx_k_opExpr2, sizeof(__pyx_k_opExpr2), 0, 0, 1, 1},
  {&__pyx_n_s_opList, __pyx_k_opList, sizeof(__pyx_k_opList), 0, 0, 1, 1},
  {&__pyx_n_s_open, __pyx_k_open, sizeof(__pyx_k_open), 0, 0, 1, 1},
  {&__pyx_n_s_openTag, __pyx_k_openTag, sizeof(__pyx_k_openTag), 0, 0, 1, 1},
  {&__pyx_n_s_opener, __pyx_k_opener, sizeof(__pyx_k_opener), 0, 0, 1, 1},
  {&__pyx_kp_u_opening_and_closing_arguments_mu, __pyx_k_opening_and_closing_arguments_mu, sizeof(__pyx_k_opening_and_closing_arguments_mu), 0, 1, 0, 0},
  {&__pyx_kp_u_opening_and_closing_strings_cann, __pyx_k_opening_and_closing_strings_cann, sizeof(__pyx_k_opening_and_closing_strings_cann), 0, 1, 0, 0},
  {&__pyx_n_s_operDef, __pyx_k_operDef, sizeof(__pyx_k_operDef), 0, 0, 1, 1},
  {&__pyx_n_s_operatorPrecedence, __pyx_k_operatorPrecedence, sizeof(__pyx_k_operatorPrecedence), 0, 0, 1, 1},
  {&__pyx_n_u_operatorPrecedence, __pyx_k_operatorPrecedence, sizeof(__pyx_k_operatorPrecedence), 0, 1, 0, 1},
  {&__pyx_kp_u_operator_must_be_unary_1_binary, __pyx_k_operator_must_be_unary_1_binary, sizeof(__pyx_k_operator_must_be_unary_1_binary), 0, 1, 0, 0},
  {&__pyx_kp_u_operator_must_indicate_right_or, __pyx_k_operator_must_indicate_right_or, sizeof(__pyx_k_operator_must_indicate_right_or), 0, 1, 0, 0},
  {&__pyx_n_s_opt1, __pyx_k_opt1, sizeof(__pyx_k_opt1), 0, 0, 1, 1},
  {&__pyx_n_s_opt1map, __pyx_k_opt1map, sizeof(__pyx_k_opt1map), 0, 0, 1, 1},
  {&__pyx_n_s_opt2, __pyx_k_opt2, sizeof(__pyx_k_opt2), 0, 0, 1, 1},
  {&__pyx_n_s_optElements, __pyx_k_optElements, sizeof(__pyx_k_optElements), 0, 0, 1, 1},
  {&__pyx_n_s_optionalNotMatched, __pyx_k_optionalNotMatched, sizeof(__pyx_k_optionalNotMatched), 0, 0, 1, 1},
  {&__pyx_n_s_optionals, __pyx_k_optionals, sizeof(__pyx_k_optionals), 0, 0, 1, 1},
  {&__pyx_n_s_or, __pyx_k_or, sizeof(__pyx_k_or), 0, 0, 1, 1},
  {&__pyx_n_s_ordereddict, __pyx_k_ordereddict, sizeof(__pyx_k_ordereddict), 0, 0, 1, 1},
  {&__pyx_n_u_original, __pyx_k_original, sizeof(__pyx_k_original), 0, 1, 0, 1},
  {&__pyx_n_s_originalParseMethod, __pyx_k_originalParseMethod, sizeof(__pyx_k_originalParseMethod), 0, 0, 1, 1},
  {&__pyx_n_u_originalParseMethod, __pyx_k_originalParseMethod, sizeof(__pyx_k_originalParseMethod), 0, 1, 0, 1},
  {&__pyx_n_s_originalTextFor, __pyx_k_originalTextFor, sizeof(__pyx_k_originalTextFor), 0, 0, 1, 1},
  {&__pyx_n_u_originalTextFor, __pyx_k_originalTextFor, sizeof(__pyx_k_originalTextFor), 0, 1, 0, 1},
  {&__pyx_n_s_originalTextFor_locals_extractTe, __pyx_k_originalTextFor_locals_extractTe, sizeof(__pyx_k_originalTextFor_locals_extractTe), 0, 0, 1, 1},
  {&__pyx_n_s_originalTextFor_locals_lambda, __pyx_k_originalTextFor_locals_lambda, sizeof(__pyx_k_originalTextFor_locals_lambda), 0, 0, 1, 1},
  {&__pyx_n_s_original_end, __pyx_k_original_end, sizeof(__pyx_k_original_end), 0, 0, 1, 1},
  {&__pyx_n_u_original_end, __pyx_k_original_end, sizeof(__pyx_k_original_end), 0, 1, 0, 1},
  {&__pyx_n_s_original_start, __pyx_k_original_start, sizeof(__pyx_k_original_start), 0, 0, 1, 1},
  {&__pyx_n_u_original_start, __pyx_k_original_start, sizeof(__pyx_k_original_start), 0, 1, 0, 1},
  {&__pyx_n_s_os, __pyx_k_os, sizeof(__pyx_k_os), 0, 0, 1, 1},
  {&__pyx_n_s_os_path, __pyx_k_os_path, sizeof(__pyx_k_os_path), 0, 0, 1, 1},
  {&__pyx_n_s_other, __pyx_k_other, sizeof(__pyx_k_other), 0, 0, 1, 1},
  {&__pyx_n_s_otherdictitems, __pyx_k_otherdictitems, sizeof(__pyx_k_otherdictitems), 0, 0, 1, 1},
  {&__pyx_n_s_otheritems, __pyx_k_otheritems, sizeof(__pyx_k_otheritems), 0, 0, 1, 1},
  {&__pyx_n_s_out, __pyx_k_out, sizeof(__pyx_k_out), 0, 0, 1, 1},
  {&__pyx_n_s_overlap, __pyx_k_overlap, sizeof(__pyx_k_overlap), 0, 0, 1, 1},
  {&__pyx_n_s_p, __pyx_k_p, sizeof(__pyx_k_p), 0, 0, 1, 1},
  {&__pyx_n_s_p1, __pyx_k_p1, sizeof(__pyx_k_p1), 0, 0, 1, 1},
  {&__pyx_n_s_p2, __pyx_k_p2, sizeof(__pyx_k_p2), 0, 0, 1, 1},
  {&__pyx_n_s_pa, __pyx_k_pa, sizeof(__pyx_k_pa), 0, 0, 1, 1},
  {&__pyx_n_s_paArgs, __pyx_k_paArgs, sizeof(__pyx_k_paArgs), 0, 0, 1, 1},
  {&__pyx_n_s_packratEnabled, __pyx_k_packratEnabled, sizeof(__pyx_k_packratEnabled), 0, 0, 1, 1},
  {&__pyx_n_s_packrat_cache, __pyx_k_packrat_cache, sizeof(__pyx_k_packrat_cache), 0, 0, 1, 1},
  {&__pyx_n_s_packrat_cache_lock, __pyx_k_packrat_cache_lock, sizeof(__pyx_k_packrat_cache_lock), 0, 0, 1, 1},
  {&__pyx_n_s_packrat_cache_stats, __pyx_k_packrat_cache_stats, sizeof(__pyx_k_packrat_cache_stats), 0, 0, 1, 1},
  {&__pyx_n_s_par, __pyx_k_par, sizeof(__pyx_k_par), 0, 0, 1, 1},
  {&__pyx_n_s_parse, __pyx_k_parse, sizeof(__pyx_k_parse), 0, 0, 1, 1},
  {&__pyx_n_s_parseAction, __pyx_k_parseAction, sizeof(__pyx_k_parseAction), 0, 0, 1, 1},
  {&__pyx_n_s_parseAll, __pyx_k_parseAll, sizeof(__pyx_k_parseAll), 0, 0, 1, 1},
  {&__pyx_n_s_parseCache, __pyx_k_parseCache, sizeof(__pyx_k_parseCache), 0, 0, 1, 1},
  {&__pyx_n_s_parseElementClass, __pyx_k_parseElementClass, sizeof(__pyx_k_parseElementClass), 0, 0, 1, 1},
  {&__pyx_n_s_parseElementList, __pyx_k_parseElementList, sizeof(__pyx_k_parseElementList), 0, 0, 1, 1},
  {&__pyx_n_s_parseElementTrace, __pyx_k_parseElementTrace, sizeof(__pyx_k_parseElementTrace), 0, 0, 1, 1},
  {&__pyx_n_s_parseFile, __pyx_k_parseFile, sizeof(__pyx_k_parseFile), 0, 0, 1, 1},
  {&__pyx_n_s_parseFn, __pyx_k_parseFn, sizeof(__pyx_k_parseFn), 0, 0, 1, 1},
  {&__pyx_n_s_parseImpl, __pyx_k_parseImpl, sizeof(__pyx_k_parseImpl), 0, 0, 1, 1},
  {&__pyx_n_s_parseMethod, __pyx_k_parseMethod, sizeof(__pyx_k_parseMethod), 0, 0, 1, 1},
  {&__pyx_n_s_parseNoCache, __pyx_k_parseNoCache, sizeof(__pyx_k_parseNoCache), 0, 0, 1, 1},
  {&__pyx_n_s_parseString, __pyx_k_parseString, sizeof(__pyx_k_parseString), 0, 0, 1, 1},
  {&__pyx_n_s_parseWithTabs, __pyx_k_parseWithTabs, sizeof(__pyx_k_parseWithTabs), 0, 0, 1, 1},
  {&__pyx_kp_u_parse_action, __pyx_k_parse_action, sizeof(__pyx_k_parse_action), 0, 1, 0, 0},
  {&__pyx_n_s_parserElement, __pyx_k_parserElement, sizeof(__pyx_k_parserElement), 0, 0, 1, 1},
  {&__pyx_n_s_pattern, __pyx_k_pattern, sizeof(__pyx_k_pattern), 0, 0, 1, 1},
  {&__pyx_n_s_pdb, __pyx_k_pdb, sizeof(__pyx_k_pdb), 0, 0, 1, 1},
  {&__pyx_n_s_pe, __pyx_k_pe, sizeof(__pyx_k_pe), 0, 0, 1, 1},
  {&__pyx_n_s_pop, __pyx_k_pop, sizeof(__pyx_k_pop), 0, 0, 1, 1},
  {&__pyx_kp_u_pop_got_an_unexpected_keyword_ar, __pyx_k_pop_got_an_unexpected_keyword_ar, sizeof(__pyx_k_pop_got_an_unexpected_keyword_ar), 0, 1, 0, 0},
  {&__pyx_n_s_popitem, __pyx_k_popitem, sizeof(__pyx_k_popitem), 0, 0, 1, 1},
  {&__pyx_n_s_popleft, __pyx_k_popleft, sizeof(__pyx_k_popleft), 0, 0, 1, 1},
  {&__pyx_n_s_position, __pyx_k_position, sizeof(__pyx_k_position), 0, 0, 1, 1},
  {&__pyx_n_s_postParse, __pyx_k_postParse, sizeof(__pyx_k_postParse), 0, 0, 1, 1},
  {&__pyx_n_s_pprint, __pyx_k_pprint, sizeof(__pyx_k_pprint), 0, 0, 1, 1},
  {&__pyx_n_s_preParse, __pyx_k_preParse, sizeof(__pyx_k_preParse), 0, 0, 1, 1},
  {&__pyx_n_s_preloc, __pyx_k_preloc, sizeof(__pyx_k_preloc), 0, 0, 1, 1},
  {&__pyx_n_s_prepare, __pyx_k_prepare, sizeof(__pyx_k_prepare), 0, 0, 1, 1},
  {&__pyx_n_s_preparseFn, __pyx_k_preparseFn, sizeof(__pyx_k_preparseFn), 0, 0, 1, 1},
  {&__pyx_kp_u_prev, __pyx_k_prev, sizeof(__pyx_k_prev), 0, 1, 0, 0},
  {&__pyx_n_s_print, __pyx_k_print, sizeof(__pyx_k_print), 0, 0, 1, 1},
  {&__pyx_n_s_printResults, __pyx_k_printResults, sizeof(__pyx_k_printResults), 0, 0, 1, 1},
  {&__pyx_n_s_printable, __pyx_k_printable, sizeof(__pyx_k_printable), 0, 0, 1, 1},
  {&__pyx_n_s_printables, __pyx_k_printables, sizeof(__pyx_k_printables), 0, 0, 1, 1},
  {&__pyx_n_u_printables, __pyx_k_printables, sizeof(__pyx_k_printables), 0, 1, 0, 1},
  {&__pyx_n_s_printablesLessRAbrack, __pyx_k_printablesLessRAbrack, sizeof(__pyx_k_printablesLessRAbrack), 0, 0, 1, 1},
  {&__pyx_n_s_pstr, __pyx_k_pstr, sizeof(__pyx_k_pstr), 0, 0, 1, 1},
  {&__pyx_n_s_punc8bit, __pyx_k_punc8bit, sizeof(__pyx_k_punc8bit), 0, 0, 1, 1},
  {&__pyx_n_u_punc8bit, __pyx_k_punc8bit, sizeof(__pyx_k_punc8bit), 0, 1, 0, 1},
  {&__pyx_n_s_py_str, __pyx_k_py_str, sizeof(__pyx_k_py_str), 0, 0, 1, 1},
  {&__pyx_n_s_pyparsing_common, __pyx_k_pyparsing_common, sizeof(__pyx_k_pyparsing_common), 0, 0, 1, 1},
  {&__pyx_n_u_pyparsing_common, __pyx_k_pyparsing_common, sizeof(__pyx_k_pyparsing_common), 0, 1, 0, 1},
  {&__pyx_n_s_pyparsing_common_convertToDate, __pyx_k_pyparsing_common_convertToDate, sizeof(__pyx_k_pyparsing_common_convertToDate), 0, 0, 1, 1},
  {&__pyx_n_s_pyparsing_common_convertToDate_l, __pyx_k_pyparsing_common_convertToDate_l, sizeof(__pyx_k_pyparsing_common_convertToDate_l), 0, 0, 1, 1},
  {&__pyx_n_s_pyparsing_common_convertToDateti, __pyx_k_pyparsing_common_convertToDateti, sizeof(__pyx_k_pyparsing_common_convertToDateti), 0, 0, 1, 1},
  {&__pyx_n_s_pyparsing_common_convertToDateti_2, __pyx_k_pyparsing_common_convertToDateti_2, sizeof(__pyx_k_pyparsing_common_convertToDateti_2), 0, 0, 1, 1},
  {&__pyx_n_s_pyparsing_common_lambda, __pyx_k_pyparsing_common_lambda, sizeof(__pyx_k_pyparsing_common_lambda), 0, 0, 1, 1},
  {&__pyx_n_s_pyparsing_common_lambda_locals_g, __pyx_k_pyparsing_common_lambda_locals_g, sizeof(__pyx_k_pyparsing_common_lambda_locals_g), 0, 0, 1, 1},
  {&__pyx_n_s_pyparsing_common_stripHTMLTags, __pyx_k_pyparsing_common_stripHTMLTags, sizeof(__pyx_k_pyparsing_common_stripHTMLTags), 0, 0, 1, 1},
  {&__pyx_n_s_pythonStyleComment, __pyx_k_pythonStyleComment, sizeof(__pyx_k_pythonStyleComment), 0, 0, 1, 1},
  {&__pyx_n_u_pythonStyleComment, __pyx_k_pythonStyleComment, sizeof(__pyx_k_pythonStyleComment), 0, 1, 0, 1},
  {&__pyx_n_s_qualname, __pyx_k_qualname, sizeof(__pyx_k_qualname), 0, 0, 1, 1},
  {&__pyx_n_s_quoteChar, __pyx_k_quoteChar, sizeof(__pyx_k_quoteChar), 0, 0, 1, 1},
  {&__pyx_n_s_quoteCharLen, __pyx_k_quoteCharLen, sizeof(__pyx_k_quoteCharLen), 0, 0, 1, 1},
  {&__pyx_kp_u_quoteChar_cannot_be_the_empty_st, __pyx_k_quoteChar_cannot_be_the_empty_st, sizeof(__pyx_k_quoteChar_cannot_be_the_empty_st), 0, 1, 0, 0},
  {&__pyx_n_s_quotedString, __pyx_k_quotedString, sizeof(__pyx_k_quotedString), 0, 0, 1, 1},
  {&__pyx_n_u_quotedString, __pyx_k_quotedString, sizeof(__pyx_k_quotedString), 0, 1, 0, 1},
  {&__pyx_kp_u_quotedString_using_single_or_dou, __pyx_k_quotedString_using_single_or_dou, sizeof(__pyx_k_quotedString_using_single_or_dou), 0, 1, 0, 0},
  {&__pyx_kp_u_quoted_string_starting_with_s_en, __pyx_k_quoted_string_starting_with_s_en, sizeof(__pyx_k_quoted_string_starting_with_s_en), 0, 1, 0, 0},
  {&__pyx_n_u_r, __pyx_k_r, sizeof(__pyx_k_r), 0, 1, 0, 1},
  {&__pyx_kp_u_r_2, __pyx_k_r_2, sizeof(__pyx_k_r_2), 0, 1, 0, 0},
  {&__pyx_n_s_radd, __pyx_k_radd, sizeof(__pyx_k_radd), 0, 0, 1, 1},
  {&__pyx_n_s_rand, __pyx_k_rand, sizeof(__pyx_k_rand), 0, 0, 1, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_re, __pyx_k_re, sizeof(__pyx_k_re), 0, 0, 1, 1},
  {&__pyx_n_s_reBracketExpr, __pyx_k_reBracketExpr, sizeof(__pyx_k_reBracketExpr), 0, 0, 1, 1},
  {&__pyx_n_s_reString, __pyx_k_reString, sizeof(__pyx_k_reString), 0, 0, 1, 1},
  {&__pyx_n_s_read, __pyx_k_read, sizeof(__pyx_k_read), 0, 0, 1, 1},
  {&__pyx_n_s_real, __pyx_k_real, sizeof(__pyx_k_real), 0, 0, 1, 1},
  {&__pyx_kp_u_real_number, __pyx_k_real_number, sizeof(__pyx_k_real_number), 0, 1, 0, 0},
  {&__pyx_kp_u_real_number_with_scientific_nota, __pyx_k_real_number_with_scientific_nota, sizeof(__pyx_k_real_number_with_scientific_nota), 0, 1, 0, 0},
  {&__pyx_n_s_ref, __pyx_k_ref, sizeof(__pyx_k_ref), 0, 0, 1, 1},
  {&__pyx_n_s_register, __pyx_k_register, sizeof(__pyx_k_register), 0, 0, 1, 1},
  {&__pyx_n_s_remove, __pyx_k_remove, sizeof(__pyx_k_remove), 0, 0, 1, 1},
  {&__pyx_n_s_removeQuotes, __pyx_k_removeQuotes, sizeof(__pyx_k_removeQuotes), 0, 0, 1, 1},
  {&__pyx_n_u_removeQuotes, __pyx_k_removeQuotes, sizeof(__pyx_k_removeQuotes), 0, 1, 0, 1},
  {&__pyx_n_s_removed, __pyx_k_removed, sizeof(__pyx_k_removed), 0, 0, 1, 1},
  {&__pyx_n_s_rep, __pyx_k_rep, sizeof(__pyx_k_rep), 0, 0, 1, 1},
  {&__pyx_n_s_replStr, __pyx_k_replStr, sizeof(__pyx_k_replStr), 0, 0, 1, 1},
  {&__pyx_n_s_replace, __pyx_k_replace, sizeof(__pyx_k_replace), 0, 0, 1, 1},
  {&__pyx_n_s_replaceHTMLEntity, __pyx_k_replaceHTMLEntity, sizeof(__pyx_k_replaceHTMLEntity), 0, 0, 1, 1},
  {&__pyx_n_u_replaceHTMLEntity, __pyx_k_replaceHTMLEntity, sizeof(__pyx_k_replaceHTMLEntity), 0, 1, 0, 1},
  {&__pyx_n_s_replaceWith, __pyx_k_replaceWith, sizeof(__pyx_k_replaceWith), 0, 0, 1, 1},
  {&__pyx_n_u_replaceWith, __pyx_k_replaceWith, sizeof(__pyx_k_replaceWith), 0, 1, 0, 1},
  {&__pyx_n_s_replaceWith_locals_lambda, __pyx_k_replaceWith_locals_lambda, sizeof(__pyx_k_replaceWith_locals_lambda), 0, 0, 1, 1},
  {&__pyx_n_s_repr, __pyx_k_repr, sizeof(__pyx_k_repr), 0, 0, 1, 1},
  {&__pyx_n_s_repr_2, __pyx_k_repr_2, sizeof(__pyx_k_repr_2), 0, 0, 1, 1},
  {&__pyx_n_s_repr_3, __pyx_k_repr_3, sizeof(__pyx_k_repr_3), 0, 0, 1, 1},
  {&__pyx_n_s_req, __pyx_k_req, sizeof(__pyx_k_req), 0, 0, 1, 1},
  {&__pyx_n_s_required, __pyx_k_required, sizeof(__pyx_k_required), 0, 0, 1, 1},
  {&__pyx_n_s_res, __pyx_k_res, sizeof(__pyx_k_res), 0, 0, 1, 1},
  {&__pyx_n_s_resTag, __pyx_k_resTag, sizeof(__pyx_k_resTag), 0, 0, 1, 1},
  {&__pyx_n_s_reset, __pyx_k_reset, sizeof(__pyx_k_reset), 0, 0, 1, 1},
  {&__pyx_n_s_resetCache, __pyx_k_resetCache, sizeof(__pyx_k_resetCache), 0, 0, 1, 1},
  {&__pyx_n_s_resname, __pyx_k_resname, sizeof(__pyx_k_resname), 0, 0, 1, 1},
  {&__pyx_n_s_restOfLine, __pyx_k_restOfLine, sizeof(__pyx_k_restOfLine), 0, 0, 1, 1},
  {&__pyx_n_u_restOfLine, __pyx_k_restOfLine, sizeof(__pyx_k_restOfLine), 0, 1, 0, 1},
  {&__pyx_kp_u_rest_of_line, __pyx_k_rest_of_line, sizeof(__pyx_k_rest_of_line), 0, 1, 0, 0},
  {&__pyx_n_s_result, __pyx_k_result, sizeof(__pyx_k_result), 0, 0, 1, 1},
  {&__pyx_n_s_resultlist, __pyx_k_resultlist, sizeof(__pyx_k_resultlist), 0, 0, 1, 1},
  {&__pyx_n_s_results, __pyx_k_results, sizeof(__pyx_k_results), 0, 0, 1, 1},
  {&__pyx_n_s_resultsName, __pyx_k_resultsName, sizeof(__pyx_k_resultsName), 0, 0, 1, 1},
  {&__pyx_n_s_ret, __pyx_k_ret, sizeof(__pyx_k_ret), 0, 0, 1, 1},
  {&__pyx_n_s_retTokens, __pyx_k_retTokens, sizeof(__pyx_k_retTokens), 0, 0, 1, 1},
  {&__pyx_n_s_retToks, __pyx_k_retToks, sizeof(__pyx_k_retToks), 0, 0, 1, 1},
  {&__pyx_n_s_retobj, __pyx_k_retobj, sizeof(__pyx_k_retobj), 0, 0, 1, 1},
  {&__pyx_n_s_returnString, __pyx_k_returnString, sizeof(__pyx_k_returnString), 0, 0, 1, 1},
  {&__pyx_n_s_reversed, __pyx_k_reversed, sizeof(__pyx_k_reversed), 0, 0, 1, 1},
  {&__pyx_n_s_reversed_2, __pyx_k_reversed_2, sizeof(__pyx_k_reversed_2), 0, 0, 1, 1},
  {&__pyx_n_s_rfind, __pyx_k_rfind, sizeof(__pyx_k_rfind), 0, 0, 1, 1},
  {&__pyx_n_s_rightLeftAssoc, __pyx_k_rightLeftAssoc, sizeof(__pyx_k_rightLeftAssoc), 0, 0, 1, 1},
  {&__pyx_n_s_rmul, __pyx_k_rmul, sizeof(__pyx_k_rmul), 0, 0, 1, 1},
  {&__pyx_n_s_rne, __pyx_k_rne, sizeof(__pyx_k_rne), 0, 0, 1, 1},
  {&__pyx_n_s_ror, __pyx_k_ror, sizeof(__pyx_k_ror), 0, 0, 1, 1},
  {&__pyx_n_s_rpar, __pyx_k_rpar, sizeof(__pyx_k_rpar), 0, 0, 1, 1},
  {&__pyx_n_s_rstrip, __pyx_k_rstrip, sizeof(__pyx_k_rstrip), 0, 0, 1, 1},
  {&__pyx_n_s_rsub, __pyx_k_rsub, sizeof(__pyx_k_rsub), 0, 0, 1, 1},
  {&__pyx_n_s_runTests, __pyx_k_runTests, sizeof(__pyx_k_runTests), 0, 0, 1, 1},
  {&__pyx_n_s_rxor, __pyx_k_rxor, sizeof(__pyx_k_rxor), 0, 0, 1, 1},
  {&__pyx_n_s_s, __pyx_k_s, sizeof(__pyx_k_s), 0, 0, 1, 1},
  {&__pyx_kp_u_s_10, __pyx_k_s_10, sizeof(__pyx_k_s_10), 0, 1, 0, 0},
  {&__pyx_kp_u_s_2, __pyx_k_s_2, sizeof(__pyx_k_s_2), 0, 1, 0, 0},
  {&__pyx_kp_u_s_3, __pyx_k_s_3, sizeof(__pyx_k_s_3), 0, 1, 0, 0},
  {&__pyx_kp_u_s_4, __pyx_k_s_4, sizeof(__pyx_k_s_4), 0, 1, 0, 0},
  {&__pyx_kp_u_s_5, __pyx_k_s_5, sizeof(__pyx_k_s_5), 0, 1, 0, 0},
  {&__pyx_kp_u_s_6, __pyx_k_s_6, sizeof(__pyx_k_s_6), 0, 1, 0, 0},
  {&__pyx_kp_u_s_7, __pyx_k_s_7, sizeof(__pyx_k_s_7), 0, 1, 0, 0},
  {&__pyx_kp_u_s_8, __pyx_k_s_8, sizeof(__pyx_k_s_8), 0, 1, 0, 0},
  {&__pyx_kp_u_s_9, __pyx_k_s_9, sizeof(__pyx_k_s_9), 0, 1, 0, 0},
  {&__pyx_kp_u_s_S, __pyx_k_s_S, sizeof(__pyx_k_s_S), 0, 1, 0, 0},
  {&__pyx_kp_u_s_at_char_d_line_d_col_d, __pyx_k_s_at_char_d_line_d_col_d, sizeof(__pyx_k_s_at_char_d_line_d_col_d), 0, 1, 0, 0},
  {&__pyx_kp_u_s_class, __pyx_k_s_class, sizeof(__pyx_k_s_class), 0, 1, 0, 0},
  {&__pyx_n_s_s_m, __pyx_k_s_m, sizeof(__pyx_k_s_m), 0, 0, 1, 1},
  {&__pyx_kp_u_s_s, __pyx_k_s_s, sizeof(__pyx_k_s_s), 0, 1, 0, 0},
  {&__pyx_kp_u_s_s_2, __pyx_k_s_s_2, sizeof(__pyx_k_s_s_2), 0, 1, 0, 0},
  {&__pyx_kp_u_s_s_3, __pyx_k_s_s_3, sizeof(__pyx_k_s_s_3), 0, 1, 0, 0},
  {&__pyx_kp_u_s_s_4, __pyx_k_s_s_4, sizeof(__pyx_k_s_s_4), 0, 1, 0, 0},
  {&__pyx_kp_u_s_s_5, __pyx_k_s_s_5, sizeof(__pyx_k_s_s_5), 0, 1, 0, 0},
  {&__pyx_kp_u_s_s_d_s_s_s, __pyx_k_s_s_d_s_s_s, sizeof(__pyx_k_s_s_d_s_s_s), 0, 1, 0, 0},
  {&__pyx_kp_u_s_s_n_r_s, __pyx_k_s_s_n_r_s, sizeof(__pyx_k_s_s_n_r_s), 0, 1, 0, 0},
  {&__pyx_kp_u_s_s_s, __pyx_k_s_s_s, sizeof(__pyx_k_s_s_s), 0, 1, 0, 0},
  {&__pyx_kp_u_s_s_s_2, __pyx_k_s_s_s_2, sizeof(__pyx_k_s_s_s_2), 0, 1, 0, 0},
  {&__pyx_kp_u_s_s_term, __pyx_k_s_s_term, sizeof(__pyx_k_s_s_term), 0, 1, 0, 0},
  {&__pyx_kp_u_s_term, __pyx_k_s_term, sizeof(__pyx_k_s_term), 0, 1, 0, 0},
  {&__pyx_n_s_saveAsList, __pyx_k_saveAsList, sizeof(__pyx_k_saveAsList), 0, 0, 1, 1},
  {&__pyx_n_s_savelist, __pyx_k_savelist, sizeof(__pyx_k_savelist), 0, 0, 1, 1},
  {&__pyx_n_s_scanString, __pyx_k_scanString, sizeof(__pyx_k_scanString), 0, 0, 1, 1},
  {&__pyx_n_s_sci_real, __pyx_k_sci_real, sizeof(__pyx_k_sci_real), 0, 0, 1, 1},
  {&__pyx_n_s_se, __pyx_k_se, sizeof(__pyx_k_se), 0, 0, 1, 1},
  {&__pyx_n_s_searchString, __pyx_k_searchString, sizeof(__pyx_k_searchString), 0, 0, 1, 1},
  {&__pyx_kp_u_second_tuple_value_must_be_great, __pyx_k_second_tuple_value_must_be_great, sizeof(__pyx_k_second_tuple_value_must_be_great), 0, 1, 0, 0},
  {&__pyx_n_u_select, __pyx_k_select, sizeof(__pyx_k_select), 0, 1, 0, 1},
  {&__pyx_n_s_selectToken, __pyx_k_selectToken, sizeof(__pyx_k_selectToken), 0, 0, 1, 1},
  {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
  {&__pyx_n_s_selfTag, __pyx_k_selfTag, sizeof(__pyx_k_selfTag), 0, 0, 1, 1},
  {&__pyx_n_s_self_expr_parse, __pyx_k_self_expr_parse, sizeof(__pyx_k_self_expr_parse), 0, 0, 1, 1},
  {&__pyx_n_s_self_failOn_canParseNext, __pyx_k_self_failOn_canParseNext, sizeof(__pyx_k_self_failOn_canParseNext), 0, 0, 1, 1},
  {&__pyx_n_s_self_ignoreExpr_tryParse, __pyx_k_self_ignoreExpr_tryParse, sizeof(__pyx_k_self_ignoreExpr_tryParse), 0, 0, 1, 1},
  {&__pyx_n_s_self_skip_ignorables, __pyx_k_self_skip_ignorables, sizeof(__pyx_k_self_skip_ignorables), 0, 0, 1, 1},
  {&__pyx_n_s_send, __pyx_k_send, sizeof(__pyx_k_send), 0, 0, 1, 1},
  {&__pyx_n_s_sep, __pyx_k_sep, sizeof(__pyx_k_sep), 0, 0, 1, 1},
  {&__pyx_n_s_set, __pyx_k_set, sizeof(__pyx_k_set), 0, 0, 1, 1},
  {&__pyx_n_s_setBreak, __pyx_k_setBreak, sizeof(__pyx_k_setBreak), 0, 0, 1, 1},
  {&__pyx_n_s_setDebug, __pyx_k_setDebug, sizeof(__pyx_k_setDebug), 0, 0, 1, 1},
  {&__pyx_n_s_setDebugActions, __pyx_k_setDebugActions, sizeof(__pyx_k_setDebugActions), 0, 0, 1, 1},
  {&__pyx_n_s_setDefaultKeywordChars, __pyx_k_setDefaultKeywordChars, sizeof(__pyx_k_setDefaultKeywordChars), 0, 0, 1, 1},
  {&__pyx_n_s_setDefaultWhitespaceChars, __pyx_k_setDefaultWhitespaceChars, sizeof(__pyx_k_setDefaultWhitespaceChars), 0, 0, 1, 1},
  {&__pyx_n_s_setFailAction, __pyx_k_setFailAction, sizeof(__pyx_k_setFailAction), 0, 0, 1, 1},
  {&__pyx_n_s_setName, __pyx_k_setName, sizeof(__pyx_k_setName), 0, 0, 1, 1},
  {&__pyx_n_s_setOffset, __pyx_k_setOffset, sizeof(__pyx_k_setOffset), 0, 0, 1, 1},
  {&__pyx_n_s_setParseAction, __pyx_k_setParseAction, sizeof(__pyx_k_setParseAction), 0, 0, 1, 1},
  {&__pyx_n_s_setResultsName, __pyx_k_setResultsName, sizeof(__pyx_k_setResultsName), 0, 0, 1, 1},
  {&__pyx_n_s_setWhitespaceChars, __pyx_k_setWhitespaceChars, sizeof(__pyx_k_setWhitespaceChars), 0, 0, 1, 1},
  {&__pyx_n_s_set_trace, __pyx_k_set_trace, sizeof(__pyx_k_set_trace), 0, 0, 1, 1},
  {&__pyx_n_s_setitem, __pyx_k_setitem, sizeof(__pyx_k_setitem), 0, 0, 1, 1},
  {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
  {&__pyx_n_s_sglQuotedString, __pyx_k_sglQuotedString, sizeof(__pyx_k_sglQuotedString), 0, 0, 1, 1},
  {&__pyx_n_u_sglQuotedString, __pyx_k_sglQuotedString, sizeof(__pyx_k_sglQuotedString), 0, 1, 0, 1},
  {&__pyx_kp_u_short_IPv6_address, __pyx_k_short_IPv6_address, sizeof(__pyx_k_short_IPv6_address), 0, 1, 0, 0},
  {&__pyx_n_s_short_ipv6_address, __pyx_k_short_ipv6_address, sizeof(__pyx_k_short_ipv6_address), 0, 0, 1, 1},
  {&__pyx_kp_u_signed_integer, __pyx_k_signed_integer, sizeof(__pyx_k_signed_integer), 0, 1, 0, 0},
  {&__pyx_n_s_signed_integer_2, __pyx_k_signed_integer_2, sizeof(__pyx_k_signed_integer_2), 0, 0, 1, 1},
  {&__pyx_n_s_simpleSQL, __pyx_k_simpleSQL, sizeof(__pyx_k_simpleSQL), 0, 0, 1, 1},
  {&__pyx_n_s_singleArgBuiltins, __pyx_k_singleArgBuiltins, sizeof(__pyx_k_singleArgBuiltins), 0, 0, 1, 1},
  {&__pyx_n_s_singleChar, __pyx_k_singleChar, sizeof(__pyx_k_singleChar), 0, 0, 1, 1},
  {&__pyx_n_s_size, __pyx_k_size, sizeof(__pyx_k_size), 0, 0, 1, 1},
  {&__pyx_n_s_skipIgnorables, __pyx_k_skipIgnorables, sizeof(__pyx_k_skipIgnorables), 0, 0, 1, 1},
  {&__pyx_n_s_skipWhitespace, __pyx_k_skipWhitespace, sizeof(__pyx_k_skipWhitespace), 0, 0, 1, 1},
  {&__pyx_n_s_skipresult, __pyx_k_skipresult, sizeof(__pyx_k_skipresult), 0, 0, 1, 1},
  {&__pyx_n_s_skiptext, __pyx_k_skiptext, sizeof(__pyx_k_skiptext), 0, 0, 1, 1},
  {&__pyx_n_s_smExpr, __pyx_k_smExpr, sizeof(__pyx_k_smExpr), 0, 0, 1, 1},
  {&__pyx_n_s_sort, __pyx_k_sort, sizeof(__pyx_k_sort), 0, 0, 1, 1},
  {&__pyx_n_s_sorted, __pyx_k_sorted, sizeof(__pyx_k_sorted), 0, 0, 1, 1},
  {&__pyx_n_s_split, __pyx_k_split, sizeof(__pyx_k_split), 0, 0, 1, 1},
  {&__pyx_n_s_splitlines, __pyx_k_splitlines, sizeof(__pyx_k_splitlines), 0, 0, 1, 1},
  {&__pyx_n_s_splits, __pyx_k_splits, sizeof(__pyx_k_splits), 0, 0, 1, 1},
  {&__pyx_n_s_srange, __pyx_k_srange, sizeof(__pyx_k_srange), 0, 0, 1, 1},
  {&__pyx_n_u_srange, __pyx_k_srange, sizeof(__pyx_k_srange), 0, 1, 0, 1},
  {&__pyx_n_s_srange_locals__expanded, __pyx_k_srange_locals__expanded, sizeof(__pyx_k_srange_locals__expanded), 0, 0, 1, 1},
  {&__pyx_n_s_srange_locals__expanded_locals_g, __pyx_k_srange_locals__expanded_locals_g, sizeof(__pyx_k_srange_locals__expanded_locals_g), 0, 0, 1, 1},
  {&__pyx_n_s_srange_locals_genexpr, __pyx_k_srange_locals_genexpr, sizeof(__pyx_k_srange_locals_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_src, __pyx_k_src, sizeof(__pyx_k_src), 0, 0, 1, 1},
  {&__pyx_n_s_sre_constants, __pyx_k_sre_constants, sizeof(__pyx_k_sre_constants), 0, 0, 1, 1},
  {&__pyx_n_s_stacklevel, __pyx_k_stacklevel, sizeof(__pyx_k_stacklevel), 0, 0, 1, 1},
  {&__pyx_n_s_start, __pyx_k_start, sizeof(__pyx_k_start), 0, 0, 1, 1},
  {&__pyx_n_u_start, __pyx_k_start, sizeof(__pyx_k_start), 0, 1, 0, 1},
  {&__pyx_n_s_startAction, __pyx_k_startAction, sizeof(__pyx_k_startAction), 0, 0, 1, 1},
  {&__pyx_n_s_startloc, __pyx_k_startloc, sizeof(__pyx_k_startloc), 0, 0, 1, 1},
  {&__pyx_n_s_startswith, __pyx_k_startswith, sizeof(__pyx_k_startswith), 0, 0, 1, 1},
  {&__pyx_n_s_state, __pyx_k_state, sizeof(__pyx_k_state), 0, 0, 1, 1},
  {&__pyx_n_s_staticmethod, __pyx_k_staticmethod, sizeof(__pyx_k_staticmethod), 0, 0, 1, 1},
  {&__pyx_n_s_stderr, __pyx_k_stderr, sizeof(__pyx_k_stderr), 0, 0, 1, 1},
  {&__pyx_n_s_stopOn, __pyx_k_stopOn, sizeof(__pyx_k_stopOn), 0, 0, 1, 1},
  {&__pyx_n_s_str, __pyx_k_str, sizeof(__pyx_k_str), 0, 0, 1, 1},
  {&__pyx_n_s_strRepr, __pyx_k_strRepr, sizeof(__pyx_k_strRepr), 0, 0, 1, 1},
  {&__pyx_n_s_str_2, __pyx_k_str_2, sizeof(__pyx_k_str_2), 0, 0, 1, 1},
  {&__pyx_n_s_streamline, __pyx_k_streamline, sizeof(__pyx_k_streamline), 0, 0, 1, 1},
  {&__pyx_n_s_streamlined, __pyx_k_streamlined, sizeof(__pyx_k_streamlined), 0, 0, 1, 1},
  {&__pyx_n_s_strg, __pyx_k_strg, sizeof(__pyx_k_strg), 0, 0, 1, 1},
  {&__pyx_n_s_string, __pyx_k_string, sizeof(__pyx_k_string), 0, 0, 1, 1},
  {&__pyx_n_s_stringEnd, __pyx_k_stringEnd, sizeof(__pyx_k_stringEnd), 0, 0, 1, 1},
  {&__pyx_n_u_stringEnd, __pyx_k_stringEnd, sizeof(__pyx_k_stringEnd), 0, 1, 0, 1},
  {&__pyx_n_s_stringStart, __pyx_k_stringStart, sizeof(__pyx_k_stringStart), 0, 0, 1, 1},
  {&__pyx_n_u_stringStart, __pyx_k_stringStart, sizeof(__pyx_k_stringStart), 0, 1, 0, 1},
  {&__pyx_kp_u_string_enclosed_in_double_quotes, __pyx_k_string_enclosed_in_double_quotes, sizeof(__pyx_k_string_enclosed_in_double_quotes), 0, 1, 0, 0},
  {&__pyx_kp_u_string_enclosed_in_single_quotes, __pyx_k_string_enclosed_in_single_quotes, sizeof(__pyx_k_string_enclosed_in_single_quotes), 0, 1, 0, 0},
  {&__pyx_n_s_strip, __pyx_k_strip, sizeof(__pyx_k_strip), 0, 0, 1, 1},
  {&__pyx_n_s_stripHTMLTags, __pyx_k_stripHTMLTags, sizeof(__pyx_k_stripHTMLTags), 0, 0, 1, 1},
  {&__pyx_n_s_strptime, __pyx_k_strptime, sizeof(__pyx_k_strptime), 0, 0, 1, 1},
  {&__pyx_n_s_strs, __pyx_k_strs, sizeof(__pyx_k_strs), 0, 0, 1, 1},
  {&__pyx_n_s_sub, __pyx_k_sub, sizeof(__pyx_k_sub), 0, 0, 1, 1},
  {&__pyx_n_s_subRecCheckList, __pyx_k_subRecCheckList, sizeof(__pyx_k_subRecCheckList), 0, 0, 1, 1},
  {&__pyx_n_s_sub_2, __pyx_k_sub_2, sizeof(__pyx_k_sub_2), 0, 0, 1, 1},
  {&__pyx_n_s_success, __pyx_k_success, sizeof(__pyx_k_success), 0, 0, 1, 1},
  {&__pyx_n_s_successAction, __pyx_k_successAction, sizeof(__pyx_k_successAction), 0, 0, 1, 1},
  {&__pyx_n_s_sum, __pyx_k_sum, sizeof(__pyx_k_sum), 0, 0, 1, 1},
  {&__pyx_kp_u_sum_len_sorted_reversed_list_tup, __pyx_k_sum_len_sorted_reversed_list_tup, sizeof(__pyx_k_sum_len_sorted_reversed_list_tup), 0, 1, 0, 0},
  {&__pyx_n_s_super, __pyx_k_super, sizeof(__pyx_k_super), 0, 0, 1, 1},
  {&__pyx_n_s_suppress, __pyx_k_suppress, sizeof(__pyx_k_suppress), 0, 0, 1, 1},
  {&__pyx_n_s_symbols, __pyx_k_symbols, sizeof(__pyx_k_symbols), 0, 0, 1, 1},
  {&__pyx_n_s_sys, __pyx_k_sys, sizeof(__pyx_k_sys), 0, 0, 1, 1},
  {&__pyx_n_s_system_version, __pyx_k_system_version, sizeof(__pyx_k_system_version), 0, 0, 1, 1},
  {&__pyx_n_s_t, __pyx_k_t, sizeof(__pyx_k_t), 0, 0, 1, 1},
  {&__pyx_kp_u_t_2, __pyx_k_t_2, sizeof(__pyx_k_t_2), 0, 1, 0, 0},
  {&__pyx_n_s_tableName, __pyx_k_tableName, sizeof(__pyx_k_tableName), 0, 0, 1, 1},
  {&__pyx_n_s_tableNameList, __pyx_k_tableNameList, sizeof(__pyx_k_tableNameList), 0, 0, 1, 1},
  {&__pyx_n_u_tables, __pyx_k_tables, sizeof(__pyx_k_tables), 0, 1, 0, 1},
  {&__pyx_n_s_tag, __pyx_k_tag, sizeof(__pyx_k_tag), 0, 0, 1, 1},
  {&__pyx_n_u_tag, __pyx_k_tag, sizeof(__pyx_k_tag), 0, 1, 0, 1},
  {&__pyx_n_s_tagAttrName, __pyx_k_tagAttrName, sizeof(__pyx_k_tagAttrName), 0, 0, 1, 1},
  {&__pyx_n_s_tagAttrValue, __pyx_k_tagAttrValue, sizeof(__pyx_k_tagAttrValue), 0, 0, 1, 1},
  {&__pyx_n_s_tagStr, __pyx_k_tagStr, sizeof(__pyx_k_tagStr), 0, 0, 1, 1},
  {&__pyx_n_s_tb, __pyx_k_tb, sizeof(__pyx_k_tb), 0, 0, 1, 1},
  {&__pyx_n_s_tb_info, __pyx_k_tb_info, sizeof(__pyx_k_tb_info), 0, 0, 1, 1},
  {&__pyx_n_s_tb_info_synth, __pyx_k_tb_info_synth, sizeof(__pyx_k_tb_info_synth), 0, 0, 1, 1},
  {&__pyx_n_s_termName, __pyx_k_termName, sizeof(__pyx_k_termName), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_testString, __pyx_k_testString, sizeof(__pyx_k_testString), 0, 0, 1, 1},
  {&__pyx_n_s_tests, __pyx_k_tests, sizeof(__pyx_k_tests), 0, 0, 1, 1},
  {&__pyx_n_s_tflat, __pyx_k_tflat, sizeof(__pyx_k_tflat), 0, 0, 1, 1},
  {&__pyx_n_s_theseTokens, __pyx_k_theseTokens, sizeof(__pyx_k_theseTokens), 0, 0, 1, 1},
  {&__pyx_n_s_thisExpr, __pyx_k_thisExpr, sizeof(__pyx_k_thisExpr), 0, 0, 1, 1},
  {&__pyx_n_s_thisFunc, __pyx_k_thisFunc, sizeof(__pyx_k_thisFunc), 0, 0, 1, 1},
  {&__pyx_n_s_thiscol, __pyx_k_thiscol, sizeof(__pyx_k_thiscol), 0, 0, 1, 1},
  {&__pyx_n_s_thread, __pyx_k_thread, sizeof(__pyx_k_thread), 0, 0, 1, 1},
  {&__pyx_n_s_threading, __pyx_k_threading, sizeof(__pyx_k_threading), 0, 0, 1, 1},
  {&__pyx_n_s_throw, __pyx_k_throw, sizeof(__pyx_k_throw), 0, 0, 1, 1},
  {&__pyx_n_s_throwException, __pyx_k_throwException, sizeof(__pyx_k_throwException), 0, 0, 1, 1},
  {&__pyx_n_s_title, __pyx_k_title, sizeof(__pyx_k_title), 0, 0, 1, 1},
  {&__pyx_n_s_tmp, __pyx_k_tmp, sizeof(__pyx_k_tmp), 0, 0, 1, 1},
  {&__pyx_n_s_tmpExprs, __pyx_k_tmpExprs, sizeof(__pyx_k_tmpExprs), 0, 0, 1, 1},
  {&__pyx_n_s_tmpLoc, __pyx_k_tmpLoc, sizeof(__pyx_k_tmpLoc), 0, 0, 1, 1},
  {&__pyx_n_s_tmpOpt, __pyx_k_tmpOpt, sizeof(__pyx_k_tmpOpt), 0, 0, 1, 1},
  {&__pyx_n_s_tmpReqd, __pyx_k_tmpReqd, sizeof(__pyx_k_tmpReqd), 0, 0, 1, 1},
  {&__pyx_n_s_tmploc, __pyx_k_tmploc, sizeof(__pyx_k_tmploc), 0, 0, 1, 1},
  {&__pyx_n_s_tmptokens, __pyx_k_tmptokens, sizeof(__pyx_k_tmptokens), 0, 0, 1, 1},
  {&__pyx_n_s_to, __pyx_k_to, sizeof(__pyx_k_to), 0, 0, 1, 1},
  {&__pyx_n_s_toItem, __pyx_k_toItem, sizeof(__pyx_k_toItem), 0, 0, 1, 1},
  {&__pyx_n_s_to_symbols, __pyx_k_to_symbols, sizeof(__pyx_k_to_symbols), 0, 0, 1, 1},
  {&__pyx_n_s_tok, __pyx_k_tok, sizeof(__pyx_k_tok), 0, 0, 1, 1},
  {&__pyx_n_s_tokenMap, __pyx_k_tokenMap, sizeof(__pyx_k_tokenMap), 0, 0, 1, 1},
  {&__pyx_n_u_tokenMap, __pyx_k_tokenMap, sizeof(__pyx_k_tokenMap), 0, 1, 0, 1},
  {&__pyx_n_s_tokenMap_locals_pa, __pyx_k_tokenMap_locals_pa, sizeof(__pyx_k_tokenMap_locals_pa), 0, 0, 1, 1},
  {&__pyx_n_s_tokenlist, __pyx_k_tokenlist, sizeof(__pyx_k_tokenlist), 0, 0, 1, 1},
  {&__pyx_n_s_tokens, __pyx_k_tokens, sizeof(__pyx_k_tokens), 0, 0, 1, 1},
  {&__pyx_n_s_tokensStart, __pyx_k_tokensStart, sizeof(__pyx_k_tokensStart), 0, 0, 1, 1},
  {&__pyx_n_s_toklist, __pyx_k_toklist, sizeof(__pyx_k_toklist), 0, 0, 1, 1},
  {&__pyx_n_s_toks, __pyx_k_toks, sizeof(__pyx_k_toks), 0, 0, 1, 1},
  {&__pyx_n_s_traceParseAction, __pyx_k_traceParseAction, sizeof(__pyx_k_traceParseAction), 0, 0, 1, 1},
  {&__pyx_n_u_traceParseAction, __pyx_k_traceParseAction, sizeof(__pyx_k_traceParseAction), 0, 1, 0, 1},
  {&__pyx_n_s_traceParseAction_locals_z, __pyx_k_traceParseAction_locals_z, sizeof(__pyx_k_traceParseAction_locals_z), 0, 0, 1, 1},
  {&__pyx_n_s_traceback, __pyx_k_traceback, sizeof(__pyx_k_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_traceback_2, __pyx_k_traceback_2, sizeof(__pyx_k_traceback_2), 0, 0, 1, 1},
  {&__pyx_n_s_transformString, __pyx_k_transformString, sizeof(__pyx_k_transformString), 0, 0, 1, 1},
  {&__pyx_n_s_trim_arity, __pyx_k_trim_arity, sizeof(__pyx_k_trim_arity), 0, 0, 1, 1},
  {&__pyx_n_s_trim_arity_locals_extract_tb, __pyx_k_trim_arity_locals_extract_tb, sizeof(__pyx_k_trim_arity_locals_extract_tb), 0, 0, 1, 1},
  {&__pyx_n_s_trim_arity_locals_lambda, __pyx_k_trim_arity_locals_lambda, sizeof(__pyx_k_trim_arity_locals_lambda), 0, 0, 1, 1},
  {&__pyx_n_s_trim_arity_locals_wrapper, __pyx_k_trim_arity_locals_wrapper, sizeof(__pyx_k_trim_arity_locals_wrapper), 0, 0, 1, 1},
  {&__pyx_n_s_tryParse, __pyx_k_tryParse, sizeof(__pyx_k_tryParse), 0, 0, 1, 1},
  {&__pyx_n_s_try_not_ender, __pyx_k_try_not_ender, sizeof(__pyx_k_try_not_ender), 0, 0, 1, 1},
  {&__pyx_n_s_tup, __pyx_k_tup, sizeof(__pyx_k_tup), 0, 0, 1, 1},
  {&__pyx_n_s_types, __pyx_k_types, sizeof(__pyx_k_types), 0, 0, 1, 1},
  {&__pyx_n_u_u, __pyx_k_u, sizeof(__pyx_k_u), 0, 1, 0, 1},
  {&__pyx_n_s_ungroup, __pyx_k_ungroup, sizeof(__pyx_k_ungroup), 0, 0, 1, 1},
  {&__pyx_n_u_ungroup, __pyx_k_ungroup, sizeof(__pyx_k_ungroup), 0, 1, 0, 1},
  {&__pyx_n_s_ungroup_locals_lambda, __pyx_k_ungroup_locals_lambda, sizeof(__pyx_k_ungroup_locals_lambda), 0, 0, 1, 1},
  {&__pyx_n_s_unichr, __pyx_k_unichr, sizeof(__pyx_k_unichr), 0, 0, 1, 1},
  {&__pyx_n_s_unicodeString, __pyx_k_unicodeString, sizeof(__pyx_k_unicodeString), 0, 0, 1, 1},
  {&__pyx_n_u_unicodeString, __pyx_k_unicodeString, sizeof(__pyx_k_unicodeString), 0, 1, 0, 1},
  {&__pyx_kp_u_unicode_string_literal, __pyx_k_unicode_string_literal, sizeof(__pyx_k_unicode_string_literal), 0, 1, 0, 0},
  {&__pyx_n_s_unquoteResults, __pyx_k_unquoteResults, sizeof(__pyx_k_unquoteResults), 0, 0, 1, 1},
  {&__pyx_n_s_upcaseTokens, __pyx_k_upcaseTokens, sizeof(__pyx_k_upcaseTokens), 0, 0, 1, 1},
  {&__pyx_n_u_upcaseTokens, __pyx_k_upcaseTokens, sizeof(__pyx_k_upcaseTokens), 0, 1, 0, 1},
  {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
  {&__pyx_n_s_upper, __pyx_k_upper, sizeof(__pyx_k_upper), 0, 0, 1, 1},
  {&__pyx_n_s_useRegex, __pyx_k_useRegex, sizeof(__pyx_k_useRegex), 0, 0, 1, 1},
  {&__pyx_kp_s_user_throwable_exception_thrown, __pyx_k_user_throwable_exception_thrown, sizeof(__pyx_k_user_throwable_exception_thrown), 0, 0, 1, 0},
  {&__pyx_n_s_ustr, __pyx_k_ustr, sizeof(__pyx_k_ustr), 0, 0, 1, 1},
  {&__pyx_n_u_utf8, __pyx_k_utf8, sizeof(__pyx_k_utf8), 0, 1, 0, 1},
  {&__pyx_n_s_uuid, __pyx_k_uuid, sizeof(__pyx_k_uuid), 0, 0, 1, 1},
  {&__pyx_n_s_v, __pyx_k_v, sizeof(__pyx_k_v), 0, 0, 1, 1},
  {&__pyx_n_s_validate, __pyx_k_validate, sizeof(__pyx_k_validate), 0, 0, 1, 1},
  {&__pyx_n_s_validateTrace, __pyx_k_validateTrace, sizeof(__pyx_k_validateTrace), 0, 0, 1, 1},
  {&__pyx_n_s_value, __pyx_k_value, sizeof(__pyx_k_value), 0, 0, 1, 1},
  {&__pyx_n_u_value, __pyx_k_value, sizeof(__pyx_k_value), 0, 1, 0, 1},
  {&__pyx_n_s_values, __pyx_k_values, sizeof(__pyx_k_values), 0, 0, 1, 1},
  {&__pyx_n_s_vars, __pyx_k_vars, sizeof(__pyx_k_vars), 0, 0, 1, 1},
  {&__pyx_n_s_ve, __pyx_k_ve, sizeof(__pyx_k_ve), 0, 0, 1, 1},
  {&__pyx_n_s_verbose_stacktrace, __pyx_k_verbose_stacktrace, sizeof(__pyx_k_verbose_stacktrace), 0, 0, 1, 1},
  {&__pyx_n_s_verifyCol, __pyx_k_verifyCol, sizeof(__pyx_k_verifyCol), 0, 0, 1, 1},
  {&__pyx_n_s_version, __pyx_k_version, sizeof(__pyx_k_version), 0, 0, 1, 1},
  {&__pyx_n_s_version_info, __pyx_k_version_info, sizeof(__pyx_k_version_info), 0, 0, 1, 1},
  {&__pyx_n_s_vlist, __pyx_k_vlist, sizeof(__pyx_k_vlist), 0, 0, 1, 1},
  {&__pyx_n_s_vv, __pyx_k_vv, sizeof(__pyx_k_vv), 0, 0, 1, 1},
  {&__pyx_kp_u_w, __pyx_k_w, sizeof(__pyx_k_w), 0, 1, 0, 0},
  {&__pyx_n_s_warn, __pyx_k_warn, sizeof(__pyx_k_warn), 0, 0, 1, 1},
  {&__pyx_n_s_warnings, __pyx_k_warnings, sizeof(__pyx_k_warnings), 0, 0, 1, 1},
  {&__pyx_n_s_weakref, __pyx_k_weakref, sizeof(__pyx_k_weakref), 0, 0, 1, 1},
  {&__pyx_n_s_whiteChars, __pyx_k_whiteChars, sizeof(__pyx_k_whiteChars), 0, 0, 1, 1},
  {&__pyx_n_s_whiteStrs, __pyx_k_whiteStrs, sizeof(__pyx_k_whiteStrs), 0, 0, 1, 1},
  {&__pyx_n_s_whitespace, __pyx_k_whitespace, sizeof(__pyx_k_whitespace), 0, 0, 1, 1},
  {&__pyx_n_s_withAttribute, __pyx_k_withAttribute, sizeof(__pyx_k_withAttribute), 0, 0, 1, 1},
  {&__pyx_n_u_withAttribute, __pyx_k_withAttribute, sizeof(__pyx_k_withAttribute), 0, 1, 0, 1},
  {&__pyx_n_s_withAttribute___new, __pyx_k_withAttribute___new, sizeof(__pyx_k_withAttribute___new), 0, 0, 1, 1},
  {&__pyx_n_s_withAttribute___new___locals_pa, __pyx_k_withAttribute___new___locals_pa, sizeof(__pyx_k_withAttribute___new___locals_pa), 0, 0, 1, 1},
  {&__pyx_n_s_withClass, __pyx_k_withClass, sizeof(__pyx_k_withClass), 0, 0, 1, 1},
  {&__pyx_n_u_withClass, __pyx_k_withClass, sizeof(__pyx_k_withClass), 0, 1, 0, 1},
  {&__pyx_n_s_wkref, __pyx_k_wkref, sizeof(__pyx_k_wkref), 0, 0, 1, 1},
  {&__pyx_n_s_wordChars, __pyx_k_wordChars, sizeof(__pyx_k_wordChars), 0, 0, 1, 1},
  {&__pyx_n_s_wrapper, __pyx_k_wrapper, sizeof(__pyx_k_wrapper), 0, 0, 1, 1},
  {&__pyx_n_s_write, __pyx_k_write, sizeof(__pyx_k_write), 0, 0, 1, 1},
  {&__pyx_n_s_ws, __pyx_k_ws, sizeof(__pyx_k_ws), 0, 0, 1, 1},
  {&__pyx_n_s_ws_map, __pyx_k_ws_map, sizeof(__pyx_k_ws_map), 0, 0, 1, 1},
  {&__pyx_n_s_wschar, __pyx_k_wschar, sizeof(__pyx_k_wschar), 0, 0, 1, 1},
  {&__pyx_n_s_wslit, __pyx_k_wslit, sizeof(__pyx_k_wslit), 0, 0, 1, 1},
  {&__pyx_n_s_wt, __pyx_k_wt, sizeof(__pyx_k_wt), 0, 0, 1, 1},
  {&__pyx_n_s_xml, __pyx_k_xml, sizeof(__pyx_k_xml), 0, 0, 1, 1},
  {&__pyx_n_s_xmlBodyText, __pyx_k_xmlBodyText, sizeof(__pyx_k_xmlBodyText), 0, 0, 1, 1},
  {&__pyx_n_s_xml_escape, __pyx_k_xml_escape, sizeof(__pyx_k_xml_escape), 0, 0, 1, 1},
  {&__pyx_n_s_xml_escape_locals_genexpr, __pyx_k_xml_escape_locals_genexpr, sizeof(__pyx_k_xml_escape_locals_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_xor, __pyx_k_xor, sizeof(__pyx_k_xor), 0, 0, 1, 1},
  {&__pyx_n_s_xrange, __pyx_k_xrange, sizeof(__pyx_k_xrange), 0, 0, 1, 1},
  {&__pyx_n_s_z, __pyx_k_z, sizeof(__pyx_k_z), 0, 0, 1, 1},
  {&__pyx_n_s_zip, __pyx_k_zip, sizeof(__pyx_k_zip), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_ImportError = __Pyx_GetBuiltinName(__pyx_n_s_ImportError); if (!__pyx_builtin_ImportError) __PYX_ERR(0, 65, __pyx_L1_error)
  __pyx_builtin_chr = __Pyx_GetBuiltinName(__pyx_n_s_chr); if (!__pyx_builtin_chr) __PYX_ERR(0, 108, __pyx_L1_error)
  __pyx_builtin_sum = __Pyx_GetBuiltinName(__pyx_n_s_sum); if (!__pyx_builtin_sum) __PYX_ERR(0, 112, __pyx_L1_error)
  __pyx_builtin_sorted = __Pyx_GetBuiltinName(__pyx_n_s_sorted); if (!__pyx_builtin_sorted) __PYX_ERR(0, 112, __pyx_L1_error)
  __pyx_builtin_reversed = __Pyx_GetBuiltinName(__pyx_n_s_reversed); if (!__pyx_builtin_reversed) __PYX_ERR(0, 112, __pyx_L1_error)
  __pyx_builtin_any = __Pyx_GetBuiltinName(__pyx_n_s_any); if (!__pyx_builtin_any) __PYX_ERR(0, 112, __pyx_L1_error)
  __pyx_builtin_all = __Pyx_GetBuiltinName(__pyx_n_s_all); if (!__pyx_builtin_all) __PYX_ERR(0, 112, __pyx_L1_error)
  __pyx_builtin_min = __Pyx_GetBuiltinName(__pyx_n_s_min); if (!__pyx_builtin_min) __PYX_ERR(0, 112, __pyx_L1_error)
  __pyx_builtin_max = __Pyx_GetBuiltinName(__pyx_n_s_max); if (!__pyx_builtin_max) __PYX_ERR(0, 112, __pyx_L1_error)
  #if PY_MAJOR_VERSION >= 3
  __pyx_builtin_xrange = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_xrange) __PYX_ERR(0, 115, __pyx_L1_error)
  #else
  __pyx_builtin_xrange = __Pyx_GetBuiltinName(__pyx_n_s_xrange); if (!__pyx_builtin_xrange) __PYX_ERR(0, 115, __pyx_L1_error)
  #endif
  __pyx_builtin_AttributeError = __Pyx_GetBuiltinName(__pyx_n_s_AttributeError); if (!__pyx_builtin_AttributeError) __PYX_ERR(0, 155, __pyx_L1_error)
  __pyx_builtin_object = __Pyx_GetBuiltinName(__pyx_n_s_object); if (!__pyx_builtin_object) __PYX_ERR(0, 172, __pyx_L1_error)
  __pyx_builtin_staticmethod = __Pyx_GetBuiltinName(__pyx_n_s_staticmethod); if (!__pyx_builtin_staticmethod) __PYX_ERR(0, 1094, __pyx_L1_error)
  __pyx_builtin_zip = __Pyx_GetBuiltinName(__pyx_n_s_zip); if (!__pyx_builtin_zip) __PYX_ERR(0, 5462, __pyx_L1_error)
  __pyx_builtin_KeyError = __Pyx_GetBuiltinName(__pyx_n_s_KeyError); if (!__pyx_builtin_KeyError) __PYX_ERR(0, 401, __pyx_L1_error)
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s_TypeError); if (!__pyx_builtin_TypeError) __PYX_ERR(0, 401, __pyx_L1_error)
  __pyx_builtin_IndexError = __Pyx_GetBuiltinName(__pyx_n_s_IndexError); if (!__pyx_builtin_IndexError) __PYX_ERR(0, 401, __pyx_L1_error)
  __pyx_builtin_enumerate = __Pyx_GetBuiltinName(__pyx_n_s_enumerate); if (!__pyx_builtin_enumerate) __PYX_ERR(0, 442, __pyx_L1_error)
  __pyx_builtin_print = __Pyx_GetBuiltinName(__pyx_n_s_print); if (!__pyx_builtin_print) __PYX_ERR(0, 1007, __pyx_L1_error)
  __pyx_builtin_map = __Pyx_GetBuiltinName(__pyx_n_s_map); if (!__pyx_builtin_map) __PYX_ERR(0, 1271, __pyx_L1_error)
  __pyx_builtin_SyntaxWarning = __Pyx_GetBuiltinName(__pyx_n_s_SyntaxWarning); if (!__pyx_builtin_SyntaxWarning) __PYX_ERR(0, 1826, __pyx_L1_error)
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) __PYX_ERR(0, 1908, __pyx_L1_error)
  __pyx_builtin_open = __Pyx_GetBuiltinName(__pyx_n_s_open); if (!__pyx_builtin_open) __PYX_ERR(0, 2171, __pyx_L1_error)
  __pyx_builtin_vars = __Pyx_GetBuiltinName(__pyx_n_s_vars); if (!__pyx_builtin_vars) __PYX_ERR(0, 2184, __pyx_L1_error)
  __pyx_builtin_super = __Pyx_GetBuiltinName(__pyx_n_s_super); if (!__pyx_builtin_super) __PYX_ERR(0, 2188, __pyx_L1_error)
  __pyx_builtin_id = __Pyx_GetBuiltinName(__pyx_n_s_id); if (!__pyx_builtin_id) __PYX_ERR(0, 2194, __pyx_L1_error)
  __pyx_builtin_SyntaxError = __Pyx_GetBuiltinName(__pyx_n_s_SyntaxError); if (!__pyx_builtin_SyntaxError) __PYX_ERR(0, 2874, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "cPyparsing.pyx":158
 *             continue
 * 
 * _generatorType = type((y for y in range(1)))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple_ = PyTuple_Pack(1, __pyx_int_1); if (unlikely(!__pyx_tuple_)) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);

  /* "cPyparsing.pyx":4832
 * 
 * _escapedPunc = Word(_bslash, r"\[]-*.$+^?()~ ", exact=2).setParseAction(lambda s, l, t: t[0][1])
 * _escapedHexChar = Regex(r"\\0?[xX][0-9a-fA-F]+").setParseAction(lambda s, l, t: unichr(int(t[0].lstrip(r'\0x'), 16)))             # <<<<<<<<<<<<<<
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | Word(printables, excludeChars=r'\]', exact=1) | Regex(r"\w", re.UNICODE)
 */
  __pyx_tuple__2 = PyTuple_Pack(1, __pyx_kp_u_0x); if (unlikely(!__pyx_tuple__2)) __PYX_ERR(0, 4832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__2);
  __Pyx_GIVEREF(__pyx_tuple__2);

  /* "cPyparsing.pyx":4833
 * _escapedPunc = Word(_bslash, r"\[]-*.$+^?()~ ", exact=2).setParseAction(lambda s, l, t: t[0][1])
 * _escapedHexChar = Regex(r"\\0?[xX][0-9a-fA-F]+").setParseAction(lambda s, l, t: unichr(int(t[0].lstrip(r'\0x'), 16)))
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))             # <<<<<<<<<<<<<<
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | Word(printables, excludeChars=r'\]', exact=1) | Regex(r"\w", re.UNICODE)
 * _charRange = Group(_singleChar + Suppress("-") + _singleChar)
 */
  __pyx_slice__3 = PySlice_New(__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_slice__3)) __PYX_ERR(0, 4833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__3);
  __Pyx_GIVEREF(__pyx_slice__3);

  /* "cPyparsing.pyx":120
 *     def repr(obj):
 *         if isinstance(obj, unicode):
 *             return _repr(obj).lstrip("u")             # <<<<<<<<<<<<<<
 *         else:
 *             return _repr(obj)
 */
  __pyx_tuple__4 = PyTuple_Pack(1, __pyx_n_u_u); if (unlikely(!__pyx_tuple__4)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__4);
  __Pyx_GIVEREF(__pyx_tuple__4);

  /* "cPyparsing.pyx":127
 *     def _ustr(obj):
 *         if isinstance(obj, py_str):
 *             obj = obj.decode("utf8")             # <<<<<<<<<<<<<<
 *         return unicode(obj)
 *     # def _ustr(obj):
 */
  __pyx_tuple__5 = PyTuple_Pack(1, __pyx_n_u_utf8); if (unlikely(!__pyx_tuple__5)) __PYX_ERR(0, 127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);

  /* "cPyparsing.pyx":376
 *                 toklist = []
 *             if isinstance(toklist, list):
 *                 self.__toklist = toklist[:]             # <<<<<<<<<<<<<<
 *             elif isinstance(toklist, _generatorType):
 *                 self.__toklist = list(toklist)
 */
  __pyx_slice__11 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_slice__11)) __PYX_ERR(0, 376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__11);
  __Pyx_GIVEREF(__pyx_slice__11);

  /* "cPyparsing.pyx":457
 *     def __iter__(self): return iter(self.__toklist)
 * 
 *     def __reversed__(self): return iter(self.__toklist[::-1])             # <<<<<<<<<<<<<<
 * 
 *     def _iterkeys(self):
 */
  __pyx_slice__12 = PySlice_New(Py_None, Py_None, __pyx_int_neg_1); if (unlikely(!__pyx_slice__12)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__12);
  __Pyx_GIVEREF(__pyx_slice__12);

  /* "cPyparsing.pyx":638
 *         Clear all elements and results names.
 *         """
 *         del self.__toklist[:]             # <<<<<<<<<<<<<<
 *         self.__tokdict.clear()
 * 
 */
  __pyx_slice__13 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_slice__13)) __PYX_ERR(0, 638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__13);
  __Pyx_GIVEREF(__pyx_slice__13);

  /* "cPyparsing.pyx":664
 *             offset = len(self.__toklist)
 * 
 *             def addoffset(a): return offset if a < 0 else a + offset             # <<<<<<<<<<<<<<
 *             otheritems = other.__tokdict.items()
 *             otherdictitems = [(k, _ParseResultsWithOffset(v[0], addoffset(v[1])))
 */
  __pyx_tuple__14 = PyTuple_Pack(1, __pyx_n_s_a); if (unlikely(!__pyx_tuple__14)) __PYX_ERR(0, 664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__14);
  __Pyx_GIVEREF(__pyx_tuple__14);
  __pyx_codeobj__15 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__14, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_addoffset, 664, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__15)) __PYX_ERR(0, 664, __pyx_L1_error)

  /* "cPyparsing.pyx":742
 *             item_fn = self.iteritems
 * 
 *         def toItem(obj):             # <<<<<<<<<<<<<<
 *             if isinstance(obj, ParseResults):
 *                 if obj.haskeys():
 */
  __pyx_tuple__19 = PyTuple_Pack(1, __pyx_n_s_obj); if (unlikely(!__pyx_tuple__19)) __PYX_ERR(0, 742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__19);
  __Pyx_GIVEREF(__pyx_tuple__19);
  __pyx_codeobj__20 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__19, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_toItem, 742, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__20)) __PYX_ERR(0, 742, __pyx_L1_error)

  /* "cPyparsing.pyx":1066
 *                     try:
 *                         tb = sys.exc_info()[-1]
 *                         tb_info = extract_tb(tb, limit=2)[-1][:2]             # <<<<<<<<<<<<<<
 *                         if tb_info != tb_info_synth:
 *                             raise
 */
  __pyx_slice__27 = PySlice_New(Py_None, __pyx_int_2, Py_None); if (unlikely(!__pyx_slice__27)) __PYX_ERR(0, 1066, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__27);
  __Pyx_GIVEREF(__pyx_slice__27);

  /* "cPyparsing.pyx":1032
 * 
 *     # traceback return data structure changed in Py3.5 - normalize back to plain tuples
 *     if system_version[:2] >= (3, 5):             # <<<<<<<<<<<<<<
 *         # def extract_stack(limit=None):
 *         #     # special handling for Python 3.5.0 - extra deep call stack by 1
 */
  __pyx_slice__28 = PySlice_New(Py_None, __pyx_int_2, Py_None); if (unlikely(!__pyx_slice__28)) __PYX_ERR(0, 1032, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__28);
  __Pyx_GIVEREF(__pyx_slice__28);
  __pyx_tuple__29 = PyTuple_Pack(2, __pyx_int_3, __pyx_int_5); if (unlikely(!__pyx_tuple__29)) __PYX_ERR(0, 1032, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__29);
  __Pyx_GIVEREF(__pyx_tuple__29);

  /* "cPyparsing.pyx":1039
 *         #     return [(frame_summary.filename, frame_summary.lineno)]
 * 
 *         def extract_tb(tb, limit=None):             # <<<<<<<<<<<<<<
 *             frames = traceback.extract_tb(tb, limit=limit)
 *             frame_summary = frames[-1]
 */
  __pyx_tuple__30 = PyTuple_Pack(4, __pyx_n_s_tb, __pyx_n_s_limit, __pyx_n_s_frames, __pyx_n_s_frame_summary); if (unlikely(!__pyx_tuple__30)) __PYX_ERR(0, 1039, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__30);
  __Pyx_GIVEREF(__pyx_tuple__30);
  __pyx_codeobj__31 = (PyObject*)__Pyx_PyCode_New(2, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__30, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_extract_tb, 1039, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__31)) __PYX_ERR(0, 1039, __pyx_L1_error)
  __pyx_tuple__32 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__32)) __PYX_ERR(0, 1039, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__32);
  __Pyx_GIVEREF(__pyx_tuple__32);

  /* "cPyparsing.pyx":1051
 *     tb_info_synth = (_FILE_NAME, _WRAP_CALL_LINE_NUM)
 * 
 *     def wrapper(*args):             # <<<<<<<<<<<<<<
 *         nonlocal foundArity, limit
 *         while True:
 */
  __pyx_tuple__33 = PyTuple_Pack(4, __pyx_n_s_args, __pyx_n_s_ret, __pyx_n_s_tb, __pyx_n_s_tb_info); if (unlikely(!__pyx_tuple__33)) __PYX_ERR(0, 1051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__33);
  __Pyx_GIVEREF(__pyx_tuple__33);
  __pyx_codeobj__34 = (PyObject*)__Pyx_PyCode_New(0, 0, 4, 0, CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__33, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_wrapper, 1051, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__34)) __PYX_ERR(0, 1051, __pyx_L1_error)

  /* "cPyparsing.pyx":1148
 *         self.errmsg = ""
 *         self.modalResults = True  # used to mark results names as modal (report only last) or cumulative (list all)
 *         self.debugActions = (None, None, None)  # custom debug actions             # <<<<<<<<<<<<<<
 *         self.re = None
 *         self.callPreparse = True  # used to avoid redundant calls to preParse
 */
  __pyx_tuple__35 = PyTuple_Pack(3, Py_None, Py_None, Py_None); if (unlikely(!__pyx_tuple__35)) __PYX_ERR(0, 1148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__35);
  __Pyx_GIVEREF(__pyx_tuple__35);

  /* "cPyparsing.pyx":1170
 *         """
 *         cpy = copy.copy(self)
 *         cpy.parseAction = self.parseAction[:]             # <<<<<<<<<<<<<<
 *         cpy.ignoreExprs = self.ignoreExprs[:]
 *         if self.copyDefaultWhiteChars:
 */
  __pyx_slice__36 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_slice__36)) __PYX_ERR(0, 1170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__36);
  __Pyx_GIVEREF(__pyx_slice__36);

  /* "cPyparsing.pyx":1171
 *         cpy = copy.copy(self)
 *         cpy.parseAction = self.parseAction[:]
 *         cpy.ignoreExprs = self.ignoreExprs[:]             # <<<<<<<<<<<<<<
 *         if self.copyDefaultWhiteChars:
 *             cpy.whiteChars = ParserElement.DEFAULT_WHITE_CHARS
 */
  __pyx_slice__37 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_slice__37)) __PYX_ERR(0, 1171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__37);
  __Pyx_GIVEREF(__pyx_slice__37);

  /* "cPyparsing.pyx":1211
 *         """
 *         newself = self.copy()
 *         if name.endswith("*"):             # <<<<<<<<<<<<<<
 *             name = name[:-1]
 *             listAllMatches = True
 */
  __pyx_tuple__39 = PyTuple_Pack(1, __pyx_kp_u__38); if (unlikely(!__pyx_tuple__39)) __PYX_ERR(0, 1211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__39);
  __Pyx_GIVEREF(__pyx_tuple__39);

  /* "cPyparsing.pyx":1212
 *         newself = self.copy()
 *         if name.endswith("*"):
 *             name = name[:-1]             # <<<<<<<<<<<<<<
 *             listAllMatches = True
 *         newself.resultsName = name
 */
  __pyx_slice__40 = PySlice_New(Py_None, __pyx_int_neg_1, Py_None); if (unlikely(!__pyx_slice__40)) __PYX_ERR(0, 1212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__40);
  __Pyx_GIVEREF(__pyx_slice__40);

  /* "cPyparsing.pyx":1226
 *             _parseMethod = self._parse
 * 
 *             def breaker(instring, loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *                 import pdb
 *                 pdb.set_trace()
 */
  __pyx_tuple__41 = PyTuple_Pack(5, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_callPreParse, __pyx_n_s_pdb); if (unlikely(!__pyx_tuple__41)) __PYX_ERR(0, 1226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__41);
  __Pyx_GIVEREF(__pyx_tuple__41);
  __pyx_codeobj__42 = (PyObject*)__Pyx_PyCode_New(4, 0, 5, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__41, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_breaker, 1226, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__42)) __PYX_ERR(0, 1226, __pyx_L1_error)
  __pyx_tuple__43 = PyTuple_Pack(2, ((PyObject *)Py_True), ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__43)) __PYX_ERR(0, 1226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__43);
  __Pyx_GIVEREF(__pyx_tuple__43);

  /* "cPyparsing.pyx":1305
 *         exc_type = ParseFatalException if kwargs.get("fatal", False) else ParseException
 *         for fn in fns:
 *             def pa(s, l, t):             # <<<<<<<<<<<<<<
 *                 if not bool(_trim_arity(fn)(s, l, t)):
 *                     raise exc_type(s, l, msg)
 */
  __pyx_tuple__44 = PyTuple_Pack(3, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t); if (unlikely(!__pyx_tuple__44)) __PYX_ERR(0, 1305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__44);
  __Pyx_GIVEREF(__pyx_tuple__44);
  __pyx_codeobj__45 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__44, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_pa, 1305, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__45)) __PYX_ERR(0, 1305, __pyx_L1_error)

  /* "cPyparsing.pyx":1448
 *             self.not_in_cache = not_in_cache = object()
 * 
 *             def get(self, key):             # <<<<<<<<<<<<<<
 *                 return cache.get(key, not_in_cache)
 * 
 */
  __pyx_tuple__46 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_key); if (unlikely(!__pyx_tuple__46)) __PYX_ERR(0, 1448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__46);
  __Pyx_GIVEREF(__pyx_tuple__46);
  __pyx_codeobj__47 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__46, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_get, 1448, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__47)) __PYX_ERR(0, 1448, __pyx_L1_error)

  /* "cPyparsing.pyx":1451
 *                 return cache.get(key, not_in_cache)
 * 
 *             def set(self, key, value):             # <<<<<<<<<<<<<<
 *                 cache[key] = value
 * 
 */
  __pyx_tuple__48 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_key, __pyx_n_s_value); if (unlikely(!__pyx_tuple__48)) __PYX_ERR(0, 1451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__48);
  __Pyx_GIVEREF(__pyx_tuple__48);
  __pyx_codeobj__49 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__48, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_set, 1451, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__49)) __PYX_ERR(0, 1451, __pyx_L1_error)

  /* "cPyparsing.pyx":1454
 *                 cache[key] = value
 * 
 *             def clear(self):             # <<<<<<<<<<<<<<
 *                 cache.clear()
 * 
 */
  __pyx_tuple__50 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__50)) __PYX_ERR(0, 1454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__50);
  __Pyx_GIVEREF(__pyx_tuple__50);
  __pyx_codeobj__51 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__50, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_clear, 1454, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__51)) __PYX_ERR(0, 1454, __pyx_L1_error)

  /* "cPyparsing.pyx":1457
 *                 cache.clear()
 * 
 *             def cache_len(self):             # <<<<<<<<<<<<<<
 *                 return len(cache)
 * 
 */
  __pyx_tuple__52 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__52)) __PYX_ERR(0, 1457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__52);
  __Pyx_GIVEREF(__pyx_tuple__52);
  __pyx_codeobj__53 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__52, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_cache_len, 1457, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__53)) __PYX_ERR(0, 1457, __pyx_L1_error)

  /* "cPyparsing.pyx":1479
 *                     while len(cache) > size:
 *                         try:
 *                             cache.popitem(False)             # <<<<<<<<<<<<<<
 *                         except KeyError:
 *                             pass
 */
  __pyx_tuple__54 = PyTuple_Pack(1, Py_False); if (unlikely(!__pyx_tuple__54)) __PYX_ERR(0, 1479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__54);
  __Pyx_GIVEREF(__pyx_tuple__54);

  /* "cPyparsing.pyx":1472
 *                 cache = _OrderedDict()
 * 
 *                 def get(self, key):             # <<<<<<<<<<<<<<
 *                     return cache.get(key, not_in_cache)
 * 
 */
  __pyx_tuple__55 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_key); if (unlikely(!__pyx_tuple__55)) __PYX_ERR(0, 1472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__55);
  __Pyx_GIVEREF(__pyx_tuple__55);
  __pyx_codeobj__56 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__55, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_get, 1472, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__56)) __PYX_ERR(0, 1472, __pyx_L1_error)

  /* "cPyparsing.pyx":1475
 *                     return cache.get(key, not_in_cache)
 * 
 *                 def set(self, key, value):             # <<<<<<<<<<<<<<
 *                     cache[key] = value
 *                     while len(cache) > size:
 */
  __pyx_tuple__57 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_key, __pyx_n_s_value); if (unlikely(!__pyx_tuple__57)) __PYX_ERR(0, 1475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__57);
  __Pyx_GIVEREF(__pyx_tuple__57);
  __pyx_codeobj__58 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__57, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_set, 1475, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__58)) __PYX_ERR(0, 1475, __pyx_L1_error)

  /* "cPyparsing.pyx":1483
 *                             pass
 * 
 *                 def clear(self):             # <<<<<<<<<<<<<<
 *                     cache.clear()
 * 
 */
  __pyx_tuple__59 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__59)) __PYX_ERR(0, 1483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__59);
  __Pyx_GIVEREF(__pyx_tuple__59);
  __pyx_codeobj__60 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__59, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_clear, 1483, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__60)) __PYX_ERR(0, 1483, __pyx_L1_error)

  /* "cPyparsing.pyx":1486
 *                     cache.clear()
 * 
 *                 def cache_len(self):             # <<<<<<<<<<<<<<
 *                     return len(cache)
 * 
 */
  __pyx_tuple__61 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__61)) __PYX_ERR(0, 1486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__61);
  __Pyx_GIVEREF(__pyx_tuple__61);
  __pyx_codeobj__62 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__61, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_cache_len, 1486, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__62)) __PYX_ERR(0, 1486, __pyx_L1_error)

  /* "cPyparsing.pyx":1502
 *                 key_fifo = collections.deque([], size)
 * 
 *                 def get(self, key):             # <<<<<<<<<<<<<<
 *                     return cache.get(key, not_in_cache)
 * 
 */
  __pyx_tuple__63 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_key); if (unlikely(!__pyx_tuple__63)) __PYX_ERR(0, 1502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__63);
  __Pyx_GIVEREF(__pyx_tuple__63);
  __pyx_codeobj__64 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__63, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_get, 1502, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__64)) __PYX_ERR(0, 1502, __pyx_L1_error)

  /* "cPyparsing.pyx":1505
 *                     return cache.get(key, not_in_cache)
 * 
 *                 def set(self, key, value):             # <<<<<<<<<<<<<<
 *                     cache[key] = value
 *                     while len(key_fifo) > size:
 */
  __pyx_tuple__65 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_key, __pyx_n_s_value); if (unlikely(!__pyx_tuple__65)) __PYX_ERR(0, 1505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__65);
  __Pyx_GIVEREF(__pyx_tuple__65);
  __pyx_codeobj__66 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__65, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_set, 1505, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__66)) __PYX_ERR(0, 1505, __pyx_L1_error)

  /* "cPyparsing.pyx":1511
 *                     key_fifo.append(key)
 * 
 *                 def clear(self):             # <<<<<<<<<<<<<<
 *                     cache.clear()
 *                     key_fifo.clear()
 */
  __pyx_tuple__67 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__67)) __PYX_ERR(0, 1511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__67);
  __Pyx_GIVEREF(__pyx_tuple__67);
  __pyx_codeobj__68 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__67, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_clear, 1511, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__68)) __PYX_ERR(0, 1511, __pyx_L1_error)

  /* "cPyparsing.pyx":1515
 *                     key_fifo.clear()
 * 
 *                 def cache_len(self):             # <<<<<<<<<<<<<<
 *                     return len(cache)
 * 
 */
  __pyx_tuple__69 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__69)) __PYX_ERR(0, 1515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__69);
  __Pyx_GIVEREF(__pyx_tuple__69);
  __pyx_codeobj__70 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__69, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_cache_len, 1515, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__70)) __PYX_ERR(0, 1515, __pyx_L1_error)

  /* "cPyparsing.pyx":1533
 *         HIT, MISS = 0, 1
 *         lookup = (self, instring, loc, callPreParse, doActions)
 *         with ParserElement.packrat_cache_lock:             # <<<<<<<<<<<<<<
 *             cache = ParserElement.packrat_cache
 *             value = cache.get(lookup)
 */
  __pyx_tuple__71 = PyTuple_Pack(3, Py_None, Py_None, Py_None); if (unlikely(!__pyx_tuple__71)) __PYX_ERR(0, 1533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__71);
  __Pyx_GIVEREF(__pyx_tuple__71);
  __pyx_tuple__72 = PyTuple_Pack(3, Py_None, Py_None, Py_None); if (unlikely(!__pyx_tuple__72)) __PYX_ERR(0, 1533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__72);
  __Pyx_GIVEREF(__pyx_tuple__72);

  /* "cPyparsing.pyx":1558
 *     def resetCache():
 *         ParserElement.packrat_cache.clear()
 *         ParserElement.packrat_cache_stats[:] = [0] * len(ParserElement.packrat_cache_stats)             # <<<<<<<<<<<<<<
 * 
 *     _packratEnabled = False
 */
  __pyx_slice__73 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_slice__73)) __PYX_ERR(0, 1558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__73);
  __Pyx_GIVEREF(__pyx_slice__73);

  /* "cPyparsing.pyx":1889
 *             minElements, optElements = other, 0
 *         elif isinstance(other, tuple):
 *             other = (other + (None, None))[:2]             # <<<<<<<<<<<<<<
 *             if other[0] is None:
 *                 other = (0, other[1])
 */
  __pyx_tuple__74 = PyTuple_Pack(2, Py_None, Py_None); if (unlikely(!__pyx_tuple__74)) __PYX_ERR(0, 1889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__74);
  __Pyx_GIVEREF(__pyx_tuple__74);
  __pyx_slice__75 = PySlice_New(Py_None, __pyx_int_2, Py_None); if (unlikely(!__pyx_slice__75)) __PYX_ERR(0, 1889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__75);
  __Pyx_GIVEREF(__pyx_slice__75);

  /* "cPyparsing.pyx":1908
 * 
 *         if minElements < 0:
 *             raise ValueError("cannot multiply ParserElement by negative value")             # <<<<<<<<<<<<<<
 *         if optElements < 0:
 *             raise ValueError("second tuple value must be greater or equal to first tuple value")
 */
  __pyx_tuple__76 = PyTuple_Pack(1, __pyx_kp_u_cannot_multiply_ParserElement_by); if (unlikely(!__pyx_tuple__76)) __PYX_ERR(0, 1908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__76);
  __Pyx_GIVEREF(__pyx_tuple__76);

  /* "cPyparsing.pyx":1910
 *             raise ValueError("cannot multiply ParserElement by negative value")
 *         if optElements < 0:
 *             raise ValueError("second tuple value must be greater or equal to first tuple value")             # <<<<<<<<<<<<<<
 *         if minElements == optElements == 0:
 *             raise ValueError("cannot multiply ParserElement by 0 or (0,0)")
 */
  __pyx_tuple__77 = PyTuple_Pack(1, __pyx_kp_u_second_tuple_value_must_be_great); if (unlikely(!__pyx_tuple__77)) __PYX_ERR(0, 1910, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__77);
  __Pyx_GIVEREF(__pyx_tuple__77);

  /* "cPyparsing.pyx":1912
 *             raise ValueError("second tuple value must be greater or equal to first tuple value")
 *         if minElements == optElements == 0:
 *             raise ValueError("cannot multiply ParserElement by 0 or (0,0)")             # <<<<<<<<<<<<<<
 * 
 *         if (optElements):
 */
  __pyx_tuple__78 = PyTuple_Pack(1, __pyx_kp_u_cannot_multiply_ParserElement_by_2); if (unlikely(!__pyx_tuple__78)) __PYX_ERR(0, 1912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__78);
  __Pyx_GIVEREF(__pyx_tuple__78);

  /* "cPyparsing.pyx":1915
 * 
 *         if (optElements):
 *             def makeOptionalList(n):             # <<<<<<<<<<<<<<
 *                 if n > 1:
 *                     return Optional(self + makeOptionalList(n - 1))
 */
  __pyx_tuple__79 = PyTuple_Pack(1, __pyx_n_s_n); if (unlikely(!__pyx_tuple__79)) __PYX_ERR(0, 1915, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__79);
  __Pyx_GIVEREF(__pyx_tuple__79);
  __pyx_codeobj__80 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__79, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_makeOptionalList, 1915, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__80)) __PYX_ERR(0, 1915, __pyx_L1_error)

  /* "cPyparsing.pyx":2171
 *             file_contents = file_or_filename.read()
 *         except AttributeError:
 *             with open(file_or_filename, "r") as f:             # <<<<<<<<<<<<<<
 *                 file_contents = f.read()
 *         try:
 */
  __pyx_tuple__81 = PyTuple_Pack(3, Py_None, Py_None, Py_None); if (unlikely(!__pyx_tuple__81)) __PYX_ERR(0, 2171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__81);
  __Pyx_GIVEREF(__pyx_tuple__81);

  /* "cPyparsing.pyx":2324
 *             comments = []
 *             try:
 *                 t = t.replace(r'\n', '\n')             # <<<<<<<<<<<<<<
 *                 result = self.parseString(t, parseAll=parseAll)
 *                 out.append(result.dump(full=fullDump))
 */
  __pyx_tuple__83 = PyTuple_Pack(2, __pyx_kp_u_n_2, __pyx_kp_u__21); if (unlikely(!__pyx_tuple__83)) __PYX_ERR(0, 2324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__83);
  __Pyx_GIVEREF(__pyx_tuple__83);

  /* "cPyparsing.pyx":2674
 * 
 *         if min < 1:
 *             raise ValueError("cannot specify a minimum length < 1; use Optional(Word()) if zero-length word is permitted")             # <<<<<<<<<<<<<<
 * 
 *         self.minLen = min
 */
  __pyx_tuple__86 = PyTuple_Pack(1, __pyx_kp_u_cannot_specify_a_minimum_length); if (unlikely(!__pyx_tuple__86)) __PYX_ERR(0, 2674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__86);
  __Pyx_GIVEREF(__pyx_tuple__86);

  /* "cPyparsing.pyx":2755
 *             def charsAsStr(s):
 *                 if len(s) > 4:
 *                     return s[:4] + "..."             # <<<<<<<<<<<<<<
 *                 else:
 *                     return s
 */
  __pyx_slice__87 = PySlice_New(Py_None, __pyx_int_4, Py_None); if (unlikely(!__pyx_slice__87)) __PYX_ERR(0, 2755, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__87);
  __Pyx_GIVEREF(__pyx_slice__87);

  /* "cPyparsing.pyx":2753
 *         if self.strRepr is None:
 * 
 *             def charsAsStr(s):             # <<<<<<<<<<<<<<
 *                 if len(s) > 4:
 *                     return s[:4] + "..."
 */
  __pyx_tuple__89 = PyTuple_Pack(1, __pyx_n_s_s); if (unlikely(!__pyx_tuple__89)) __PYX_ERR(0, 2753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__89);
  __Pyx_GIVEREF(__pyx_tuple__89);
  __pyx_codeobj__90 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__89, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_charsAsStr, 2753, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__90)) __PYX_ERR(0, 2753, __pyx_L1_error)

  /* "cPyparsing.pyx":2809
 * 
 *         else:
 *             raise ValueError("Regex may only be constructed with a string or a compiled RE object")             # <<<<<<<<<<<<<<
 * 
 *         self.name = _ustr(self)
 */
  __pyx_tuple__91 = PyTuple_Pack(1, __pyx_kp_u_Regex_may_only_be_constructed_wi); if (unlikely(!__pyx_tuple__91)) __PYX_ERR(0, 2809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__91);
  __Pyx_GIVEREF(__pyx_tuple__91);

  /* "cPyparsing.pyx":3002
 * 
 *         if min < 1:
 *             raise ValueError("cannot specify a minimum length < 1; use Optional(CharsNotIn()) if zero-length char group is permitted")             # <<<<<<<<<<<<<<
 * 
 *         self.minLen = min
 */
  __pyx_tuple__100 = PyTuple_Pack(1, __pyx_kp_u_cannot_specify_a_minimum_length_2); if (unlikely(!__pyx_tuple__100)) __PYX_ERR(0, 3002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__100);
  __Pyx_GIVEREF(__pyx_tuple__100);

  /* "cPyparsing.pyx":3045
 *         if self.strRepr is None:
 *             if len(self.notChars) > 4:
 *                 self.strRepr = "!W:(%s...)" % self.notChars[:4]             # <<<<<<<<<<<<<<
 *             else:
 *                 self.strRepr = "!W:(%s)" % self.notChars
 */
  __pyx_slice__101 = PySlice_New(Py_None, __pyx_int_4, Py_None); if (unlikely(!__pyx_slice__101)) __PYX_ERR(0, 3045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__101);
  __Pyx_GIVEREF(__pyx_slice__101);

  /* "cPyparsing.pyx":3178
 *     def __init__(self):
 *         super(LineEnd, self).__init__()
 *         self.setWhitespaceChars(ParserElement.DEFAULT_WHITE_CHARS.replace("\n", ""))             # <<<<<<<<<<<<<<
 *         self.errmsg = "Expected end of line"
 * 
 */
  __pyx_tuple__103 = PyTuple_Pack(2, __pyx_kp_u__21, __pyx_kp_u__9); if (unlikely(!__pyx_tuple__103)) __PYX_ERR(0, 3178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__103);
  __Pyx_GIVEREF(__pyx_tuple__103);

  /* "cPyparsing.pyx":3355
 *                 other.resultsName is None and
 *                     not other.debug):
 *                 self.exprs = other.exprs[:] + [self.exprs[1]]             # <<<<<<<<<<<<<<
 *                 self.strRepr = None
 *                 self.mayReturnEmpty |= other.mayReturnEmpty
 */
  __pyx_slice__104 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_slice__104)) __PYX_ERR(0, 3355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__104);
  __Pyx_GIVEREF(__pyx_slice__104);

  /* "cPyparsing.pyx":3365
 *                 other.resultsName is None and
 *                     not other.debug):
 *                 self.exprs = self.exprs[:-1] + other.exprs[:]             # <<<<<<<<<<<<<<
 *                 self.strRepr = None
 *                 self.mayReturnEmpty |= other.mayReturnEmpty
 */
  __pyx_slice__105 = PySlice_New(Py_None, __pyx_int_neg_1, Py_None); if (unlikely(!__pyx_slice__105)) __PYX_ERR(0, 3365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__105);
  __Pyx_GIVEREF(__pyx_slice__105);
  __pyx_slice__106 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_slice__106)) __PYX_ERR(0, 3365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__106);
  __Pyx_GIVEREF(__pyx_slice__106);

  /* "cPyparsing.pyx":3379
 * 
 *     def validate(self, validateTrace=[]):
 *         tmp = validateTrace[:] + [self]             # <<<<<<<<<<<<<<
 *         for e in self.exprs:
 *             e.validate(tmp)
 */
  __pyx_slice__107 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_slice__107)) __PYX_ERR(0, 3379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__107);
  __Pyx_GIVEREF(__pyx_slice__107);

  /* "cPyparsing.pyx":3424
 *         loc, resultlist = self.exprs[0]._parse(instring, loc, doActions, callPreParse=False)
 *         errorStop = False
 *         for e in self.exprs[1:]:             # <<<<<<<<<<<<<<
 *             if isinstance(e, And._ErrorStop):
 *                 errorStop = True
 */
  __pyx_slice__109 = PySlice_New(__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_slice__109)) __PYX_ERR(0, 3424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__109);
  __Pyx_GIVEREF(__pyx_slice__109);

  /* "cPyparsing.pyx":3450
 * 
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]             # <<<<<<<<<<<<<<
 *         for e in self.exprs:
 *             e.checkRecursion(subRecCheckList)
 */
  __pyx_slice__110 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_slice__110)) __PYX_ERR(0, 3450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__110);
  __Pyx_GIVEREF(__pyx_slice__110);

  /* "cPyparsing.pyx":3540
 * 
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]             # <<<<<<<<<<<<<<
 *         for e in self.exprs:
 *             e.checkRecursion(subRecCheckList)
 */
  __pyx_slice__114 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_slice__114)) __PYX_ERR(0, 3540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__114);
  __Pyx_GIVEREF(__pyx_slice__114);

  /* "cPyparsing.pyx":3609
 * 
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]             # <<<<<<<<<<<<<<
 *         for e in self.exprs:
 *             e.checkRecursion(subRecCheckList)
 */
  __pyx_slice__116 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_slice__116)) __PYX_ERR(0, 3609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__116);
  __Pyx_GIVEREF(__pyx_slice__116);

  /* "cPyparsing.pyx":3687
 *             self.initExprGroups = False
 *         tmpLoc = loc
 *         tmpReqd = self.required[:]             # <<<<<<<<<<<<<<
 *         tmpOpt = self.optionals[:]
 *         matchOrder = []
 */
  __pyx_slice__117 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_slice__117)) __PYX_ERR(0, 3687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__117);
  __Pyx_GIVEREF(__pyx_slice__117);

  /* "cPyparsing.pyx":3688
 *         tmpLoc = loc
 *         tmpReqd = self.required[:]
 *         tmpOpt = self.optionals[:]             # <<<<<<<<<<<<<<
 *         matchOrder = []
 * 
 */
  __pyx_slice__118 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_slice__118)) __PYX_ERR(0, 3688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__118);
  __Pyx_GIVEREF(__pyx_slice__118);

  /* "cPyparsing.pyx":3734
 * 
 *     def checkRecursion(self, parseElementList):
 *         subRecCheckList = parseElementList[:] + [self]             # <<<<<<<<<<<<<<
 *         for e in self.exprs:
 *             e.checkRecursion(subRecCheckList)
 */
  __pyx_slice__120 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_slice__120)) __PYX_ERR(0, 3734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__120);
  __Pyx_GIVEREF(__pyx_slice__120);

  /* "cPyparsing.pyx":3796
 *         if self in parseElementList:
 *             raise RecursiveGrammarException(parseElementList + [self])
 *         subRecCheckList = parseElementList[:] + [self]             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             self.expr.checkRecursion(subRecCheckList)
 */
  __pyx_slice__121 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_slice__121)) __PYX_ERR(0, 3796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__121);
  __Pyx_GIVEREF(__pyx_slice__121);

  /* "cPyparsing.pyx":3801
 * 
 *     def validate(self, validateTrace=[]):
 *         tmp = validateTrace[:] + [self]             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             self.expr.validate(tmp)
 */
  __pyx_slice__122 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_slice__122)) __PYX_ERR(0, 3801, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__122);
  __Pyx_GIVEREF(__pyx_slice__122);

  /* "cPyparsing.pyx":4237
 *     def validate(self, validateTrace=[]):
 *         if self not in validateTrace:
 *             tmp = validateTrace[:] + [self]             # <<<<<<<<<<<<<<
 *             if self.expr is not None:
 *                 self.expr.validate(tmp)
 */
  __pyx_slice__126 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_slice__126)) __PYX_ERR(0, 4237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__126);
  __Pyx_GIVEREF(__pyx_slice__126);

  /* "cPyparsing.pyx":4320
 *     def postParse(self, instring, loc, tokenlist):
 *         retToks = tokenlist.copy()
 *         del retToks[:]             # <<<<<<<<<<<<<<
 *         retToks += ParseResults(["".join(tokenlist._asStringList(self.joinString))], modal=self.modalResults)
 * 
 */
  __pyx_slice__128 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_slice__128)) __PYX_ERR(0, 4320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__128);
  __Pyx_GIVEREF(__pyx_slice__128);

  /* "cPyparsing.pyx":4488
 *     f = _trim_arity(f)
 * 
 *     def z(*paArgs):             # <<<<<<<<<<<<<<
 *         thisFunc = f.__name__
 *         s, l, t = paArgs[-3:]
 */
  __pyx_tuple__130 = PyTuple_Pack(7, __pyx_n_s_paArgs, __pyx_n_s_thisFunc, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t, __pyx_n_s_ret, __pyx_n_s_exc); if (unlikely(!__pyx_tuple__130)) __PYX_ERR(0, 4488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__130);
  __Pyx_GIVEREF(__pyx_tuple__130);
  __pyx_codeobj__131 = (PyObject*)__Pyx_PyCode_New(0, 0, 7, 0, CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__130, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_z, 4488, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__131)) __PYX_ERR(0, 4488, __pyx_L1_error)

  /* "cPyparsing.pyx":4552
 *     arrayExpr = Forward()
 * 
 *     def countFieldParseAction(s, l, t):             # <<<<<<<<<<<<<<
 *         n = t[0]
 *         arrayExpr << (n and Group(And([expr] * n)) or Group(empty))
 */
  __pyx_tuple__134 = PyTuple_Pack(4, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t, __pyx_n_s_n); if (unlikely(!__pyx_tuple__134)) __PYX_ERR(0, 4552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__134);
  __Pyx_GIVEREF(__pyx_tuple__134);
  __pyx_codeobj__135 = (PyObject*)__Pyx_PyCode_New(3, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__134, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_countFieldParseAction, 4552, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__135)) __PYX_ERR(0, 4552, __pyx_L1_error)

  /* "cPyparsing.pyx":4560
 *     else:
 *         intExpr = intExpr.copy()
 *     intExpr.setName("arrayLen")             # <<<<<<<<<<<<<<
 *     intExpr.addParseAction(countFieldParseAction, callDuringTry=True)
 *     return (intExpr + arrayExpr).setName('(len) ' + _ustr(expr) + '...')
 */
  __pyx_tuple__136 = PyTuple_Pack(1, __pyx_n_u_arrayLen); if (unlikely(!__pyx_tuple__136)) __PYX_ERR(0, 4560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__136);
  __Pyx_GIVEREF(__pyx_tuple__136);

  /* "cPyparsing.pyx":4590
 *     rep = Forward()
 * 
 *     def copyTokenToRepeater(s, l, t):             # <<<<<<<<<<<<<<
 *         if t:
 *             if len(t) == 1:
 */
  __pyx_tuple__137 = PyTuple_Pack(6, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t, __pyx_n_s_tflat, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__137)) __PYX_ERR(0, 4590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__137);
  __Pyx_GIVEREF(__pyx_tuple__137);
  __pyx_codeobj__138 = (PyObject*)__Pyx_PyCode_New(3, 0, 6, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__137, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_copyTokenToRepeater, 4590, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__138)) __PYX_ERR(0, 4590, __pyx_L1_error)

  /* "cPyparsing.pyx":4629
 *             theseTokens = _flatten(t.asList())
 *             if theseTokens != matchTokens:
 *                 raise ParseException("", 0, "")             # <<<<<<<<<<<<<<
 *         rep.setParseAction(mustMatchTheseTokens, callDuringTry=True)
 *     expr.addParseAction(copyTokenToRepeater, callDuringTry=True)
 */
  __pyx_tuple__139 = PyTuple_Pack(3, __pyx_kp_u__9, __pyx_int_0, __pyx_kp_u__9); if (unlikely(!__pyx_tuple__139)) __PYX_ERR(0, 4629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__139);
  __Pyx_GIVEREF(__pyx_tuple__139);

  /* "cPyparsing.pyx":4626
 *         matchTokens = _flatten(t.asList())
 * 
 *         def mustMatchTheseTokens(s, l, t):             # <<<<<<<<<<<<<<
 *             theseTokens = _flatten(t.asList())
 *             if theseTokens != matchTokens:
 */
  __pyx_tuple__140 = PyTuple_Pack(4, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t, __pyx_n_s_theseTokens); if (unlikely(!__pyx_tuple__140)) __PYX_ERR(0, 4626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__140);
  __Pyx_GIVEREF(__pyx_tuple__140);
  __pyx_codeobj__141 = (PyObject*)__Pyx_PyCode_New(3, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__140, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_mustMatchTheseTokens, 4626, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__141)) __PYX_ERR(0, 4626, __pyx_L1_error)

  /* "cPyparsing.pyx":4623
 *     rep <<= e2
 * 
 *     def copyTokenToRepeater(s, l, t):             # <<<<<<<<<<<<<<
 *         matchTokens = _flatten(t.asList())
 * 
 */
  __pyx_tuple__142 = PyTuple_Pack(6, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t, __pyx_n_s_matchTokens, __pyx_n_s_mustMatchTheseTokens, __pyx_n_s_mustMatchTheseTokens); if (unlikely(!__pyx_tuple__142)) __PYX_ERR(0, 4623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__142);
  __Pyx_GIVEREF(__pyx_tuple__142);
  __pyx_codeobj__143 = (PyObject*)__Pyx_PyCode_New(3, 0, 6, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__142, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_copyTokenToRepeater, 4623, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__143)) __PYX_ERR(0, 4623, __pyx_L1_error)

  /* "cPyparsing.pyx":4640
 *     for c in r"\^-]":
 *         s = s.replace(c, _bslash + c)
 *     s = s.replace("\n", r"\n")             # <<<<<<<<<<<<<<
 *     s = s.replace("\t", r"\t")
 *     return _ustr(s)
 */
  __pyx_tuple__144 = PyTuple_Pack(2, __pyx_kp_u__21, __pyx_kp_u_n_2); if (unlikely(!__pyx_tuple__144)) __PYX_ERR(0, 4640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__144);
  __Pyx_GIVEREF(__pyx_tuple__144);

  /* "cPyparsing.pyx":4641
 *         s = s.replace(c, _bslash + c)
 *     s = s.replace("\n", r"\n")
 *     s = s.replace("\t", r"\t")             # <<<<<<<<<<<<<<
 *     return _ustr(s)
 * 
 */
  __pyx_tuple__145 = PyTuple_Pack(2, __pyx_kp_u__97, __pyx_kp_u_t_2); if (unlikely(!__pyx_tuple__145)) __PYX_ERR(0, 4641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__145);
  __Pyx_GIVEREF(__pyx_tuple__145);

  /* "cPyparsing.pyx":4786
 *     else:
 *         def extractText(s, l, t):
 *             t[:] = [s[t.pop('_original_start'):t.pop('_original_end')]]             # <<<<<<<<<<<<<<
 *     matchExpr.setParseAction(extractText)
 *     matchExpr.ignoreExprs = expr.ignoreExprs
 */
  __pyx_tuple__147 = PyTuple_Pack(1, __pyx_n_u_original_start); if (unlikely(!__pyx_tuple__147)) __PYX_ERR(0, 4786, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__147);
  __Pyx_GIVEREF(__pyx_tuple__147);
  __pyx_tuple__148 = PyTuple_Pack(1, __pyx_n_u_original_end); if (unlikely(!__pyx_tuple__148)) __PYX_ERR(0, 4786, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__148);
  __Pyx_GIVEREF(__pyx_tuple__148);
  __pyx_slice__149 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_slice__149)) __PYX_ERR(0, 4786, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__149);
  __Pyx_GIVEREF(__pyx_slice__149);

  /* "cPyparsing.pyx":4781
 *     endlocMarker = locMarker.copy()
 *     endlocMarker.callPreparse = False
 *     matchExpr = locMarker("_original_start") + expr + endlocMarker("_original_end")             # <<<<<<<<<<<<<<
 *     if asString:
 *         def extractText(s, l, t): return s[t._original_start:t._original_end]
 */
  __pyx_tuple__150 = PyTuple_Pack(1, __pyx_n_u_original_start); if (unlikely(!__pyx_tuple__150)) __PYX_ERR(0, 4781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__150);
  __Pyx_GIVEREF(__pyx_tuple__150);
  __pyx_tuple__151 = PyTuple_Pack(1, __pyx_n_u_original_end); if (unlikely(!__pyx_tuple__151)) __PYX_ERR(0, 4781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__151);
  __Pyx_GIVEREF(__pyx_tuple__151);

  /* "cPyparsing.pyx":4783
 *     matchExpr = locMarker("_original_start") + expr + endlocMarker("_original_end")
 *     if asString:
 *         def extractText(s, l, t): return s[t._original_start:t._original_end]             # <<<<<<<<<<<<<<
 *     else:
 *         def extractText(s, l, t):
 */
  __pyx_tuple__152 = PyTuple_Pack(3, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t); if (unlikely(!__pyx_tuple__152)) __PYX_ERR(0, 4783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__152);
  __Pyx_GIVEREF(__pyx_tuple__152);
  __pyx_codeobj__153 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__152, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_extractText, 4783, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__153)) __PYX_ERR(0, 4783, __pyx_L1_error)

  /* "cPyparsing.pyx":4785
 *         def extractText(s, l, t): return s[t._original_start:t._original_end]
 *     else:
 *         def extractText(s, l, t):             # <<<<<<<<<<<<<<
 *             t[:] = [s[t.pop('_original_start'):t.pop('_original_end')]]
 *     matchExpr.setParseAction(extractText)
 */
  __pyx_tuple__154 = PyTuple_Pack(3, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t); if (unlikely(!__pyx_tuple__154)) __PYX_ERR(0, 4785, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__154);
  __Pyx_GIVEREF(__pyx_tuple__154);
  __pyx_codeobj__155 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__154, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_extractText, 4785, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__155)) __PYX_ERR(0, 4785, __pyx_L1_error)

  /* "cPyparsing.pyx":4821
 *     """
 *     locator = Empty().setParseAction(lambda s, l, t: l)
 *     return Group(locator("locn_start") + expr("value") + locator.copy().leaveWhitespace()("locn_end"))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__156 = PyTuple_Pack(1, __pyx_n_u_locn_start); if (unlikely(!__pyx_tuple__156)) __PYX_ERR(0, 4821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__156);
  __Pyx_GIVEREF(__pyx_tuple__156);
  __pyx_tuple__157 = PyTuple_Pack(1, __pyx_n_u_value); if (unlikely(!__pyx_tuple__157)) __PYX_ERR(0, 4821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__157);
  __Pyx_GIVEREF(__pyx_tuple__157);
  __pyx_tuple__158 = PyTuple_Pack(1, __pyx_n_u_locn_end); if (unlikely(!__pyx_tuple__158)) __PYX_ERR(0, 4821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__158);
  __Pyx_GIVEREF(__pyx_tuple__158);

  /* "cPyparsing.pyx":4857
 *      - any combination of the above (C{'aeiouy'}, C{'a-zA-Z0-9_$'}, etc.)
 *     """
 *     def _expanded(p): return p if not isinstance(p, ParseResults) else ''.join(unichr(c) for c in range(ord(p[0]), ord(p[1]) + 1))             # <<<<<<<<<<<<<<
 *     try:
 *         return "".join(_expanded(part) for part in _reBracketExpr.parseString(s).body)
 */
  __pyx_tuple__159 = PyTuple_Pack(3, __pyx_n_s_p, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__159)) __PYX_ERR(0, 4857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__159);
  __Pyx_GIVEREF(__pyx_tuple__159);
  __pyx_codeobj__160 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__159, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_expanded, 4857, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__160)) __PYX_ERR(0, 4857, __pyx_L1_error)

  /* "cPyparsing.pyx":4869
 *     column in the input text.
 *     """
 *     def verifyCol(strg, locn, toks):             # <<<<<<<<<<<<<<
 *         if col(locn, strg) != n:
 *             raise ParseException(strg, locn, "matched token not at column %d" % n)
 */
  __pyx_tuple__161 = PyTuple_Pack(3, __pyx_n_s_strg, __pyx_n_s_locn, __pyx_n_s_toks); if (unlikely(!__pyx_tuple__161)) __PYX_ERR(0, 4869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__161);
  __Pyx_GIVEREF(__pyx_tuple__161);
  __pyx_codeobj__162 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__161, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_verifyCol, 4869, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__162)) __PYX_ERR(0, 4869, __pyx_L1_error)

  /* "cPyparsing.pyx":4902
 *         quotedString.parseString("'Now is the Winter of our Discontent'") # -> ["Now is the Winter of our Discontent"]
 *     """
 *     return t[0][1:-1]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_slice__163 = PySlice_New(__pyx_int_1, __pyx_int_neg_1, Py_None); if (unlikely(!__pyx_slice__163)) __PYX_ERR(0, 4902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__163);
  __Pyx_GIVEREF(__pyx_slice__163);

  /* "cPyparsing.pyx":4937
 *         ['Now Is The Winter Of Our Discontent Made Glorious Summer By This Sun Of York']
 *     """
 *     def pa(s, l, t):             # <<<<<<<<<<<<<<
 *         return [func(tokn, *args) for tokn in t]
 * 
 */
  __pyx_tuple__164 = PyTuple_Pack(3, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t); if (unlikely(!__pyx_tuple__164)) __PYX_ERR(0, 4937, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__164);
  __Pyx_GIVEREF(__pyx_tuple__164);
  __pyx_codeobj__165 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__164, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_pa, 4937, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__165)) __PYX_ERR(0, 4937, __pyx_L1_error)

  /* "cPyparsing.pyx":4968
 *     if (xml):
 *         tagAttrValue = dblQuotedString.copy().setParseAction(removeQuotes)
 *         openTag = Suppress("<") + tagStr("tag") + \             # <<<<<<<<<<<<<<
 *             Dict(ZeroOrMore(Group(tagAttrName + Suppress("=") + tagAttrValue))) + \
 *             Optional("/", default=[False]).setResultsName("empty").setParseAction(lambda s, l, t: t[0] == '/') + Suppress(">")
 */
  __pyx_tuple__168 = PyTuple_Pack(1, __pyx_kp_u__23); if (unlikely(!__pyx_tuple__168)) __PYX_ERR(0, 4968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__168);
  __Pyx_GIVEREF(__pyx_tuple__168);
  __pyx_tuple__169 = PyTuple_Pack(1, __pyx_n_u_tag); if (unlikely(!__pyx_tuple__169)) __PYX_ERR(0, 4968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__169);
  __Pyx_GIVEREF(__pyx_tuple__169);

  /* "cPyparsing.pyx":4969
 *         tagAttrValue = dblQuotedString.copy().setParseAction(removeQuotes)
 *         openTag = Suppress("<") + tagStr("tag") + \
 *             Dict(ZeroOrMore(Group(tagAttrName + Suppress("=") + tagAttrValue))) + \             # <<<<<<<<<<<<<<
 *             Optional("/", default=[False]).setResultsName("empty").setParseAction(lambda s, l, t: t[0] == '/') + Suppress(">")
 *     else:
 */
  __pyx_tuple__171 = PyTuple_Pack(1, __pyx_kp_u__170); if (unlikely(!__pyx_tuple__171)) __PYX_ERR(0, 4969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__171);
  __Pyx_GIVEREF(__pyx_tuple__171);

  /* "cPyparsing.pyx":4970
 *         openTag = Suppress("<") + tagStr("tag") + \
 *             Dict(ZeroOrMore(Group(tagAttrName + Suppress("=") + tagAttrValue))) + \
 *             Optional("/", default=[False]).setResultsName("empty").setParseAction(lambda s, l, t: t[0] == '/') + Suppress(">")             # <<<<<<<<<<<<<<
 *     else:
 *         printablesLessRAbrack = "".join(c for c in printables if c not in ">")
 */
  __pyx_tuple__172 = PyTuple_Pack(1, __pyx_kp_u__166); if (unlikely(!__pyx_tuple__172)) __PYX_ERR(0, 4970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__172);
  __Pyx_GIVEREF(__pyx_tuple__172);
  __pyx_tuple__173 = PyTuple_Pack(1, __pyx_n_u_empty); if (unlikely(!__pyx_tuple__173)) __PYX_ERR(0, 4970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__173);
  __Pyx_GIVEREF(__pyx_tuple__173);
  __pyx_tuple__174 = PyTuple_Pack(1, __pyx_kp_u__24); if (unlikely(!__pyx_tuple__174)) __PYX_ERR(0, 4970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__174);
  __Pyx_GIVEREF(__pyx_tuple__174);

  /* "cPyparsing.pyx":4974
 *         printablesLessRAbrack = "".join(c for c in printables if c not in ">")
 *         tagAttrValue = quotedString.copy().setParseAction(removeQuotes) | Word(printablesLessRAbrack)
 *         openTag = Suppress("<") + tagStr("tag") + \             # <<<<<<<<<<<<<<
 *             Dict(ZeroOrMore(Group(tagAttrName.setParseAction(downcaseTokens) +
 *                                   Optional(Suppress("=") + tagAttrValue)))) + \
 */
  __pyx_tuple__175 = PyTuple_Pack(1, __pyx_kp_u__23); if (unlikely(!__pyx_tuple__175)) __PYX_ERR(0, 4974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__175);
  __Pyx_GIVEREF(__pyx_tuple__175);
  __pyx_tuple__176 = PyTuple_Pack(1, __pyx_n_u_tag); if (unlikely(!__pyx_tuple__176)) __PYX_ERR(0, 4974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__176);
  __Pyx_GIVEREF(__pyx_tuple__176);

  /* "cPyparsing.pyx":4976
 *         openTag = Suppress("<") + tagStr("tag") + \
 *             Dict(ZeroOrMore(Group(tagAttrName.setParseAction(downcaseTokens) +
 *                                   Optional(Suppress("=") + tagAttrValue)))) + \             # <<<<<<<<<<<<<<
 *             Optional("/", default=[False]).setResultsName("empty").setParseAction(lambda s, l, t: t[0] == '/') + Suppress(">")
 *     closeTag = Combine(_L("</") + tagStr + ">")
 */
  __pyx_tuple__177 = PyTuple_Pack(1, __pyx_kp_u__170); if (unlikely(!__pyx_tuple__177)) __PYX_ERR(0, 4976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__177);
  __Pyx_GIVEREF(__pyx_tuple__177);

  /* "cPyparsing.pyx":4977
 *             Dict(ZeroOrMore(Group(tagAttrName.setParseAction(downcaseTokens) +
 *                                   Optional(Suppress("=") + tagAttrValue)))) + \
 *             Optional("/", default=[False]).setResultsName("empty").setParseAction(lambda s, l, t: t[0] == '/') + Suppress(">")             # <<<<<<<<<<<<<<
 *     closeTag = Combine(_L("</") + tagStr + ">")
 * 
 */
  __pyx_tuple__178 = PyTuple_Pack(1, __pyx_kp_u__166); if (unlikely(!__pyx_tuple__178)) __PYX_ERR(0, 4977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__178);
  __Pyx_GIVEREF(__pyx_tuple__178);
  __pyx_tuple__179 = PyTuple_Pack(1, __pyx_n_u_empty); if (unlikely(!__pyx_tuple__179)) __PYX_ERR(0, 4977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__179);
  __Pyx_GIVEREF(__pyx_tuple__179);
  __pyx_tuple__180 = PyTuple_Pack(1, __pyx_kp_u__24); if (unlikely(!__pyx_tuple__180)) __PYX_ERR(0, 4977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__180);
  __Pyx_GIVEREF(__pyx_tuple__180);

  /* "cPyparsing.pyx":4978
 *                                   Optional(Suppress("=") + tagAttrValue)))) + \
 *             Optional("/", default=[False]).setResultsName("empty").setParseAction(lambda s, l, t: t[0] == '/') + Suppress(">")
 *     closeTag = Combine(_L("</") + tagStr + ">")             # <<<<<<<<<<<<<<
 * 
 *     openTag = openTag.setResultsName("start" + "".join(resname.replace(":", " ").title().split())).setName("<%s>" % resname)
 */
  __pyx_tuple__181 = PyTuple_Pack(1, __pyx_kp_u__25); if (unlikely(!__pyx_tuple__181)) __PYX_ERR(0, 4978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__181);
  __Pyx_GIVEREF(__pyx_tuple__181);

  /* "cPyparsing.pyx":4980
 *     closeTag = Combine(_L("</") + tagStr + ">")
 * 
 *     openTag = openTag.setResultsName("start" + "".join(resname.replace(":", " ").title().split())).setName("<%s>" % resname)             # <<<<<<<<<<<<<<
 *     closeTag = closeTag.setResultsName("end" + "".join(resname.replace(":", " ").title().split())).setName("</%s>" % resname)
 *     openTag.tag = resname
 */
  __pyx_tuple__183 = PyTuple_Pack(2, __pyx_kp_u__182, __pyx_kp_u__84); if (unlikely(!__pyx_tuple__183)) __PYX_ERR(0, 4980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__183);
  __Pyx_GIVEREF(__pyx_tuple__183);

  /* "cPyparsing.pyx":4981
 * 
 *     openTag = openTag.setResultsName("start" + "".join(resname.replace(":", " ").title().split())).setName("<%s>" % resname)
 *     closeTag = closeTag.setResultsName("end" + "".join(resname.replace(":", " ").title().split())).setName("</%s>" % resname)             # <<<<<<<<<<<<<<
 *     openTag.tag = resname
 *     closeTag.tag = resname
 */
  __pyx_tuple__184 = PyTuple_Pack(2, __pyx_kp_u__182, __pyx_kp_u__84); if (unlikely(!__pyx_tuple__184)) __PYX_ERR(0, 4981, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__184);
  __Pyx_GIVEREF(__pyx_tuple__184);

  /* "cPyparsing.pyx":5076
 *         attrs = [(k, v) for k, v in attrs]
 * 
 *         def pa(s, l, tokens):             # <<<<<<<<<<<<<<
 *             for attrName, attrValue in attrs:
 *                 if attrName not in tokens:
 */
  __pyx_tuple__185 = PyTuple_Pack(5, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_tokens, __pyx_n_s_attrName, __pyx_n_s_attrValue); if (unlikely(!__pyx_tuple__185)) __PYX_ERR(0, 5076, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__185);
  __Pyx_GIVEREF(__pyx_tuple__185);
  __pyx_codeobj__186 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__185, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_pa, 5076, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__186)) __PYX_ERR(0, 5076, __pyx_L1_error)

  /* "cPyparsing.pyx":5191
 *     lastExpr = baseExpr | (lpar + ret + rpar)
 *     for i, operDef in enumerate(opList):
 *         opExpr, arity, rightLeftAssoc, pa = (operDef + (None,))[:4]             # <<<<<<<<<<<<<<
 *         termName = "%s term" % opExpr if arity < 3 else "%s%s term" % opExpr
 *         if arity == 3:
 */
  __pyx_tuple__189 = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_tuple__189)) __PYX_ERR(0, 5191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__189);
  __Pyx_GIVEREF(__pyx_tuple__189);
  __pyx_slice__190 = PySlice_New(Py_None, __pyx_int_4, Py_None); if (unlikely(!__pyx_slice__190)) __PYX_ERR(0, 5191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__190);
  __Pyx_GIVEREF(__pyx_slice__190);

  /* "cPyparsing.pyx":5195
 *         if arity == 3:
 *             if opExpr is None or len(opExpr) != 2:
 *                 raise ValueError("if numterms=3, opExpr must be a tuple or list of two expressions")             # <<<<<<<<<<<<<<
 *             opExpr1, opExpr2 = opExpr
 *         thisExpr = Forward().setName(termName)
 */
  __pyx_tuple__191 = PyTuple_Pack(1, __pyx_kp_u_if_numterms_3_opExpr_must_be_a_t); if (unlikely(!__pyx_tuple__191)) __PYX_ERR(0, 5195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__191);
  __Pyx_GIVEREF(__pyx_tuple__191);

  /* "cPyparsing.pyx":5210
 *                     Group(lastExpr + opExpr1 + lastExpr + opExpr2 + lastExpr)
 *             else:
 *                 raise ValueError("operator must be unary (1), binary (2), or ternary (3)")             # <<<<<<<<<<<<<<
 *         elif rightLeftAssoc == opAssoc.RIGHT:
 *             if arity == 1:
 */
  __pyx_tuple__192 = PyTuple_Pack(1, __pyx_kp_u_operator_must_be_unary_1_binary); if (unlikely(!__pyx_tuple__192)) __PYX_ERR(0, 5210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__192);
  __Pyx_GIVEREF(__pyx_tuple__192);

  /* "cPyparsing.pyx":5226
 *                     Group(lastExpr + opExpr1 + thisExpr + opExpr2 + thisExpr)
 *             else:
 *                 raise ValueError("operator must be unary (1), binary (2), or ternary (3)")             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError("operator must indicate right or left associativity")
 */
  __pyx_tuple__193 = PyTuple_Pack(1, __pyx_kp_u_operator_must_be_unary_1_binary); if (unlikely(!__pyx_tuple__193)) __PYX_ERR(0, 5226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__193);
  __Pyx_GIVEREF(__pyx_tuple__193);

  /* "cPyparsing.pyx":5228
 *                 raise ValueError("operator must be unary (1), binary (2), or ternary (3)")
 *         else:
 *             raise ValueError("operator must indicate right or left associativity")             # <<<<<<<<<<<<<<
 *         if pa:
 *             if isinstance(pa, (tuple, list)):
 */
  __pyx_tuple__194 = PyTuple_Pack(1, __pyx_kp_u_operator_must_indicate_right_or); if (unlikely(!__pyx_tuple__194)) __PYX_ERR(0, 5228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__194);
  __Pyx_GIVEREF(__pyx_tuple__194);

  /* "cPyparsing.pyx":5309
 *     """
 *     if opener == closer:
 *         raise ValueError("opening and closing strings cannot be the same")             # <<<<<<<<<<<<<<
 *     if content is None:
 *         if isinstance(opener, basestring) and isinstance(closer, basestring):
 */
  __pyx_tuple__197 = PyTuple_Pack(1, __pyx_kp_u_opening_and_closing_strings_cann); if (unlikely(!__pyx_tuple__197)) __PYX_ERR(0, 5309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__197);
  __Pyx_GIVEREF(__pyx_tuple__197);

  /* "cPyparsing.pyx":5331
 *                                        ).setParseAction(lambda t: t[0].strip()))
 *         else:
 *             raise ValueError("opening and closing arguments must be strings if no content expression is given")             # <<<<<<<<<<<<<<
 *     ret = Forward()
 *     if ignoreExpr is not None:
 */
  __pyx_tuple__198 = PyTuple_Pack(1, __pyx_kp_u_opening_and_closing_arguments_mu); if (unlikely(!__pyx_tuple__198)) __PYX_ERR(0, 5331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__198);
  __Pyx_GIVEREF(__pyx_tuple__198);

  /* "cPyparsing.pyx":5419
 *           [[['def', 'eggs', ['(', 'z', ')'], ':', [['pass']]]]]]]
 *     """
 *     def checkPeerIndent(s, l, t):             # <<<<<<<<<<<<<<
 *         if l >= len(s):
 *             return
 */
  __pyx_tuple__199 = PyTuple_Pack(4, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t, __pyx_n_s_curCol); if (unlikely(!__pyx_tuple__199)) __PYX_ERR(0, 5419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__199);
  __Pyx_GIVEREF(__pyx_tuple__199);
  __pyx_codeobj__200 = (PyObject*)__Pyx_PyCode_New(3, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__199, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_checkPeerIndent, 5419, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__200)) __PYX_ERR(0, 5419, __pyx_L1_error)

  /* "cPyparsing.pyx":5428
 *             raise ParseException(s, l, "not a peer entry")
 * 
 *     def checkSubIndent(s, l, t):             # <<<<<<<<<<<<<<
 *         curCol = col(l, s)
 *         if curCol > indentStack[-1]:
 */
  __pyx_tuple__201 = PyTuple_Pack(4, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t, __pyx_n_s_curCol); if (unlikely(!__pyx_tuple__201)) __PYX_ERR(0, 5428, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__201);
  __Pyx_GIVEREF(__pyx_tuple__201);
  __pyx_codeobj__202 = (PyObject*)__Pyx_PyCode_New(3, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__201, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_checkSubIndent, 5428, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__202)) __PYX_ERR(0, 5428, __pyx_L1_error)

  /* "cPyparsing.pyx":5435
 *             raise ParseException(s, l, "not a subentry")
 * 
 *     def checkUnindent(s, l, t):             # <<<<<<<<<<<<<<
 *         if l >= len(s):
 *             return
 */
  __pyx_tuple__203 = PyTuple_Pack(4, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t, __pyx_n_s_curCol); if (unlikely(!__pyx_tuple__203)) __PYX_ERR(0, 5435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__203);
  __Pyx_GIVEREF(__pyx_tuple__203);
  __pyx_codeobj__204 = (PyObject*)__Pyx_PyCode_New(3, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__203, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_checkUnindent, 5435, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__204)) __PYX_ERR(0, 5435, __pyx_L1_error)

  /* "cPyparsing.pyx":5443
 *         indentStack.pop()
 * 
 *     NL = OneOrMore(LineEnd().setWhitespaceChars("\t ").suppress())             # <<<<<<<<<<<<<<
 *     INDENT = (Empty() + Empty().setParseAction(checkSubIndent)).setName('INDENT')
 *     PEER = Empty().setParseAction(checkPeerIndent).setName('')
 */
  __pyx_tuple__206 = PyTuple_Pack(1, __pyx_kp_u__205); if (unlikely(!__pyx_tuple__206)) __PYX_ERR(0, 5443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__206);
  __Pyx_GIVEREF(__pyx_tuple__206);

  /* "cPyparsing.pyx":5444
 * 
 *     NL = OneOrMore(LineEnd().setWhitespaceChars("\t ").suppress())
 *     INDENT = (Empty() + Empty().setParseAction(checkSubIndent)).setName('INDENT')             # <<<<<<<<<<<<<<
 *     PEER = Empty().setParseAction(checkPeerIndent).setName('')
 *     UNDENT = Empty().setParseAction(checkUnindent).setName('UNINDENT')
 */
  __pyx_tuple__207 = PyTuple_Pack(1, __pyx_n_u_INDENT); if (unlikely(!__pyx_tuple__207)) __PYX_ERR(0, 5444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__207);
  __Pyx_GIVEREF(__pyx_tuple__207);

  /* "cPyparsing.pyx":5445
 *     NL = OneOrMore(LineEnd().setWhitespaceChars("\t ").suppress())
 *     INDENT = (Empty() + Empty().setParseAction(checkSubIndent)).setName('INDENT')
 *     PEER = Empty().setParseAction(checkPeerIndent).setName('')             # <<<<<<<<<<<<<<
 *     UNDENT = Empty().setParseAction(checkUnindent).setName('UNINDENT')
 *     if indent:
 */
  __pyx_tuple__208 = PyTuple_Pack(1, __pyx_kp_u__9); if (unlikely(!__pyx_tuple__208)) __PYX_ERR(0, 5445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__208);
  __Pyx_GIVEREF(__pyx_tuple__208);

  /* "cPyparsing.pyx":5446
 *     INDENT = (Empty() + Empty().setParseAction(checkSubIndent)).setName('INDENT')
 *     PEER = Empty().setParseAction(checkPeerIndent).setName('')
 *     UNDENT = Empty().setParseAction(checkUnindent).setName('UNINDENT')             # <<<<<<<<<<<<<<
 *     if indent:
 *         smExpr = Group(Optional(NL) +
 */
  __pyx_tuple__209 = PyTuple_Pack(1, __pyx_n_u_UNINDENT); if (unlikely(!__pyx_tuple__209)) __PYX_ERR(0, 5446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__209);
  __Pyx_GIVEREF(__pyx_tuple__209);

  /* "cPyparsing.pyx":5455
 *                        (OneOrMore(PEER + Group(blockStatementExpr) + Optional(NL))))
 *     blockStatementExpr.ignore(_bslash + LineEnd())
 *     return smExpr.setName('indented block')             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__210 = PyTuple_Pack(1, __pyx_kp_u_indented_block); if (unlikely(!__pyx_tuple__210)) __PYX_ERR(0, 5455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__210);
  __Pyx_GIVEREF(__pyx_tuple__210);

  /* "cPyparsing.pyx":5709
 *             [datetime.date(1999, 12, 31)]
 *         """
 *         def cvt_fn(s, l, t):             # <<<<<<<<<<<<<<
 *             try:
 *                 return datetime.strptime(t[0], fmt).date()
 */
  __pyx_tuple__211 = PyTuple_Pack(4, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t, __pyx_n_s_ve); if (unlikely(!__pyx_tuple__211)) __PYX_ERR(0, 5709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__211);
  __Pyx_GIVEREF(__pyx_tuple__211);
  __pyx_codeobj__212 = (PyObject*)__Pyx_PyCode_New(3, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__211, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_cvt_fn, 5709, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__212)) __PYX_ERR(0, 5709, __pyx_L1_error)

  /* "cPyparsing.pyx":5731
 *             [datetime.datetime(1999, 12, 31, 23, 59, 59, 999000)]
 *         """
 *         def cvt_fn(s, l, t):             # <<<<<<<<<<<<<<
 *             try:
 *                 return datetime.strptime(t[0], fmt)
 */
  __pyx_tuple__213 = PyTuple_Pack(4, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t, __pyx_n_s_ve); if (unlikely(!__pyx_tuple__213)) __PYX_ERR(0, 5731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__213);
  __Pyx_GIVEREF(__pyx_tuple__213);
  __pyx_codeobj__214 = (PyObject*)__Pyx_PyCode_New(3, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__213, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_cvt_fn, 5731, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__214)) __PYX_ERR(0, 5731, __pyx_L1_error)

  /* "cPyparsing.pyx":118
 * 
 *     _repr = repr
 *     def repr(obj):             # <<<<<<<<<<<<<<
 *         if isinstance(obj, unicode):
 *             return _repr(obj).lstrip("u")
 */
  __pyx_tuple__215 = PyTuple_Pack(1, __pyx_n_s_obj); if (unlikely(!__pyx_tuple__215)) __PYX_ERR(0, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__215);
  __Pyx_GIVEREF(__pyx_tuple__215);
  __pyx_codeobj__216 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__215, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_repr_2, 118, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__216)) __PYX_ERR(0, 118, __pyx_L1_error)

  /* "cPyparsing.pyx":125
 * 
 *     str = unicode
 *     def _ustr(obj):             # <<<<<<<<<<<<<<
 *         if isinstance(obj, py_str):
 *             obj = obj.decode("utf8")
 */
  __pyx_tuple__217 = PyTuple_Pack(1, __pyx_n_s_obj); if (unlikely(!__pyx_tuple__217)) __PYX_ERR(0, 125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__217);
  __Pyx_GIVEREF(__pyx_tuple__217);
  __pyx_codeobj__218 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__217, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_ustr, 125, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__218)) __PYX_ERR(0, 125, __pyx_L1_error)

  /* "cPyparsing.pyx":161
 * 
 * 
 * def _xml_escape(data):             # <<<<<<<<<<<<<<
 *     """Escape &, <, >, ", ', etc. in a string of data."""
 * 
 */
  __pyx_tuple__219 = PyTuple_Pack(7, __pyx_n_s_data, __pyx_n_s_from_symbols, __pyx_n_s_to_symbols, __pyx_n_s_from, __pyx_n_s_to, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__219)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__219);
  __Pyx_GIVEREF(__pyx_tuple__219);
  __pyx_codeobj__220 = (PyObject*)__Pyx_PyCode_New(1, 0, 7, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__219, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_xml_escape, 161, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__220)) __PYX_ERR(0, 161, __pyx_L1_error)

  /* "cPyparsing.pyx":180
 * hexnums = nums + "ABCDEFabcdef"
 * alphanums = alphas + nums
 * _bslash = chr(92)             # <<<<<<<<<<<<<<
 * printables = "".join(c for c in string.printable if c not in string.whitespace)
 * 
 */
  __pyx_tuple__221 = PyTuple_Pack(1, __pyx_int_92); if (unlikely(!__pyx_tuple__221)) __PYX_ERR(0, 180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__221);
  __Pyx_GIVEREF(__pyx_tuple__221);

  /* "cPyparsing.pyx":189
 *     # constructor as small and fast as possible
 * 
 *     def __init__(self, pstr, loc=0, msg=None, elem=None):             # <<<<<<<<<<<<<<
 *         self.loc = loc
 *         if msg is None:
 */
  __pyx_tuple__222 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_pstr, __pyx_n_s_loc, __pyx_n_s_msg, __pyx_n_s_elem); if (unlikely(!__pyx_tuple__222)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__222);
  __Pyx_GIVEREF(__pyx_tuple__222);
  __pyx_codeobj__223 = (PyObject*)__Pyx_PyCode_New(5, 0, 5, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__222, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 189, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__223)) __PYX_ERR(0, 189, __pyx_L1_error)
  __pyx_tuple__224 = PyTuple_Pack(3, ((PyObject *)__pyx_int_0), ((PyObject *)Py_None), ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__224)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__224);
  __Pyx_GIVEREF(__pyx_tuple__224);

  /* "cPyparsing.pyx":201
 * 
 *     @classmethod
 *     def _from_exception(cls, pe):             # <<<<<<<<<<<<<<
 *         """
 *         internal factory method to simplify creating one type of ParseException
 */
  __pyx_tuple__225 = PyTuple_Pack(2, __pyx_n_s_cls, __pyx_n_s_pe); if (unlikely(!__pyx_tuple__225)) __PYX_ERR(0, 201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__225);
  __Pyx_GIVEREF(__pyx_tuple__225);
  __pyx_codeobj__226 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__225, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_from_exception, 201, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__226)) __PYX_ERR(0, 201, __pyx_L1_error)

  /* "cPyparsing.pyx":208
 *         return cls(pe.pstr, pe.loc, pe.msg, pe.parserElement)
 * 
 *     def __getattr__(self, aname):             # <<<<<<<<<<<<<<
 *         """supported attributes by name are:
 *             - lineno - returns the line number of the exception text
 */
  __pyx_tuple__227 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_aname); if (unlikely(!__pyx_tuple__227)) __PYX_ERR(0, 208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__227);
  __Pyx_GIVEREF(__pyx_tuple__227);
  __pyx_codeobj__228 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__227, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_getattr, 208, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__228)) __PYX_ERR(0, 208, __pyx_L1_error)

  /* "cPyparsing.pyx":223
 *             raise AttributeError(aname)
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "%s (at char %d), (line:%d, col:%d)" % \
 *             (self.msg, self.loc, self.lineno, self.column)
 */
  __pyx_tuple__229 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__229)) __PYX_ERR(0, 223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__229);
  __Pyx_GIVEREF(__pyx_tuple__229);
  __pyx_codeobj__230 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__229, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_str_2, 223, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__230)) __PYX_ERR(0, 223, __pyx_L1_error)

  /* "cPyparsing.pyx":227
 *             (self.msg, self.loc, self.lineno, self.column)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return _ustr(self)
 * 
 */
  __pyx_tuple__231 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__231)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__231);
  __Pyx_GIVEREF(__pyx_tuple__231);
  __pyx_codeobj__232 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__231, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_repr_3, 227, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__232)) __PYX_ERR(0, 227, __pyx_L1_error)

  /* "cPyparsing.pyx":230
 *         return _ustr(self)
 * 
 *     def markInputline(self, markerString=">!<"):             # <<<<<<<<<<<<<<
 *         """Extracts the exception line from the input string, and marks
 *            the location of the exception with a special symbol.
 */
  __pyx_tuple__233 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_markerString, __pyx_n_s_line_str, __pyx_n_s_line_column); if (unlikely(!__pyx_tuple__233)) __PYX_ERR(0, 230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__233);
  __Pyx_GIVEREF(__pyx_tuple__233);
  __pyx_codeobj__234 = (PyObject*)__Pyx_PyCode_New(2, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__233, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_markInputline, 230, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__234)) __PYX_ERR(0, 230, __pyx_L1_error)
  __pyx_tuple__235 = PyTuple_Pack(1, ((PyObject*)__pyx_kp_u__10)); if (unlikely(!__pyx_tuple__235)) __PYX_ERR(0, 230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__235);
  __Pyx_GIVEREF(__pyx_tuple__235);

  /* "cPyparsing.pyx":241
 *         return line_str.strip()
 * 
 *     def __dir__(self):             # <<<<<<<<<<<<<<
 *         return "lineno col line".split() + dir(type(self))
 * 
 */
  __pyx_tuple__236 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__236)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__236);
  __Pyx_GIVEREF(__pyx_tuple__236);
  __pyx_codeobj__237 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__236, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_dir, 241, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__237)) __PYX_ERR(0, 241, __pyx_L1_error)

  /* "cPyparsing.pyx":296
 *     """exception thrown by L{ParserElement.validate} if the grammar could be improperly recursive"""
 * 
 *     def __init__(self, parseElementList):             # <<<<<<<<<<<<<<
 *         self.parseElementTrace = parseElementList
 * 
 */
  __pyx_tuple__238 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_parseElementList); if (unlikely(!__pyx_tuple__238)) __PYX_ERR(0, 296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__238);
  __Pyx_GIVEREF(__pyx_tuple__238);
  __pyx_codeobj__239 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__238, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 296, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__239)) __PYX_ERR(0, 296, __pyx_L1_error)

  /* "cPyparsing.pyx":299
 *         self.parseElementTrace = parseElementList
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "RecursiveGrammarException: %s" % self.parseElementTrace
 * 
 */
  __pyx_tuple__240 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__240)) __PYX_ERR(0, 299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__240);
  __Pyx_GIVEREF(__pyx_tuple__240);
  __pyx_codeobj__241 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__240, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_str_2, 299, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__241)) __PYX_ERR(0, 299, __pyx_L1_error)

  /* "cPyparsing.pyx":304
 * 
 * class _ParseResultsWithOffset(object):
 *     def __init__(self, p1, p2):             # <<<<<<<<<<<<<<
 *         self.tup = (p1, p2)
 * 
 */
  __pyx_tuple__242 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_p1, __pyx_n_s_p2); if (unlikely(!__pyx_tuple__242)) __PYX_ERR(0, 304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__242);
  __Pyx_GIVEREF(__pyx_tuple__242);
  __pyx_codeobj__243 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__242, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 304, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__243)) __PYX_ERR(0, 304, __pyx_L1_error)

  /* "cPyparsing.pyx":307
 *         self.tup = (p1, p2)
 * 
 *     def __getitem__(self, i):             # <<<<<<<<<<<<<<
 *         return self.tup[i]
 * 
 */
  __pyx_tuple__244 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_i); if (unlikely(!__pyx_tuple__244)) __PYX_ERR(0, 307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__244);
  __Pyx_GIVEREF(__pyx_tuple__244);
  __pyx_codeobj__245 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__244, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_getitem, 307, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__245)) __PYX_ERR(0, 307, __pyx_L1_error)

  /* "cPyparsing.pyx":310
 *         return self.tup[i]
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return repr(self.tup[0])
 * 
 */
  __pyx_tuple__246 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__246)) __PYX_ERR(0, 310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__246);
  __Pyx_GIVEREF(__pyx_tuple__246);
  __pyx_codeobj__247 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__246, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_repr_3, 310, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__247)) __PYX_ERR(0, 310, __pyx_L1_error)

  /* "cPyparsing.pyx":313
 *         return repr(self.tup[0])
 * 
 *     def setOffset(self, i):             # <<<<<<<<<<<<<<
 *         self.tup = (self.tup[0], i)
 * 
 */
  __pyx_tuple__248 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_i); if (unlikely(!__pyx_tuple__248)) __PYX_ERR(0, 313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__248);
  __Pyx_GIVEREF(__pyx_tuple__248);
  __pyx_codeobj__249 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__248, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_setOffset, 313, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__249)) __PYX_ERR(0, 313, __pyx_L1_error)

  /* "cPyparsing.pyx":356
 *         - year: 1999
 *     """
 *     def __new__(cls, toklist=None, name=None, asList=True, modal=True):             # <<<<<<<<<<<<<<
 *         if isinstance(toklist, cls):
 *             return toklist
 */
  __pyx_tuple__250 = PyTuple_Pack(6, __pyx_n_s_cls, __pyx_n_s_toklist, __pyx_n_s_name, __pyx_n_s_asList, __pyx_n_s_modal, __pyx_n_s_retobj); if (unlikely(!__pyx_tuple__250)) __PYX_ERR(0, 356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__250);
  __Pyx_GIVEREF(__pyx_tuple__250);
  __pyx_codeobj__251 = (PyObject*)__Pyx_PyCode_New(5, 0, 6, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__250, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_new, 356, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__251)) __PYX_ERR(0, 356, __pyx_L1_error)
  __pyx_tuple__252 = PyTuple_Pack(4, ((PyObject *)Py_None), ((PyObject *)Py_None), ((PyObject *)Py_True), ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__252)) __PYX_ERR(0, 356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__252);
  __Pyx_GIVEREF(__pyx_tuple__252);

  /* "cPyparsing.pyx":365
 *     # Performance tuning: we construct a *lot* of these, so keep this
 *     # constructor as small and fast as possible
 *     def __init__(self, toklist=None, name=None, asList=True, modal=True, isinstance=isinstance):             # <<<<<<<<<<<<<<
 *         if self.__doinit:
 *             self.__doinit = False
 */
  __pyx_tuple__253 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_toklist, __pyx_n_s_name, __pyx_n_s_asList, __pyx_n_s_modal, __pyx_n_s_isinstance); if (unlikely(!__pyx_tuple__253)) __PYX_ERR(0, 365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__253);
  __Pyx_GIVEREF(__pyx_tuple__253);
  __pyx_codeobj__254 = (PyObject*)__Pyx_PyCode_New(6, 0, 6, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__253, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 365, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__254)) __PYX_ERR(0, 365, __pyx_L1_error)

  /* "cPyparsing.pyx":404
 *                         self[name] = toklist
 * 
 *     def __getitem__(self, i):             # <<<<<<<<<<<<<<
 *         if isinstance(i, (int, slice)):
 *             return self.__toklist[i]
 */
  __pyx_tuple__255 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_i); if (unlikely(!__pyx_tuple__255)) __PYX_ERR(0, 404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__255);
  __Pyx_GIVEREF(__pyx_tuple__255);
  __pyx_codeobj__256 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__255, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_getitem, 404, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__256)) __PYX_ERR(0, 404, __pyx_L1_error)

  /* "cPyparsing.pyx":413
 *                 return ParseResults([v[0] for v in self.__tokdict[i]])
 * 
 *     def __setitem__(self, k, v, isinstance=isinstance):             # <<<<<<<<<<<<<<
 *         if isinstance(v, _ParseResultsWithOffset):
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [v]
 */
  __pyx_tuple__257 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_k, __pyx_n_s_v, __pyx_n_s_isinstance, __pyx_n_s_sub); if (unlikely(!__pyx_tuple__257)) __PYX_ERR(0, 413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__257);
  __Pyx_GIVEREF(__pyx_tuple__257);
  __pyx_codeobj__258 = (PyObject*)__Pyx_PyCode_New(4, 0, 5, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__257, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_setitem, 413, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__258)) __PYX_ERR(0, 413, __pyx_L1_error)

  /* "cPyparsing.pyx":426
 *             sub.__parent = wkref(self)
 * 
 *     def __delitem__(self, i):             # <<<<<<<<<<<<<<
 *         if isinstance(i, (int, slice)):
 *             mylen = len(self.__toklist)
 */
  __pyx_tuple__259 = PyTuple_Pack(10, __pyx_n_s_self, __pyx_n_s_i, __pyx_n_s_mylen, __pyx_n_s_removed, __pyx_n_s_name, __pyx_n_s_occurrences, __pyx_n_s_j, __pyx_n_s_k, __pyx_n_s_value, __pyx_n_s_position); if (unlikely(!__pyx_tuple__259)) __PYX_ERR(0, 426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__259);
  __Pyx_GIVEREF(__pyx_tuple__259);
  __pyx_codeobj__260 = (PyObject*)__Pyx_PyCode_New(2, 0, 10, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__259, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_delitem, 426, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__260)) __PYX_ERR(0, 426, __pyx_L1_error)

  /* "cPyparsing.pyx":447
 *             del self.__tokdict[i]
 * 
 *     def __contains__(self, k):             # <<<<<<<<<<<<<<
 *         return k in self.__tokdict
 * 
 */
  __pyx_tuple__261 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_k); if (unlikely(!__pyx_tuple__261)) __PYX_ERR(0, 447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__261);
  __Pyx_GIVEREF(__pyx_tuple__261);
  __pyx_codeobj__262 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__261, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_contains, 447, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__262)) __PYX_ERR(0, 447, __pyx_L1_error)

  /* "cPyparsing.pyx":450
 *         return k in self.__tokdict
 * 
 *     def __len__(self): return len(self.__toklist)             # <<<<<<<<<<<<<<
 * 
 *     def __bool__(self): return (not not self.__toklist)
 */
  __pyx_tuple__263 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__263)) __PYX_ERR(0, 450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__263);
  __Pyx_GIVEREF(__pyx_tuple__263);
  __pyx_codeobj__264 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__263, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_len, 450, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__264)) __PYX_ERR(0, 450, __pyx_L1_error)

  /* "cPyparsing.pyx":452
 *     def __len__(self): return len(self.__toklist)
 * 
 *     def __bool__(self): return (not not self.__toklist)             # <<<<<<<<<<<<<<
 *     __nonzero__ = __bool__
 * 
 */
  __pyx_tuple__265 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__265)) __PYX_ERR(0, 452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__265);
  __Pyx_GIVEREF(__pyx_tuple__265);
  __pyx_codeobj__266 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__265, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_bool, 452, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__266)) __PYX_ERR(0, 452, __pyx_L1_error)

  /* "cPyparsing.pyx":455
 *     __nonzero__ = __bool__
 * 
 *     def __iter__(self): return iter(self.__toklist)             # <<<<<<<<<<<<<<
 * 
 *     def __reversed__(self): return iter(self.__toklist[::-1])
 */
  __pyx_tuple__267 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__267)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__267);
  __Pyx_GIVEREF(__pyx_tuple__267);
  __pyx_codeobj__268 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__267, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_iter, 455, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__268)) __PYX_ERR(0, 455, __pyx_L1_error)

  /* "cPyparsing.pyx":457
 *     def __iter__(self): return iter(self.__toklist)
 * 
 *     def __reversed__(self): return iter(self.__toklist[::-1])             # <<<<<<<<<<<<<<
 * 
 *     def _iterkeys(self):
 */
  __pyx_tuple__269 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__269)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__269);
  __Pyx_GIVEREF(__pyx_tuple__269);
  __pyx_codeobj__270 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__269, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_reversed_2, 457, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__270)) __PYX_ERR(0, 457, __pyx_L1_error)

  /* "cPyparsing.pyx":459
 *     def __reversed__(self): return iter(self.__toklist[::-1])
 * 
 *     def _iterkeys(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self.__tokdict, "iterkeys"):
 *             return self.__tokdict.iterkeys()
 */
  __pyx_tuple__271 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__271)) __PYX_ERR(0, 459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__271);
  __Pyx_GIVEREF(__pyx_tuple__271);
  __pyx_codeobj__272 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__271, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_iterkeys_2, 459, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__272)) __PYX_ERR(0, 459, __pyx_L1_error)

  /* "cPyparsing.pyx":465
 *             return iter(self.__tokdict)
 * 
 *     def _itervalues(self):             # <<<<<<<<<<<<<<
 *         return (self[k] for k in self._iterkeys())
 * 
 */
  __pyx_tuple__273 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__273)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__273);
  __Pyx_GIVEREF(__pyx_tuple__273);
  __pyx_codeobj__274 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__273, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_itervalues_2, 465, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__274)) __PYX_ERR(0, 465, __pyx_L1_error)

  /* "cPyparsing.pyx":468
 *         return (self[k] for k in self._iterkeys())
 * 
 *     def _iteritems(self):             # <<<<<<<<<<<<<<
 *         return ((k, self[k]) for k in self._iterkeys())
 * 
 */
  __pyx_tuple__275 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__275)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__275);
  __Pyx_GIVEREF(__pyx_tuple__275);
  __pyx_codeobj__276 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__275, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_iteritems_2, 468, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__276)) __PYX_ERR(0, 468, __pyx_L1_error)

  /* "cPyparsing.pyx":491
 *         """Returns an iterator of all named result key-value tuples (Python 2.x only)."""
 * 
 *         def keys(self):             # <<<<<<<<<<<<<<
 *             """Returns all named result keys (as a list in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.iterkeys())
 */
  __pyx_tuple__277 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__277)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__277);
  __Pyx_GIVEREF(__pyx_tuple__277);
  __pyx_codeobj__278 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__277, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_keys, 491, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__278)) __PYX_ERR(0, 491, __pyx_L1_error)

  /* "cPyparsing.pyx":495
 *             return list(self.iterkeys())
 * 
 *         def values(self):             # <<<<<<<<<<<<<<
 *             """Returns all named result values (as a list in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.itervalues())
 */
  __pyx_tuple__279 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__279)) __PYX_ERR(0, 495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__279);
  __Pyx_GIVEREF(__pyx_tuple__279);
  __pyx_codeobj__280 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__279, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_values, 495, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__280)) __PYX_ERR(0, 495, __pyx_L1_error)

  /* "cPyparsing.pyx":499
 *             return list(self.itervalues())
 * 
 *         def items(self):             # <<<<<<<<<<<<<<
 *             """Returns all named result key-values (as a list of tuples in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.iteritems())
 */
  __pyx_tuple__281 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__281)) __PYX_ERR(0, 499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__281);
  __Pyx_GIVEREF(__pyx_tuple__281);
  __pyx_codeobj__282 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__281, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_items, 499, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__282)) __PYX_ERR(0, 499, __pyx_L1_error)

  /* "cPyparsing.pyx":503
 *             return list(self.iteritems())
 * 
 *     def haskeys(self):             # <<<<<<<<<<<<<<
 *         """Since keys() returns an iterator, this method is helpful in bypassing
 *            code that looks for the existence of any defined results names."""
 */
  __pyx_tuple__283 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__283)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__283);
  __Pyx_GIVEREF(__pyx_tuple__283);
  __pyx_codeobj__284 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__283, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_haskeys, 503, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__284)) __PYX_ERR(0, 503, __pyx_L1_error)

  /* "cPyparsing.pyx":508
 *         return bool(self.__tokdict)
 * 
 *     def pop(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Removes and returns item at specified index (default=C{last}).
 */
  __pyx_tuple__285 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_args, __pyx_n_s_kwargs, __pyx_n_s_k, __pyx_n_s_v, __pyx_n_s_index, __pyx_n_s_ret, __pyx_n_s_defaultvalue); if (unlikely(!__pyx_tuple__285)) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__285);
  __Pyx_GIVEREF(__pyx_tuple__285);
  __pyx_codeobj__286 = (PyObject*)__Pyx_PyCode_New(1, 0, 8, 0, CO_VARARGS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__285, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_pop, 508, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__286)) __PYX_ERR(0, 508, __pyx_L1_error)

  /* "cPyparsing.pyx":560
 *             return defaultvalue
 * 
 *     def get(self, key, defaultValue=None):             # <<<<<<<<<<<<<<
 *         """
 *         Returns named result matching the given key, or if there is no
 */
  __pyx_tuple__287 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_key, __pyx_n_s_defaultValue); if (unlikely(!__pyx_tuple__287)) __PYX_ERR(0, 560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__287);
  __Pyx_GIVEREF(__pyx_tuple__287);
  __pyx_codeobj__288 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__287, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_get, 560, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__288)) __PYX_ERR(0, 560, __pyx_L1_error)
  __pyx_tuple__289 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__289)) __PYX_ERR(0, 560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__289);
  __Pyx_GIVEREF(__pyx_tuple__289);

  /* "cPyparsing.pyx":582
 *             return defaultValue
 * 
 *     def insert(self, index, insStr):             # <<<<<<<<<<<<<<
 *         """
 *         Inserts new element at location index in the list of parsed tokens.
 */
  __pyx_tuple__290 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_index, __pyx_n_s_insStr, __pyx_n_s_name, __pyx_n_s_occurrences, __pyx_n_s_k, __pyx_n_s_value, __pyx_n_s_position); if (unlikely(!__pyx_tuple__290)) __PYX_ERR(0, 582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__290);
  __Pyx_GIVEREF(__pyx_tuple__290);
  __pyx_codeobj__291 = (PyObject*)__Pyx_PyCode_New(3, 0, 8, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__290, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_insert, 582, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__291)) __PYX_ERR(0, 582, __pyx_L1_error)

  /* "cPyparsing.pyx":602
 *                 occurrences[k] = _ParseResultsWithOffset(value, position + (position > index))
 * 
 *     def append(self, item):             # <<<<<<<<<<<<<<
 *         """
 *         Add single element to end of ParseResults list of elements.
 */
  __pyx_tuple__292 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_item); if (unlikely(!__pyx_tuple__292)) __PYX_ERR(0, 602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__292);
  __Pyx_GIVEREF(__pyx_tuple__292);
  __pyx_codeobj__293 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__292, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_append, 602, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__293)) __PYX_ERR(0, 602, __pyx_L1_error)

  /* "cPyparsing.pyx":616
 *         self.__toklist.append(item)
 * 
 *     def extend(self, itemseq):             # <<<<<<<<<<<<<<
 *         """
 *         Add sequence of elements to end of ParseResults list of elements.
 */
  __pyx_tuple__294 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_itemseq); if (unlikely(!__pyx_tuple__294)) __PYX_ERR(0, 616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__294);
  __Pyx_GIVEREF(__pyx_tuple__294);
  __pyx_codeobj__295 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__294, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_extend, 616, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__295)) __PYX_ERR(0, 616, __pyx_L1_error)

  /* "cPyparsing.pyx":634
 *             self.__toklist.extend(itemseq)
 * 
 *     def clear(self):             # <<<<<<<<<<<<<<
 *         """
 *         Clear all elements and results names.
 */
  __pyx_tuple__296 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__296)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__296);
  __Pyx_GIVEREF(__pyx_tuple__296);
  __pyx_codeobj__297 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__296, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_clear, 634, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__297)) __PYX_ERR(0, 634, __pyx_L1_error)

  /* "cPyparsing.pyx":641
 *         self.__tokdict.clear()
 * 
 *     def __getattr__(self, name):             # <<<<<<<<<<<<<<
 *         try:
 *             return self[name]
 */
  __pyx_tuple__298 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_name); if (unlikely(!__pyx_tuple__298)) __PYX_ERR(0, 641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__298);
  __Pyx_GIVEREF(__pyx_tuple__298);
  __pyx_codeobj__299 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__298, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_getattr, 641, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__299)) __PYX_ERR(0, 641, __pyx_L1_error)

  /* "cPyparsing.pyx":655
 *         #     return ""
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         ret = self.copy()
 *         ret += other
 */
  __pyx_tuple__300 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_ret); if (unlikely(!__pyx_tuple__300)) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__300);
  __Pyx_GIVEREF(__pyx_tuple__300);
  __pyx_codeobj__301 = (PyObject*)__Pyx_PyCode_New(2, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__300, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_add, 655, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__301)) __PYX_ERR(0, 655, __pyx_L1_error)

  /* "cPyparsing.pyx":660
 *         return ret
 * 
 *     def __iadd__(self, other):             # <<<<<<<<<<<<<<
 *         if other.__tokdict:
 *             offset = len(self.__toklist)
 */
  __pyx_tuple__302 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_offset, __pyx_n_s_addoffset, __pyx_n_s_addoffset, __pyx_n_s_otheritems, __pyx_n_s_otherdictitems, __pyx_n_s_k, __pyx_n_s_v); if (unlikely(!__pyx_tuple__302)) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__302);
  __Pyx_GIVEREF(__pyx_tuple__302);
  __pyx_codeobj__303 = (PyObject*)__Pyx_PyCode_New(2, 0, 9, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__302, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_iadd, 660, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__303)) __PYX_ERR(0, 660, __pyx_L1_error)

  /* "cPyparsing.pyx":677
 *         return self
 * 
 *     def __radd__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, int) and other == 0:
 *             # useful for merging many ParseResults using sum() builtin
 */
  __pyx_tuple__304 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__304)) __PYX_ERR(0, 677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__304);
  __Pyx_GIVEREF(__pyx_tuple__304);
  __pyx_codeobj__305 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__304, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_radd, 677, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__305)) __PYX_ERR(0, 677, __pyx_L1_error)

  /* "cPyparsing.pyx":685
 *             return other + self
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "(%s, %s)" % (repr(self.__toklist), repr(self.__tokdict))
 * 
 */
  __pyx_tuple__306 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__306)) __PYX_ERR(0, 685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__306);
  __Pyx_GIVEREF(__pyx_tuple__306);
  __pyx_codeobj__307 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__306, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_repr_3, 685, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__307)) __PYX_ERR(0, 685, __pyx_L1_error)

  /* "cPyparsing.pyx":688
 *         return "(%s, %s)" % (repr(self.__toklist), repr(self.__tokdict))
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'
 * 
 */
  __pyx_tuple__308 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__308)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__308);
  __Pyx_GIVEREF(__pyx_tuple__308);
  __pyx_codeobj__309 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__308, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_str_2, 688, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__309)) __PYX_ERR(0, 688, __pyx_L1_error)

  /* "cPyparsing.pyx":691
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'
 * 
 *     def _asStringList(self, sep=''):             # <<<<<<<<<<<<<<
 *         out = []
 *         for item in self.__toklist:
 */
  __pyx_tuple__310 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_sep, __pyx_n_s_out, __pyx_n_s_item); if (unlikely(!__pyx_tuple__310)) __PYX_ERR(0, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__310);
  __Pyx_GIVEREF(__pyx_tuple__310);
  __pyx_codeobj__311 = (PyObject*)__Pyx_PyCode_New(2, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__310, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_asStringList, 691, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__311)) __PYX_ERR(0, 691, __pyx_L1_error)
  __pyx_tuple__312 = PyTuple_Pack(1, ((PyObject*)__pyx_kp_u__9)); if (unlikely(!__pyx_tuple__312)) __PYX_ERR(0, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__312);
  __Pyx_GIVEREF(__pyx_tuple__312);

  /* "cPyparsing.pyx":702
 *         return out
 * 
 *     def asList(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the parse results as a nested list of matching tokens, all converted to strings.
 */
  __pyx_tuple__313 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__313)) __PYX_ERR(0, 702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__313);
  __Pyx_GIVEREF(__pyx_tuple__313);
  __pyx_codeobj__314 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__313, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_asList, 702, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__314)) __PYX_ERR(0, 702, __pyx_L1_error)

  /* "cPyparsing.pyx":718
 *         return [res.asList() if isinstance(res, ParseResults) else res for res in self.__toklist]
 * 
 *     def asDict(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the named parse results as a nested dictionary.
 */
  __pyx_tuple__315 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_item_fn, __pyx_n_s_toItem, __pyx_n_s_toItem, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__315)) __PYX_ERR(0, 718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__315);
  __Pyx_GIVEREF(__pyx_tuple__315);
  __pyx_codeobj__316 = (PyObject*)__Pyx_PyCode_New(1, 0, 6, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__315, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_asDict, 718, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__316)) __PYX_ERR(0, 718, __pyx_L1_error)

  /* "cPyparsing.pyx":753
 *         return dict((k, toItem(v)) for k, v in item_fn())
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns a new copy of a C{ParseResults} object.
 */
  __pyx_tuple__317 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_ret); if (unlikely(!__pyx_tuple__317)) __PYX_ERR(0, 753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__317);
  __Pyx_GIVEREF(__pyx_tuple__317);
  __pyx_codeobj__318 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__317, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_copy, 753, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__318)) __PYX_ERR(0, 753, __pyx_L1_error)

  /* "cPyparsing.pyx":764
 *         return ret
 * 
 *     def asXML(self, doctag=None, namedItemsOnly=False, indent="", formatted=True):             # <<<<<<<<<<<<<<
 *         """
 *         (Deprecated) Returns the parse results as XML. Tags are created for tokens and lists that have defined results names.
 */
  __pyx_tuple__319 = PyTuple_Pack(16, __pyx_n_s_self, __pyx_n_s_doctag, __pyx_n_s_namedItemsOnly, __pyx_n_s_indent, __pyx_n_s_formatted, __pyx_n_s_nl, __pyx_n_s_out, __pyx_n_s_namedItems, __pyx_n_s_nextLevelIndent, __pyx_n_s_selfTag, __pyx_n_s_i, __pyx_n_s_res, __pyx_n_s_resTag, __pyx_n_s_xmlBodyText, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__319)) __PYX_ERR(0, 764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__319);
  __Pyx_GIVEREF(__pyx_tuple__319);
  __pyx_codeobj__320 = (PyObject*)__Pyx_PyCode_New(5, 0, 16, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__319, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_asXML, 764, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__320)) __PYX_ERR(0, 764, __pyx_L1_error)
  __pyx_tuple__321 = PyTuple_Pack(4, ((PyObject *)Py_None), ((PyObject *)Py_False), ((PyObject*)__pyx_kp_u__9), ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__321)) __PYX_ERR(0, 764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__321);
  __Pyx_GIVEREF(__pyx_tuple__321);

  /* "cPyparsing.pyx":825
 *         return "".join(out)
 * 
 *     def __lookup(self, sub):             # <<<<<<<<<<<<<<
 *         for k, vlist in self.__tokdict.items():
 *             for v, loc in vlist:
 */
  __pyx_tuple__322 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_sub, __pyx_n_s_k, __pyx_n_s_vlist, __pyx_n_s_v, __pyx_n_s_loc); if (unlikely(!__pyx_tuple__322)) __PYX_ERR(0, 825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__322);
  __Pyx_GIVEREF(__pyx_tuple__322);
  __pyx_codeobj__323 = (PyObject*)__Pyx_PyCode_New(2, 0, 6, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__322, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_lookup, 825, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__323)) __PYX_ERR(0, 825, __pyx_L1_error)

  /* "cPyparsing.pyx":832
 *         return None
 * 
 *     def getName(self):             # <<<<<<<<<<<<<<
 *         r"""
 *         Returns the results name for this token expression. Useful when several
 */
  __pyx_tuple__324 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_par); if (unlikely(!__pyx_tuple__324)) __PYX_ERR(0, 832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__324);
  __Pyx_GIVEREF(__pyx_tuple__324);
  __pyx_codeobj__325 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__324, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_getName, 832, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__325)) __PYX_ERR(0, 832, __pyx_L1_error)

  /* "cPyparsing.pyx":869
 *             return None
 * 
 *     def dump(self, indent='', depth=0, full=True):             # <<<<<<<<<<<<<<
 *         """
 *         Diagnostic method for listing out the contents of a C{ParseResults}.
 */
  __pyx_tuple__326 = PyTuple_Pack(14, __pyx_n_s_self, __pyx_n_s_indent, __pyx_n_s_depth, __pyx_n_s_full, __pyx_n_s_out, __pyx_n_s_NL, __pyx_n_s_items, __pyx_n_s_k, __pyx_n_s_v, __pyx_n_s_i, __pyx_n_s_vv, __pyx_n_s_genexpr, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__326)) __PYX_ERR(0, 869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__326);
  __Pyx_GIVEREF(__pyx_tuple__326);
  __pyx_codeobj__327 = (PyObject*)__Pyx_PyCode_New(4, 0, 14, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__326, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_dump, 869, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__327)) __PYX_ERR(0, 869, __pyx_L1_error)
  __pyx_tuple__328 = PyTuple_Pack(3, ((PyObject*)__pyx_kp_u__9), ((PyObject *)__pyx_int_0), ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__328)) __PYX_ERR(0, 869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__328);
  __Pyx_GIVEREF(__pyx_tuple__328);

  /* "cPyparsing.pyx":914
 *         return "".join(out)
 * 
 *     def pprint(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Pretty-printer for parsed results as a list, using the C{pprint} module.
 */
  __pyx_tuple__329 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_args, __pyx_n_s_kwargs); if (unlikely(!__pyx_tuple__329)) __PYX_ERR(0, 914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__329);
  __Pyx_GIVEREF(__pyx_tuple__329);
  __pyx_codeobj__330 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, CO_VARARGS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__329, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_pprint, 914, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__330)) __PYX_ERR(0, 914, __pyx_L1_error)

  /* "cPyparsing.pyx":938
 * 
 *     # add support for pickle protocol
 *     def __getstate__(self):             # <<<<<<<<<<<<<<
 *         return (self.__toklist,
 *                 (self.__tokdict.copy(),
 */
  __pyx_tuple__331 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__331)) __PYX_ERR(0, 938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__331);
  __Pyx_GIVEREF(__pyx_tuple__331);
  __pyx_codeobj__332 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__331, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_getstate, 938, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__332)) __PYX_ERR(0, 938, __pyx_L1_error)

  /* "cPyparsing.pyx":945
 *                  self.__name))
 * 
 *     def __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.__toklist = state[0]
 *         (self.__tokdict,
 */
  __pyx_tuple__333 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_state, __pyx_n_s_par, __pyx_n_s_inAccumNames); if (unlikely(!__pyx_tuple__333)) __PYX_ERR(0, 945, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__333);
  __Pyx_GIVEREF(__pyx_tuple__333);
  __pyx_codeobj__334 = (PyObject*)__Pyx_PyCode_New(2, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__333, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_setstate, 945, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__334)) __PYX_ERR(0, 945, __pyx_L1_error)

  /* "cPyparsing.pyx":958
 *             self.__parent = None
 * 
 *     def __getnewargs__(self):             # <<<<<<<<<<<<<<
 *         return self.__toklist, self.__name, self.__asList, self.__modal
 * 
 */
  __pyx_tuple__335 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__335)) __PYX_ERR(0, 958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__335);
  __Pyx_GIVEREF(__pyx_tuple__335);
  __pyx_codeobj__336 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__335, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_getnewargs, 958, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__336)) __PYX_ERR(0, 958, __pyx_L1_error)

  /* "cPyparsing.pyx":961
 *         return self.__toklist, self.__name, self.__asList, self.__modal
 * 
 *     def __dir__(self):             # <<<<<<<<<<<<<<
 *         return (dir(type(self)) + list(self.keys()))
 * 
 */
  __pyx_tuple__337 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__337)) __PYX_ERR(0, 961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__337);
  __Pyx_GIVEREF(__pyx_tuple__337);
  __pyx_codeobj__338 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__337, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_dir, 961, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__338)) __PYX_ERR(0, 961, __pyx_L1_error)

  /* "cPyparsing.pyx":968
 * 
 * 
 * def col(int loc, strg):             # <<<<<<<<<<<<<<
 *     """Returns current column within a string, counting newlines as line separators.
 *     The first column is number 1.
 */
  __pyx_tuple__339 = PyTuple_Pack(3, __pyx_n_s_loc, __pyx_n_s_strg, __pyx_n_s_s); if (unlikely(!__pyx_tuple__339)) __PYX_ERR(0, 968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__339);
  __Pyx_GIVEREF(__pyx_tuple__339);
  __pyx_codeobj__340 = (PyObject*)__Pyx_PyCode_New(2, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__339, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_col, 968, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__340)) __PYX_ERR(0, 968, __pyx_L1_error)

  /* "cPyparsing.pyx":982
 * 
 * 
 * def lineno(int loc, strg):             # <<<<<<<<<<<<<<
 *     """Returns current line number within a string, counting newlines as line separators.
 *     The first line is number 1.
 */
  __pyx_tuple__341 = PyTuple_Pack(2, __pyx_n_s_loc, __pyx_n_s_strg); if (unlikely(!__pyx_tuple__341)) __PYX_ERR(0, 982, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__341);
  __Pyx_GIVEREF(__pyx_tuple__341);
  __pyx_codeobj__342 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__341, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_lineno, 982, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__342)) __PYX_ERR(0, 982, __pyx_L1_error)

  /* "cPyparsing.pyx":995
 * 
 * 
 * def line(int loc, strg):             # <<<<<<<<<<<<<<
 *     """Returns the line of text containing loc within a string, counting newlines as line separators.
 *     """
 */
  __pyx_tuple__343 = PyTuple_Pack(4, __pyx_n_s_loc, __pyx_n_s_strg, __pyx_n_s_lastCR, __pyx_n_s_nextCR); if (unlikely(!__pyx_tuple__343)) __PYX_ERR(0, 995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__343);
  __Pyx_GIVEREF(__pyx_tuple__343);
  __pyx_codeobj__344 = (PyObject*)__Pyx_PyCode_New(2, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__343, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_line, 995, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__344)) __PYX_ERR(0, 995, __pyx_L1_error)

  /* "cPyparsing.pyx":1006
 * 
 * 
 * def _defaultStartDebugAction(instring, loc, expr):             # <<<<<<<<<<<<<<
 *     print(("Match " + _ustr(expr) + " at loc " + _ustr(loc) + "(%d,%d)" % (lineno(loc, instring), col(loc, instring))))
 * 
 */
  __pyx_tuple__345 = PyTuple_Pack(3, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_expr); if (unlikely(!__pyx_tuple__345)) __PYX_ERR(0, 1006, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__345);
  __Pyx_GIVEREF(__pyx_tuple__345);
  __pyx_codeobj__346 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__345, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_defaultStartDebugAction, 1006, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__346)) __PYX_ERR(0, 1006, __pyx_L1_error)

  /* "cPyparsing.pyx":1010
 * 
 * 
 * def _defaultSuccessDebugAction(instring, startloc, endloc, expr, toks):             # <<<<<<<<<<<<<<
 *     print("Matched " + _ustr(expr) + " -> " + str(toks.asList()))
 * 
 */
  __pyx_tuple__347 = PyTuple_Pack(5, __pyx_n_s_instring, __pyx_n_s_startloc, __pyx_n_s_endloc, __pyx_n_s_expr, __pyx_n_s_toks); if (unlikely(!__pyx_tuple__347)) __PYX_ERR(0, 1010, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__347);
  __Pyx_GIVEREF(__pyx_tuple__347);
  __pyx_codeobj__348 = (PyObject*)__Pyx_PyCode_New(5, 0, 5, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__347, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_defaultSuccessDebugAction, 1010, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__348)) __PYX_ERR(0, 1010, __pyx_L1_error)

  /* "cPyparsing.pyx":1014
 * 
 * 
 * def _defaultExceptionDebugAction(instring, loc, expr, exc):             # <<<<<<<<<<<<<<
 *     print("Exception raised:" + _ustr(exc))
 * 
 */
  __pyx_tuple__349 = PyTuple_Pack(4, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_expr, __pyx_n_s_exc); if (unlikely(!__pyx_tuple__349)) __PYX_ERR(0, 1014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__349);
  __Pyx_GIVEREF(__pyx_tuple__349);
  __pyx_codeobj__350 = (PyObject*)__Pyx_PyCode_New(4, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__349, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_defaultExceptionDebugAction, 1014, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__350)) __PYX_ERR(0, 1014, __pyx_L1_error)

  /* "cPyparsing.pyx":1018
 * 
 * 
 * def nullDebugAction(*args):             # <<<<<<<<<<<<<<
 *     """'Do-nothing' debug action, to suppress debugging output during parsing."""
 *     pass
 */
  __pyx_tuple__351 = PyTuple_Pack(1, __pyx_n_s_args); if (unlikely(!__pyx_tuple__351)) __PYX_ERR(0, 1018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__351);
  __Pyx_GIVEREF(__pyx_tuple__351);
  __pyx_codeobj__352 = (PyObject*)__Pyx_PyCode_New(0, 0, 1, 0, CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__351, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_nullDebugAction, 1018, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__352)) __PYX_ERR(0, 1018, __pyx_L1_error)

  /* "cPyparsing.pyx":1023
 * 
 * 
 * def _trim_arity(func, maxargs=2):             # <<<<<<<<<<<<<<
 *     """decorator to trim function calls to match the arity of the target"""
 * 
 */
  __pyx_tuple__353 = PyTuple_Pack(10, __pyx_n_s_func, __pyx_n_s_maxargs, __pyx_n_s_limit, __pyx_n_s_foundArity, __pyx_n_s_extract_tb, __pyx_n_s_extract_tb, __pyx_n_s_tb_info_synth, __pyx_n_s_wrapper, __pyx_n_s_wrapper, __pyx_n_s_func_name); if (unlikely(!__pyx_tuple__353)) __PYX_ERR(0, 1023, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__353);
  __Pyx_GIVEREF(__pyx_tuple__353);
  __pyx_codeobj__354 = (PyObject*)__Pyx_PyCode_New(2, 0, 10, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__353, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_trim_arity, 1023, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__354)) __PYX_ERR(0, 1023, __pyx_L1_error)

  /* "cPyparsing.pyx":1095
 * 
 *     @staticmethod
 *     def setDefaultWhitespaceChars(chars):             # <<<<<<<<<<<<<<
 *         r"""
 *         Overrides the default whitespace chars
 */
  __pyx_tuple__356 = PyTuple_Pack(1, __pyx_n_s_chars); if (unlikely(!__pyx_tuple__356)) __PYX_ERR(0, 1095, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__356);
  __Pyx_GIVEREF(__pyx_tuple__356);
  __pyx_codeobj__357 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__356, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_setDefaultWhitespaceChars, 1095, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__357)) __PYX_ERR(0, 1095, __pyx_L1_error)

  /* "cPyparsing.pyx":1110
 * 
 *     @staticmethod
 *     def inlineLiteralsUsing(cls):             # <<<<<<<<<<<<<<
 *         """
 *         Set class to be used for inclusion of string literals into a parser.
 */
  __pyx_tuple__358 = PyTuple_Pack(1, __pyx_n_s_cls); if (unlikely(!__pyx_tuple__358)) __PYX_ERR(0, 1110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__358);
  __Pyx_GIVEREF(__pyx_tuple__358);
  __pyx_codeobj__359 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__358, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_inlineLiteralsUsing, 1110, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__359)) __PYX_ERR(0, 1110, __pyx_L1_error)

  /* "cPyparsing.pyx":1130
 *         ParserElement._literalStringClass = cls
 * 
 *     def __init__(self, savelist=False):             # <<<<<<<<<<<<<<
 *         self.parseAction = list()
 *         self.failAction = None
 */
  __pyx_tuple__360 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_savelist); if (unlikely(!__pyx_tuple__360)) __PYX_ERR(0, 1130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__360);
  __Pyx_GIVEREF(__pyx_tuple__360);
  __pyx_codeobj__361 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__360, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 1130, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__361)) __PYX_ERR(0, 1130, __pyx_L1_error)
  __pyx_tuple__362 = PyTuple_Pack(1, ((PyObject *)Py_False)); if (unlikely(!__pyx_tuple__362)) __PYX_ERR(0, 1130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__362);
  __Pyx_GIVEREF(__pyx_tuple__362);

  /* "cPyparsing.pyx":1153
 *         self.callDuringTry = False
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         """
 *         Make a copy of this C{ParserElement}.  Useful for defining different parse actions
 */
  __pyx_tuple__363 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_cpy); if (unlikely(!__pyx_tuple__363)) __PYX_ERR(0, 1153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__363);
  __Pyx_GIVEREF(__pyx_tuple__363);
  __pyx_codeobj__364 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__363, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_copy, 1153, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__364)) __PYX_ERR(0, 1153, __pyx_L1_error)

  /* "cPyparsing.pyx":1176
 *         return cpy
 * 
 *     def setName(self, name):             # <<<<<<<<<<<<<<
 *         """
 *         Define name for this expression, makes debugging and exception messages clearer.
 */
  __pyx_tuple__365 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_name); if (unlikely(!__pyx_tuple__365)) __PYX_ERR(0, 1176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__365);
  __Pyx_GIVEREF(__pyx_tuple__365);
  __pyx_codeobj__366 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__365, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_setName, 1176, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__366)) __PYX_ERR(0, 1176, __pyx_L1_error)

  /* "cPyparsing.pyx":1190
 *         return self
 * 
 *     def setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         """
 *         Define name for referencing matching tokens as a nested attribute
 */
  __pyx_tuple__367 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_name, __pyx_n_s_listAllMatches, __pyx_n_s_newself); if (unlikely(!__pyx_tuple__367)) __PYX_ERR(0, 1190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__367);
  __Pyx_GIVEREF(__pyx_tuple__367);
  __pyx_codeobj__368 = (PyObject*)__Pyx_PyCode_New(3, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__367, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_setResultsName, 1190, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__368)) __PYX_ERR(0, 1190, __pyx_L1_error)
  __pyx_tuple__369 = PyTuple_Pack(1, ((PyObject *)Py_False)); if (unlikely(!__pyx_tuple__369)) __PYX_ERR(0, 1190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__369);
  __Pyx_GIVEREF(__pyx_tuple__369);

  /* "cPyparsing.pyx":1218
 *         return newself
 * 
 *     def setBreak(self, breakFlag=True):             # <<<<<<<<<<<<<<
 *         """Method to invoke the Python pdb debugger when this element is
 *            about to be parsed. Set C{breakFlag} to True to enable, False to
 */
  __pyx_tuple__370 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_breakFlag, __pyx_n_s_parseMethod, __pyx_n_s_breaker, __pyx_n_s_breaker); if (unlikely(!__pyx_tuple__370)) __PYX_ERR(0, 1218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__370);
  __Pyx_GIVEREF(__pyx_tuple__370);
  __pyx_codeobj__371 = (PyObject*)__Pyx_PyCode_New(2, 0, 5, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__370, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_setBreak, 1218, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__371)) __PYX_ERR(0, 1218, __pyx_L1_error)
  __pyx_tuple__372 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__372)) __PYX_ERR(0, 1218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__372);
  __Pyx_GIVEREF(__pyx_tuple__372);

  /* "cPyparsing.pyx":1237
 *         return self
 * 
 *     def setParseAction(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Define one or more actions to perform when successfully matching parse element definition.
 */
  __pyx_tuple__373 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_fns, __pyx_n_s_kwargs); if (unlikely(!__pyx_tuple__373)) __PYX_ERR(0, 1237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__373);
  __Pyx_GIVEREF(__pyx_tuple__373);
  __pyx_codeobj__374 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, CO_VARARGS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__373, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_setParseAction, 1237, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__374)) __PYX_ERR(0, 1237, __pyx_L1_error)

  /* "cPyparsing.pyx":1275
 *         return self
 * 
 *     def addParseAction(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Add one or more parse actions to expression's list of parse actions. See L{I{setParseAction}<setParseAction>}.
 */
  __pyx_tuple__375 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_fns, __pyx_n_s_kwargs); if (unlikely(!__pyx_tuple__375)) __PYX_ERR(0, 1275, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__375);
  __Pyx_GIVEREF(__pyx_tuple__375);
  __pyx_codeobj__376 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, CO_VARARGS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__375, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_addParseAction, 1275, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__376)) __PYX_ERR(0, 1275, __pyx_L1_error)

  /* "cPyparsing.pyx":1285
 *         return self
 * 
 *     def addCondition(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """Add a boolean predicate function to expression's list of parse actions. See
 *         L{I{setParseAction}<setParseAction>} for function call signatures. Unlike C{setParseAction},
 */
  __pyx_tuple__377 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_fns, __pyx_n_s_kwargs, __pyx_n_s_msg, __pyx_n_s_exc_type, __pyx_n_s_fn, __pyx_n_s_pa, __pyx_n_s_pa); if (unlikely(!__pyx_tuple__377)) __PYX_ERR(0, 1285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__377);
  __Pyx_GIVEREF(__pyx_tuple__377);
  __pyx_codeobj__378 = (PyObject*)__Pyx_PyCode_New(1, 0, 8, 0, CO_VARARGS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__377, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_addCondition, 1285, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__378)) __PYX_ERR(0, 1285, __pyx_L1_error)

  /* "cPyparsing.pyx":1312
 *         return self
 * 
 *     def setFailAction(self, fn):             # <<<<<<<<<<<<<<
 *         """Define action to perform if parsing fails at this expression.
 *            Fail acton fn is a callable function that takes the arguments
 */
  __pyx_tuple__379 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_fn); if (unlikely(!__pyx_tuple__379)) __PYX_ERR(0, 1312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__379);
  __Pyx_GIVEREF(__pyx_tuple__379);
  __pyx_codeobj__380 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__379, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_setFailAction, 1312, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__380)) __PYX_ERR(0, 1312, __pyx_L1_error)

  /* "cPyparsing.pyx":1325
 *         return self
 * 
 *     def _skipIgnorables(self, instring, loc):             # <<<<<<<<<<<<<<
 *         exprsFound = True
 *         while exprsFound:
 */
  __pyx_tuple__381 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_exprsFound, __pyx_n_s_e, __pyx_n_s_dummy); if (unlikely(!__pyx_tuple__381)) __PYX_ERR(0, 1325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__381);
  __Pyx_GIVEREF(__pyx_tuple__381);
  __pyx_codeobj__382 = (PyObject*)__Pyx_PyCode_New(3, 0, 6, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__381, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_skipIgnorables, 1325, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__382)) __PYX_ERR(0, 1325, __pyx_L1_error)

  /* "cPyparsing.pyx":1338
 *         return loc
 * 
 *     def preParse(self, instring, int loc):             # <<<<<<<<<<<<<<
 *         if self.ignoreExprs:
 *             loc = self._skipIgnorables(instring, loc)
 */
  __pyx_tuple__383 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_wt, __pyx_n_s_instrlen); if (unlikely(!__pyx_tuple__383)) __PYX_ERR(0, 1338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__383);
  __Pyx_GIVEREF(__pyx_tuple__383);
  __pyx_codeobj__384 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__383, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_preParse, 1338, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__384)) __PYX_ERR(0, 1338, __pyx_L1_error)

  /* "cPyparsing.pyx":1350
 *         return loc
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         return loc, []
 * 
 */
  __pyx_tuple__385 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions); if (unlikely(!__pyx_tuple__385)) __PYX_ERR(0, 1350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__385);
  __Pyx_GIVEREF(__pyx_tuple__385);
  __pyx_codeobj__386 = (PyObject*)__Pyx_PyCode_New(4, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__385, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 1350, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__386)) __PYX_ERR(0, 1350, __pyx_L1_error)
  __pyx_tuple__387 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__387)) __PYX_ERR(0, 1350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__387);
  __Pyx_GIVEREF(__pyx_tuple__387);

  /* "cPyparsing.pyx":1353
 *         return loc, []
 * 
 *     def postParse(self, instring, int loc, tokenlist):             # <<<<<<<<<<<<<<
 *         return tokenlist
 * 
 */
  __pyx_tuple__388 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_tokenlist); if (unlikely(!__pyx_tuple__388)) __PYX_ERR(0, 1353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__388);
  __Pyx_GIVEREF(__pyx_tuple__388);
  __pyx_codeobj__389 = (PyObject*)__Pyx_PyCode_New(4, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__388, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_postParse, 1353, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__389)) __PYX_ERR(0, 1353, __pyx_L1_error)

  /* "cPyparsing.pyx":1357
 * 
 *     #~ @profile
 *     def _parseNoCache(self, instring, int loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *         debugging = (self.debug)  # and doActions )
 * 
 */
  __pyx_tuple__390 = PyTuple_Pack(12, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_callPreParse, __pyx_n_s_debugging, __pyx_n_s_preloc, __pyx_n_s_tokensStart, __pyx_n_s_tokens, __pyx_n_s_err, __pyx_n_s_retTokens, __pyx_n_s_fn); if (unlikely(!__pyx_tuple__390)) __PYX_ERR(0, 1357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__390);
  __Pyx_GIVEREF(__pyx_tuple__390);
  __pyx_codeobj__391 = (PyObject*)__Pyx_PyCode_New(5, 0, 12, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__390, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseNoCache, 1357, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__391)) __PYX_ERR(0, 1357, __pyx_L1_error)
  __pyx_tuple__392 = PyTuple_Pack(2, ((PyObject *)Py_True), ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__392)) __PYX_ERR(0, 1357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__392);
  __Pyx_GIVEREF(__pyx_tuple__392);

  /* "cPyparsing.pyx":1429
 *         return loc, retTokens
 * 
 *     def tryParse(self, instring, int loc):             # <<<<<<<<<<<<<<
 *         try:
 *             return self._parse(instring, loc, doActions=False)[0]
 */
  __pyx_tuple__393 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc); if (unlikely(!__pyx_tuple__393)) __PYX_ERR(0, 1429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__393);
  __Pyx_GIVEREF(__pyx_tuple__393);
  __pyx_codeobj__394 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__393, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_tryParse, 1429, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__394)) __PYX_ERR(0, 1429, __pyx_L1_error)

  /* "cPyparsing.pyx":1435
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *     def canParseNext(self, instring, int loc):             # <<<<<<<<<<<<<<
 *         try:
 *             self.tryParse(instring, loc)
 */
  __pyx_tuple__395 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc); if (unlikely(!__pyx_tuple__395)) __PYX_ERR(0, 1435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__395);
  __Pyx_GIVEREF(__pyx_tuple__395);
  __pyx_codeobj__396 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__395, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_canParseNext, 1435, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__396)) __PYX_ERR(0, 1435, __pyx_L1_error)

  /* "cPyparsing.pyx":1444
 * 
 *     class _UnboundedCache(object):
 *         def __init__(self):             # <<<<<<<<<<<<<<
 *             cache = {}
 *             self.not_in_cache = not_in_cache = object()
 */
  __pyx_tuple__397 = PyTuple_Pack(11, __pyx_n_s_self, __pyx_n_s_cache, __pyx_n_s_not_in_cache, __pyx_n_s_get, __pyx_n_s_get, __pyx_n_s_set, __pyx_n_s_set, __pyx_n_s_clear, __pyx_n_s_clear, __pyx_n_s_cache_len, __pyx_n_s_cache_len); if (unlikely(!__pyx_tuple__397)) __PYX_ERR(0, 1444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__397);
  __Pyx_GIVEREF(__pyx_tuple__397);
  __pyx_codeobj__398 = (PyObject*)__Pyx_PyCode_New(1, 0, 11, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__397, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 1444, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__398)) __PYX_ERR(0, 1444, __pyx_L1_error)

  /* "cPyparsing.pyx":1467
 *     if _OrderedDict is not None:
 *         class _FifoCache(object):
 *             def __init__(self, size):             # <<<<<<<<<<<<<<
 *                 self.not_in_cache = not_in_cache = object()
 * 
 */
  __pyx_tuple__399 = PyTuple_Pack(12, __pyx_n_s_self, __pyx_n_s_size, __pyx_n_s_not_in_cache, __pyx_n_s_cache, __pyx_n_s_get, __pyx_n_s_get, __pyx_n_s_set, __pyx_n_s_set, __pyx_n_s_clear, __pyx_n_s_clear, __pyx_n_s_cache_len, __pyx_n_s_cache_len); if (unlikely(!__pyx_tuple__399)) __PYX_ERR(0, 1467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__399);
  __Pyx_GIVEREF(__pyx_tuple__399);
  __pyx_codeobj__400 = (PyObject*)__Pyx_PyCode_New(2, 0, 12, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__399, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 1467, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__400)) __PYX_ERR(0, 1467, __pyx_L1_error)

  /* "cPyparsing.pyx":1496
 *     else:
 *         class _FifoCache(object):
 *             def __init__(self, size):             # <<<<<<<<<<<<<<
 *                 self.not_in_cache = not_in_cache = object()
 * 
 */
  __pyx_tuple__401 = PyTuple_Pack(13, __pyx_n_s_self, __pyx_n_s_size, __pyx_n_s_not_in_cache, __pyx_n_s_cache, __pyx_n_s_key_fifo, __pyx_n_s_get, __pyx_n_s_get, __pyx_n_s_set, __pyx_n_s_set, __pyx_n_s_clear, __pyx_n_s_clear, __pyx_n_s_cache_len, __pyx_n_s_cache_len); if (unlikely(!__pyx_tuple__401)) __PYX_ERR(0, 1496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__401);
  __Pyx_GIVEREF(__pyx_tuple__401);
  __pyx_codeobj__402 = (PyObject*)__Pyx_PyCode_New(2, 0, 13, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__401, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 1496, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__402)) __PYX_ERR(0, 1496, __pyx_L1_error)

  /* "cPyparsing.pyx":1530
 *     # this method gets repeatedly called during backtracking with the same arguments -
 *     # we can cache these arguments and save ourselves the trouble of re-parsing the contained expression
 *     def _parseCache(self, instring, int loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *         HIT, MISS = 0, 1
 *         lookup = (self, instring, loc, callPreParse, doActions)
 */
  __pyx_tuple__403 = PyTuple_Pack(11, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_callPreParse, __pyx_n_s_HIT, __pyx_n_s_MISS, __pyx_n_s_lookup_2, __pyx_n_s_cache, __pyx_n_s_value, __pyx_n_s_pe); if (unlikely(!__pyx_tuple__403)) __PYX_ERR(0, 1530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__403);
  __Pyx_GIVEREF(__pyx_tuple__403);
  __pyx_codeobj__404 = (PyObject*)__Pyx_PyCode_New(5, 0, 11, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__403, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseCache, 1530, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__404)) __PYX_ERR(0, 1530, __pyx_L1_error)
  __pyx_tuple__405 = PyTuple_Pack(2, ((PyObject *)Py_True), ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__405)) __PYX_ERR(0, 1530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__405);
  __Pyx_GIVEREF(__pyx_tuple__405);

  /* "cPyparsing.pyx":1556
 * 
 *     @staticmethod
 *     def resetCache():             # <<<<<<<<<<<<<<
 *         ParserElement.packrat_cache.clear()
 *         ParserElement.packrat_cache_stats[:] = [0] * len(ParserElement.packrat_cache_stats)
 */
  __pyx_codeobj__406 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_resetCache, 1556, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__406)) __PYX_ERR(0, 1556, __pyx_L1_error)

  /* "cPyparsing.pyx":1563
 * 
 *     @staticmethod
 *     def enablePackrat(cache_size_limit=128):             # <<<<<<<<<<<<<<
 *         """Enables "packrat" parsing, which adds memoizing to the parsing logic.
 *            Repeated parse attempts at the same string location (which happens
 */
  __pyx_tuple__407 = PyTuple_Pack(1, __pyx_n_s_cache_size_limit); if (unlikely(!__pyx_tuple__407)) __PYX_ERR(0, 1563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__407);
  __Pyx_GIVEREF(__pyx_tuple__407);
  __pyx_codeobj__408 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__407, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_enablePackrat, 1563, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__408)) __PYX_ERR(0, 1563, __pyx_L1_error)
  __pyx_tuple__409 = PyTuple_Pack(1, ((PyObject *)__pyx_int_128)); if (unlikely(!__pyx_tuple__409)) __PYX_ERR(0, 1563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__409);
  __Pyx_GIVEREF(__pyx_tuple__409);

  /* "cPyparsing.pyx":1597
 *             ParserElement._parse = ParserElement._parseCache
 * 
 *     def parseString(self, instring, parseAll=False):             # <<<<<<<<<<<<<<
 *         """
 *         Execute the parse expression with the given string.
 */
  __pyx_tuple__410 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_parseAll, __pyx_n_s_e, __pyx_n_s_loc, __pyx_n_s_tokens, __pyx_n_s_se, __pyx_n_s_exc); if (unlikely(!__pyx_tuple__410)) __PYX_ERR(0, 1597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__410);
  __Pyx_GIVEREF(__pyx_tuple__410);
  __pyx_codeobj__411 = (PyObject*)__Pyx_PyCode_New(3, 0, 8, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__410, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseString, 1597, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__411)) __PYX_ERR(0, 1597, __pyx_L1_error)
  __pyx_tuple__412 = PyTuple_Pack(1, ((PyObject *)Py_False)); if (unlikely(!__pyx_tuple__412)) __PYX_ERR(0, 1597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__412);
  __Pyx_GIVEREF(__pyx_tuple__412);

  /* "cPyparsing.pyx":1647
 *             return tokens
 * 
 *     def scanString(self, instring, maxMatches=_MAX_INT, overlap=False):             # <<<<<<<<<<<<<<
 *         """
 *         Scan the input string for expression matches.  Each match will return the
 */
  __pyx_tuple__413 = PyTuple_Pack(15, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_maxMatches, __pyx_n_s_overlap, __pyx_n_s_e, __pyx_n_s_instrlen, __pyx_n_s_loc, __pyx_n_s_preparseFn, __pyx_n_s_parseFn, __pyx_n_s_matches, __pyx_n_s_preloc, __pyx_n_s_nextLoc, __pyx_n_s_tokens, __pyx_n_s_nextloc, __pyx_n_s_exc); if (unlikely(!__pyx_tuple__413)) __PYX_ERR(0, 1647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__413);
  __Pyx_GIVEREF(__pyx_tuple__413);
  __pyx_codeobj__414 = (PyObject*)__Pyx_PyCode_New(4, 0, 15, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__413, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_scanString, 1647, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__414)) __PYX_ERR(0, 1647, __pyx_L1_error)

  /* "cPyparsing.pyx":1718
 *                 raise exc
 * 
 *     def transformString(self, instring):             # <<<<<<<<<<<<<<
 *         """
 *         Extension to C{L{scanString}}, to modify matching text with modified tokens that may
 */
  __pyx_tuple__415 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_out, __pyx_n_s_lastE, __pyx_n_s_t, __pyx_n_s_s, __pyx_n_s_e, __pyx_n_s_exc); if (unlikely(!__pyx_tuple__415)) __PYX_ERR(0, 1718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__415);
  __Pyx_GIVEREF(__pyx_tuple__415);
  __pyx_codeobj__416 = (PyObject*)__Pyx_PyCode_New(2, 0, 8, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__415, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_transformString, 1718, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__416)) __PYX_ERR(0, 1718, __pyx_L1_error)

  /* "cPyparsing.pyx":1761
 *                 raise exc
 * 
 *     def searchString(self, instring, maxMatches=_MAX_INT):             # <<<<<<<<<<<<<<
 *         """
 *         Another extension to C{L{scanString}}, simplifying the access to the tokens found
 */
  __pyx_tuple__417 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_maxMatches, __pyx_n_s_exc); if (unlikely(!__pyx_tuple__417)) __PYX_ERR(0, 1761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__417);
  __Pyx_GIVEREF(__pyx_tuple__417);
  __pyx_codeobj__418 = (PyObject*)__Pyx_PyCode_New(3, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__417, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_searchString, 1761, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__418)) __PYX_ERR(0, 1761, __pyx_L1_error)

  /* "cPyparsing.pyx":1788
 *                 raise exc
 * 
 *     def split(self, instring, maxsplit=_MAX_INT, includeSeparators=False):             # <<<<<<<<<<<<<<
 *         """
 *         Generator method to split a string using the given expression as a separator.
 */
  __pyx_tuple__419 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_maxsplit, __pyx_n_s_includeSeparators, __pyx_n_s_splits, __pyx_n_s_last, __pyx_n_s_t, __pyx_n_s_s, __pyx_n_s_e); if (unlikely(!__pyx_tuple__419)) __PYX_ERR(0, 1788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__419);
  __Pyx_GIVEREF(__pyx_tuple__419);
  __pyx_codeobj__420 = (PyObject*)__Pyx_PyCode_New(4, 0, 9, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__419, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_split, 1788, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__420)) __PYX_ERR(0, 1788, __pyx_L1_error)

  /* "cPyparsing.pyx":1810
 *         yield instring[last:]
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of + operator - returns C{L{And}}. Adding strings to a ParserElement
 */
  __pyx_tuple__421 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__421)) __PYX_ERR(0, 1810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__421);
  __Pyx_GIVEREF(__pyx_tuple__421);
  __pyx_codeobj__422 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__421, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_add, 1810, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__422)) __PYX_ERR(0, 1810, __pyx_L1_error)

  /* "cPyparsing.pyx":1830
 *         return And([self, other])
 * 
 *     def __radd__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of + operator when left operand is not a C{L{ParserElement}}
 */
  __pyx_tuple__423 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__423)) __PYX_ERR(0, 1830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__423);
  __Pyx_GIVEREF(__pyx_tuple__423);
  __pyx_codeobj__424 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__423, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_radd, 1830, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__424)) __PYX_ERR(0, 1830, __pyx_L1_error)

  /* "cPyparsing.pyx":1842
 *         return other + self
 * 
 *     def __sub__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of - operator, returns C{L{And}} with error stop
 */
  __pyx_tuple__425 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__425)) __PYX_ERR(0, 1842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__425);
  __Pyx_GIVEREF(__pyx_tuple__425);
  __pyx_codeobj__426 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__425, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_sub_2, 1842, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__426)) __PYX_ERR(0, 1842, __pyx_L1_error)

  /* "cPyparsing.pyx":1854
 *         return self + And._ErrorStop() + other
 * 
 *     def __rsub__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of - operator when left operand is not a C{L{ParserElement}}
 */
  __pyx_tuple__427 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__427)) __PYX_ERR(0, 1854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__427);
  __Pyx_GIVEREF(__pyx_tuple__427);
  __pyx_codeobj__428 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__427, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_rsub, 1854, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__428)) __PYX_ERR(0, 1854, __pyx_L1_error)

  /* "cPyparsing.pyx":1866
 *         return other - self
 * 
 *     def __mul__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of * operator, allows use of C{expr * 3} in place of
 */
  __pyx_tuple__429 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_minElements, __pyx_n_s_optElements, __pyx_n_s_makeOptionalList, __pyx_n_s_makeOptionalList, __pyx_n_s_ret); if (unlikely(!__pyx_tuple__429)) __PYX_ERR(0, 1866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__429);
  __Pyx_GIVEREF(__pyx_tuple__429);
  __pyx_codeobj__430 = (PyObject*)__Pyx_PyCode_New(2, 0, 7, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__429, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_mul, 1866, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__430)) __PYX_ERR(0, 1866, __pyx_L1_error)

  /* "cPyparsing.pyx":1934
 *         return ret
 * 
 *     def __rmul__(self, other):             # <<<<<<<<<<<<<<
 *         return self.__mul__(other)
 * 
 */
  __pyx_tuple__431 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__431)) __PYX_ERR(0, 1934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__431);
  __Pyx_GIVEREF(__pyx_tuple__431);
  __pyx_codeobj__432 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__431, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_rmul, 1934, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__432)) __PYX_ERR(0, 1934, __pyx_L1_error)

  /* "cPyparsing.pyx":1937
 *         return self.__mul__(other)
 * 
 *     def __or__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of | operator - returns C{L{MatchFirst}}
 */
  __pyx_tuple__433 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__433)) __PYX_ERR(0, 1937, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__433);
  __Pyx_GIVEREF(__pyx_tuple__433);
  __pyx_codeobj__434 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__433, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_or, 1937, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__434)) __PYX_ERR(0, 1937, __pyx_L1_error)

  /* "cPyparsing.pyx":1949
 *         return MatchFirst([self, other])
 * 
 *     def __ror__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of | operator when left operand is not a C{L{ParserElement}}
 */
  __pyx_tuple__435 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__435)) __PYX_ERR(0, 1949, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__435);
  __Pyx_GIVEREF(__pyx_tuple__435);
  __pyx_codeobj__436 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__435, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_ror, 1949, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__436)) __PYX_ERR(0, 1949, __pyx_L1_error)

  /* "cPyparsing.pyx":1961
 *         return other | self
 * 
 *     def __xor__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of ^ operator - returns C{L{Or}}
 */
  __pyx_tuple__437 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__437)) __PYX_ERR(0, 1961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__437);
  __Pyx_GIVEREF(__pyx_tuple__437);
  __pyx_codeobj__438 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__437, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_xor, 1961, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__438)) __PYX_ERR(0, 1961, __pyx_L1_error)

  /* "cPyparsing.pyx":1973
 *         return Or([self, other])
 * 
 *     def __rxor__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of ^ operator when left operand is not a C{L{ParserElement}}
 */
  __pyx_tuple__439 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__439)) __PYX_ERR(0, 1973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__439);
  __Pyx_GIVEREF(__pyx_tuple__439);
  __pyx_codeobj__440 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__439, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_rxor, 1973, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__440)) __PYX_ERR(0, 1973, __pyx_L1_error)

  /* "cPyparsing.pyx":1985
 *         return other ^ self
 * 
 *     def __and__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of & operator - returns C{L{Each}}
 */
  __pyx_tuple__441 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__441)) __PYX_ERR(0, 1985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__441);
  __Pyx_GIVEREF(__pyx_tuple__441);
  __pyx_codeobj__442 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__441, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_and, 1985, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__442)) __PYX_ERR(0, 1985, __pyx_L1_error)

  /* "cPyparsing.pyx":1997
 *         return Each([self, other])
 * 
 *     def __rand__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of & operator when left operand is not a C{L{ParserElement}}
 */
  __pyx_tuple__443 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__443)) __PYX_ERR(0, 1997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__443);
  __Pyx_GIVEREF(__pyx_tuple__443);
  __pyx_codeobj__444 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__443, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_rand, 1997, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__444)) __PYX_ERR(0, 1997, __pyx_L1_error)

  /* "cPyparsing.pyx":2009
 *         return other & self
 * 
 *     def __invert__(self):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of ~ operator - returns C{L{NotAny}}
 */
  __pyx_tuple__445 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__445)) __PYX_ERR(0, 2009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__445);
  __Pyx_GIVEREF(__pyx_tuple__445);
  __pyx_codeobj__446 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__445, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_invert, 2009, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__446)) __PYX_ERR(0, 2009, __pyx_L1_error)

  /* "cPyparsing.pyx":2015
 *         return NotAny(self)
 * 
 *     def __call__(self, name=None):             # <<<<<<<<<<<<<<
 *         """
 *         Shortcut for C{L{setResultsName}}, with C{listAllMatches=False}.
 */
  __pyx_tuple__447 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_name); if (unlikely(!__pyx_tuple__447)) __PYX_ERR(0, 2015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__447);
  __Pyx_GIVEREF(__pyx_tuple__447);
  __pyx_codeobj__448 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__447, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_call, 2015, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__448)) __PYX_ERR(0, 2015, __pyx_L1_error)
  __pyx_tuple__449 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__449)) __PYX_ERR(0, 2015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__449);
  __Pyx_GIVEREF(__pyx_tuple__449);

  /* "cPyparsing.pyx":2034
 *             return self.copy()
 * 
 *     def suppress(self):             # <<<<<<<<<<<<<<
 *         """
 *         Suppresses the output of this C{ParserElement}; useful to keep punctuation from
 */
  __pyx_tuple__450 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__450)) __PYX_ERR(0, 2034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__450);
  __Pyx_GIVEREF(__pyx_tuple__450);
  __pyx_codeobj__451 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__450, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_suppress, 2034, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__451)) __PYX_ERR(0, 2034, __pyx_L1_error)

  /* "cPyparsing.pyx":2041
 *         return Suppress(self)
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         """
 *         Disables the skipping of whitespace before matching the characters in the
 */
  __pyx_tuple__452 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__452)) __PYX_ERR(0, 2041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__452);
  __Pyx_GIVEREF(__pyx_tuple__452);
  __pyx_codeobj__453 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__452, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_leaveWhitespace, 2041, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__453)) __PYX_ERR(0, 2041, __pyx_L1_error)

  /* "cPyparsing.pyx":2050
 *         return self
 * 
 *     def setWhitespaceChars(self, chars):             # <<<<<<<<<<<<<<
 *         """
 *         Overrides the default whitespace chars
 */
  __pyx_tuple__454 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_chars); if (unlikely(!__pyx_tuple__454)) __PYX_ERR(0, 2050, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__454);
  __Pyx_GIVEREF(__pyx_tuple__454);
  __pyx_codeobj__455 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__454, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_setWhitespaceChars, 2050, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__455)) __PYX_ERR(0, 2050, __pyx_L1_error)

  /* "cPyparsing.pyx":2059
 *         return self
 * 
 *     def parseWithTabs(self):             # <<<<<<<<<<<<<<
 *         """
 *         Overrides default behavior to expand C{<TAB>}s to spaces before parsing the input string.
 */
  __pyx_tuple__456 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__456)) __PYX_ERR(0, 2059, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__456);
  __Pyx_GIVEREF(__pyx_tuple__456);
  __pyx_codeobj__457 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__456, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseWithTabs, 2059, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__457)) __PYX_ERR(0, 2059, __pyx_L1_error)

  /* "cPyparsing.pyx":2068
 *         return self
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Define expression to be ignored (e.g., comments) while doing pattern
 */
  __pyx_tuple__458 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__458)) __PYX_ERR(0, 2068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__458);
  __Pyx_GIVEREF(__pyx_tuple__458);
  __pyx_codeobj__459 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__458, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_ignore, 2068, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__459)) __PYX_ERR(0, 2068, __pyx_L1_error)

  /* "cPyparsing.pyx":2091
 *         return self
 * 
 *     def setDebugActions(self, startAction, successAction, exceptionAction):             # <<<<<<<<<<<<<<
 *         """
 *         Enable display of debugging messages while doing pattern matching.
 */
  __pyx_tuple__460 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_startAction, __pyx_n_s_successAction, __pyx_n_s_exceptionAction); if (unlikely(!__pyx_tuple__460)) __PYX_ERR(0, 2091, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__460);
  __Pyx_GIVEREF(__pyx_tuple__460);
  __pyx_codeobj__461 = (PyObject*)__Pyx_PyCode_New(4, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__460, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_setDebugActions, 2091, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__461)) __PYX_ERR(0, 2091, __pyx_L1_error)

  /* "cPyparsing.pyx":2101
 *         return self
 * 
 *     def setDebug(self, flag=True):             # <<<<<<<<<<<<<<
 *         """
 *         Enable display of debugging messages while doing pattern matching.
 */
  __pyx_tuple__462 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_flag); if (unlikely(!__pyx_tuple__462)) __PYX_ERR(0, 2101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__462);
  __Pyx_GIVEREF(__pyx_tuple__462);
  __pyx_codeobj__463 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__462, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_setDebug, 2101, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__463)) __PYX_ERR(0, 2101, __pyx_L1_error)
  __pyx_tuple__464 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__464)) __PYX_ERR(0, 2101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__464);
  __Pyx_GIVEREF(__pyx_tuple__464);

  /* "cPyparsing.pyx":2142
 *         return self
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return self.name
 * 
 */
  __pyx_tuple__465 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__465)) __PYX_ERR(0, 2142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__465);
  __Pyx_GIVEREF(__pyx_tuple__465);
  __pyx_codeobj__466 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__465, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_str_2, 2142, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__466)) __PYX_ERR(0, 2142, __pyx_L1_error)

  /* "cPyparsing.pyx":2145
 *         return self.name
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return _ustr(self)
 * 
 */
  __pyx_tuple__467 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__467)) __PYX_ERR(0, 2145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__467);
  __Pyx_GIVEREF(__pyx_tuple__467);
  __pyx_codeobj__468 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__467, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_repr_3, 2145, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__468)) __PYX_ERR(0, 2145, __pyx_L1_error)

  /* "cPyparsing.pyx":2148
 *         return _ustr(self)
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         self.streamlined = True
 *         self.strRepr = None
 */
  __pyx_tuple__469 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__469)) __PYX_ERR(0, 2148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__469);
  __Pyx_GIVEREF(__pyx_tuple__469);
  __pyx_codeobj__470 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__469, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_streamline, 2148, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__470)) __PYX_ERR(0, 2148, __pyx_L1_error)

  /* "cPyparsing.pyx":2153
 *         return self
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         pass
 * 
 */
  __pyx_tuple__471 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_parseElementList); if (unlikely(!__pyx_tuple__471)) __PYX_ERR(0, 2153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__471);
  __Pyx_GIVEREF(__pyx_tuple__471);
  __pyx_codeobj__472 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__471, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_checkRecursion, 2153, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__472)) __PYX_ERR(0, 2153, __pyx_L1_error)

  /* "cPyparsing.pyx":2156
 *         pass
 * 
 *     def validate(self, validateTrace=[]):             # <<<<<<<<<<<<<<
 *         """
 *         Check defined expressions for valid structure, check for infinite recursive definitions.
 */
  __pyx_tuple__473 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_validateTrace); if (unlikely(!__pyx_tuple__473)) __PYX_ERR(0, 2156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__473);
  __Pyx_GIVEREF(__pyx_tuple__473);
  __pyx_codeobj__474 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__473, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_validate, 2156, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__474)) __PYX_ERR(0, 2156, __pyx_L1_error)

  /* "cPyparsing.pyx":2162
 *         self.checkRecursion([])
 * 
 *     def parseFile(self, file_or_filename, parseAll=False):             # <<<<<<<<<<<<<<
 *         """
 *         Execute the parse expression on the given file or filename.
 */
  __pyx_tuple__475 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_file_or_filename, __pyx_n_s_parseAll, __pyx_n_s_file_contents, __pyx_n_s_f_2, __pyx_n_s_exc); if (unlikely(!__pyx_tuple__475)) __PYX_ERR(0, 2162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__475);
  __Pyx_GIVEREF(__pyx_tuple__475);
  __pyx_codeobj__476 = (PyObject*)__Pyx_PyCode_New(3, 0, 6, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__475, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseFile, 2162, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__476)) __PYX_ERR(0, 2162, __pyx_L1_error)
  __pyx_tuple__477 = PyTuple_Pack(1, ((PyObject *)Py_False)); if (unlikely(!__pyx_tuple__477)) __PYX_ERR(0, 2162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__477);
  __Pyx_GIVEREF(__pyx_tuple__477);

  /* "cPyparsing.pyx":2182
 *                 raise exc
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, ParserElement):
 *             return self is other or vars(self) == vars(other)
 */
  __pyx_tuple__478 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__478)) __PYX_ERR(0, 2182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__478);
  __Pyx_GIVEREF(__pyx_tuple__478);
  __pyx_codeobj__479 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__478, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_eq, 2182, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__479)) __PYX_ERR(0, 2182, __pyx_L1_error)

  /* "cPyparsing.pyx":2190
 *             return super(ParserElement, self) == other
 * 
 *     def __ne__(self, other):             # <<<<<<<<<<<<<<
 *         return not (self == other)
 * 
 */
  __pyx_tuple__480 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__480)) __PYX_ERR(0, 2190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__480);
  __Pyx_GIVEREF(__pyx_tuple__480);
  __pyx_codeobj__481 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__480, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_ne, 2190, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__481)) __PYX_ERR(0, 2190, __pyx_L1_error)

  /* "cPyparsing.pyx":2193
 *         return not (self == other)
 * 
 *     def __hash__(self):             # <<<<<<<<<<<<<<
 *         return hash(id(self))
 * 
 */
  __pyx_tuple__482 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__482)) __PYX_ERR(0, 2193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__482);
  __Pyx_GIVEREF(__pyx_tuple__482);
  __pyx_codeobj__483 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__482, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_hash, 2193, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__483)) __PYX_ERR(0, 2193, __pyx_L1_error)

  /* "cPyparsing.pyx":2196
 *         return hash(id(self))
 * 
 *     def __req__(self, other):             # <<<<<<<<<<<<<<
 *         return self == other
 * 
 */
  __pyx_tuple__484 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__484)) __PYX_ERR(0, 2196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__484);
  __Pyx_GIVEREF(__pyx_tuple__484);
  __pyx_codeobj__485 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__484, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_req, 2196, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__485)) __PYX_ERR(0, 2196, __pyx_L1_error)

  /* "cPyparsing.pyx":2199
 *         return self == other
 * 
 *     def __rne__(self, other):             # <<<<<<<<<<<<<<
 *         return not (self == other)
 * 
 */
  __pyx_tuple__486 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__486)) __PYX_ERR(0, 2199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__486);
  __Pyx_GIVEREF(__pyx_tuple__486);
  __pyx_codeobj__487 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__486, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_rne, 2199, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__487)) __PYX_ERR(0, 2199, __pyx_L1_error)

  /* "cPyparsing.pyx":2202
 *         return not (self == other)
 * 
 *     def matches(self, testString, parseAll=True):             # <<<<<<<<<<<<<<
 *         """
 *         Method for quick testing of a parser against a test string. Good for simple
 */
  __pyx_tuple__488 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_testString, __pyx_n_s_parseAll); if (unlikely(!__pyx_tuple__488)) __PYX_ERR(0, 2202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__488);
  __Pyx_GIVEREF(__pyx_tuple__488);
  __pyx_codeobj__489 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__488, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_matches, 2202, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__489)) __PYX_ERR(0, 2202, __pyx_L1_error)
  __pyx_tuple__490 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__490)) __PYX_ERR(0, 2202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__490);
  __Pyx_GIVEREF(__pyx_tuple__490);

  /* "cPyparsing.pyx":2221
 *             return False
 * 
 *     def runTests(self, tests, parseAll=True, comment='#', fullDump=True, printResults=True, failureTests=False):             # <<<<<<<<<<<<<<
 *         """
 *         Execute the parse expression on a series of test strings, showing each
 */
  __pyx_tuple__491 = PyTuple_Pack(16, __pyx_n_s_self, __pyx_n_s_tests, __pyx_n_s_parseAll, __pyx_n_s_comment, __pyx_n_s_fullDump, __pyx_n_s_printResults, __pyx_n_s_failureTests, __pyx_n_s_allResults, __pyx_n_s_comments, __pyx_n_s_success, __pyx_n_s_t, __pyx_n_s_out, __pyx_n_s_result, __pyx_n_s_pe, __pyx_n_s_fatal, __pyx_n_s_exc); if (unlikely(!__pyx_tuple__491)) __PYX_ERR(0, 2221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__491);
  __Pyx_GIVEREF(__pyx_tuple__491);
  __pyx_codeobj__492 = (PyObject*)__Pyx_PyCode_New(7, 0, 16, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__491, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_runTests, 2221, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__492)) __PYX_ERR(0, 2221, __pyx_L1_error)
  __pyx_tuple__493 = PyTuple_Pack(5, ((PyObject *)Py_True), ((PyObject*)__pyx_kp_u__82), ((PyObject *)Py_True), ((PyObject *)Py_True), ((PyObject *)Py_False)); if (unlikely(!__pyx_tuple__493)) __PYX_ERR(0, 2221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__493);
  __Pyx_GIVEREF(__pyx_tuple__493);

  /* "cPyparsing.pyx":2358
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(Token, self).__init__(savelist=False)
 * 
 */
  __pyx_tuple__494 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__494)) __PYX_ERR(0, 2358, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__494);
  __Pyx_GIVEREF(__pyx_tuple__494);
  __pyx_codeobj__495 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__494, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 2358, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__495)) __PYX_ERR(0, 2358, __pyx_L1_error)

  /* "cPyparsing.pyx":2367
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(Empty, self).__init__()
 *         self.name = "Empty"
 */
  __pyx_tuple__496 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__496)) __PYX_ERR(0, 2367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__496);
  __Pyx_GIVEREF(__pyx_tuple__496);
  __pyx_codeobj__497 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__496, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 2367, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__497)) __PYX_ERR(0, 2367, __pyx_L1_error)

  /* "cPyparsing.pyx":2379
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(NoMatch, self).__init__()
 *         self.name = "NoMatch"
 */
  __pyx_tuple__498 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__498)) __PYX_ERR(0, 2379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__498);
  __Pyx_GIVEREF(__pyx_tuple__498);
  __pyx_codeobj__499 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__498, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 2379, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__499)) __PYX_ERR(0, 2379, __pyx_L1_error)

  /* "cPyparsing.pyx":2386
 *         self.errmsg = "Unmatchable token"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  __pyx_tuple__500 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions); if (unlikely(!__pyx_tuple__500)) __PYX_ERR(0, 2386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__500);
  __Pyx_GIVEREF(__pyx_tuple__500);
  __pyx_codeobj__501 = (PyObject*)__Pyx_PyCode_New(4, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__500, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 2386, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__501)) __PYX_ERR(0, 2386, __pyx_L1_error)
  __pyx_tuple__502 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__502)) __PYX_ERR(0, 2386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__502);
  __Pyx_GIVEREF(__pyx_tuple__502);

  /* "cPyparsing.pyx":2405
 *     """
 * 
 *     def __init__(self, matchString):             # <<<<<<<<<<<<<<
 *         super(Literal, self).__init__()
 *         self.match = matchString
 */
  __pyx_tuple__503 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_matchString); if (unlikely(!__pyx_tuple__503)) __PYX_ERR(0, 2405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__503);
  __Pyx_GIVEREF(__pyx_tuple__503);
  __pyx_codeobj__504 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__503, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 2405, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__504)) __PYX_ERR(0, 2405, __pyx_L1_error)

  /* "cPyparsing.pyx":2424
 *     # short-circuit as quickly as possible, and avoid calling startswith
 *     #~ @profile
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if (instring[loc] == self.firstMatchChar and
 *                 (self.matchLen == 1 or instring.startswith(self.match, loc))):
 */
  __pyx_tuple__505 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions); if (unlikely(!__pyx_tuple__505)) __PYX_ERR(0, 2424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__505);
  __Pyx_GIVEREF(__pyx_tuple__505);
  __pyx_codeobj__506 = (PyObject*)__Pyx_PyCode_New(4, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__505, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 2424, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__506)) __PYX_ERR(0, 2424, __pyx_L1_error)
  __pyx_tuple__507 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__507)) __PYX_ERR(0, 2424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__507);
  __Pyx_GIVEREF(__pyx_tuple__507);

  /* "cPyparsing.pyx":2454
 *     DEFAULT_KEYWORD_CHARS = alphanums + "_$"
 * 
 *     def __init__(self, matchString, identChars=None, caseless=False):             # <<<<<<<<<<<<<<
 *         super(Keyword, self).__init__()
 *         if identChars is None:
 */
  __pyx_tuple__509 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_matchString, __pyx_n_s_identChars, __pyx_n_s_caseless); if (unlikely(!__pyx_tuple__509)) __PYX_ERR(0, 2454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__509);
  __Pyx_GIVEREF(__pyx_tuple__509);
  __pyx_codeobj__510 = (PyObject*)__Pyx_PyCode_New(4, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__509, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 2454, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__510)) __PYX_ERR(0, 2454, __pyx_L1_error)
  __pyx_tuple__511 = PyTuple_Pack(2, ((PyObject *)Py_None), ((PyObject *)Py_False)); if (unlikely(!__pyx_tuple__511)) __PYX_ERR(0, 2454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__511);
  __Pyx_GIVEREF(__pyx_tuple__511);

  /* "cPyparsing.pyx":2475
 *         self.identChars = set(identChars)
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.caseless:
 *             if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch) and
 */
  __pyx_tuple__512 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions); if (unlikely(!__pyx_tuple__512)) __PYX_ERR(0, 2475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__512);
  __Pyx_GIVEREF(__pyx_tuple__512);
  __pyx_codeobj__513 = (PyObject*)__Pyx_PyCode_New(4, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__512, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 2475, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__513)) __PYX_ERR(0, 2475, __pyx_L1_error)
  __pyx_tuple__514 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__514)) __PYX_ERR(0, 2475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__514);
  __Pyx_GIVEREF(__pyx_tuple__514);

  /* "cPyparsing.pyx":2489
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         c = super(Keyword, self).copy()
 *         c.identChars = Keyword.DEFAULT_KEYWORD_CHARS
 */
  __pyx_tuple__515 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_c); if (unlikely(!__pyx_tuple__515)) __PYX_ERR(0, 2489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__515);
  __Pyx_GIVEREF(__pyx_tuple__515);
  __pyx_codeobj__516 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__515, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_copy, 2489, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__516)) __PYX_ERR(0, 2489, __pyx_L1_error)

  /* "cPyparsing.pyx":2495
 * 
 *     @staticmethod
 *     def setDefaultKeywordChars(chars):             # <<<<<<<<<<<<<<
 *         """Overrides the default Keyword chars
 *         """
 */
  __pyx_tuple__517 = PyTuple_Pack(1, __pyx_n_s_chars); if (unlikely(!__pyx_tuple__517)) __PYX_ERR(0, 2495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__517);
  __Pyx_GIVEREF(__pyx_tuple__517);
  __pyx_codeobj__518 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__517, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_setDefaultKeywordChars, 2495, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__518)) __PYX_ERR(0, 2495, __pyx_L1_error)

  /* "cPyparsing.pyx":2513
 *     """
 * 
 *     def __init__(self, matchString):             # <<<<<<<<<<<<<<
 *         super(CaselessLiteral, self).__init__(matchString.upper())
 *         # Preserve the defining literal.
 */
  __pyx_tuple__519 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_matchString); if (unlikely(!__pyx_tuple__519)) __PYX_ERR(0, 2513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__519);
  __Pyx_GIVEREF(__pyx_tuple__519);
  __pyx_codeobj__520 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__519, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 2513, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__520)) __PYX_ERR(0, 2513, __pyx_L1_error)

  /* "cPyparsing.pyx":2520
 *         self.errmsg = "Expected " + self.name
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc:loc + self.matchLen].upper() == self.match:
 *             return loc + self.matchLen, self.returnString
 */
  __pyx_tuple__521 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions); if (unlikely(!__pyx_tuple__521)) __PYX_ERR(0, 2520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__521);
  __Pyx_GIVEREF(__pyx_tuple__521);
  __pyx_codeobj__522 = (PyObject*)__Pyx_PyCode_New(4, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__521, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 2520, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__522)) __PYX_ERR(0, 2520, __pyx_L1_error)
  __pyx_tuple__523 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__523)) __PYX_ERR(0, 2520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__523);
  __Pyx_GIVEREF(__pyx_tuple__523);

  /* "cPyparsing.pyx":2536
 *     """
 * 
 *     def __init__(self, matchString, identChars=None):             # <<<<<<<<<<<<<<
 *         super(CaselessKeyword, self).__init__(matchString, identChars, caseless=True)
 * 
 */
  __pyx_tuple__524 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_matchString, __pyx_n_s_identChars); if (unlikely(!__pyx_tuple__524)) __PYX_ERR(0, 2536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__524);
  __Pyx_GIVEREF(__pyx_tuple__524);
  __pyx_codeobj__525 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__524, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 2536, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__525)) __PYX_ERR(0, 2536, __pyx_L1_error)
  __pyx_tuple__526 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__526)) __PYX_ERR(0, 2536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__526);
  __Pyx_GIVEREF(__pyx_tuple__526);

  /* "cPyparsing.pyx":2539
 *         super(CaselessKeyword, self).__init__(matchString, identChars, caseless=True)
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch) and
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen].upper() not in self.identChars)):
 */
  __pyx_tuple__527 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions); if (unlikely(!__pyx_tuple__527)) __PYX_ERR(0, 2539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__527);
  __Pyx_GIVEREF(__pyx_tuple__527);
  __pyx_codeobj__528 = (PyObject*)__Pyx_PyCode_New(4, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__527, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 2539, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__528)) __PYX_ERR(0, 2539, __pyx_L1_error)
  __pyx_tuple__529 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__529)) __PYX_ERR(0, 2539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__529);
  __Pyx_GIVEREF(__pyx_tuple__529);

  /* "cPyparsing.pyx":2572
 *     """
 * 
 *     def __init__(self, match_string, maxMismatches=1):             # <<<<<<<<<<<<<<
 *         super(CloseMatch, self).__init__()
 *         self.name = match_string
 */
  __pyx_tuple__530 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_match_string, __pyx_n_s_maxMismatches); if (unlikely(!__pyx_tuple__530)) __PYX_ERR(0, 2572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__530);
  __Pyx_GIVEREF(__pyx_tuple__530);
  __pyx_codeobj__531 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__530, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 2572, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__531)) __PYX_ERR(0, 2572, __pyx_L1_error)
  __pyx_tuple__532 = PyTuple_Pack(1, ((PyObject *)__pyx_int_1)); if (unlikely(!__pyx_tuple__532)) __PYX_ERR(0, 2572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__532);
  __Pyx_GIVEREF(__pyx_tuple__532);

  /* "cPyparsing.pyx":2581
 *         self.mayReturnEmpty = False
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         start = loc
 *         instrlen = len(instring)
 */
  __pyx_tuple__533 = PyTuple_Pack(15, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_start, __pyx_n_s_instrlen, __pyx_n_s_maxloc, __pyx_n_s_match_string, __pyx_n_s_match_stringloc, __pyx_n_s_mismatches, __pyx_n_s_maxMismatches, __pyx_n_s_s_m, __pyx_n_s_src, __pyx_n_s_mat, __pyx_n_s_results); if (unlikely(!__pyx_tuple__533)) __PYX_ERR(0, 2581, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__533);
  __Pyx_GIVEREF(__pyx_tuple__533);
  __pyx_codeobj__534 = (PyObject*)__Pyx_PyCode_New(4, 0, 15, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__533, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 2581, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__534)) __PYX_ERR(0, 2581, __pyx_L1_error)
  __pyx_tuple__535 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__535)) __PYX_ERR(0, 2581, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__535);
  __Pyx_GIVEREF(__pyx_tuple__535);

  /* "cPyparsing.pyx":2656
 *     """
 * 
 *     def __init__(self, initChars, bodyChars=None, min=1, max=0, exact=0, asKeyword=False, excludeChars=None):             # <<<<<<<<<<<<<<
 *         super(Word, self).__init__()
 *         if excludeChars:
 */
  __pyx_tuple__536 = PyTuple_Pack(11, __pyx_n_s_self, __pyx_n_s_initChars, __pyx_n_s_bodyChars, __pyx_n_s_min, __pyx_n_s_max, __pyx_n_s_exact, __pyx_n_s_asKeyword, __pyx_n_s_excludeChars, __pyx_n_s_genexpr, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__536)) __PYX_ERR(0, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__536);
  __Pyx_GIVEREF(__pyx_tuple__536);
  __pyx_codeobj__537 = (PyObject*)__Pyx_PyCode_New(8, 0, 11, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__536, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 2656, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__537)) __PYX_ERR(0, 2656, __pyx_L1_error)
  __pyx_tuple__538 = PyTuple_Pack(6, ((PyObject *)Py_None), ((PyObject *)__pyx_int_1), ((PyObject *)__pyx_int_0), ((PyObject *)__pyx_int_0), ((PyObject *)Py_False), ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__538)) __PYX_ERR(0, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__538);
  __Pyx_GIVEREF(__pyx_tuple__538);

  /* "cPyparsing.pyx":2710
 *                 self.re = None
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.re:
 *             result = self.re.match(instring, loc)
 */
  __pyx_tuple__539 = PyTuple_Pack(10, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_result, __pyx_n_s_start, __pyx_n_s_instrlen, __pyx_n_s_bodychars, __pyx_n_s_maxloc, __pyx_n_s_throwException); if (unlikely(!__pyx_tuple__539)) __PYX_ERR(0, 2710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__539);
  __Pyx_GIVEREF(__pyx_tuple__539);
  __pyx_codeobj__540 = (PyObject*)__Pyx_PyCode_New(4, 0, 10, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__539, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 2710, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__540)) __PYX_ERR(0, 2710, __pyx_L1_error)
  __pyx_tuple__541 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__541)) __PYX_ERR(0, 2710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__541);
  __Pyx_GIVEREF(__pyx_tuple__541);

  /* "cPyparsing.pyx":2745
 *         return loc, instring[start:loc]
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(Word, self).__str__()
 */
  __pyx_tuple__542 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_charsAsStr, __pyx_n_s_charsAsStr); if (unlikely(!__pyx_tuple__542)) __PYX_ERR(0, 2745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__542);
  __Pyx_GIVEREF(__pyx_tuple__542);
  __pyx_codeobj__543 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__542, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_str_2, 2745, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__543)) __PYX_ERR(0, 2745, __pyx_L1_error)

  /* "cPyparsing.pyx":2780
 *         roman = Regex(r"M{0,4}(CM|CD|D?C{0,3})(XC|XL|L?X{0,3})(IX|IV|V?I{0,3})")
 *     """
 *     compiledREtype = type(re.compile("[A-Z]"))             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, pattern, flags=0):
 */
  __pyx_tuple__544 = PyTuple_Pack(1, __pyx_kp_u_A_Z); if (unlikely(!__pyx_tuple__544)) __PYX_ERR(0, 2780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__544);
  __Pyx_GIVEREF(__pyx_tuple__544);

  /* "cPyparsing.pyx":2782
 *     compiledREtype = type(re.compile("[A-Z]"))
 * 
 *     def __init__(self, pattern, flags=0):             # <<<<<<<<<<<<<<
 *         """The parameters C{pattern} and C{flags} are passed to the C{re.compile()} function as-is. See the Python C{re} module for an explanation of the acceptable patterns and flags."""
 *         super(Regex, self).__init__()
 */
  __pyx_tuple__545 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_pattern, __pyx_n_s_flags); if (unlikely(!__pyx_tuple__545)) __PYX_ERR(0, 2782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__545);
  __Pyx_GIVEREF(__pyx_tuple__545);
  __pyx_codeobj__546 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__545, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 2782, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__546)) __PYX_ERR(0, 2782, __pyx_L1_error)
  __pyx_tuple__547 = PyTuple_Pack(1, ((PyObject *)__pyx_int_0)); if (unlikely(!__pyx_tuple__547)) __PYX_ERR(0, 2782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__547);
  __Pyx_GIVEREF(__pyx_tuple__547);

  /* "cPyparsing.pyx":2816
 *         self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = self.re.match(instring, loc)
 *         if not result:
 */
  __pyx_tuple__548 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_result, __pyx_n_s_d, __pyx_n_s_ret, __pyx_n_s_k); if (unlikely(!__pyx_tuple__548)) __PYX_ERR(0, 2816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__548);
  __Pyx_GIVEREF(__pyx_tuple__548);
  __pyx_codeobj__549 = (PyObject*)__Pyx_PyCode_New(4, 0, 8, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__548, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 2816, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__549)) __PYX_ERR(0, 2816, __pyx_L1_error)
  __pyx_tuple__550 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__550)) __PYX_ERR(0, 2816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__550);
  __Pyx_GIVEREF(__pyx_tuple__550);

  /* "cPyparsing.pyx":2829
 *         return loc, ret
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(Regex, self).__str__()
 */
  __pyx_tuple__551 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__551)) __PYX_ERR(0, 2829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__551);
  __Pyx_GIVEREF(__pyx_tuple__551);
  __pyx_codeobj__552 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__551, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_str_2, 2829, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__552)) __PYX_ERR(0, 2829, __pyx_L1_error)

  /* "cPyparsing.pyx":2867
 *     """
 * 
 *     def __init__(self, quoteChar, escChar=None, escQuote=None, multiline=False, unquoteResults=True, endQuoteChar=None, convertWhitespaceEscapes=True):             # <<<<<<<<<<<<<<
 *         super(QuotedString, self).__init__()
 * 
 */
  __pyx_tuple__553 = PyTuple_Pack(10, __pyx_n_s_self, __pyx_n_s_quoteChar, __pyx_n_s_escChar, __pyx_n_s_escQuote, __pyx_n_s_multiline, __pyx_n_s_unquoteResults, __pyx_n_s_endQuoteChar, __pyx_n_s_convertWhitespaceEscapes, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__553)) __PYX_ERR(0, 2867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__553);
  __Pyx_GIVEREF(__pyx_tuple__553);
  __pyx_codeobj__554 = (PyObject*)__Pyx_PyCode_New(8, 0, 10, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__553, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 2867, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__554)) __PYX_ERR(0, 2867, __pyx_L1_error)
  __pyx_tuple__555 = PyTuple_Pack(6, ((PyObject *)Py_None), ((PyObject *)Py_None), ((PyObject *)Py_False), ((PyObject *)Py_True), ((PyObject *)Py_None), ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__555)) __PYX_ERR(0, 2867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__555);
  __Pyx_GIVEREF(__pyx_tuple__555);

  /* "cPyparsing.pyx":2932
 *         self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = instring[loc] == self.firstQuoteChar and self.re.match(instring, loc) or None
 *         if not result:
 */
  __pyx_tuple__556 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_result, __pyx_n_s_ret, __pyx_n_s_ws_map, __pyx_n_s_wslit, __pyx_n_s_wschar); if (unlikely(!__pyx_tuple__556)) __PYX_ERR(0, 2932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__556);
  __Pyx_GIVEREF(__pyx_tuple__556);
  __pyx_codeobj__557 = (PyObject*)__Pyx_PyCode_New(4, 0, 9, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__556, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 2932, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__557)) __PYX_ERR(0, 2932, __pyx_L1_error)
  __pyx_tuple__558 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__558)) __PYX_ERR(0, 2932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__558);
  __Pyx_GIVEREF(__pyx_tuple__558);

  /* "cPyparsing.pyx":2967
 *         return loc, ret
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(QuotedString, self).__str__()
 */
  __pyx_tuple__559 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__559)) __PYX_ERR(0, 2967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__559);
  __Pyx_GIVEREF(__pyx_tuple__559);
  __pyx_codeobj__560 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__559, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_str_2, 2967, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__560)) __PYX_ERR(0, 2967, __pyx_L1_error)

  /* "cPyparsing.pyx":2996
 *     """
 * 
 *     def __init__(self, notChars, min=1, max=0, exact=0):             # <<<<<<<<<<<<<<
 *         super(CharsNotIn, self).__init__()
 *         self.skipWhitespace = False
 */
  __pyx_tuple__561 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_notChars, __pyx_n_s_min, __pyx_n_s_max, __pyx_n_s_exact); if (unlikely(!__pyx_tuple__561)) __PYX_ERR(0, 2996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__561);
  __Pyx_GIVEREF(__pyx_tuple__561);
  __pyx_codeobj__562 = (PyObject*)__Pyx_PyCode_New(5, 0, 5, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__561, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 2996, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__562)) __PYX_ERR(0, 2996, __pyx_L1_error)
  __pyx_tuple__563 = PyTuple_Pack(3, ((PyObject *)__pyx_int_1), ((PyObject *)__pyx_int_0), ((PyObject *)__pyx_int_0)); if (unlikely(!__pyx_tuple__563)) __PYX_ERR(0, 2996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__563);
  __Pyx_GIVEREF(__pyx_tuple__563);

  /* "cPyparsing.pyx":3020
 *         self.mayIndexError = False
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc] in self.notChars:
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_tuple__564 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_start, __pyx_n_s_notchars, __pyx_n_s_maxlen); if (unlikely(!__pyx_tuple__564)) __PYX_ERR(0, 3020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__564);
  __Pyx_GIVEREF(__pyx_tuple__564);
  __pyx_codeobj__565 = (PyObject*)__Pyx_PyCode_New(4, 0, 7, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__564, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 3020, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__565)) __PYX_ERR(0, 3020, __pyx_L1_error)
  __pyx_tuple__566 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__566)) __PYX_ERR(0, 3020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__566);
  __Pyx_GIVEREF(__pyx_tuple__566);

  /* "cPyparsing.pyx":3037
 *         return loc, instring[start:loc]
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(CharsNotIn, self).__str__()
 */
  __pyx_tuple__567 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__567)) __PYX_ERR(0, 3037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__567);
  __Pyx_GIVEREF(__pyx_tuple__567);
  __pyx_codeobj__568 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__567, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_str_2, 3037, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__568)) __PYX_ERR(0, 3037, __pyx_L1_error)

  /* "cPyparsing.pyx":3068
 *     }
 * 
 *     def __init__(self, ws=" \t\r\n", min=1, max=0, exact=0):             # <<<<<<<<<<<<<<
 *         super(White, self).__init__()
 *         self.matchWhite = ws
 */
  __pyx_tuple__569 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_ws, __pyx_n_s_min, __pyx_n_s_max, __pyx_n_s_exact, __pyx_n_s_genexpr, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__569)) __PYX_ERR(0, 3068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__569);
  __Pyx_GIVEREF(__pyx_tuple__569);
  __pyx_codeobj__570 = (PyObject*)__Pyx_PyCode_New(5, 0, 8, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__569, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 3068, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__570)) __PYX_ERR(0, 3068, __pyx_L1_error)
  __pyx_tuple__571 = PyTuple_Pack(4, ((PyObject*)__pyx_kp_u__102), ((PyObject *)__pyx_int_1), ((PyObject *)__pyx_int_0), ((PyObject *)__pyx_int_0)); if (unlikely(!__pyx_tuple__571)) __PYX_ERR(0, 3068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__571);
  __Pyx_GIVEREF(__pyx_tuple__571);

  /* "cPyparsing.pyx":3088
 *             self.minLen = exact
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if not(instring[loc] in self.matchWhite):
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_tuple__572 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_start, __pyx_n_s_maxloc); if (unlikely(!__pyx_tuple__572)) __PYX_ERR(0, 3088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__572);
  __Pyx_GIVEREF(__pyx_tuple__572);
  __pyx_codeobj__573 = (PyObject*)__Pyx_PyCode_New(4, 0, 6, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__572, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 3088, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__573)) __PYX_ERR(0, 3088, __pyx_L1_error)
  __pyx_tuple__574 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__574)) __PYX_ERR(0, 3088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__574);
  __Pyx_GIVEREF(__pyx_tuple__574);

  /* "cPyparsing.pyx":3105
 * 
 * class _PositionToken(Token):
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(_PositionToken, self).__init__()
 *         self.name = self.__class__.__name__
 */
  __pyx_tuple__575 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__575)) __PYX_ERR(0, 3105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__575);
  __Pyx_GIVEREF(__pyx_tuple__575);
  __pyx_codeobj__576 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__575, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 3105, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__576)) __PYX_ERR(0, 3105, __pyx_L1_error)

  /* "cPyparsing.pyx":3117
 *     """
 * 
 *     def __init__(self, colno):             # <<<<<<<<<<<<<<
 *         super(GoToColumn, self).__init__()
 *         self.col = colno
 */
  __pyx_tuple__577 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_colno); if (unlikely(!__pyx_tuple__577)) __PYX_ERR(0, 3117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__577);
  __Pyx_GIVEREF(__pyx_tuple__577);
  __pyx_codeobj__578 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__577, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 3117, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__578)) __PYX_ERR(0, 3117, __pyx_L1_error)

  /* "cPyparsing.pyx":3121
 *         self.col = colno
 * 
 *     def preParse(self, instring, int loc):             # <<<<<<<<<<<<<<
 *         if col(loc, instring) != self.col:
 *             instrlen = len(instring)
 */
  __pyx_tuple__579 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_instrlen); if (unlikely(!__pyx_tuple__579)) __PYX_ERR(0, 3121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__579);
  __Pyx_GIVEREF(__pyx_tuple__579);
  __pyx_codeobj__580 = (PyObject*)__Pyx_PyCode_New(3, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__579, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_preParse, 3121, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__580)) __PYX_ERR(0, 3121, __pyx_L1_error)

  /* "cPyparsing.pyx":3130
 *         return loc
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         thiscol = col(loc, instring)
 *         if thiscol > self.col:
 */
  __pyx_tuple__581 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_thiscol, __pyx_n_s_newloc, __pyx_n_s_ret); if (unlikely(!__pyx_tuple__581)) __PYX_ERR(0, 3130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__581);
  __Pyx_GIVEREF(__pyx_tuple__581);
  __pyx_codeobj__582 = (PyObject*)__Pyx_PyCode_New(4, 0, 7, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__581, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 3130, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__582)) __PYX_ERR(0, 3130, __pyx_L1_error)
  __pyx_tuple__583 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__583)) __PYX_ERR(0, 3130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__583);
  __Pyx_GIVEREF(__pyx_tuple__583);

  /* "cPyparsing.pyx":3161
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(LineStart, self).__init__()
 *         self.errmsg = "Expected start of line"
 */
  __pyx_tuple__584 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__584)) __PYX_ERR(0, 3161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__584);
  __Pyx_GIVEREF(__pyx_tuple__584);
  __pyx_codeobj__585 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__584, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 3161, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__585)) __PYX_ERR(0, 3161, __pyx_L1_error)

  /* "cPyparsing.pyx":3165
 *         self.errmsg = "Expected start of line"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if col(loc, instring) == 1:
 *             return loc, []
 */
  __pyx_tuple__586 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions); if (unlikely(!__pyx_tuple__586)) __PYX_ERR(0, 3165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__586);
  __Pyx_GIVEREF(__pyx_tuple__586);
  __pyx_codeobj__587 = (PyObject*)__Pyx_PyCode_New(4, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__586, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 3165, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__587)) __PYX_ERR(0, 3165, __pyx_L1_error)
  __pyx_tuple__588 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__588)) __PYX_ERR(0, 3165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__588);
  __Pyx_GIVEREF(__pyx_tuple__588);

  /* "cPyparsing.pyx":3176
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(LineEnd, self).__init__()
 *         self.setWhitespaceChars(ParserElement.DEFAULT_WHITE_CHARS.replace("\n", ""))
 */
  __pyx_tuple__589 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__589)) __PYX_ERR(0, 3176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__589);
  __Pyx_GIVEREF(__pyx_tuple__589);
  __pyx_codeobj__590 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__589, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 3176, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__590)) __PYX_ERR(0, 3176, __pyx_L1_error)

  /* "cPyparsing.pyx":3181
 *         self.errmsg = "Expected end of line"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc < len(instring):
 *             if instring[loc] == "\n":
 */
  __pyx_tuple__591 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions); if (unlikely(!__pyx_tuple__591)) __PYX_ERR(0, 3181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__591);
  __Pyx_GIVEREF(__pyx_tuple__591);
  __pyx_codeobj__592 = (PyObject*)__Pyx_PyCode_New(4, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__591, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 3181, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__592)) __PYX_ERR(0, 3181, __pyx_L1_error)
  __pyx_tuple__593 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__593)) __PYX_ERR(0, 3181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__593);
  __Pyx_GIVEREF(__pyx_tuple__593);

  /* "cPyparsing.pyx":3198
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(StringStart, self).__init__()
 *         self.errmsg = "Expected start of text"
 */
  __pyx_tuple__594 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__594)) __PYX_ERR(0, 3198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__594);
  __Pyx_GIVEREF(__pyx_tuple__594);
  __pyx_codeobj__595 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__594, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 3198, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__595)) __PYX_ERR(0, 3198, __pyx_L1_error)

  /* "cPyparsing.pyx":3202
 *         self.errmsg = "Expected start of text"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc != 0:
 *             # see if entire string up to here is just whitespace and ignoreables
 */
  __pyx_tuple__596 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions); if (unlikely(!__pyx_tuple__596)) __PYX_ERR(0, 3202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__596);
  __Pyx_GIVEREF(__pyx_tuple__596);
  __pyx_codeobj__597 = (PyObject*)__Pyx_PyCode_New(4, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__596, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 3202, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__597)) __PYX_ERR(0, 3202, __pyx_L1_error)
  __pyx_tuple__598 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__598)) __PYX_ERR(0, 3202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__598);
  __Pyx_GIVEREF(__pyx_tuple__598);

  /* "cPyparsing.pyx":3215
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(StringEnd, self).__init__()
 *         self.errmsg = "Expected end of text"
 */
  __pyx_tuple__599 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__599)) __PYX_ERR(0, 3215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__599);
  __Pyx_GIVEREF(__pyx_tuple__599);
  __pyx_codeobj__600 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__599, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 3215, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__600)) __PYX_ERR(0, 3215, __pyx_L1_error)

  /* "cPyparsing.pyx":3219
 *         self.errmsg = "Expected end of text"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc < len(instring):
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_tuple__601 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions); if (unlikely(!__pyx_tuple__601)) __PYX_ERR(0, 3219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__601);
  __Pyx_GIVEREF(__pyx_tuple__601);
  __pyx_codeobj__602 = (PyObject*)__Pyx_PyCode_New(4, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__601, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 3219, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__602)) __PYX_ERR(0, 3219, __pyx_L1_error)
  __pyx_tuple__603 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__603)) __PYX_ERR(0, 3219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__603);
  __Pyx_GIVEREF(__pyx_tuple__603);

  /* "cPyparsing.pyx":3239
 *     """
 * 
 *     def __init__(self, wordChars=printables):             # <<<<<<<<<<<<<<
 *         super(WordStart, self).__init__()
 *         self.wordChars = set(wordChars)
 */
  __pyx_tuple__604 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_wordChars); if (unlikely(!__pyx_tuple__604)) __PYX_ERR(0, 3239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__604);
  __Pyx_GIVEREF(__pyx_tuple__604);
  __pyx_codeobj__605 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__604, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 3239, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__605)) __PYX_ERR(0, 3239, __pyx_L1_error)

  /* "cPyparsing.pyx":3244
 *         self.errmsg = "Not at the start of a word"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc != 0:
 *             if (instring[loc - 1] in self.wordChars or
 */
  __pyx_tuple__606 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions); if (unlikely(!__pyx_tuple__606)) __PYX_ERR(0, 3244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__606);
  __Pyx_GIVEREF(__pyx_tuple__606);
  __pyx_codeobj__607 = (PyObject*)__Pyx_PyCode_New(4, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__606, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 3244, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__607)) __PYX_ERR(0, 3244, __pyx_L1_error)
  __pyx_tuple__608 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__608)) __PYX_ERR(0, 3244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__608);
  __Pyx_GIVEREF(__pyx_tuple__608);

  /* "cPyparsing.pyx":3261
 *     """
 * 
 *     def __init__(self, wordChars=printables):             # <<<<<<<<<<<<<<
 *         super(WordEnd, self).__init__()
 *         self.wordChars = set(wordChars)
 */
  __pyx_tuple__609 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_wordChars); if (unlikely(!__pyx_tuple__609)) __PYX_ERR(0, 3261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__609);
  __Pyx_GIVEREF(__pyx_tuple__609);
  __pyx_codeobj__610 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__609, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 3261, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__610)) __PYX_ERR(0, 3261, __pyx_L1_error)

  /* "cPyparsing.pyx":3267
 *         self.errmsg = "Not at the end of a word"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         instrlen = len(instring)
 *         if instrlen > 0 and loc < instrlen:
 */
  __pyx_tuple__611 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_instrlen); if (unlikely(!__pyx_tuple__611)) __PYX_ERR(0, 3267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__611);
  __Pyx_GIVEREF(__pyx_tuple__611);
  __pyx_codeobj__612 = (PyObject*)__Pyx_PyCode_New(4, 0, 5, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__611, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 3267, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__612)) __PYX_ERR(0, 3267, __pyx_L1_error)
  __pyx_tuple__613 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__613)) __PYX_ERR(0, 3267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__613);
  __Pyx_GIVEREF(__pyx_tuple__613);

  /* "cPyparsing.pyx":3281
 *     """
 * 
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(ParseExpression, self).__init__(savelist)
 *         if isinstance(exprs, _generatorType):
 */
  __pyx_tuple__614 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_exprs, __pyx_n_s_savelist, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__614)) __PYX_ERR(0, 3281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__614);
  __Pyx_GIVEREF(__pyx_tuple__614);
  __pyx_codeobj__615 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__614, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 3281, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__615)) __PYX_ERR(0, 3281, __pyx_L1_error)
  __pyx_tuple__616 = PyTuple_Pack(1, ((PyObject *)Py_False)); if (unlikely(!__pyx_tuple__616)) __PYX_ERR(0, 3281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__616);
  __Pyx_GIVEREF(__pyx_tuple__616);

  /* "cPyparsing.pyx":3301
 *         self.callPreparse = False
 * 
 *     def __getitem__(self, i):             # <<<<<<<<<<<<<<
 *         return self.exprs[i]
 * 
 */
  __pyx_tuple__617 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_i); if (unlikely(!__pyx_tuple__617)) __PYX_ERR(0, 3301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__617);
  __Pyx_GIVEREF(__pyx_tuple__617);
  __pyx_codeobj__618 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__617, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_getitem, 3301, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__618)) __PYX_ERR(0, 3301, __pyx_L1_error)

  /* "cPyparsing.pyx":3304
 *         return self.exprs[i]
 * 
 *     def append(self, other):             # <<<<<<<<<<<<<<
 *         self.exprs.append(other)
 *         self.strRepr = None
 */
  __pyx_tuple__619 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__619)) __PYX_ERR(0, 3304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__619);
  __Pyx_GIVEREF(__pyx_tuple__619);
  __pyx_codeobj__620 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__619, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_append, 3304, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__620)) __PYX_ERR(0, 3304, __pyx_L1_error)

  /* "cPyparsing.pyx":3309
 *         return self
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         """Extends C{leaveWhitespace} defined in base class, and also invokes C{leaveWhitespace} on
 *            all contained expressions."""
 */
  __pyx_tuple__621 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_e); if (unlikely(!__pyx_tuple__621)) __PYX_ERR(0, 3309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__621);
  __Pyx_GIVEREF(__pyx_tuple__621);
  __pyx_codeobj__622 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__621, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_leaveWhitespace, 3309, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__622)) __PYX_ERR(0, 3309, __pyx_L1_error)

  /* "cPyparsing.pyx":3318
 *         return self
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:
 */
  __pyx_tuple__623 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_e); if (unlikely(!__pyx_tuple__623)) __PYX_ERR(0, 3318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__623);
  __Pyx_GIVEREF(__pyx_tuple__623);
  __pyx_codeobj__624 = (PyObject*)__Pyx_PyCode_New(2, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__623, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_ignore, 3318, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__624)) __PYX_ERR(0, 3318, __pyx_L1_error)

  /* "cPyparsing.pyx":3330
 *         return self
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(ParseExpression, self).__str__()
 */
  __pyx_tuple__625 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__625)) __PYX_ERR(0, 3330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__625);
  __Pyx_GIVEREF(__pyx_tuple__625);
  __pyx_codeobj__626 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__625, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_str_2, 3330, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__626)) __PYX_ERR(0, 3330, __pyx_L1_error)

  /* "cPyparsing.pyx":3340
 *         return self.strRepr
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(ParseExpression, self).streamline()
 * 
 */
  __pyx_tuple__627 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_e, __pyx_n_s_other); if (unlikely(!__pyx_tuple__627)) __PYX_ERR(0, 3340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__627);
  __Pyx_GIVEREF(__pyx_tuple__627);
  __pyx_codeobj__628 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__627, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_streamline, 3340, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__628)) __PYX_ERR(0, 3340, __pyx_L1_error)

  /* "cPyparsing.pyx":3374
 *         return self
 * 
 *     def setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         ret = super(ParseExpression, self).setResultsName(name, listAllMatches)
 *         return ret
 */
  __pyx_tuple__629 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_name, __pyx_n_s_listAllMatches, __pyx_n_s_ret); if (unlikely(!__pyx_tuple__629)) __PYX_ERR(0, 3374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__629);
  __Pyx_GIVEREF(__pyx_tuple__629);
  __pyx_codeobj__630 = (PyObject*)__Pyx_PyCode_New(3, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__629, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_setResultsName, 3374, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__630)) __PYX_ERR(0, 3374, __pyx_L1_error)
  __pyx_tuple__631 = PyTuple_Pack(1, ((PyObject *)Py_False)); if (unlikely(!__pyx_tuple__631)) __PYX_ERR(0, 3374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__631);
  __Pyx_GIVEREF(__pyx_tuple__631);

  /* "cPyparsing.pyx":3378
 *         return ret
 * 
 *     def validate(self, validateTrace=[]):             # <<<<<<<<<<<<<<
 *         tmp = validateTrace[:] + [self]
 *         for e in self.exprs:
 */
  __pyx_tuple__632 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_validateTrace, __pyx_n_s_tmp, __pyx_n_s_e); if (unlikely(!__pyx_tuple__632)) __PYX_ERR(0, 3378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__632);
  __Pyx_GIVEREF(__pyx_tuple__632);
  __pyx_codeobj__633 = (PyObject*)__Pyx_PyCode_New(2, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__632, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_validate, 3378, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__633)) __PYX_ERR(0, 3378, __pyx_L1_error)

  /* "cPyparsing.pyx":3384
 *         self.checkRecursion([])
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         ret = super(ParseExpression, self).copy()
 *         ret.exprs = [e.copy() for e in self.exprs]
 */
  __pyx_tuple__634 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_ret); if (unlikely(!__pyx_tuple__634)) __PYX_ERR(0, 3384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__634);
  __Pyx_GIVEREF(__pyx_tuple__634);
  __pyx_codeobj__635 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__634, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_copy, 3384, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__635)) __PYX_ERR(0, 3384, __pyx_L1_error)

  /* "cPyparsing.pyx":3407
 * 
 *     class _ErrorStop(Empty):
 *         def __init__(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *             super(And._ErrorStop, self).__init__(*args, **kwargs)
 *             self.name = '-'
 */
  __pyx_tuple__636 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_args, __pyx_n_s_kwargs); if (unlikely(!__pyx_tuple__636)) __PYX_ERR(0, 3407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__636);
  __Pyx_GIVEREF(__pyx_tuple__636);
  __pyx_codeobj__637 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, CO_VARARGS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__636, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 3407, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__637)) __PYX_ERR(0, 3407, __pyx_L1_error)

  /* "cPyparsing.pyx":3412
 *             self.leaveWhitespace()
 * 
 *     def __init__(self, exprs, savelist=True):             # <<<<<<<<<<<<<<
 *         super(And, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 */
  __pyx_tuple__638 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_exprs, __pyx_n_s_savelist, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__638)) __PYX_ERR(0, 3412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__638);
  __Pyx_GIVEREF(__pyx_tuple__638);
  __pyx_codeobj__639 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__638, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 3412, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__639)) __PYX_ERR(0, 3412, __pyx_L1_error)
  __pyx_tuple__640 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__640)) __PYX_ERR(0, 3412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__640);
  __Pyx_GIVEREF(__pyx_tuple__640);

  /* "cPyparsing.pyx":3419
 *         self.callPreparse = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         # pass False as last arg to _parse for first element, since we already
 *         # pre-parsed the string as part of our And pre-parsing
 */
  __pyx_tuple__641 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_resultlist, __pyx_n_s_errorStop, __pyx_n_s_e, __pyx_n_s_exprtokens, __pyx_n_s_pe); if (unlikely(!__pyx_tuple__641)) __PYX_ERR(0, 3419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__641);
  __Pyx_GIVEREF(__pyx_tuple__641);
  __pyx_codeobj__642 = (PyObject*)__Pyx_PyCode_New(4, 0, 9, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__641, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 3419, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__642)) __PYX_ERR(0, 3419, __pyx_L1_error)
  __pyx_tuple__643 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__643)) __PYX_ERR(0, 3419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__643);
  __Pyx_GIVEREF(__pyx_tuple__643);

  /* "cPyparsing.pyx":3444
 *         return loc, resultlist
 * 
 *     def __iadd__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 */
  __pyx_tuple__644 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__644)) __PYX_ERR(0, 3444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__644);
  __Pyx_GIVEREF(__pyx_tuple__644);
  __pyx_codeobj__645 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__644, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_iadd, 3444, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__645)) __PYX_ERR(0, 3444, __pyx_L1_error)

  /* "cPyparsing.pyx":3449
 *         return self.append(other)  # And( [ self, other ] )
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */
  __pyx_tuple__646 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_parseElementList, __pyx_n_s_subRecCheckList, __pyx_n_s_e); if (unlikely(!__pyx_tuple__646)) __PYX_ERR(0, 3449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__646);
  __Pyx_GIVEREF(__pyx_tuple__646);
  __pyx_codeobj__647 = (PyObject*)__Pyx_PyCode_New(2, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__646, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_checkRecursion, 3449, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__647)) __PYX_ERR(0, 3449, __pyx_L1_error)

  /* "cPyparsing.pyx":3456
 *                 break
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_tuple__648 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__648)) __PYX_ERR(0, 3456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__648);
  __Pyx_GIVEREF(__pyx_tuple__648);
  __pyx_codeobj__649 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__648, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_str_2, 3456, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__649)) __PYX_ERR(0, 3456, __pyx_L1_error)

  /* "cPyparsing.pyx":3481
 *     """
 * 
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(Or, self).__init__(exprs, savelist)
 *         if self.exprs:
 */
  __pyx_tuple__650 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_exprs, __pyx_n_s_savelist, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__650)) __PYX_ERR(0, 3481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__650);
  __Pyx_GIVEREF(__pyx_tuple__650);
  __pyx_codeobj__651 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__650, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 3481, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__651)) __PYX_ERR(0, 3481, __pyx_L1_error)
  __pyx_tuple__652 = PyTuple_Pack(1, ((PyObject *)Py_False)); if (unlikely(!__pyx_tuple__652)) __PYX_ERR(0, 3481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__652);
  __Pyx_GIVEREF(__pyx_tuple__652);

  /* "cPyparsing.pyx":3488
 *             self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         maxExcLoc = -1
 *         maxException = None
 */
  __pyx_tuple__654 = PyTuple_Pack(11, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_maxExcLoc, __pyx_n_s_maxException, __pyx_n_s_matches, __pyx_n_s_e, __pyx_n_s_loc2, __pyx_n_s_err, __pyx_n_s__653); if (unlikely(!__pyx_tuple__654)) __PYX_ERR(0, 3488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__654);
  __Pyx_GIVEREF(__pyx_tuple__654);
  __pyx_codeobj__655 = (PyObject*)__Pyx_PyCode_New(4, 0, 11, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__654, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 3488, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__655)) __PYX_ERR(0, 3488, __pyx_L1_error)
  __pyx_tuple__656 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__656)) __PYX_ERR(0, 3488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__656);
  __Pyx_GIVEREF(__pyx_tuple__656);

  /* "cPyparsing.pyx":3525
 *             raise ParseException(instring, loc, "no defined alternatives to match", self)
 * 
 *     def __ixor__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 */
  __pyx_tuple__657 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__657)) __PYX_ERR(0, 3525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__657);
  __Pyx_GIVEREF(__pyx_tuple__657);
  __pyx_codeobj__658 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__657, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_ixor, 3525, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__658)) __PYX_ERR(0, 3525, __pyx_L1_error)

  /* "cPyparsing.pyx":3530
 *         return self.append(other)  # Or( [ self, other ] )
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_tuple__659 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__659)) __PYX_ERR(0, 3530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__659);
  __Pyx_GIVEREF(__pyx_tuple__659);
  __pyx_codeobj__660 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__659, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_str_2, 3530, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__660)) __PYX_ERR(0, 3530, __pyx_L1_error)

  /* "cPyparsing.pyx":3539
 *         return self.strRepr
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */
  __pyx_tuple__661 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_parseElementList, __pyx_n_s_subRecCheckList, __pyx_n_s_e); if (unlikely(!__pyx_tuple__661)) __PYX_ERR(0, 3539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__661);
  __Pyx_GIVEREF(__pyx_tuple__661);
  __pyx_codeobj__662 = (PyObject*)__Pyx_PyCode_New(2, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__661, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_checkRecursion, 3539, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__662)) __PYX_ERR(0, 3539, __pyx_L1_error)

  /* "cPyparsing.pyx":3563
 *     """
 * 
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(MatchFirst, self).__init__(exprs, savelist)
 *         if self.exprs:
 */
  __pyx_tuple__663 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_exprs, __pyx_n_s_savelist, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__663)) __PYX_ERR(0, 3563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__663);
  __Pyx_GIVEREF(__pyx_tuple__663);
  __pyx_codeobj__664 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__663, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 3563, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__664)) __PYX_ERR(0, 3563, __pyx_L1_error)
  __pyx_tuple__665 = PyTuple_Pack(1, ((PyObject *)Py_False)); if (unlikely(!__pyx_tuple__665)) __PYX_ERR(0, 3563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__665);
  __Pyx_GIVEREF(__pyx_tuple__665);

  /* "cPyparsing.pyx":3570
 *             self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         maxExcLoc = -1
 *         maxException = None
 */
  __pyx_tuple__666 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_maxExcLoc, __pyx_n_s_maxException, __pyx_n_s_e, __pyx_n_s_ret, __pyx_n_s_err); if (unlikely(!__pyx_tuple__666)) __PYX_ERR(0, 3570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__666);
  __Pyx_GIVEREF(__pyx_tuple__666);
  __pyx_codeobj__667 = (PyObject*)__Pyx_PyCode_New(4, 0, 9, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__666, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 3570, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__667)) __PYX_ERR(0, 3570, __pyx_L1_error)
  __pyx_tuple__668 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__668)) __PYX_ERR(0, 3570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__668);
  __Pyx_GIVEREF(__pyx_tuple__668);

  /* "cPyparsing.pyx":3594
 *                 raise ParseException(instring, loc, "no defined alternatives to match", self)
 * 
 *     def __ior__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 */
  __pyx_tuple__669 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__669)) __PYX_ERR(0, 3594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__669);
  __Pyx_GIVEREF(__pyx_tuple__669);
  __pyx_codeobj__670 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__669, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_ior, 3594, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__670)) __PYX_ERR(0, 3594, __pyx_L1_error)

  /* "cPyparsing.pyx":3599
 *         return self.append(other)  # MatchFirst( [ self, other ] )
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_tuple__671 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__671)) __PYX_ERR(0, 3599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__671);
  __Pyx_GIVEREF(__pyx_tuple__671);
  __pyx_codeobj__672 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__671, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_str_2, 3599, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__672)) __PYX_ERR(0, 3599, __pyx_L1_error)

  /* "cPyparsing.pyx":3608
 *         return self.strRepr
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */
  __pyx_tuple__673 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_parseElementList, __pyx_n_s_subRecCheckList, __pyx_n_s_e); if (unlikely(!__pyx_tuple__673)) __PYX_ERR(0, 3608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__673);
  __Pyx_GIVEREF(__pyx_tuple__673);
  __pyx_codeobj__674 = (PyObject*)__Pyx_PyCode_New(2, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__673, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_checkRecursion, 3608, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__674)) __PYX_ERR(0, 3608, __pyx_L1_error)

  /* "cPyparsing.pyx":3669
 *     """
 * 
 *     def __init__(self, exprs, savelist=True):             # <<<<<<<<<<<<<<
 *         super(Each, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 */
  __pyx_tuple__675 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_exprs, __pyx_n_s_savelist, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__675)) __PYX_ERR(0, 3669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__675);
  __Pyx_GIVEREF(__pyx_tuple__675);
  __pyx_codeobj__676 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__675, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 3669, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__676)) __PYX_ERR(0, 3669, __pyx_L1_error)
  __pyx_tuple__677 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__677)) __PYX_ERR(0, 3669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__677);
  __Pyx_GIVEREF(__pyx_tuple__677);

  /* "cPyparsing.pyx":3675
 *         self.initExprGroups = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.initExprGroups:
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))
 */
  __pyx_tuple__678 = PyTuple_Pack(21, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_opt1, __pyx_n_s_opt2, __pyx_n_s_tmpLoc, __pyx_n_s_tmpReqd, __pyx_n_s_tmpOpt, __pyx_n_s_matchOrder, __pyx_n_s_keepMatching, __pyx_n_s_tmpExprs, __pyx_n_s_failed, __pyx_n_s_e, __pyx_n_s_missing, __pyx_n_s_resultlist, __pyx_n_s_results, __pyx_n_s_finalResults, __pyx_n_s_genexpr, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__678)) __PYX_ERR(0, 3675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__678);
  __Pyx_GIVEREF(__pyx_tuple__678);
  __pyx_codeobj__679 = (PyObject*)__Pyx_PyCode_New(4, 0, 21, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__678, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 3675, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__679)) __PYX_ERR(0, 3675, __pyx_L1_error)
  __pyx_tuple__680 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__680)) __PYX_ERR(0, 3675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__680);
  __Pyx_GIVEREF(__pyx_tuple__680);

  /* "cPyparsing.pyx":3724
 *         return loc, finalResults
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_tuple__681 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__681)) __PYX_ERR(0, 3724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__681);
  __Pyx_GIVEREF(__pyx_tuple__681);
  __pyx_codeobj__682 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__681, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_str_2, 3724, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__682)) __PYX_ERR(0, 3724, __pyx_L1_error)

  /* "cPyparsing.pyx":3733
 *         return self.strRepr
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */
  __pyx_tuple__683 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_parseElementList, __pyx_n_s_subRecCheckList, __pyx_n_s_e); if (unlikely(!__pyx_tuple__683)) __PYX_ERR(0, 3733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__683);
  __Pyx_GIVEREF(__pyx_tuple__683);
  __pyx_codeobj__684 = (PyObject*)__Pyx_PyCode_New(2, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__683, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_checkRecursion, 3733, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__684)) __PYX_ERR(0, 3733, __pyx_L1_error)

  /* "cPyparsing.pyx":3744
 *     """
 * 
 *     def __init__(self, expr, savelist=False):             # <<<<<<<<<<<<<<
 *         super(ParseElementEnhance, self).__init__(savelist)
 *         if isinstance(expr, basestring):
 */
  __pyx_tuple__685 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_expr, __pyx_n_s_savelist); if (unlikely(!__pyx_tuple__685)) __PYX_ERR(0, 3744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__685);
  __Pyx_GIVEREF(__pyx_tuple__685);
  __pyx_codeobj__686 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__685, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 3744, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__686)) __PYX_ERR(0, 3744, __pyx_L1_error)
  __pyx_tuple__687 = PyTuple_Pack(1, ((PyObject *)Py_False)); if (unlikely(!__pyx_tuple__687)) __PYX_ERR(0, 3744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__687);
  __Pyx_GIVEREF(__pyx_tuple__687);

  /* "cPyparsing.pyx":3762
 *             self.ignoreExprs.extend(expr.ignoreExprs)
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             return self.expr._parse(instring, loc, doActions, callPreParse=False)
 */
  __pyx_tuple__688 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions); if (unlikely(!__pyx_tuple__688)) __PYX_ERR(0, 3762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__688);
  __Pyx_GIVEREF(__pyx_tuple__688);
  __pyx_codeobj__689 = (PyObject*)__Pyx_PyCode_New(4, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__688, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 3762, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__689)) __PYX_ERR(0, 3762, __pyx_L1_error)
  __pyx_tuple__690 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__690)) __PYX_ERR(0, 3762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__690);
  __Pyx_GIVEREF(__pyx_tuple__690);

  /* "cPyparsing.pyx":3768
 *             raise ParseException("", loc, self.errmsg, self)
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = False
 *         self.expr = self.expr.copy()
 */
  __pyx_tuple__691 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__691)) __PYX_ERR(0, 3768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__691);
  __Pyx_GIVEREF(__pyx_tuple__691);
  __pyx_codeobj__692 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__691, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_leaveWhitespace, 3768, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__692)) __PYX_ERR(0, 3768, __pyx_L1_error)

  /* "cPyparsing.pyx":3775
 *         return self
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:
 */
  __pyx_tuple__693 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__693)) __PYX_ERR(0, 3775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__693);
  __Pyx_GIVEREF(__pyx_tuple__693);
  __pyx_codeobj__694 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__693, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_ignore, 3775, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__694)) __PYX_ERR(0, 3775, __pyx_L1_error)

  /* "cPyparsing.pyx":3787
 *         return self
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(ParseElementEnhance, self).streamline()
 *         if self.expr is not None:
 */
  __pyx_tuple__695 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__695)) __PYX_ERR(0, 3787, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__695);
  __Pyx_GIVEREF(__pyx_tuple__695);
  __pyx_codeobj__696 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__695, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_streamline, 3787, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__696)) __PYX_ERR(0, 3787, __pyx_L1_error)

  /* "cPyparsing.pyx":3793
 *         return self
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         if self in parseElementList:
 *             raise RecursiveGrammarException(parseElementList + [self])
 */
  __pyx_tuple__697 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_parseElementList, __pyx_n_s_subRecCheckList); if (unlikely(!__pyx_tuple__697)) __PYX_ERR(0, 3793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__697);
  __Pyx_GIVEREF(__pyx_tuple__697);
  __pyx_codeobj__698 = (PyObject*)__Pyx_PyCode_New(2, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__697, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_checkRecursion, 3793, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__698)) __PYX_ERR(0, 3793, __pyx_L1_error)

  /* "cPyparsing.pyx":3800
 *             self.expr.checkRecursion(subRecCheckList)
 * 
 *     def validate(self, validateTrace=[]):             # <<<<<<<<<<<<<<
 *         tmp = validateTrace[:] + [self]
 *         if self.expr is not None:
 */
  __pyx_tuple__699 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_validateTrace, __pyx_n_s_tmp); if (unlikely(!__pyx_tuple__699)) __PYX_ERR(0, 3800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__699);
  __Pyx_GIVEREF(__pyx_tuple__699);
  __pyx_codeobj__700 = (PyObject*)__Pyx_PyCode_New(2, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__699, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_validate, 3800, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__700)) __PYX_ERR(0, 3800, __pyx_L1_error)

  /* "cPyparsing.pyx":3806
 *         self.checkRecursion([])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(ParseElementEnhance, self).__str__()
 */
  __pyx_tuple__701 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__701)) __PYX_ERR(0, 3806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__701);
  __Pyx_GIVEREF(__pyx_tuple__701);
  __pyx_codeobj__702 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__701, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_str_2, 3806, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__702)) __PYX_ERR(0, 3806, __pyx_L1_error)

  /* "cPyparsing.pyx":3835
 *     """
 * 
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(FollowedBy, self).__init__(expr)
 *         self.mayReturnEmpty = True
 */
  __pyx_tuple__703 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_expr); if (unlikely(!__pyx_tuple__703)) __PYX_ERR(0, 3835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__703);
  __Pyx_GIVEREF(__pyx_tuple__703);
  __pyx_codeobj__704 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__703, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 3835, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__704)) __PYX_ERR(0, 3835, __pyx_L1_error)

  /* "cPyparsing.pyx":3839
 *         self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         self.expr.tryParse(instring, loc)
 *         return loc, []
 */
  __pyx_tuple__705 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions); if (unlikely(!__pyx_tuple__705)) __PYX_ERR(0, 3839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__705);
  __Pyx_GIVEREF(__pyx_tuple__705);
  __pyx_codeobj__706 = (PyObject*)__Pyx_PyCode_New(4, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__705, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 3839, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__706)) __PYX_ERR(0, 3839, __pyx_L1_error)
  __pyx_tuple__707 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__707)) __PYX_ERR(0, 3839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__707);
  __Pyx_GIVEREF(__pyx_tuple__707);

  /* "cPyparsing.pyx":3856
 *     """
 * 
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(NotAny, self).__init__(expr)
 *         #~ self.leaveWhitespace()
 */
  __pyx_tuple__708 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_expr); if (unlikely(!__pyx_tuple__708)) __PYX_ERR(0, 3856, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__708);
  __Pyx_GIVEREF(__pyx_tuple__708);
  __pyx_codeobj__709 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__708, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 3856, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__709)) __PYX_ERR(0, 3856, __pyx_L1_error)

  /* "cPyparsing.pyx":3863
 *         self.errmsg = "Found unwanted token, " + _ustr(self.expr)
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.expr.canParseNext(instring, loc):
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_tuple__710 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions); if (unlikely(!__pyx_tuple__710)) __PYX_ERR(0, 3863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__710);
  __Pyx_GIVEREF(__pyx_tuple__710);
  __pyx_codeobj__711 = (PyObject*)__Pyx_PyCode_New(4, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__710, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 3863, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__711)) __PYX_ERR(0, 3863, __pyx_L1_error)
  __pyx_tuple__712 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__712)) __PYX_ERR(0, 3863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__712);
  __Pyx_GIVEREF(__pyx_tuple__712);

  /* "cPyparsing.pyx":3868
 *         return loc, []
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_tuple__713 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__713)) __PYX_ERR(0, 3868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__713);
  __Pyx_GIVEREF(__pyx_tuple__713);
  __pyx_codeobj__714 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__713, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_str_2, 3868, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__714)) __PYX_ERR(0, 3868, __pyx_L1_error)

  /* "cPyparsing.pyx":3879
 * 
 * class _MultipleMatch(ParseElementEnhance):
 *     def __init__(self, expr, stopOn=None):             # <<<<<<<<<<<<<<
 *         super(_MultipleMatch, self).__init__(expr)
 *         self.saveAsList = True
 */
  __pyx_tuple__715 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_expr, __pyx_n_s_stopOn, __pyx_n_s_ender); if (unlikely(!__pyx_tuple__715)) __PYX_ERR(0, 3879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__715);
  __Pyx_GIVEREF(__pyx_tuple__715);
  __pyx_codeobj__716 = (PyObject*)__Pyx_PyCode_New(3, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__715, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 3879, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__716)) __PYX_ERR(0, 3879, __pyx_L1_error)
  __pyx_tuple__717 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__717)) __PYX_ERR(0, 3879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__717);
  __Pyx_GIVEREF(__pyx_tuple__717);

  /* "cPyparsing.pyx":3887
 *         self.not_ender = ~ender if ender is not None else None
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         self_expr_parse = self.expr._parse
 *         self_skip_ignorables = self._skipIgnorables
 */
  __pyx_tuple__718 = PyTuple_Pack(12, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_self_expr_parse, __pyx_n_s_self_skip_ignorables, __pyx_n_s_check_ender, __pyx_n_s_try_not_ender, __pyx_n_s_tokens, __pyx_n_s_hasIgnoreExprs, __pyx_n_s_preloc, __pyx_n_s_tmptokens); if (unlikely(!__pyx_tuple__718)) __PYX_ERR(0, 3887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__718);
  __Pyx_GIVEREF(__pyx_tuple__718);
  __pyx_codeobj__719 = (PyObject*)__Pyx_PyCode_New(4, 0, 12, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__718, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 3887, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__719)) __PYX_ERR(0, 3887, __pyx_L1_error)
  __pyx_tuple__720 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__720)) __PYX_ERR(0, 3887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__720);
  __Pyx_GIVEREF(__pyx_tuple__720);

  /* "cPyparsing.pyx":3943
 *     """
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_tuple__721 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__721)) __PYX_ERR(0, 3943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__721);
  __Pyx_GIVEREF(__pyx_tuple__721);
  __pyx_codeobj__722 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__721, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_str_2, 3943, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__722)) __PYX_ERR(0, 3943, __pyx_L1_error)

  /* "cPyparsing.pyx":3966
 *     """
 * 
 *     def __init__(self, expr, stopOn=None):             # <<<<<<<<<<<<<<
 *         super(ZeroOrMore, self).__init__(expr, stopOn=stopOn)
 *         self.mayReturnEmpty = True
 */
  __pyx_tuple__723 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_expr, __pyx_n_s_stopOn); if (unlikely(!__pyx_tuple__723)) __PYX_ERR(0, 3966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__723);
  __Pyx_GIVEREF(__pyx_tuple__723);
  __pyx_codeobj__724 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__723, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 3966, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__724)) __PYX_ERR(0, 3966, __pyx_L1_error)
  __pyx_tuple__725 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__725)) __PYX_ERR(0, 3966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__725);
  __Pyx_GIVEREF(__pyx_tuple__725);

  /* "cPyparsing.pyx":3970
 *         self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(ZeroOrMore, self).parseImpl(instring, loc, doActions)
 */
  __pyx_tuple__726 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions); if (unlikely(!__pyx_tuple__726)) __PYX_ERR(0, 3970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__726);
  __Pyx_GIVEREF(__pyx_tuple__726);
  __pyx_codeobj__727 = (PyObject*)__Pyx_PyCode_New(4, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__726, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 3970, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__727)) __PYX_ERR(0, 3970, __pyx_L1_error)
  __pyx_tuple__728 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__728)) __PYX_ERR(0, 3970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__728);
  __Pyx_GIVEREF(__pyx_tuple__728);

  /* "cPyparsing.pyx":3976
 *             return loc, []
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_tuple__729 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__729)) __PYX_ERR(0, 3976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__729);
  __Pyx_GIVEREF(__pyx_tuple__729);
  __pyx_codeobj__730 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__729, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_str_2, 3976, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__730)) __PYX_ERR(0, 3976, __pyx_L1_error)

  /* "cPyparsing.pyx":3987
 * 
 * class _NullToken(object):
 *     def __bool__(self):             # <<<<<<<<<<<<<<
 *         return False
 *     __nonzero__ = __bool__
 */
  __pyx_tuple__731 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__731)) __PYX_ERR(0, 3987, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__731);
  __Pyx_GIVEREF(__pyx_tuple__731);
  __pyx_codeobj__732 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__731, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_bool, 3987, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__732)) __PYX_ERR(0, 3987, __pyx_L1_error)

  /* "cPyparsing.pyx":3991
 *     __nonzero__ = __bool__
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */
  __pyx_tuple__733 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__733)) __PYX_ERR(0, 3991, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__733);
  __Pyx_GIVEREF(__pyx_tuple__733);
  __pyx_codeobj__734 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__733, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_str_2, 3991, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__734)) __PYX_ERR(0, 3991, __pyx_L1_error)

  /* "cPyparsing.pyx":4034
 *     """
 * 
 *     def __init__(self, expr, default=_optionalNotMatched):             # <<<<<<<<<<<<<<
 *         super(Optional, self).__init__(expr, savelist=False)
 *         self.saveAsList = self.expr.saveAsList
 */
  __pyx_tuple__735 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_expr, __pyx_n_s_default); if (unlikely(!__pyx_tuple__735)) __PYX_ERR(0, 4034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__735);
  __Pyx_GIVEREF(__pyx_tuple__735);
  __pyx_codeobj__736 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__735, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 4034, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__736)) __PYX_ERR(0, 4034, __pyx_L1_error)

  /* "cPyparsing.pyx":4040
 *         self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         try:
 *             loc, tokens = self.expr._parse(instring, loc, doActions, callPreParse=False)
 */
  __pyx_tuple__737 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_tokens); if (unlikely(!__pyx_tuple__737)) __PYX_ERR(0, 4040, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__737);
  __Pyx_GIVEREF(__pyx_tuple__737);
  __pyx_codeobj__738 = (PyObject*)__Pyx_PyCode_New(4, 0, 5, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__737, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 4040, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__738)) __PYX_ERR(0, 4040, __pyx_L1_error)
  __pyx_tuple__739 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__739)) __PYX_ERR(0, 4040, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__739);
  __Pyx_GIVEREF(__pyx_tuple__739);

  /* "cPyparsing.pyx":4054
 *         return loc, tokens
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_tuple__740 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__740)) __PYX_ERR(0, 4054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__740);
  __Pyx_GIVEREF(__pyx_tuple__740);
  __pyx_codeobj__741 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__740, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_str_2, 4054, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__741)) __PYX_ERR(0, 4054, __pyx_L1_error)

  /* "cPyparsing.pyx":4120
 *     """
 * 
 *     def __init__(self, other, *args, **kwargs):  # include=False, ignore=None, failOn=None             # <<<<<<<<<<<<<<
 *         super(SkipTo, self).__init__(other)
 *         # include is a reserved word, so we have to get creative to allow it as an argument
 */
  __pyx_tuple__742 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_args, __pyx_n_s_kwargs, __pyx_n_s_failOn); if (unlikely(!__pyx_tuple__742)) __PYX_ERR(0, 4120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__742);
  __Pyx_GIVEREF(__pyx_tuple__742);
  __pyx_codeobj__743 = (PyObject*)__Pyx_PyCode_New(2, 0, 5, 0, CO_VARARGS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__742, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 4120, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__743)) __PYX_ERR(0, 4120, __pyx_L1_error)

  /* "cPyparsing.pyx":4137
 *         self.errmsg = "No match found for " + _ustr(self.expr)
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         startloc = loc
 *         instrlen = len(instring)
 */
  __pyx_tuple__744 = PyTuple_Pack(14, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_doActions, __pyx_n_s_startloc, __pyx_n_s_instrlen, __pyx_n_s_expr, __pyx_n_s_expr_parse, __pyx_n_s_self_failOn_canParseNext, __pyx_n_s_self_ignoreExpr_tryParse, __pyx_n_s_tmploc, __pyx_n_s_skiptext, __pyx_n_s_skipresult, __pyx_n_s_mat); if (unlikely(!__pyx_tuple__744)) __PYX_ERR(0, 4137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__744);
  __Pyx_GIVEREF(__pyx_tuple__744);
  __pyx_codeobj__745 = (PyObject*)__Pyx_PyCode_New(4, 0, 14, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__744, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_parseImpl, 4137, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__745)) __PYX_ERR(0, 4137, __pyx_L1_error)
  __pyx_tuple__746 = PyTuple_Pack(1, ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__746)) __PYX_ERR(0, 4137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__746);
  __Pyx_GIVEREF(__pyx_tuple__746);

  /* "cPyparsing.pyx":4205
 *     """
 * 
 *     def __init__(self, other=None):             # <<<<<<<<<<<<<<
 *         super(Forward, self).__init__(other, savelist=False)
 * 
 */
  __pyx_tuple__747 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__747)) __PYX_ERR(0, 4205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__747);
  __Pyx_GIVEREF(__pyx_tuple__747);
  __pyx_codeobj__748 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__747, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 4205, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__748)) __PYX_ERR(0, 4205, __pyx_L1_error)
  __pyx_tuple__749 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__749)) __PYX_ERR(0, 4205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__749);
  __Pyx_GIVEREF(__pyx_tuple__749);

  /* "cPyparsing.pyx":4208
 *         super(Forward, self).__init__(other, savelist=False)
 * 
 *     def __lshift__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 */
  __pyx_tuple__750 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__750)) __PYX_ERR(0, 4208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__750);
  __Pyx_GIVEREF(__pyx_tuple__750);
  __pyx_codeobj__751 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__750, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_lshift, 4208, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__751)) __PYX_ERR(0, 4208, __pyx_L1_error)

  /* "cPyparsing.pyx":4221
 *         return self
 * 
 *     def __ilshift__(self, other):             # <<<<<<<<<<<<<<
 *         return self << other
 * 
 */
  __pyx_tuple__752 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__752)) __PYX_ERR(0, 4221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__752);
  __Pyx_GIVEREF(__pyx_tuple__752);
  __pyx_codeobj__753 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__752, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_ilshift, 4221, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__753)) __PYX_ERR(0, 4221, __pyx_L1_error)

  /* "cPyparsing.pyx":4224
 *         return self << other
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = False
 *         return self
 */
  __pyx_tuple__754 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__754)) __PYX_ERR(0, 4224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__754);
  __Pyx_GIVEREF(__pyx_tuple__754);
  __pyx_codeobj__755 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__754, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_leaveWhitespace, 4224, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__755)) __PYX_ERR(0, 4224, __pyx_L1_error)

  /* "cPyparsing.pyx":4228
 *         return self
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         if not self.streamlined:
 *             self.streamlined = True
 */
  __pyx_tuple__756 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__756)) __PYX_ERR(0, 4228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__756);
  __Pyx_GIVEREF(__pyx_tuple__756);
  __pyx_codeobj__757 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__756, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_streamline, 4228, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__757)) __PYX_ERR(0, 4228, __pyx_L1_error)

  /* "cPyparsing.pyx":4235
 *         return self
 * 
 *     def validate(self, validateTrace=[]):             # <<<<<<<<<<<<<<
 *         if self not in validateTrace:
 *             tmp = validateTrace[:] + [self]
 */
  __pyx_tuple__758 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_validateTrace, __pyx_n_s_tmp); if (unlikely(!__pyx_tuple__758)) __PYX_ERR(0, 4235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__758);
  __Pyx_GIVEREF(__pyx_tuple__758);
  __pyx_codeobj__759 = (PyObject*)__Pyx_PyCode_New(2, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__758, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_validate, 4235, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__759)) __PYX_ERR(0, 4235, __pyx_L1_error)

  /* "cPyparsing.pyx":4242
 *         self.checkRecursion([])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_tuple__760 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__760)) __PYX_ERR(0, 4242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__760);
  __Pyx_GIVEREF(__pyx_tuple__760);
  __pyx_codeobj__761 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__760, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_str_2, 4242, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__761)) __PYX_ERR(0, 4242, __pyx_L1_error)

  /* "cPyparsing.pyx":4259
 *         # return self.__class__.__name__ + ": " + retString
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             return super(Forward, self).copy()
 */
  __pyx_tuple__762 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_ret); if (unlikely(!__pyx_tuple__762)) __PYX_ERR(0, 4259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__762);
  __Pyx_GIVEREF(__pyx_tuple__762);
  __pyx_codeobj__763 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__762, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_copy, 4259, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__763)) __PYX_ERR(0, 4259, __pyx_L1_error)

  /* "cPyparsing.pyx":4269
 * 
 * class _ForwardNoRecurse(Forward):
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "..."
 * 
 */
  __pyx_tuple__764 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__764)) __PYX_ERR(0, 4269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__764);
  __Pyx_GIVEREF(__pyx_tuple__764);
  __pyx_codeobj__765 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__764, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_str_2, 4269, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__765)) __PYX_ERR(0, 4269, __pyx_L1_error)

  /* "cPyparsing.pyx":4278
 *     """
 * 
 *     def __init__(self, expr, savelist=False):             # <<<<<<<<<<<<<<
 *         super(TokenConverter, self).__init__(expr)  # , savelist )
 *         self.saveAsList = False
 */
  __pyx_tuple__766 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_expr, __pyx_n_s_savelist); if (unlikely(!__pyx_tuple__766)) __PYX_ERR(0, 4278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__766);
  __Pyx_GIVEREF(__pyx_tuple__766);
  __pyx_codeobj__767 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__766, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 4278, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__767)) __PYX_ERR(0, 4278, __pyx_L1_error)
  __pyx_tuple__768 = PyTuple_Pack(1, ((PyObject *)Py_False)); if (unlikely(!__pyx_tuple__768)) __PYX_ERR(0, 4278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__768);
  __Pyx_GIVEREF(__pyx_tuple__768);

  /* "cPyparsing.pyx":4301
 *     """
 * 
 *     def __init__(self, expr, joinString="", adjacent=True):             # <<<<<<<<<<<<<<
 *         super(Combine, self).__init__(expr)
 *         # suppress whitespace-stripping in contained parse expressions, but re-enable it on the Combine itself
 */
  __pyx_tuple__769 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_expr, __pyx_n_s_joinString, __pyx_n_s_adjacent); if (unlikely(!__pyx_tuple__769)) __PYX_ERR(0, 4301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__769);
  __Pyx_GIVEREF(__pyx_tuple__769);
  __pyx_codeobj__770 = (PyObject*)__Pyx_PyCode_New(4, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__769, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 4301, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__770)) __PYX_ERR(0, 4301, __pyx_L1_error)
  __pyx_tuple__771 = PyTuple_Pack(2, ((PyObject*)__pyx_kp_u__9), ((PyObject *)Py_True)); if (unlikely(!__pyx_tuple__771)) __PYX_ERR(0, 4301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__771);
  __Pyx_GIVEREF(__pyx_tuple__771);

  /* "cPyparsing.pyx":4311
 *         self.callPreparse = True
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         if self.adjacent:
 *             ParserElement.ignore(self, other)
 */
  __pyx_tuple__772 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__772)) __PYX_ERR(0, 4311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__772);
  __Pyx_GIVEREF(__pyx_tuple__772);
  __pyx_codeobj__773 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__772, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_ignore, 4311, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__773)) __PYX_ERR(0, 4311, __pyx_L1_error)

  /* "cPyparsing.pyx":4318
 *         return self
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         retToks = tokenlist.copy()
 *         del retToks[:]
 */
  __pyx_tuple__774 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_tokenlist, __pyx_n_s_retToks); if (unlikely(!__pyx_tuple__774)) __PYX_ERR(0, 4318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__774);
  __Pyx_GIVEREF(__pyx_tuple__774);
  __pyx_codeobj__775 = (PyObject*)__Pyx_PyCode_New(4, 0, 5, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__774, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_postParse, 4318, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__775)) __PYX_ERR(0, 4318, __pyx_L1_error)

  /* "cPyparsing.pyx":4344
 *     """
 * 
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(Group, self).__init__(expr)
 *         self.saveAsList = True
 */
  __pyx_tuple__776 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_expr); if (unlikely(!__pyx_tuple__776)) __PYX_ERR(0, 4344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__776);
  __Pyx_GIVEREF(__pyx_tuple__776);
  __pyx_codeobj__777 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__776, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 4344, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__777)) __PYX_ERR(0, 4344, __pyx_L1_error)

  /* "cPyparsing.pyx":4348
 *         self.saveAsList = True
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         return [tokenlist]
 * 
 */
  __pyx_tuple__778 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_tokenlist); if (unlikely(!__pyx_tuple__778)) __PYX_ERR(0, 4348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__778);
  __Pyx_GIVEREF(__pyx_tuple__778);
  __pyx_codeobj__779 = (PyObject*)__Pyx_PyCode_New(4, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__778, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_postParse, 4348, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__779)) __PYX_ERR(0, 4348, __pyx_L1_error)

  /* "cPyparsing.pyx":4389
 *     """
 * 
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(Dict, self).__init__(expr)
 *         self.saveAsList = True
 */
  __pyx_tuple__780 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_expr); if (unlikely(!__pyx_tuple__780)) __PYX_ERR(0, 4389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__780);
  __Pyx_GIVEREF(__pyx_tuple__780);
  __pyx_codeobj__781 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__780, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 4389, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__781)) __PYX_ERR(0, 4389, __pyx_L1_error)

  /* "cPyparsing.pyx":4393
 *         self.saveAsList = True
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         for i, tok in enumerate(tokenlist):
 *             if len(tok) == 0:
 */
  __pyx_tuple__782 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_tokenlist, __pyx_n_s_i, __pyx_n_s_tok, __pyx_n_s_ikey, __pyx_n_s_dictvalue); if (unlikely(!__pyx_tuple__782)) __PYX_ERR(0, 4393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__782);
  __Pyx_GIVEREF(__pyx_tuple__782);
  __pyx_codeobj__783 = (PyObject*)__Pyx_PyCode_New(4, 0, 8, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__782, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_postParse, 4393, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__783)) __PYX_ERR(0, 4393, __pyx_L1_error)

  /* "cPyparsing.pyx":4438
 *     """
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         return []
 * 
 */
  __pyx_tuple__784 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_instring, __pyx_n_s_loc, __pyx_n_s_tokenlist); if (unlikely(!__pyx_tuple__784)) __PYX_ERR(0, 4438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__784);
  __Pyx_GIVEREF(__pyx_tuple__784);
  __pyx_codeobj__785 = (PyObject*)__Pyx_PyCode_New(4, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__784, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_postParse, 4438, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__785)) __PYX_ERR(0, 4438, __pyx_L1_error)

  /* "cPyparsing.pyx":4441
 *         return []
 * 
 *     def suppress(self):             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  __pyx_tuple__786 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__786)) __PYX_ERR(0, 4441, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__786);
  __Pyx_GIVEREF(__pyx_tuple__786);
  __pyx_codeobj__787 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__786, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_suppress, 4441, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__787)) __PYX_ERR(0, 4441, __pyx_L1_error)

  /* "cPyparsing.pyx":4450
 *     """
 * 
 *     def __init__(self, methodCall):             # <<<<<<<<<<<<<<
 *         self.callable = _trim_arity(methodCall)
 *         self.called = False
 */
  __pyx_tuple__788 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_methodCall); if (unlikely(!__pyx_tuple__788)) __PYX_ERR(0, 4450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__788);
  __Pyx_GIVEREF(__pyx_tuple__788);
  __pyx_codeobj__789 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__788, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_init, 4450, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__789)) __PYX_ERR(0, 4450, __pyx_L1_error)

  /* "cPyparsing.pyx":4454
 *         self.called = False
 * 
 *     def __call__(self, s, l, t):             # <<<<<<<<<<<<<<
 *         if not self.called:
 *             results = self.callable(s, l, t)
 */
  __pyx_tuple__790 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t, __pyx_n_s_results); if (unlikely(!__pyx_tuple__790)) __PYX_ERR(0, 4454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__790);
  __Pyx_GIVEREF(__pyx_tuple__790);
  __pyx_codeobj__791 = (PyObject*)__Pyx_PyCode_New(4, 0, 5, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__790, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_call, 4454, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__791)) __PYX_ERR(0, 4454, __pyx_L1_error)

  /* "cPyparsing.pyx":4461
 *         raise ParseException(s, l, "")
 * 
 *     def reset(self):             # <<<<<<<<<<<<<<
 *         self.called = False
 * 
 */
  __pyx_tuple__792 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__792)) __PYX_ERR(0, 4461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__792);
  __Pyx_GIVEREF(__pyx_tuple__792);
  __pyx_codeobj__793 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__792, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_reset, 4461, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__793)) __PYX_ERR(0, 4461, __pyx_L1_error)

  /* "cPyparsing.pyx":4465
 * 
 * 
 * def traceParseAction(f):             # <<<<<<<<<<<<<<
 *     """
 *     Decorator for debugging parse actions.
 */
  __pyx_tuple__794 = PyTuple_Pack(3, __pyx_n_s_f_2, __pyx_n_s_z, __pyx_n_s_z); if (unlikely(!__pyx_tuple__794)) __PYX_ERR(0, 4465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__794);
  __Pyx_GIVEREF(__pyx_tuple__794);
  __pyx_codeobj__795 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__794, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_traceParseAction, 4465, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__795)) __PYX_ERR(0, 4465, __pyx_L1_error)

  /* "cPyparsing.pyx":4512
 * 
 * 
 * def delimitedList(expr, delim=",", combine=False):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define a delimited list of expressions - the delimiter defaults to ','.
 */
  __pyx_tuple__796 = PyTuple_Pack(4, __pyx_n_s_expr, __pyx_n_s_delim, __pyx_n_s_combine, __pyx_n_s_dlName); if (unlikely(!__pyx_tuple__796)) __PYX_ERR(0, 4512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__796);
  __Pyx_GIVEREF(__pyx_tuple__796);
  __pyx_codeobj__797 = (PyObject*)__Pyx_PyCode_New(3, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__796, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_delimitedList, 4512, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__797)) __PYX_ERR(0, 4512, __pyx_L1_error)

  /* "cPyparsing.pyx":4532
 * 
 * 
 * def countedArray(expr, intExpr=None):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define a counted list of expressions.
 */
  __pyx_tuple__798 = PyTuple_Pack(5, __pyx_n_s_expr, __pyx_n_s_intExpr, __pyx_n_s_arrayExpr, __pyx_n_s_countFieldParseAction, __pyx_n_s_countFieldParseAction); if (unlikely(!__pyx_tuple__798)) __PYX_ERR(0, 4532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__798);
  __Pyx_GIVEREF(__pyx_tuple__798);
  __pyx_codeobj__799 = (PyObject*)__Pyx_PyCode_New(2, 0, 5, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__798, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_countedArray, 4532, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__799)) __PYX_ERR(0, 4532, __pyx_L1_error)

  /* "cPyparsing.pyx":4565
 * 
 * 
 * def _flatten(L):             # <<<<<<<<<<<<<<
 *     ret = []
 *     for i in L:
 */
  __pyx_tuple__800 = PyTuple_Pack(3, __pyx_n_s_L_2, __pyx_n_s_ret, __pyx_n_s_i); if (unlikely(!__pyx_tuple__800)) __PYX_ERR(0, 4565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__800);
  __Pyx_GIVEREF(__pyx_tuple__800);
  __pyx_codeobj__801 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__800, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_flatten, 4565, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__801)) __PYX_ERR(0, 4565, __pyx_L1_error)

  /* "cPyparsing.pyx":4575
 * 
 * 
 * def matchPreviousLiteral(expr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define an expression that is indirectly defined from
 */
  __pyx_tuple__802 = PyTuple_Pack(4, __pyx_n_s_expr, __pyx_n_s_rep, __pyx_n_s_copyTokenToRepeater, __pyx_n_s_copyTokenToRepeater); if (unlikely(!__pyx_tuple__802)) __PYX_ERR(0, 4575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__802);
  __Pyx_GIVEREF(__pyx_tuple__802);
  __pyx_codeobj__803 = (PyObject*)__Pyx_PyCode_New(1, 0, 4, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__802, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_matchPreviousLiteral, 4575, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__803)) __PYX_ERR(0, 4575, __pyx_L1_error)

  /* "cPyparsing.pyx":4605
 * 
 * 
 * def matchPreviousExpr(expr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define an expression that is indirectly defined from
 */
  __pyx_tuple__804 = PyTuple_Pack(5, __pyx_n_s_expr, __pyx_n_s_rep, __pyx_n_s_e2, __pyx_n_s_copyTokenToRepeater, __pyx_n_s_copyTokenToRepeater); if (unlikely(!__pyx_tuple__804)) __PYX_ERR(0, 4605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__804);
  __Pyx_GIVEREF(__pyx_tuple__804);
  __pyx_codeobj__805 = (PyObject*)__Pyx_PyCode_New(1, 0, 5, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__804, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_matchPreviousExpr, 4605, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__805)) __PYX_ERR(0, 4605, __pyx_L1_error)

  /* "cPyparsing.pyx":4636
 * 
 * 
 * def _escapeRegexRangeChars(s):             # <<<<<<<<<<<<<<
 *     #~  escape these chars: ^-]
 *     for c in r"\^-]":
 */
  __pyx_tuple__806 = PyTuple_Pack(2, __pyx_n_s_s, __pyx_n_s_c); if (unlikely(!__pyx_tuple__806)) __PYX_ERR(0, 4636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__806);
  __Pyx_GIVEREF(__pyx_tuple__806);
  __pyx_codeobj__807 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__806, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_escapeRegexRangeChars, 4636, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__807)) __PYX_ERR(0, 4636, __pyx_L1_error)

  /* "cPyparsing.pyx":4645
 * 
 * 
 * def oneOf(strs, caseless=False, useRegex=True):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to quickly define a set of alternative Literals, and makes sure to do
 */
  __pyx_tuple__808 = PyTuple_Pack(15, __pyx_n_s_strs, __pyx_n_s_caseless, __pyx_n_s_useRegex, __pyx_n_s_isequal, __pyx_n_s_masks, __pyx_n_s_parseElementClass, __pyx_n_s_symbols, __pyx_n_s_i, __pyx_n_s_cur, __pyx_n_s_j, __pyx_n_s_other, __pyx_n_s_genexpr, __pyx_n_s_genexpr, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__808)) __PYX_ERR(0, 4645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__808);
  __Pyx_GIVEREF(__pyx_tuple__808);
  __pyx_codeobj__809 = (PyObject*)__Pyx_PyCode_New(3, 0, 15, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__808, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_oneOf, 4645, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__809)) __PYX_ERR(0, 4645, __pyx_L1_error)

  /* "cPyparsing.pyx":4718
 * 
 * 
 * def dictOf(key, value):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to easily and clearly define a dictionary by specifying the respective patterns
 */
  __pyx_tuple__810 = PyTuple_Pack(2, __pyx_n_s_key, __pyx_n_s_value); if (unlikely(!__pyx_tuple__810)) __PYX_ERR(0, 4718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__810);
  __Pyx_GIVEREF(__pyx_tuple__810);
  __pyx_codeobj__811 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__810, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_dictOf, 4718, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__811)) __PYX_ERR(0, 4718, __pyx_L1_error)

  /* "cPyparsing.pyx":4754
 * 
 * 
 * def originalTextFor(expr, asString=True):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to return the original, untokenized text for a given expression.  Useful to
 */
  __pyx_tuple__812 = PyTuple_Pack(8, __pyx_n_s_expr, __pyx_n_s_asString, __pyx_n_s_locMarker, __pyx_n_s_endlocMarker, __pyx_n_s_matchExpr, __pyx_n_s_extractText, __pyx_n_s_extractText, __pyx_n_s_extractText); if (unlikely(!__pyx_tuple__812)) __PYX_ERR(0, 4754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__812);
  __Pyx_GIVEREF(__pyx_tuple__812);
  __pyx_codeobj__813 = (PyObject*)__Pyx_PyCode_New(2, 0, 8, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__812, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_originalTextFor, 4754, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__813)) __PYX_ERR(0, 4754, __pyx_L1_error)

  /* "cPyparsing.pyx":4792
 * 
 * 
 * def ungroup(expr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to undo pyparsing's default grouping of And expressions, even
 */
  __pyx_tuple__814 = PyTuple_Pack(1, __pyx_n_s_expr); if (unlikely(!__pyx_tuple__814)) __PYX_ERR(0, 4792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__814);
  __Pyx_GIVEREF(__pyx_tuple__814);
  __pyx_codeobj__815 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__814, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_ungroup, 4792, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__815)) __PYX_ERR(0, 4792, __pyx_L1_error)

  /* "cPyparsing.pyx":4800
 * 
 * 
 * def locatedExpr(expr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to decorate a returned token with its starting and ending locations in the input string.
 */
  __pyx_tuple__816 = PyTuple_Pack(2, __pyx_n_s_expr, __pyx_n_s_locator); if (unlikely(!__pyx_tuple__816)) __PYX_ERR(0, 4800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__816);
  __Pyx_GIVEREF(__pyx_tuple__816);
  __pyx_codeobj__817 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__816, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_locatedExpr, 4800, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__817)) __PYX_ERR(0, 4800, __pyx_L1_error)

  /* "cPyparsing.pyx":4825
 * 
 * # convenience constants for positional expressions
 * empty = Empty().setName("empty")             # <<<<<<<<<<<<<<
 * lineStart = LineStart().setName("lineStart")
 * lineEnd = LineEnd().setName("lineEnd")
 */
  __pyx_tuple__818 = PyTuple_Pack(1, __pyx_n_u_empty); if (unlikely(!__pyx_tuple__818)) __PYX_ERR(0, 4825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__818);
  __Pyx_GIVEREF(__pyx_tuple__818);

  /* "cPyparsing.pyx":4826
 * # convenience constants for positional expressions
 * empty = Empty().setName("empty")
 * lineStart = LineStart().setName("lineStart")             # <<<<<<<<<<<<<<
 * lineEnd = LineEnd().setName("lineEnd")
 * stringStart = StringStart().setName("stringStart")
 */
  __pyx_tuple__819 = PyTuple_Pack(1, __pyx_n_u_lineStart); if (unlikely(!__pyx_tuple__819)) __PYX_ERR(0, 4826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__819);
  __Pyx_GIVEREF(__pyx_tuple__819);

  /* "cPyparsing.pyx":4827
 * empty = Empty().setName("empty")
 * lineStart = LineStart().setName("lineStart")
 * lineEnd = LineEnd().setName("lineEnd")             # <<<<<<<<<<<<<<
 * stringStart = StringStart().setName("stringStart")
 * stringEnd = StringEnd().setName("stringEnd")
 */
  __pyx_tuple__820 = PyTuple_Pack(1, __pyx_n_u_lineEnd); if (unlikely(!__pyx_tuple__820)) __PYX_ERR(0, 4827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__820);
  __Pyx_GIVEREF(__pyx_tuple__820);

  /* "cPyparsing.pyx":4828
 * lineStart = LineStart().setName("lineStart")
 * lineEnd = LineEnd().setName("lineEnd")
 * stringStart = StringStart().setName("stringStart")             # <<<<<<<<<<<<<<
 * stringEnd = StringEnd().setName("stringEnd")
 * 
 */
  __pyx_tuple__821 = PyTuple_Pack(1, __pyx_n_u_stringStart); if (unlikely(!__pyx_tuple__821)) __PYX_ERR(0, 4828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__821);
  __Pyx_GIVEREF(__pyx_tuple__821);

  /* "cPyparsing.pyx":4829
 * lineEnd = LineEnd().setName("lineEnd")
 * stringStart = StringStart().setName("stringStart")
 * stringEnd = StringEnd().setName("stringEnd")             # <<<<<<<<<<<<<<
 * 
 * _escapedPunc = Word(_bslash, r"\[]-*.$+^?()~ ", exact=2).setParseAction(lambda s, l, t: t[0][1])
 */
  __pyx_tuple__822 = PyTuple_Pack(1, __pyx_n_u_stringEnd); if (unlikely(!__pyx_tuple__822)) __PYX_ERR(0, 4829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__822);
  __Pyx_GIVEREF(__pyx_tuple__822);

  /* "cPyparsing.pyx":4832
 * 
 * _escapedPunc = Word(_bslash, r"\[]-*.$+^?()~ ", exact=2).setParseAction(lambda s, l, t: t[0][1])
 * _escapedHexChar = Regex(r"\\0?[xX][0-9a-fA-F]+").setParseAction(lambda s, l, t: unichr(int(t[0].lstrip(r'\0x'), 16)))             # <<<<<<<<<<<<<<
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | Word(printables, excludeChars=r'\]', exact=1) | Regex(r"\w", re.UNICODE)
 */
  __pyx_tuple__824 = PyTuple_Pack(1, __pyx_kp_u_0_xX_0_9a_fA_F); if (unlikely(!__pyx_tuple__824)) __PYX_ERR(0, 4832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__824);
  __Pyx_GIVEREF(__pyx_tuple__824);

  /* "cPyparsing.pyx":4833
 * _escapedPunc = Word(_bslash, r"\[]-*.$+^?()~ ", exact=2).setParseAction(lambda s, l, t: t[0][1])
 * _escapedHexChar = Regex(r"\\0?[xX][0-9a-fA-F]+").setParseAction(lambda s, l, t: unichr(int(t[0].lstrip(r'\0x'), 16)))
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))             # <<<<<<<<<<<<<<
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | Word(printables, excludeChars=r'\]', exact=1) | Regex(r"\w", re.UNICODE)
 * _charRange = Group(_singleChar + Suppress("-") + _singleChar)
 */
  __pyx_tuple__825 = PyTuple_Pack(1, __pyx_kp_u_0_0_7); if (unlikely(!__pyx_tuple__825)) __PYX_ERR(0, 4833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__825);
  __Pyx_GIVEREF(__pyx_tuple__825);

  /* "cPyparsing.pyx":4835
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | Word(printables, excludeChars=r'\]', exact=1) | Regex(r"\w", re.UNICODE)
 * _charRange = Group(_singleChar + Suppress("-") + _singleChar)             # <<<<<<<<<<<<<<
 * _reBracketExpr = Literal("[") + Optional("^").setResultsName("negate") + Group(OneOrMore(_charRange | _singleChar)).setResultsName("body") + "]"
 * 
 */
  __pyx_tuple__827 = PyTuple_Pack(1, __pyx_kp_u__108); if (unlikely(!__pyx_tuple__827)) __PYX_ERR(0, 4835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__827);
  __Pyx_GIVEREF(__pyx_tuple__827);

  /* "cPyparsing.pyx":4836
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | Word(printables, excludeChars=r'\]', exact=1) | Regex(r"\w", re.UNICODE)
 * _charRange = Group(_singleChar + Suppress("-") + _singleChar)
 * _reBracketExpr = Literal("[") + Optional("^").setResultsName("negate") + Group(OneOrMore(_charRange | _singleChar)).setResultsName("body") + "]"             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__828 = PyTuple_Pack(1, __pyx_kp_u__16); if (unlikely(!__pyx_tuple__828)) __PYX_ERR(0, 4836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__828);
  __Pyx_GIVEREF(__pyx_tuple__828);
  __pyx_tuple__829 = PyTuple_Pack(1, __pyx_kp_u__85); if (unlikely(!__pyx_tuple__829)) __PYX_ERR(0, 4836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__829);
  __Pyx_GIVEREF(__pyx_tuple__829);
  __pyx_tuple__830 = PyTuple_Pack(1, __pyx_n_u_negate); if (unlikely(!__pyx_tuple__830)) __PYX_ERR(0, 4836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__830);
  __Pyx_GIVEREF(__pyx_tuple__830);
  __pyx_tuple__831 = PyTuple_Pack(1, __pyx_n_u_body); if (unlikely(!__pyx_tuple__831)) __PYX_ERR(0, 4836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__831);
  __Pyx_GIVEREF(__pyx_tuple__831);

  /* "cPyparsing.pyx":4839
 * 
 * 
 * def srange(s):             # <<<<<<<<<<<<<<
 *     r"""
 *     Helper to easily define string ranges for use in Word construction.  Borrows
 */
  __pyx_tuple__832 = PyTuple_Pack(5, __pyx_n_s_s, __pyx_n_s_expanded, __pyx_n_s_expanded, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__832)) __PYX_ERR(0, 4839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__832);
  __Pyx_GIVEREF(__pyx_tuple__832);
  __pyx_codeobj__833 = (PyObject*)__Pyx_PyCode_New(1, 0, 5, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__832, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_srange, 4839, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__833)) __PYX_ERR(0, 4839, __pyx_L1_error)

  /* "cPyparsing.pyx":4864
 * 
 * 
 * def matchOnlyAtCol(n):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for defining parse actions that require matching at a specific
 */
  __pyx_tuple__834 = PyTuple_Pack(3, __pyx_n_s_n, __pyx_n_s_verifyCol, __pyx_n_s_verifyCol); if (unlikely(!__pyx_tuple__834)) __PYX_ERR(0, 4864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__834);
  __Pyx_GIVEREF(__pyx_tuple__834);
  __pyx_codeobj__835 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__834, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_matchOnlyAtCol, 4864, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__835)) __PYX_ERR(0, 4864, __pyx_L1_error)

  /* "cPyparsing.pyx":4875
 * 
 * 
 * def replaceWith(replStr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for common parse actions that simply return a literal value.  Especially
 */
  __pyx_tuple__836 = PyTuple_Pack(1, __pyx_n_s_replStr); if (unlikely(!__pyx_tuple__836)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__836);
  __Pyx_GIVEREF(__pyx_tuple__836);
  __pyx_codeobj__837 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__836, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_replaceWith, 4875, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__837)) __PYX_ERR(0, 4875, __pyx_L1_error)

  /* "cPyparsing.pyx":4890
 * 
 * 
 * def removeQuotes(s, l, t):             # <<<<<<<<<<<<<<
 *     """
 *     Helper parse action for removing quotation marks from parsed quoted strings.
 */
  __pyx_tuple__838 = PyTuple_Pack(3, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_t); if (unlikely(!__pyx_tuple__838)) __PYX_ERR(0, 4890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__838);
  __Pyx_GIVEREF(__pyx_tuple__838);
  __pyx_codeobj__839 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__838, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_removeQuotes, 4890, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__839)) __PYX_ERR(0, 4890, __pyx_L1_error)

  /* "cPyparsing.pyx":4905
 * 
 * 
 * def tokenMap(func, *args):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define a parse action by mapping a function to all elements of a ParseResults list.If any additional
 */
  __pyx_tuple__840 = PyTuple_Pack(5, __pyx_n_s_func, __pyx_n_s_args, __pyx_n_s_pa, __pyx_n_s_pa, __pyx_n_s_func_name); if (unlikely(!__pyx_tuple__840)) __PYX_ERR(0, 4905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__840);
  __Pyx_GIVEREF(__pyx_tuple__840);
  __pyx_codeobj__841 = (PyObject*)__Pyx_PyCode_New(1, 0, 5, 0, CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__840, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_tokenMap, 4905, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__841)) __PYX_ERR(0, 4905, __pyx_L1_error)

  /* "cPyparsing.pyx":4957
 * 
 * 
 * def _makeTags(tagStr, xml):             # <<<<<<<<<<<<<<
 *     """Internal helper to construct opening and closing tag expressions, given a tag name"""
 *     if isinstance(tagStr, basestring):
 */
  __pyx_tuple__842 = PyTuple_Pack(10, __pyx_n_s_tagStr, __pyx_n_s_xml, __pyx_n_s_resname, __pyx_n_s_tagAttrName, __pyx_n_s_tagAttrValue, __pyx_n_s_openTag, __pyx_n_s_printablesLessRAbrack, __pyx_n_s_closeTag, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__842)) __PYX_ERR(0, 4957, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__842);
  __Pyx_GIVEREF(__pyx_tuple__842);
  __pyx_codeobj__843 = (PyObject*)__Pyx_PyCode_New(2, 0, 10, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__842, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_makeTags, 4957, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__843)) __PYX_ERR(0, 4957, __pyx_L1_error)

  /* "cPyparsing.pyx":4987
 * 
 * 
 * def makeHTMLTags(tagStr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to construct opening and closing tag expressions for HTML, given a tag name. Matches
 */
  __pyx_tuple__844 = PyTuple_Pack(1, __pyx_n_s_tagStr); if (unlikely(!__pyx_tuple__844)) __PYX_ERR(0, 4987, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__844);
  __Pyx_GIVEREF(__pyx_tuple__844);
  __pyx_codeobj__845 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__844, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_makeHTMLTags, 4987, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__845)) __PYX_ERR(0, 4987, __pyx_L1_error)

  /* "cPyparsing.pyx":5007
 * 
 * 
 * def makeXMLTags(tagStr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to construct opening and closing tag expressions for XML, given a tag name. Matches
 */
  __pyx_tuple__846 = PyTuple_Pack(1, __pyx_n_s_tagStr); if (unlikely(!__pyx_tuple__846)) __PYX_ERR(0, 5007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__846);
  __Pyx_GIVEREF(__pyx_tuple__846);
  __pyx_codeobj__847 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__846, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_makeXMLTags, 5007, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__847)) __PYX_ERR(0, 5007, __pyx_L1_error)

  /* "cPyparsing.pyx":5069
 *     ANY_VALUE = object()
 * 
 *     def __new__(cls, *args, **attrDict):             # <<<<<<<<<<<<<<
 *         if args:
 *             attrs = args[:]
 */
  __pyx_tuple__848 = PyTuple_Pack(6, __pyx_n_s_cls, __pyx_n_s_args, __pyx_n_s_attrDict, __pyx_n_s_attrs, __pyx_n_s_pa, __pyx_n_s_pa); if (unlikely(!__pyx_tuple__848)) __PYX_ERR(0, 5069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__848);
  __Pyx_GIVEREF(__pyx_tuple__848);
  __pyx_codeobj__849 = (PyObject*)__Pyx_PyCode_New(1, 0, 6, 0, CO_VARARGS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__848, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_new, 5069, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__849)) __PYX_ERR(0, 5069, __pyx_L1_error)

  /* "cPyparsing.pyx":5086
 * 
 * 
 * def withClass(classname, namespace=''):             # <<<<<<<<<<<<<<
 *     """
 *     Simplified version of C{L{withAttribute}} when matching on a div class - made
 */
  __pyx_tuple__850 = PyTuple_Pack(3, __pyx_n_s_classname, __pyx_n_s_namespace, __pyx_n_s_classattr); if (unlikely(!__pyx_tuple__850)) __PYX_ERR(0, 5086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__850);
  __Pyx_GIVEREF(__pyx_tuple__850);
  __pyx_codeobj__851 = (PyObject*)__Pyx_PyCode_New(2, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__850, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_withClass, 5086, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__851)) __PYX_ERR(0, 5086, __pyx_L1_error)

  /* "cPyparsing.pyx":5127
 * 
 * 
 * def infixNotation(baseExpr, opList, lpar=Suppress('('), rpar=Suppress(')')):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for constructing grammars of expressions made up of
 */
  __pyx_tuple__852 = PyTuple_Pack(1, __pyx_kp_u__195); if (unlikely(!__pyx_tuple__852)) __PYX_ERR(0, 5127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__852);
  __Pyx_GIVEREF(__pyx_tuple__852);
  __pyx_tuple__853 = PyTuple_Pack(1, __pyx_kp_u__94); if (unlikely(!__pyx_tuple__853)) __PYX_ERR(0, 5127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__853);
  __Pyx_GIVEREF(__pyx_tuple__853);
  __pyx_tuple__854 = PyTuple_Pack(17, __pyx_n_s_baseExpr, __pyx_n_s_opList, __pyx_n_s_lpar, __pyx_n_s_rpar, __pyx_n_s_ret, __pyx_n_s_lastExpr, __pyx_n_s_i, __pyx_n_s_operDef, __pyx_n_s_opExpr, __pyx_n_s_arity, __pyx_n_s_rightLeftAssoc, __pyx_n_s_pa, __pyx_n_s_termName, __pyx_n_s_opExpr1, __pyx_n_s_opExpr2, __pyx_n_s_thisExpr, __pyx_n_s_matchExpr); if (unlikely(!__pyx_tuple__854)) __PYX_ERR(0, 5127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__854);
  __Pyx_GIVEREF(__pyx_tuple__854);
  __pyx_codeobj__855 = (PyObject*)__Pyx_PyCode_New(4, 0, 17, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__854, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_infixNotation, 5127, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__855)) __PYX_ERR(0, 5127, __pyx_L1_error)

  /* "cPyparsing.pyx":5243
 * """(Deprecated) Former name of C{L{infixNotation}}, will be dropped in a future release."""
 * 
 * dblQuotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"').setName("string enclosed in double quotes")             # <<<<<<<<<<<<<<
 * sglQuotedString = Combine(Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("string enclosed in single quotes")
 * quotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"' |
 */
  __pyx_tuple__856 = PyTuple_Pack(1, __pyx_kp_u_n_r_x_x_0_9a_fA_F); if (unlikely(!__pyx_tuple__856)) __PYX_ERR(0, 5243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__856);
  __Pyx_GIVEREF(__pyx_tuple__856);
  __pyx_tuple__858 = PyTuple_Pack(1, __pyx_kp_u_string_enclosed_in_double_quotes); if (unlikely(!__pyx_tuple__858)) __PYX_ERR(0, 5243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__858);
  __Pyx_GIVEREF(__pyx_tuple__858);

  /* "cPyparsing.pyx":5244
 * 
 * dblQuotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"').setName("string enclosed in double quotes")
 * sglQuotedString = Combine(Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("string enclosed in single quotes")             # <<<<<<<<<<<<<<
 * quotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"' |
 *                        Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("quotedString using single or double quotes")
 */
  __pyx_tuple__859 = PyTuple_Pack(1, __pyx_kp_u_n_r_x_x_0_9a_fA_F_2); if (unlikely(!__pyx_tuple__859)) __PYX_ERR(0, 5244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__859);
  __Pyx_GIVEREF(__pyx_tuple__859);
  __pyx_tuple__861 = PyTuple_Pack(1, __pyx_kp_u_string_enclosed_in_single_quotes); if (unlikely(!__pyx_tuple__861)) __PYX_ERR(0, 5244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__861);
  __Pyx_GIVEREF(__pyx_tuple__861);

  /* "cPyparsing.pyx":5245
 * dblQuotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"').setName("string enclosed in double quotes")
 * sglQuotedString = Combine(Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("string enclosed in single quotes")
 * quotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"' |             # <<<<<<<<<<<<<<
 *                        Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("quotedString using single or double quotes")
 * unicodeString = Combine(_L('u') + quotedString.copy()).setName("unicode string literal")
 */
  __pyx_tuple__862 = PyTuple_Pack(1, __pyx_kp_u_n_r_x_x_0_9a_fA_F); if (unlikely(!__pyx_tuple__862)) __PYX_ERR(0, 5245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__862);
  __Pyx_GIVEREF(__pyx_tuple__862);

  /* "cPyparsing.pyx":5246
 * sglQuotedString = Combine(Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("string enclosed in single quotes")
 * quotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"' |
 *                        Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("quotedString using single or double quotes")             # <<<<<<<<<<<<<<
 * unicodeString = Combine(_L('u') + quotedString.copy()).setName("unicode string literal")
 * 
 */
  __pyx_tuple__863 = PyTuple_Pack(1, __pyx_kp_u_n_r_x_x_0_9a_fA_F_2); if (unlikely(!__pyx_tuple__863)) __PYX_ERR(0, 5246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__863);
  __Pyx_GIVEREF(__pyx_tuple__863);
  __pyx_tuple__864 = PyTuple_Pack(1, __pyx_kp_u_quotedString_using_single_or_dou); if (unlikely(!__pyx_tuple__864)) __PYX_ERR(0, 5246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__864);
  __Pyx_GIVEREF(__pyx_tuple__864);

  /* "cPyparsing.pyx":5247
 * quotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"' |
 *                        Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("quotedString using single or double quotes")
 * unicodeString = Combine(_L('u') + quotedString.copy()).setName("unicode string literal")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__865 = PyTuple_Pack(1, __pyx_n_u_u); if (unlikely(!__pyx_tuple__865)) __PYX_ERR(0, 5247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__865);
  __Pyx_GIVEREF(__pyx_tuple__865);
  __pyx_tuple__866 = PyTuple_Pack(1, __pyx_kp_u_unicode_string_literal); if (unlikely(!__pyx_tuple__866)) __PYX_ERR(0, 5247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__866);
  __Pyx_GIVEREF(__pyx_tuple__866);

  /* "cPyparsing.pyx":5250
 * 
 * 
 * def nestedExpr(opener="(", closer=")", content=None, ignoreExpr=quotedString.copy()):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for defining nested lists enclosed in opening and closing
 */
  __pyx_tuple__867 = PyTuple_Pack(5, __pyx_n_s_opener, __pyx_n_s_closer, __pyx_n_s_content, __pyx_n_s_ignoreExpr, __pyx_n_s_ret); if (unlikely(!__pyx_tuple__867)) __PYX_ERR(0, 5250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__867);
  __Pyx_GIVEREF(__pyx_tuple__867);
  __pyx_codeobj__868 = (PyObject*)__Pyx_PyCode_New(4, 0, 5, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__867, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_nestedExpr, 5250, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__868)) __PYX_ERR(0, 5250, __pyx_L1_error)

  /* "cPyparsing.pyx":5341
 * 
 * 
 * def indentedBlock(blockStatementExpr, indentStack, indent=True):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for defining space-delimited indentation blocks, such as
 */
  __pyx_tuple__869 = PyTuple_Pack(14, __pyx_n_s_blockStatementExpr, __pyx_n_s_indentStack, __pyx_n_s_indent, __pyx_n_s_checkPeerIndent, __pyx_n_s_checkPeerIndent, __pyx_n_s_checkSubIndent, __pyx_n_s_checkSubIndent, __pyx_n_s_checkUnindent, __pyx_n_s_checkUnindent, __pyx_n_s_NL, __pyx_n_s_INDENT, __pyx_n_s_PEER, __pyx_n_s_UNDENT, __pyx_n_s_smExpr); if (unlikely(!__pyx_tuple__869)) __PYX_ERR(0, 5341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__869);
  __Pyx_GIVEREF(__pyx_tuple__869);
  __pyx_codeobj__870 = (PyObject*)__Pyx_PyCode_New(3, 0, 14, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__869, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_indentedBlock, 5341, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__870)) __PYX_ERR(0, 5341, __pyx_L1_error)

  /* "cPyparsing.pyx":5458
 * 
 * 
 * alphas8bit = srange(r"[\0xc0-\0xd6\0xd8-\0xf6\0xf8-\0xff]")             # <<<<<<<<<<<<<<
 * punc8bit = srange(r"[\0xa1-\0xbf\0xd7\0xf7]")
 * 
 */
  __pyx_tuple__871 = PyTuple_Pack(1, __pyx_kp_u_0xc0_0xd6_0xd8_0xf6_0xf8_0xff); if (unlikely(!__pyx_tuple__871)) __PYX_ERR(0, 5458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__871);
  __Pyx_GIVEREF(__pyx_tuple__871);

  /* "cPyparsing.pyx":5459
 * 
 * alphas8bit = srange(r"[\0xc0-\0xd6\0xd8-\0xf6\0xf8-\0xff]")
 * punc8bit = srange(r"[\0xa1-\0xbf\0xd7\0xf7]")             # <<<<<<<<<<<<<<
 * 
 * anyOpenTag, anyCloseTag = makeHTMLTags(Word(alphas, alphanums + "_:").setName('any tag'))
 */
  __pyx_tuple__872 = PyTuple_Pack(1, __pyx_kp_u_0xa1_0xbf_0xd7_0xf7); if (unlikely(!__pyx_tuple__872)) __PYX_ERR(0, 5459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__872);
  __Pyx_GIVEREF(__pyx_tuple__872);

  /* "cPyparsing.pyx":5461
 * punc8bit = srange(r"[\0xa1-\0xbf\0xd7\0xf7]")
 * 
 * anyOpenTag, anyCloseTag = makeHTMLTags(Word(alphas, alphanums + "_:").setName('any tag'))             # <<<<<<<<<<<<<<
 * _htmlEntityMap = dict(zip("gt lt amp nbsp quot apos".split(), '><& "\''))
 * commonHTMLEntity = Regex('&(?P<entity>' + '|'.join(_htmlEntityMap.keys()) + ");").setName("common HTML entity")
 */
  __pyx_tuple__874 = PyTuple_Pack(1, __pyx_kp_u_any_tag); if (unlikely(!__pyx_tuple__874)) __PYX_ERR(0, 5461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__874);
  __Pyx_GIVEREF(__pyx_tuple__874);

  /* "cPyparsing.pyx":5463
 * anyOpenTag, anyCloseTag = makeHTMLTags(Word(alphas, alphanums + "_:").setName('any tag'))
 * _htmlEntityMap = dict(zip("gt lt amp nbsp quot apos".split(), '><& "\''))
 * commonHTMLEntity = Regex('&(?P<entity>' + '|'.join(_htmlEntityMap.keys()) + ");").setName("common HTML entity")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__877 = PyTuple_Pack(1, __pyx_kp_u_common_HTML_entity); if (unlikely(!__pyx_tuple__877)) __PYX_ERR(0, 5463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__877);
  __Pyx_GIVEREF(__pyx_tuple__877);

  /* "cPyparsing.pyx":5466
 * 
 * 
 * def replaceHTMLEntity(t):             # <<<<<<<<<<<<<<
 *     """Helper parser action to replace common HTML entities with their special characters"""
 *     return _htmlEntityMap.get(t.entity)
 */
  __pyx_tuple__878 = PyTuple_Pack(1, __pyx_n_s_t); if (unlikely(!__pyx_tuple__878)) __PYX_ERR(0, 5466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__878);
  __Pyx_GIVEREF(__pyx_tuple__878);
  __pyx_codeobj__879 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__878, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_replaceHTMLEntity, 5466, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__879)) __PYX_ERR(0, 5466, __pyx_L1_error)

  /* "cPyparsing.pyx":5472
 * 
 * # it's easy to get these comment structures wrong - they're very common, so may as well make them available
 * cStyleComment = Combine(Regex(r"/\*(?:[^*]|\*(?!/))*") + '*[inserted by cython to avoid comment closer]/').setName("C style comment")             # <<<<<<<<<<<<<<
 * "Comment of the form C{/[inserted by cython to avoid comment start]* ... *[inserted by cython to avoid comment closer]/}"
 * 
 */
  __pyx_tuple__881 = PyTuple_Pack(1, __pyx_kp_u__880); if (unlikely(!__pyx_tuple__881)) __PYX_ERR(0, 5472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__881);
  __Pyx_GIVEREF(__pyx_tuple__881);
  __pyx_tuple__883 = PyTuple_Pack(1, __pyx_kp_u_C_style_comment); if (unlikely(!__pyx_tuple__883)) __PYX_ERR(0, 5472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__883);
  __Pyx_GIVEREF(__pyx_tuple__883);

  /* "cPyparsing.pyx":5475
 * "Comment of the form C{/[inserted by cython to avoid comment start]* ... *[inserted by cython to avoid comment closer]/}"
 * 
 * htmlComment = Regex(r"<!--[\s\S]*?-->").setName("HTML comment")             # <<<<<<<<<<<<<<
 * "Comment of the form C{<!-- ... -->}"
 * 
 */
  __pyx_tuple__884 = PyTuple_Pack(1, __pyx_kp_u_s_S); if (unlikely(!__pyx_tuple__884)) __PYX_ERR(0, 5475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__884);
  __Pyx_GIVEREF(__pyx_tuple__884);
  __pyx_tuple__885 = PyTuple_Pack(1, __pyx_kp_u_HTML_comment); if (unlikely(!__pyx_tuple__885)) __PYX_ERR(0, 5475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__885);
  __Pyx_GIVEREF(__pyx_tuple__885);

  /* "cPyparsing.pyx":5478
 * "Comment of the form C{<!-- ... -->}"
 * 
 * restOfLine = Regex(r".*").leaveWhitespace().setName("rest of line")             # <<<<<<<<<<<<<<
 * dblSlashComment = Regex(r"//(?:\\\n|[^\n])*").setName("// comment")
 * "Comment of the form C{// ... (to end of line)}"
 */
  __pyx_tuple__887 = PyTuple_Pack(1, __pyx_kp_u__886); if (unlikely(!__pyx_tuple__887)) __PYX_ERR(0, 5478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__887);
  __Pyx_GIVEREF(__pyx_tuple__887);
  __pyx_tuple__888 = PyTuple_Pack(1, __pyx_kp_u_rest_of_line); if (unlikely(!__pyx_tuple__888)) __PYX_ERR(0, 5478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__888);
  __Pyx_GIVEREF(__pyx_tuple__888);

  /* "cPyparsing.pyx":5479
 * 
 * restOfLine = Regex(r".*").leaveWhitespace().setName("rest of line")
 * dblSlashComment = Regex(r"//(?:\\\n|[^\n])*").setName("// comment")             # <<<<<<<<<<<<<<
 * "Comment of the form C{// ... (to end of line)}"
 * 
 */
  __pyx_tuple__889 = PyTuple_Pack(1, __pyx_kp_u_n_n); if (unlikely(!__pyx_tuple__889)) __PYX_ERR(0, 5479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__889);
  __Pyx_GIVEREF(__pyx_tuple__889);
  __pyx_tuple__890 = PyTuple_Pack(1, __pyx_kp_u_comment_2); if (unlikely(!__pyx_tuple__890)) __PYX_ERR(0, 5479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__890);
  __Pyx_GIVEREF(__pyx_tuple__890);

  /* "cPyparsing.pyx":5482
 * "Comment of the form C{// ... (to end of line)}"
 * 
 * cppStyleComment = Combine(Regex(r"/\*(?:[^*]|\*(?!/))*") + '*[inserted by cython to avoid comment closer]/' | dblSlashComment).setName("C++ style comment")             # <<<<<<<<<<<<<<
 * "Comment of either form C{L{cStyleComment}} or C{L{dblSlashComment}}"
 * 
 */
  __pyx_tuple__891 = PyTuple_Pack(1, __pyx_kp_u__880); if (unlikely(!__pyx_tuple__891)) __PYX_ERR(0, 5482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__891);
  __Pyx_GIVEREF(__pyx_tuple__891);
  __pyx_tuple__892 = PyTuple_Pack(1, __pyx_kp_u_C_style_comment_2); if (unlikely(!__pyx_tuple__892)) __PYX_ERR(0, 5482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__892);
  __Pyx_GIVEREF(__pyx_tuple__892);

  /* "cPyparsing.pyx":5488
 * "Same as C{L{cppStyleComment}}"
 * 
 * pythonStyleComment = Regex(r"#.*").setName("Python style comment")             # <<<<<<<<<<<<<<
 * "Comment of the form C{# ... (to end of line)}"
 * 
 */
  __pyx_tuple__894 = PyTuple_Pack(1, __pyx_kp_u__893); if (unlikely(!__pyx_tuple__894)) __PYX_ERR(0, 5488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__894);
  __Pyx_GIVEREF(__pyx_tuple__894);
  __pyx_tuple__895 = PyTuple_Pack(1, __pyx_kp_u_Python_style_comment); if (unlikely(!__pyx_tuple__895)) __PYX_ERR(0, 5488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__895);
  __Pyx_GIVEREF(__pyx_tuple__895);

  /* "cPyparsing.pyx":5492
 * 
 * _commasepitem = Combine(OneOrMore(Word(printables, excludeChars=',') +
 *                                   Optional(Word(" \t") +             # <<<<<<<<<<<<<<
 *                                            ~Literal(",") + ~LineEnd()))).streamline().setName("commaItem")
 * commaSeparatedList = delimitedList(Optional(quotedString.copy() | _commasepitem, default="")).setName("commaSeparatedList")
 */
  __pyx_tuple__897 = PyTuple_Pack(1, __pyx_kp_u__896); if (unlikely(!__pyx_tuple__897)) __PYX_ERR(0, 5492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__897);
  __Pyx_GIVEREF(__pyx_tuple__897);

  /* "cPyparsing.pyx":5493
 * _commasepitem = Combine(OneOrMore(Word(printables, excludeChars=',') +
 *                                   Optional(Word(" \t") +
 *                                            ~Literal(",") + ~LineEnd()))).streamline().setName("commaItem")             # <<<<<<<<<<<<<<
 * commaSeparatedList = delimitedList(Optional(quotedString.copy() | _commasepitem, default="")).setName("commaSeparatedList")
 * """(Deprecated) Predefined expression of 1 or more printable words or quoted strings, separated by commas.
 */
  __pyx_tuple__898 = PyTuple_Pack(1, __pyx_kp_u__132); if (unlikely(!__pyx_tuple__898)) __PYX_ERR(0, 5493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__898);
  __Pyx_GIVEREF(__pyx_tuple__898);
  __pyx_tuple__899 = PyTuple_Pack(1, __pyx_n_u_commaItem); if (unlikely(!__pyx_tuple__899)) __PYX_ERR(0, 5493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__899);
  __Pyx_GIVEREF(__pyx_tuple__899);

  /* "cPyparsing.pyx":5494
 *                                   Optional(Word(" \t") +
 *                                            ~Literal(",") + ~LineEnd()))).streamline().setName("commaItem")
 * commaSeparatedList = delimitedList(Optional(quotedString.copy() | _commasepitem, default="")).setName("commaSeparatedList")             # <<<<<<<<<<<<<<
 * """(Deprecated) Predefined expression of 1 or more printable words or quoted strings, separated by commas.
 *    This expression is deprecated in favor of L{pyparsing_common.comma_separated_list}."""
 */
  __pyx_tuple__900 = PyTuple_Pack(1, __pyx_n_u_commaSeparatedList); if (unlikely(!__pyx_tuple__900)) __PYX_ERR(0, 5494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__900);
  __Pyx_GIVEREF(__pyx_tuple__900);

  /* "cPyparsing.pyx":5647
 *     """
 * 
 *     integer = Word(nums).setName("integer").setParseAction(convertToInteger)             # <<<<<<<<<<<<<<
 *     """expression that parses an unsigned integer, returns an int"""
 * 
 */
  __pyx_tuple__901 = PyTuple_Pack(1, __pyx_n_u_integer); if (unlikely(!__pyx_tuple__901)) __PYX_ERR(0, 5647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__901);
  __Pyx_GIVEREF(__pyx_tuple__901);

  /* "cPyparsing.pyx":5650
 *     """expression that parses an unsigned integer, returns an int"""
 * 
 *     hex_integer = Word(hexnums).setName("hex integer").setParseAction(tokenMap(int, 16))             # <<<<<<<<<<<<<<
 *     """expression that parses a hexadecimal integer, returns an int"""
 * 
 */
  __pyx_tuple__902 = PyTuple_Pack(1, __pyx_kp_u_hex_integer); if (unlikely(!__pyx_tuple__902)) __PYX_ERR(0, 5650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__902);
  __Pyx_GIVEREF(__pyx_tuple__902);

  /* "cPyparsing.pyx":5653
 *     """expression that parses a hexadecimal integer, returns an int"""
 * 
 *     signed_integer = Regex(r'[+-]?\d+').setName("signed integer").setParseAction(convertToInteger)             # <<<<<<<<<<<<<<
 *     """expression that parses an integer with optional leading sign, returns an int"""
 * 
 */
  __pyx_tuple__903 = PyTuple_Pack(1, __pyx_kp_u_d_2); if (unlikely(!__pyx_tuple__903)) __PYX_ERR(0, 5653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__903);
  __Pyx_GIVEREF(__pyx_tuple__903);
  __pyx_tuple__904 = PyTuple_Pack(1, __pyx_kp_u_signed_integer); if (unlikely(!__pyx_tuple__904)) __PYX_ERR(0, 5653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__904);
  __Pyx_GIVEREF(__pyx_tuple__904);

  /* "cPyparsing.pyx":5656
 *     """expression that parses an integer with optional leading sign, returns an int"""
 * 
 *     fraction = (signed_integer().setParseAction(convertToFloat) + '/' + signed_integer().setParseAction(convertToFloat)).setName("fraction")             # <<<<<<<<<<<<<<
 *     """fractional expression of an integer divided by an integer, returns a float"""
 *     fraction.addParseAction(lambda t: t[0] / t[-1])
 */
  __pyx_tuple__905 = PyTuple_Pack(1, __pyx_n_u_fraction); if (unlikely(!__pyx_tuple__905)) __PYX_ERR(0, 5656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__905);
  __Pyx_GIVEREF(__pyx_tuple__905);

  /* "cPyparsing.pyx":5660
 *     fraction.addParseAction(lambda t: t[0] / t[-1])
 * 
 *     mixed_integer = (fraction | signed_integer + Optional(Optional('-').suppress() + fraction)).setName("fraction or mixed integer-fraction")             # <<<<<<<<<<<<<<
 *     """mixed integer of the form 'integer - fraction', with optional leading integer, returns float"""
 *     mixed_integer.addParseAction(sum)
 */
  __pyx_tuple__906 = PyTuple_Pack(1, __pyx_kp_u__108); if (unlikely(!__pyx_tuple__906)) __PYX_ERR(0, 5660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__906);
  __Pyx_GIVEREF(__pyx_tuple__906);
  __pyx_tuple__907 = PyTuple_Pack(1, __pyx_kp_u_fraction_or_mixed_integer_fracti); if (unlikely(!__pyx_tuple__907)) __PYX_ERR(0, 5660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__907);
  __Pyx_GIVEREF(__pyx_tuple__907);

  /* "cPyparsing.pyx":5664
 *     mixed_integer.addParseAction(sum)
 * 
 *     real = Regex(r'[+-]?\d+\.\d*').setName("real number").setParseAction(convertToFloat)             # <<<<<<<<<<<<<<
 *     """expression that parses a floating point number and returns a float"""
 * 
 */
  __pyx_tuple__908 = PyTuple_Pack(1, __pyx_kp_u_d_d_2); if (unlikely(!__pyx_tuple__908)) __PYX_ERR(0, 5664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__908);
  __Pyx_GIVEREF(__pyx_tuple__908);
  __pyx_tuple__909 = PyTuple_Pack(1, __pyx_kp_u_real_number); if (unlikely(!__pyx_tuple__909)) __PYX_ERR(0, 5664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__909);
  __Pyx_GIVEREF(__pyx_tuple__909);

  /* "cPyparsing.pyx":5667
 *     """expression that parses a floating point number and returns a float"""
 * 
 *     sci_real = Regex(r'[+-]?\d+([eE][+-]?\d+|\.\d*([eE][+-]?\d+)?)').setName("real number with scientific notation").setParseAction(convertToFloat)             # <<<<<<<<<<<<<<
 *     """expression that parses a floating point number with optional scientific notation and returns a float"""
 * 
 */
  __pyx_tuple__910 = PyTuple_Pack(1, __pyx_kp_u_d_eE_d_d_eE_d); if (unlikely(!__pyx_tuple__910)) __PYX_ERR(0, 5667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__910);
  __Pyx_GIVEREF(__pyx_tuple__910);
  __pyx_tuple__911 = PyTuple_Pack(1, __pyx_kp_u_real_number_with_scientific_nota); if (unlikely(!__pyx_tuple__911)) __PYX_ERR(0, 5667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__911);
  __Pyx_GIVEREF(__pyx_tuple__911);

  /* "cPyparsing.pyx":5674
 *     """any numeric expression, returns the corresponding Python type"""
 * 
 *     fnumber = Regex(r'[+-]?\d+\.?\d*([eE][+-]?\d+)?').setName("fnumber").setParseAction(convertToFloat)             # <<<<<<<<<<<<<<
 *     """any int or real number, returned as float"""
 * 
 */
  __pyx_tuple__912 = PyTuple_Pack(1, __pyx_kp_u_d_d_eE_d); if (unlikely(!__pyx_tuple__912)) __PYX_ERR(0, 5674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__912);
  __Pyx_GIVEREF(__pyx_tuple__912);
  __pyx_tuple__913 = PyTuple_Pack(1, __pyx_n_u_fnumber); if (unlikely(!__pyx_tuple__913)) __PYX_ERR(0, 5674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__913);
  __Pyx_GIVEREF(__pyx_tuple__913);

  /* "cPyparsing.pyx":5677
 *     """any int or real number, returned as float"""
 * 
 *     identifier = Word(alphas + '_', alphanums + '_').setName("identifier")             # <<<<<<<<<<<<<<
 *     """typical code identifier (leading alpha or '_', followed by 0 or more alphas, nums, or '_')"""
 * 
 */
  __pyx_tuple__914 = PyTuple_Pack(1, __pyx_n_u_identifier); if (unlikely(!__pyx_tuple__914)) __PYX_ERR(0, 5677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__914);
  __Pyx_GIVEREF(__pyx_tuple__914);

  /* "cPyparsing.pyx":5680
 *     """typical code identifier (leading alpha or '_', followed by 0 or more alphas, nums, or '_')"""
 * 
 *     ipv4_address = Regex(r'(25[0-5]|2[0-4][0-9]|1?[0-9]{1,2})(\.(25[0-5]|2[0-4][0-9]|1?[0-9]{1,2})){3}').setName("IPv4 address")             # <<<<<<<<<<<<<<
 *     "IPv4 address (C{0.0.0.0 - 255.255.255.255})"
 * 
 */
  __pyx_tuple__915 = PyTuple_Pack(1, __pyx_kp_u_25_0_5_2_0_4_0_9_1_0_9_1_2_25_0); if (unlikely(!__pyx_tuple__915)) __PYX_ERR(0, 5680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__915);
  __Pyx_GIVEREF(__pyx_tuple__915);
  __pyx_tuple__916 = PyTuple_Pack(1, __pyx_kp_u_IPv4_address); if (unlikely(!__pyx_tuple__916)) __PYX_ERR(0, 5680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__916);
  __Pyx_GIVEREF(__pyx_tuple__916);

  /* "cPyparsing.pyx":5683
 *     "IPv4 address (C{0.0.0.0 - 255.255.255.255})"
 * 
 *     _ipv6_part = Regex(r'[0-9a-fA-F]{1,4}').setName("hex_integer")             # <<<<<<<<<<<<<<
 *     _full_ipv6_address = (_ipv6_part + (':' + _ipv6_part) * 7).setName("full IPv6 address")
 *     _short_ipv6_address = (Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6)) + "::" + Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))).setName("short IPv6 address")
 */
  __pyx_tuple__917 = PyTuple_Pack(1, __pyx_kp_u_0_9a_fA_F_1_4); if (unlikely(!__pyx_tuple__917)) __PYX_ERR(0, 5683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__917);
  __Pyx_GIVEREF(__pyx_tuple__917);
  __pyx_tuple__918 = PyTuple_Pack(1, __pyx_n_u_hex_integer_2); if (unlikely(!__pyx_tuple__918)) __PYX_ERR(0, 5683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__918);
  __Pyx_GIVEREF(__pyx_tuple__918);

  /* "cPyparsing.pyx":5684
 * 
 *     _ipv6_part = Regex(r'[0-9a-fA-F]{1,4}').setName("hex_integer")
 *     _full_ipv6_address = (_ipv6_part + (':' + _ipv6_part) * 7).setName("full IPv6 address")             # <<<<<<<<<<<<<<
 *     _short_ipv6_address = (Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6)) + "::" + Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))).setName("short IPv6 address")
 *     _short_ipv6_address.addCondition(lambda t: sum(1 for tt in t if pyparsing_common._ipv6_part.matches(tt)) < 8)
 */
  __pyx_tuple__919 = PyTuple_Pack(1, __pyx_kp_u_full_IPv6_address); if (unlikely(!__pyx_tuple__919)) __PYX_ERR(0, 5684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__919);
  __Pyx_GIVEREF(__pyx_tuple__919);

  /* "cPyparsing.pyx":5685
 *     _ipv6_part = Regex(r'[0-9a-fA-F]{1,4}').setName("hex_integer")
 *     _full_ipv6_address = (_ipv6_part + (':' + _ipv6_part) * 7).setName("full IPv6 address")
 *     _short_ipv6_address = (Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6)) + "::" + Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))).setName("short IPv6 address")             # <<<<<<<<<<<<<<
 *     _short_ipv6_address.addCondition(lambda t: sum(1 for tt in t if pyparsing_common._ipv6_part.matches(tt)) < 8)
 *     _mixed_ipv6_address = ("::ffff:" + ipv4_address).setName("mixed IPv6 address")
 */
  __pyx_tuple__920 = PyTuple_Pack(2, __pyx_int_0, __pyx_int_6); if (unlikely(!__pyx_tuple__920)) __PYX_ERR(0, 5685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__920);
  __Pyx_GIVEREF(__pyx_tuple__920);
  __pyx_tuple__922 = PyTuple_Pack(2, __pyx_int_0, __pyx_int_6); if (unlikely(!__pyx_tuple__922)) __PYX_ERR(0, 5685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__922);
  __Pyx_GIVEREF(__pyx_tuple__922);
  __pyx_tuple__923 = PyTuple_Pack(1, __pyx_kp_u_short_IPv6_address); if (unlikely(!__pyx_tuple__923)) __PYX_ERR(0, 5685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__923);
  __Pyx_GIVEREF(__pyx_tuple__923);

  /* "cPyparsing.pyx":5687
 *     _short_ipv6_address = (Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6)) + "::" + Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))).setName("short IPv6 address")
 *     _short_ipv6_address.addCondition(lambda t: sum(1 for tt in t if pyparsing_common._ipv6_part.matches(tt)) < 8)
 *     _mixed_ipv6_address = ("::ffff:" + ipv4_address).setName("mixed IPv6 address")             # <<<<<<<<<<<<<<
 *     ipv6_address = Combine((_full_ipv6_address | _mixed_ipv6_address | _short_ipv6_address).setName("IPv6 address")).setName("IPv6 address")
 *     "IPv6 address (long, short, or mixed form)"
 */
  __pyx_tuple__924 = PyTuple_Pack(1, __pyx_kp_u_mixed_IPv6_address); if (unlikely(!__pyx_tuple__924)) __PYX_ERR(0, 5687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__924);
  __Pyx_GIVEREF(__pyx_tuple__924);

  /* "cPyparsing.pyx":5688
 *     _short_ipv6_address.addCondition(lambda t: sum(1 for tt in t if pyparsing_common._ipv6_part.matches(tt)) < 8)
 *     _mixed_ipv6_address = ("::ffff:" + ipv4_address).setName("mixed IPv6 address")
 *     ipv6_address = Combine((_full_ipv6_address | _mixed_ipv6_address | _short_ipv6_address).setName("IPv6 address")).setName("IPv6 address")             # <<<<<<<<<<<<<<
 *     "IPv6 address (long, short, or mixed form)"
 * 
 */
  __pyx_tuple__925 = PyTuple_Pack(1, __pyx_kp_u_IPv6_address); if (unlikely(!__pyx_tuple__925)) __PYX_ERR(0, 5688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__925);
  __Pyx_GIVEREF(__pyx_tuple__925);
  __pyx_tuple__926 = PyTuple_Pack(1, __pyx_kp_u_IPv6_address); if (unlikely(!__pyx_tuple__926)) __PYX_ERR(0, 5688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__926);
  __Pyx_GIVEREF(__pyx_tuple__926);

  /* "cPyparsing.pyx":5691
 *     "IPv6 address (long, short, or mixed form)"
 * 
 *     mac_address = Regex(r'[0-9a-fA-F]{2}([:.-])[0-9a-fA-F]{2}(?:\1[0-9a-fA-F]{2}){4}').setName("MAC address")             # <<<<<<<<<<<<<<
 *     "MAC address xx:xx:xx:xx:xx (may also have '-' or '.' delimiters)"
 * 
 */
  __pyx_tuple__927 = PyTuple_Pack(1, __pyx_kp_u_0_9a_fA_F_2_0_9a_fA_F_2_1_0_9a); if (unlikely(!__pyx_tuple__927)) __PYX_ERR(0, 5691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__927);
  __Pyx_GIVEREF(__pyx_tuple__927);
  __pyx_tuple__928 = PyTuple_Pack(1, __pyx_kp_u_MAC_address); if (unlikely(!__pyx_tuple__928)) __PYX_ERR(0, 5691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__928);
  __Pyx_GIVEREF(__pyx_tuple__928);

  /* "cPyparsing.pyx":5695
 * 
 *     @staticmethod
 *     def convertToDate(fmt="%Y-%m-%d"):             # <<<<<<<<<<<<<<
 *         """
 *         Helper to create a parse action for converting parsed date string to Python datetime.date
 */
  __pyx_tuple__929 = PyTuple_Pack(3, __pyx_n_s_fmt, __pyx_n_s_cvt_fn, __pyx_n_s_cvt_fn); if (unlikely(!__pyx_tuple__929)) __PYX_ERR(0, 5695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__929);
  __Pyx_GIVEREF(__pyx_tuple__929);
  __pyx_codeobj__930 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__929, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_convertToDate, 5695, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__930)) __PYX_ERR(0, 5695, __pyx_L1_error)
  __pyx_tuple__931 = PyTuple_Pack(1, ((PyObject*)__pyx_kp_u_Y_m_d)); if (unlikely(!__pyx_tuple__931)) __PYX_ERR(0, 5695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__931);
  __Pyx_GIVEREF(__pyx_tuple__931);

  /* "cPyparsing.pyx":5717
 * 
 *     @staticmethod
 *     def convertToDatetime(fmt="%Y-%m-%dT%H:%M:%S.%f"):             # <<<<<<<<<<<<<<
 *         """
 *         Helper to create a parse action for converting parsed datetime string to Python datetime.datetime
 */
  __pyx_tuple__932 = PyTuple_Pack(3, __pyx_n_s_fmt, __pyx_n_s_cvt_fn, __pyx_n_s_cvt_fn); if (unlikely(!__pyx_tuple__932)) __PYX_ERR(0, 5717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__932);
  __Pyx_GIVEREF(__pyx_tuple__932);
  __pyx_codeobj__933 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__932, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_convertToDatetime, 5717, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__933)) __PYX_ERR(0, 5717, __pyx_L1_error)
  __pyx_tuple__934 = PyTuple_Pack(1, ((PyObject*)__pyx_kp_u_Y_m_dT_H_M_S_f)); if (unlikely(!__pyx_tuple__934)) __PYX_ERR(0, 5717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__934);
  __Pyx_GIVEREF(__pyx_tuple__934);

  /* "cPyparsing.pyx":5738
 *         return cvt_fn
 * 
 *     iso8601_date = Regex(r'(?P<year>\d{4})(?:-(?P<month>\d\d)(?:-(?P<day>\d\d))?)?').setName("ISO8601 date")             # <<<<<<<<<<<<<<
 *     "ISO8601 date (C{yyyy-mm-dd})"
 * 
 */
  __pyx_tuple__935 = PyTuple_Pack(1, __pyx_kp_u_P_year_d_4_P_month_d_d_P_day_d); if (unlikely(!__pyx_tuple__935)) __PYX_ERR(0, 5738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__935);
  __Pyx_GIVEREF(__pyx_tuple__935);
  __pyx_tuple__936 = PyTuple_Pack(1, __pyx_kp_u_ISO8601_date); if (unlikely(!__pyx_tuple__936)) __PYX_ERR(0, 5738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__936);
  __Pyx_GIVEREF(__pyx_tuple__936);

  /* "cPyparsing.pyx":5741
 *     "ISO8601 date (C{yyyy-mm-dd})"
 * 
 *     iso8601_datetime = Regex(r'(?P<year>\d{4})-(?P<month>\d\d)-(?P<day>\d\d)[T ](?P<hour>\d\d):(?P<minute>\d\d)(:(?P<second>\d\d(\.\d*)?)?)?(?P<tz>Z|[+-]\d\d:?\d\d)?').setName("ISO8601 datetime")             # <<<<<<<<<<<<<<
 *     "ISO8601 datetime (C{yyyy-mm-ddThh:mm:ss.s(Z|+-00:00)}) - trailing seconds, milliseconds, and timezone optional; accepts separating C{'T'} or C{' '}"
 * 
 */
  __pyx_tuple__937 = PyTuple_Pack(1, __pyx_kp_u_P_year_d_4_P_month_d_d_P_day_d_2); if (unlikely(!__pyx_tuple__937)) __PYX_ERR(0, 5741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__937);
  __Pyx_GIVEREF(__pyx_tuple__937);
  __pyx_tuple__938 = PyTuple_Pack(1, __pyx_kp_u_ISO8601_datetime); if (unlikely(!__pyx_tuple__938)) __PYX_ERR(0, 5741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__938);
  __Pyx_GIVEREF(__pyx_tuple__938);

  /* "cPyparsing.pyx":5744
 *     "ISO8601 datetime (C{yyyy-mm-ddThh:mm:ss.s(Z|+-00:00)}) - trailing seconds, milliseconds, and timezone optional; accepts separating C{'T'} or C{' '}"
 * 
 *     uuid = Regex(r'[0-9a-fA-F]{8}(-[0-9a-fA-F]{4}){3}-[0-9a-fA-F]{12}').setName("UUID")             # <<<<<<<<<<<<<<
 *     "UUID (C{xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx})"
 * 
 */
  __pyx_tuple__939 = PyTuple_Pack(1, __pyx_kp_u_0_9a_fA_F_8_0_9a_fA_F_4_3_0_9a); if (unlikely(!__pyx_tuple__939)) __PYX_ERR(0, 5744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__939);
  __Pyx_GIVEREF(__pyx_tuple__939);
  __pyx_tuple__940 = PyTuple_Pack(1, __pyx_n_u_UUID); if (unlikely(!__pyx_tuple__940)) __PYX_ERR(0, 5744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__940);
  __Pyx_GIVEREF(__pyx_tuple__940);

  /* "cPyparsing.pyx":5750
 * 
 *     @staticmethod
 *     def stripHTMLTags(s, l, tokens):             # <<<<<<<<<<<<<<
 *         """
 *         Parse action to remove HTML tags from web page HTML source
 */
  __pyx_tuple__941 = PyTuple_Pack(3, __pyx_n_s_s, __pyx_n_s_l, __pyx_n_s_tokens); if (unlikely(!__pyx_tuple__941)) __PYX_ERR(0, 5750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__941);
  __Pyx_GIVEREF(__pyx_tuple__941);
  __pyx_codeobj__942 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__941, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_home_travis_build_evhub_cpypars, __pyx_n_s_stripHTMLTags, 5750, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__942)) __PYX_ERR(0, 5750, __pyx_L1_error)

  /* "cPyparsing.pyx":5764
 *         return pyparsing_common._html_stripper.transformString(tokens[0])
 * 
 *     _commasepitem = Combine(OneOrMore(~Literal(",") + ~LineEnd() + Word(printables, excludeChars=',')             # <<<<<<<<<<<<<<
 *                                       + Optional(White(" \t")))).streamline().setName("commaItem")
 *     comma_separated_list = delimitedList(Optional(quotedString.copy() | _commasepitem, default="")).setName("comma separated list")
 */
  __pyx_tuple__943 = PyTuple_Pack(1, __pyx_kp_u__132); if (unlikely(!__pyx_tuple__943)) __PYX_ERR(0, 5764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__943);
  __Pyx_GIVEREF(__pyx_tuple__943);

  /* "cPyparsing.pyx":5765
 * 
 *     _commasepitem = Combine(OneOrMore(~Literal(",") + ~LineEnd() + Word(printables, excludeChars=',')
 *                                       + Optional(White(" \t")))).streamline().setName("commaItem")             # <<<<<<<<<<<<<<
 *     comma_separated_list = delimitedList(Optional(quotedString.copy() | _commasepitem, default="")).setName("comma separated list")
 *     """Predefined expression of 1 or more printable words or quoted strings, separated by commas."""
 */
  __pyx_tuple__944 = PyTuple_Pack(1, __pyx_kp_u__896); if (unlikely(!__pyx_tuple__944)) __PYX_ERR(0, 5765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__944);
  __Pyx_GIVEREF(__pyx_tuple__944);
  __pyx_tuple__945 = PyTuple_Pack(1, __pyx_n_u_commaItem); if (unlikely(!__pyx_tuple__945)) __PYX_ERR(0, 5765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__945);
  __Pyx_GIVEREF(__pyx_tuple__945);

  /* "cPyparsing.pyx":5766
 *     _commasepitem = Combine(OneOrMore(~Literal(",") + ~LineEnd() + Word(printables, excludeChars=',')
 *                                       + Optional(White(" \t")))).streamline().setName("commaItem")
 *     comma_separated_list = delimitedList(Optional(quotedString.copy() | _commasepitem, default="")).setName("comma separated list")             # <<<<<<<<<<<<<<
 *     """Predefined expression of 1 or more printable words or quoted strings, separated by commas."""
 * 
 */
  __pyx_tuple__946 = PyTuple_Pack(1, __pyx_kp_u_comma_separated_list); if (unlikely(!__pyx_tuple__946)) __PYX_ERR(0, 5766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__946);
  __Pyx_GIVEREF(__pyx_tuple__946);

  /* "cPyparsing.pyx":5778
 * if __name__ == "__main__":
 * 
 *     selectToken = CaselessLiteral("select")             # <<<<<<<<<<<<<<
 *     fromToken = CaselessLiteral("from")
 * 
 */
  __pyx_tuple__947 = PyTuple_Pack(1, __pyx_n_u_select); if (unlikely(!__pyx_tuple__947)) __PYX_ERR(0, 5778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__947);
  __Pyx_GIVEREF(__pyx_tuple__947);

  /* "cPyparsing.pyx":5779
 * 
 *     selectToken = CaselessLiteral("select")
 *     fromToken = CaselessLiteral("from")             # <<<<<<<<<<<<<<
 * 
 *     ident = Word(alphas, alphanums + "_$")
 */
  __pyx_tuple__948 = PyTuple_Pack(1, __pyx_n_u_from_2); if (unlikely(!__pyx_tuple__948)) __PYX_ERR(0, 5779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__948);
  __Pyx_GIVEREF(__pyx_tuple__948);

  /* "cPyparsing.pyx":5784
 * 
 *     columnName = delimitedList(ident, ".", combine=True).setParseAction(upcaseTokens)
 *     columnNameList = Group(delimitedList(columnName)).setName("columns")             # <<<<<<<<<<<<<<
 *     columnSpec = ('*' | columnNameList)
 * 
 */
  __pyx_tuple__949 = PyTuple_Pack(1, __pyx_n_u_columns); if (unlikely(!__pyx_tuple__949)) __PYX_ERR(0, 5784, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__949);
  __Pyx_GIVEREF(__pyx_tuple__949);

  /* "cPyparsing.pyx":5788
 * 
 *     tableName = delimitedList(ident, ".", combine=True).setParseAction(upcaseTokens)
 *     tableNameList = Group(delimitedList(tableName)).setName("tables")             # <<<<<<<<<<<<<<
 * 
 *     simpleSQL = selectToken("command") + columnSpec("columns") + fromToken + tableNameList("tables")
 */
  __pyx_tuple__950 = PyTuple_Pack(1, __pyx_n_u_tables); if (unlikely(!__pyx_tuple__950)) __PYX_ERR(0, 5788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__950);
  __Pyx_GIVEREF(__pyx_tuple__950);

  /* "cPyparsing.pyx":5790
 *     tableNameList = Group(delimitedList(tableName)).setName("tables")
 * 
 *     simpleSQL = selectToken("command") + columnSpec("columns") + fromToken + tableNameList("tables")             # <<<<<<<<<<<<<<
 * 
 *     # demo runTests method, including embedded comments in test string
 */
  __pyx_tuple__951 = PyTuple_Pack(1, __pyx_n_u_command); if (unlikely(!__pyx_tuple__951)) __PYX_ERR(0, 5790, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__951);
  __Pyx_GIVEREF(__pyx_tuple__951);
  __pyx_tuple__952 = PyTuple_Pack(1, __pyx_n_u_columns); if (unlikely(!__pyx_tuple__952)) __PYX_ERR(0, 5790, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__952);
  __Pyx_GIVEREF(__pyx_tuple__952);
  __pyx_tuple__953 = PyTuple_Pack(1, __pyx_n_u_tables); if (unlikely(!__pyx_tuple__953)) __PYX_ERR(0, 5790, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__953);
  __Pyx_GIVEREF(__pyx_tuple__953);

  /* "cPyparsing.pyx":5793
 * 
 *     # demo runTests method, including embedded comments in test string
 *     simpleSQL.runTests("""             # <<<<<<<<<<<<<<
 *         # '*' as column list and dotted table name
 *         select * from SYS.XYZZY
 */
  __pyx_tuple__954 = PyTuple_Pack(1, __pyx_kp_u_as_column_list_and_dotted_table); if (unlikely(!__pyx_tuple__954)) __PYX_ERR(0, 5793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__954);
  __Pyx_GIVEREF(__pyx_tuple__954);

  /* "cPyparsing.pyx":5817
 *         """)
 * 
 *     pyparsing_common.number.runTests("""             # <<<<<<<<<<<<<<
 *         100
 *         -100
 */
  __pyx_tuple__955 = PyTuple_Pack(1, __pyx_kp_u_100_100_100_3_14159_6_02e23_1e); if (unlikely(!__pyx_tuple__955)) __PYX_ERR(0, 5817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__955);
  __Pyx_GIVEREF(__pyx_tuple__955);

  /* "cPyparsing.pyx":5827
 * 
 *     # any int or real number, returned as float
 *     pyparsing_common.fnumber.runTests("""             # <<<<<<<<<<<<<<
 *         100
 *         -100
 */
  __pyx_tuple__956 = PyTuple_Pack(1, __pyx_kp_u_100_100_100_3_14159_6_02e23_1e); if (unlikely(!__pyx_tuple__956)) __PYX_ERR(0, 5827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__956);
  __Pyx_GIVEREF(__pyx_tuple__956);

  /* "cPyparsing.pyx":5836
 *         """)
 * 
 *     pyparsing_common.hex_integer.runTests("""             # <<<<<<<<<<<<<<
 *         100
 *         FF
 */
  __pyx_tuple__957 = PyTuple_Pack(1, __pyx_kp_u_100_FF); if (unlikely(!__pyx_tuple__957)) __PYX_ERR(0, 5836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__957);
  __Pyx_GIVEREF(__pyx_tuple__957);

  /* "cPyparsing.pyx":5843
 *     import uuid
 *     pyparsing_common.uuid.setParseAction(tokenMap(uuid.UUID))
 *     pyparsing_common.uuid.runTests("""             # <<<<<<<<<<<<<<
 *         12345678-1234-5678-1234-567812345678
 *         """)
 */
  __pyx_tuple__958 = PyTuple_Pack(1, __pyx_kp_u_12345678_1234_5678_1234_5678123); if (unlikely(!__pyx_tuple__958)) __PYX_ERR(0, 5843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__958);
  __Pyx_GIVEREF(__pyx_tuple__958);
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_InitGlobals(void) {
  /* Common.init */
  __Pyx_check_twos_complement();

if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* SizeCheck.init */
  __Pyx_check_sane_Py_ssize_t();

if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  __pyx_umethod_PyDict_Type_items.type = (PyObject*)&PyDict_Type;
  __pyx_umethod_PyList_Type_pop.type = (PyObject*)&PyList_Type;
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_4 = PyInt_FromLong(4); if (unlikely(!__pyx_int_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_5 = PyInt_FromLong(5); if (unlikely(!__pyx_int_5)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_6 = PyInt_FromLong(6); if (unlikely(!__pyx_int_6)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_7 = PyInt_FromLong(7); if (unlikely(!__pyx_int_7)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8 = PyInt_FromLong(8); if (unlikely(!__pyx_int_8)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_16 = PyInt_FromLong(16); if (unlikely(!__pyx_int_16)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_92 = PyInt_FromLong(92); if (unlikely(!__pyx_int_92)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_128 = PyInt_FromLong(128); if (unlikely(!__pyx_int_128)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1056 = PyInt_FromLong(1056); if (unlikely(!__pyx_int_1056)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_neg_1 = PyInt_FromLong(-1); if (unlikely(!__pyx_int_neg_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

#if PY_MAJOR_VERSION < 3
PyMODINIT_FUNC initcPyparsing(void); /*proto*/
PyMODINIT_FUNC initcPyparsing(void)
#else
PyMODINIT_FUNC PyInit_cPyparsing(void); /*proto*/
PyMODINIT_FUNC PyInit_cPyparsing(void)
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  Py_ssize_t __pyx_t_15;
  int __pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  int __pyx_t_18;
  PyObject *__pyx_t_19 = NULL;
  PyObject *(*__pyx_t_20)(PyObject *);
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  __Pyx_RefNannyDeclarations
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
      PyErr_Clear();
      __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
      if (!__Pyx_RefNanny)
          Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  __Pyx_RefNannySetupContext("PyMODINIT_FUNC PyInit_cPyparsing(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("cPyparsing", __pyx_methods, __pyx_k_cPyparsing_is_an_alternative_im, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  #if CYTHON_COMPILING_IN_PYPY
  Py_INCREF(__pyx_b);
  #endif
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_cPyparsing) {
    if (PyObject_SetAttrString(__pyx_m, "__name__", __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "cPyparsing")) {
      if (unlikely(PyDict_SetItemString(modules, "cPyparsing", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global init code ---*/
  /*--- Variable export code ---*/
  /*--- Function export code ---*/
  /*--- Type init code ---*/
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct__genexpr) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct__genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct__genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct__genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_1_genexpr) < 0) __PYX_ERR(0, 166, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_1_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_1_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_1_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_2_genexpr) < 0) __PYX_ERR(0, 181, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_2_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_2_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_2_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_3__itervalues) < 0) __PYX_ERR(0, 465, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_3__itervalues.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_3__itervalues = &__pyx_type_10cPyparsing___pyx_scope_struct_3__itervalues;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_4_genexpr) < 0) __PYX_ERR(0, 466, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_4_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_4_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_4_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_5__iteritems) < 0) __PYX_ERR(0, 468, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_5__iteritems.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_5__iteritems = &__pyx_type_10cPyparsing___pyx_scope_struct_5__iteritems;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_6_genexpr) < 0) __PYX_ERR(0, 469, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_6_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_6_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_6_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_7___iadd__) < 0) __PYX_ERR(0, 660, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_7___iadd__.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_7___iadd__ = &__pyx_type_10cPyparsing___pyx_scope_struct_7___iadd__;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_8___str__) < 0) __PYX_ERR(0, 688, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_8___str__.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_8___str__ = &__pyx_type_10cPyparsing___pyx_scope_struct_8___str__;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_9_genexpr) < 0) __PYX_ERR(0, 689, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_9_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_9_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_9_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_10_asDict) < 0) __PYX_ERR(0, 718, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_10_asDict.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_10_asDict = &__pyx_type_10cPyparsing___pyx_scope_struct_10_asDict;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_11_genexpr) < 0) __PYX_ERR(0, 751, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_11_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_11_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_11_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_12_asXML) < 0) __PYX_ERR(0, 764, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_12_asXML.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_12_asXML = &__pyx_type_10cPyparsing___pyx_scope_struct_12_asXML;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_13_genexpr) < 0) __PYX_ERR(0, 770, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_13_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_13_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_13_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_14_dump) < 0) __PYX_ERR(0, 869, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_14_dump.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_14_dump = &__pyx_type_10cPyparsing___pyx_scope_struct_14_dump;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_15_genexpr) < 0) __PYX_ERR(0, 892, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_15_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_15_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_15_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_16_genexpr) < 0) __PYX_ERR(0, 904, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_16_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_16_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_16_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_17__trim_arity) < 0) __PYX_ERR(0, 1023, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_17__trim_arity.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_17__trim_arity = &__pyx_type_10cPyparsing___pyx_scope_struct_17__trim_arity;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_18_setBreak) < 0) __PYX_ERR(0, 1218, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_18_setBreak.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_18_setBreak = &__pyx_type_10cPyparsing___pyx_scope_struct_18_setBreak;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_19_addCondition) < 0) __PYX_ERR(0, 1285, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_19_addCondition.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_19_addCondition = &__pyx_type_10cPyparsing___pyx_scope_struct_19_addCondition;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_20___init__) < 0) __PYX_ERR(0, 1444, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_20___init__.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_20___init__ = &__pyx_type_10cPyparsing___pyx_scope_struct_20___init__;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_21___init__) < 0) __PYX_ERR(0, 1467, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_21___init__.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_21___init__ = &__pyx_type_10cPyparsing___pyx_scope_struct_21___init__;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_22___init__) < 0) __PYX_ERR(0, 1496, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_22___init__.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_22___init__ = &__pyx_type_10cPyparsing___pyx_scope_struct_22___init__;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_23_scanString) < 0) __PYX_ERR(0, 1647, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_23_scanString.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_23_scanString = &__pyx_type_10cPyparsing___pyx_scope_struct_23_scanString;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_24_split) < 0) __PYX_ERR(0, 1788, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_24_split.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_24_split = &__pyx_type_10cPyparsing___pyx_scope_struct_24_split;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_25___mul__) < 0) __PYX_ERR(0, 1866, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_25___mul__.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_25___mul__ = &__pyx_type_10cPyparsing___pyx_scope_struct_25___mul__;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_26___init__) < 0) __PYX_ERR(0, 2656, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_26___init__.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_26___init__ = &__pyx_type_10cPyparsing___pyx_scope_struct_26___init__;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_27_genexpr) < 0) __PYX_ERR(0, 2659, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_27_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_27_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_27_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_28_genexpr) < 0) __PYX_ERR(0, 2661, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_28_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_28_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_28_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_29___init__) < 0) __PYX_ERR(0, 2867, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_29___init__.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_29___init__ = &__pyx_type_10cPyparsing___pyx_scope_struct_29___init__;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_30_genexpr) < 0) __PYX_ERR(0, 2908, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_30_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_30_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_30_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_31___init__) < 0) __PYX_ERR(0, 3068, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_31___init__.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_31___init__ = &__pyx_type_10cPyparsing___pyx_scope_struct_31___init__;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_32_genexpr) < 0) __PYX_ERR(0, 3071, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_32_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_32_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_32_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_33_genexpr) < 0) __PYX_ERR(0, 3073, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_33_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_33_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_33_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_34___init__) < 0) __PYX_ERR(0, 3281, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_34___init__.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_34___init__ = &__pyx_type_10cPyparsing___pyx_scope_struct_34___init__;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_35_genexpr) < 0) __PYX_ERR(0, 3291, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_35_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_35_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_35_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_36___init__) < 0) __PYX_ERR(0, 3412, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_36___init__.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_36___init__ = &__pyx_type_10cPyparsing___pyx_scope_struct_36___init__;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_37_genexpr) < 0) __PYX_ERR(0, 3414, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_37_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_37_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_37_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_38___str__) < 0) __PYX_ERR(0, 3456, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_38___str__.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_38___str__ = &__pyx_type_10cPyparsing___pyx_scope_struct_38___str__;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_39_genexpr) < 0) __PYX_ERR(0, 3461, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_39_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_39_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_39_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_40___init__) < 0) __PYX_ERR(0, 3481, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_40___init__.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_40___init__ = &__pyx_type_10cPyparsing___pyx_scope_struct_40___init__;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_41_genexpr) < 0) __PYX_ERR(0, 3484, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_41_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_41_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_41_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_42___str__) < 0) __PYX_ERR(0, 3530, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_42___str__.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_42___str__ = &__pyx_type_10cPyparsing___pyx_scope_struct_42___str__;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_43_genexpr) < 0) __PYX_ERR(0, 3535, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_43_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_43_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_43_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_44___init__) < 0) __PYX_ERR(0, 3563, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_44___init__.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_44___init__ = &__pyx_type_10cPyparsing___pyx_scope_struct_44___init__;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_45_genexpr) < 0) __PYX_ERR(0, 3566, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_45_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_45_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_45_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_46___str__) < 0) __PYX_ERR(0, 3599, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_46___str__.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_46___str__ = &__pyx_type_10cPyparsing___pyx_scope_struct_46___str__;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_47_genexpr) < 0) __PYX_ERR(0, 3604, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_47_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_47_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_47_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_48___init__) < 0) __PYX_ERR(0, 3669, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_48___init__.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_48___init__ = &__pyx_type_10cPyparsing___pyx_scope_struct_48___init__;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_49_genexpr) < 0) __PYX_ERR(0, 3671, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_49_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_49_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_49_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_50_parseImpl) < 0) __PYX_ERR(0, 3675, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_50_parseImpl.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_50_parseImpl = &__pyx_type_10cPyparsing___pyx_scope_struct_50_parseImpl;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_51_genexpr) < 0) __PYX_ERR(0, 3677, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_51_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_51_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_51_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_52_genexpr) < 0) __PYX_ERR(0, 3710, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_52_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_52_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_52_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_53___str__) < 0) __PYX_ERR(0, 3724, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_53___str__.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_53___str__ = &__pyx_type_10cPyparsing___pyx_scope_struct_53___str__;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_54_genexpr) < 0) __PYX_ERR(0, 3729, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_54_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_54_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_54_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_55_traceParseAction) < 0) __PYX_ERR(0, 4465, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_55_traceParseAction.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_55_traceParseAction = &__pyx_type_10cPyparsing___pyx_scope_struct_55_traceParseAction;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_56_countedArray) < 0) __PYX_ERR(0, 4532, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_56_countedArray.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_56_countedArray = &__pyx_type_10cPyparsing___pyx_scope_struct_56_countedArray;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral) < 0) __PYX_ERR(0, 4575, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral = &__pyx_type_10cPyparsing___pyx_scope_struct_57_matchPreviousLiteral;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater) < 0) __PYX_ERR(0, 4590, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater = &__pyx_type_10cPyparsing___pyx_scope_struct_58_copyTokenToRepeater;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_59_genexpr) < 0) __PYX_ERR(0, 4597, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_59_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_59_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_59_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr) < 0) __PYX_ERR(0, 4605, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr = &__pyx_type_10cPyparsing___pyx_scope_struct_60_matchPreviousExpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater) < 0) __PYX_ERR(0, 4623, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater = &__pyx_type_10cPyparsing___pyx_scope_struct_61_copyTokenToRepeater;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_62_oneOf) < 0) __PYX_ERR(0, 4645, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_62_oneOf.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_62_oneOf = &__pyx_type_10cPyparsing___pyx_scope_struct_62_oneOf;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_63_genexpr) < 0) __PYX_ERR(0, 4707, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_63_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_63_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_63_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_64_genexpr) < 0) __PYX_ERR(0, 4709, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_64_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_64_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_64_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_65_genexpr) < 0) __PYX_ERR(0, 4715, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_65_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_65_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_65_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_66_srange) < 0) __PYX_ERR(0, 4839, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_66_srange.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_66_srange = &__pyx_type_10cPyparsing___pyx_scope_struct_66_srange;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_67__expanded) < 0) __PYX_ERR(0, 4857, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_67__expanded.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_67__expanded = &__pyx_type_10cPyparsing___pyx_scope_struct_67__expanded;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_68_genexpr) < 0) __PYX_ERR(0, 4857, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_68_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_68_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_68_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_69_genexpr) < 0) __PYX_ERR(0, 4859, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_69_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_69_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_69_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol) < 0) __PYX_ERR(0, 4864, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol = &__pyx_type_10cPyparsing___pyx_scope_struct_70_matchOnlyAtCol;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_71_replaceWith) < 0) __PYX_ERR(0, 4875, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_71_replaceWith.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_71_replaceWith = &__pyx_type_10cPyparsing___pyx_scope_struct_71_replaceWith;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_72_tokenMap) < 0) __PYX_ERR(0, 4905, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_72_tokenMap.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_72_tokenMap = &__pyx_type_10cPyparsing___pyx_scope_struct_72_tokenMap;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_73_genexpr) < 0) __PYX_ERR(0, 4972, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_73_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_73_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_73_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_74___new__) < 0) __PYX_ERR(0, 5069, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_74___new__.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_74___new__ = &__pyx_type_10cPyparsing___pyx_scope_struct_74___new__;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_75_indentedBlock) < 0) __PYX_ERR(0, 5341, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_75_indentedBlock.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_75_indentedBlock = &__pyx_type_10cPyparsing___pyx_scope_struct_75_indentedBlock;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56) < 0) __PYX_ERR(0, 5686, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56 = &__pyx_type_10cPyparsing___pyx_scope_struct_76___pyx_lambda_funcdef_10cPyparsing_16pyparsing_common_lambda56;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_77_genexpr) < 0) __PYX_ERR(0, 5686, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_77_genexpr.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_77_genexpr = &__pyx_type_10cPyparsing___pyx_scope_struct_77_genexpr;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_78_convertToDate) < 0) __PYX_ERR(0, 5695, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_78_convertToDate.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_78_convertToDate = &__pyx_type_10cPyparsing___pyx_scope_struct_78_convertToDate;
  if (PyType_Ready(&__pyx_type_10cPyparsing___pyx_scope_struct_79_convertToDatetime) < 0) __PYX_ERR(0, 5717, __pyx_L1_error)
  __pyx_type_10cPyparsing___pyx_scope_struct_79_convertToDatetime.tp_print = 0;
  __pyx_ptype_10cPyparsing___pyx_scope_struct_79_convertToDatetime = &__pyx_type_10cPyparsing___pyx_scope_struct_79_convertToDatetime;
  /*--- Type import code ---*/
  /*--- Variable import code ---*/
  /*--- Function import code ---*/
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "cPyparsing.pyx":41
 * 
 * # automatically updated by constants.py prior to compilation
 * __version__ = "2.2.0"             # <<<<<<<<<<<<<<
 * _FILE_NAME = "cPyparsing.pyx"
 * _WRAP_CALL_LINE_NUM = 1056
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_version, __pyx_kp_u_2_2_0) < 0) __PYX_ERR(0, 41, __pyx_L1_error)

  /* "cPyparsing.pyx":42
 * # automatically updated by constants.py prior to compilation
 * __version__ = "2.2.0"
 * _FILE_NAME = "cPyparsing.pyx"             # <<<<<<<<<<<<<<
 * _WRAP_CALL_LINE_NUM = 1056
 * 
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_FILE_NAME, __pyx_kp_u_cPyparsing_pyx) < 0) __PYX_ERR(0, 42, __pyx_L1_error)

  /* "cPyparsing.pyx":43
 * __version__ = "2.2.0"
 * _FILE_NAME = "cPyparsing.pyx"
 * _WRAP_CALL_LINE_NUM = 1056             # <<<<<<<<<<<<<<
 * 
 * #-----------------------------------------------------------------------------------------------------------------------
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_WRAP_CALL_LINE_NUM, __pyx_int_1056) < 0) __PYX_ERR(0, 43, __pyx_L1_error)

  /* "cPyparsing.pyx":49
 * #-----------------------------------------------------------------------------------------------------------------------
 * 
 * import sys             # <<<<<<<<<<<<<<
 * import string
 * from weakref import ref as wkref
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_sys, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sys, __pyx_t_1) < 0) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":50
 * 
 * import sys
 * import string             # <<<<<<<<<<<<<<
 * from weakref import ref as wkref
 * import copy
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_string, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 50, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_string, __pyx_t_1) < 0) __PYX_ERR(0, 50, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":51
 * import sys
 * import string
 * from weakref import ref as wkref             # <<<<<<<<<<<<<<
 * import copy
 * import warnings
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_ref);
  __Pyx_GIVEREF(__pyx_n_s_ref);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_ref);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_weakref, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_ref); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_wkref, __pyx_t_1) < 0) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":52
 * import string
 * from weakref import ref as wkref
 * import copy             # <<<<<<<<<<<<<<
 * import warnings
 * import re
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_copy, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_copy, __pyx_t_2) < 0) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":53
 * from weakref import ref as wkref
 * import copy
 * import warnings             # <<<<<<<<<<<<<<
 * import re
 * import sre_constants
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_warnings, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_warnings, __pyx_t_2) < 0) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":54
 * import copy
 * import warnings
 * import re             # <<<<<<<<<<<<<<
 * import sre_constants
 * import collections
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_re, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_re, __pyx_t_2) < 0) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":55
 * import warnings
 * import re
 * import sre_constants             # <<<<<<<<<<<<<<
 * import collections
 * import pprint
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_sre_constants, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 55, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sre_constants, __pyx_t_2) < 0) __PYX_ERR(0, 55, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":56
 * import re
 * import sre_constants
 * import collections             # <<<<<<<<<<<<<<
 * import pprint
 * import traceback
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_collections, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_collections, __pyx_t_2) < 0) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":57
 * import sre_constants
 * import collections
 * import pprint             # <<<<<<<<<<<<<<
 * import traceback
 * import types
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_pprint, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pprint, __pyx_t_2) < 0) __PYX_ERR(0, 57, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":58
 * import collections
 * import pprint
 * import traceback             # <<<<<<<<<<<<<<
 * import types
 * from datetime import datetime
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_traceback, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_traceback, __pyx_t_2) < 0) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":59
 * import pprint
 * import traceback
 * import types             # <<<<<<<<<<<<<<
 * from datetime import datetime
 * import os.path
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_types, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_types, __pyx_t_2) < 0) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":60
 * import traceback
 * import types
 * from datetime import datetime             # <<<<<<<<<<<<<<
 * import os.path
 * 
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_datetime);
  __Pyx_GIVEREF(__pyx_n_s_datetime);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_datetime);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_datetime, __pyx_t_2, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_datetime); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_datetime, __pyx_t_2) < 0) __PYX_ERR(0, 60, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":61
 * import types
 * from datetime import datetime
 * import os.path             # <<<<<<<<<<<<<<
 * 
 * try:
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_os_path, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 61, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_os, __pyx_t_1) < 0) __PYX_ERR(0, 61, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":63
 * import os.path
 * 
 * try:             # <<<<<<<<<<<<<<
 *     from _thread import RLock
 * except ImportError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    /*try:*/ {

      /* "cPyparsing.pyx":64
 * 
 * try:
 *     from _thread import RLock             # <<<<<<<<<<<<<<
 * except ImportError:
 *     from threading import RLock
 */
      __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 64, __pyx_L2_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_n_s_RLock);
      __Pyx_GIVEREF(__pyx_n_s_RLock);
      PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_RLock);
      __pyx_t_2 = __Pyx_Import(__pyx_n_s_thread, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 64, __pyx_L2_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_RLock); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 64, __pyx_L2_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_RLock, __pyx_t_1) < 0) __PYX_ERR(0, 64, __pyx_L2_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "cPyparsing.pyx":63
 * import os.path
 * 
 * try:             # <<<<<<<<<<<<<<
 *     from _thread import RLock
 * except ImportError:
 */
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L9_try_end;
    __pyx_L2_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":65
 * try:
 *     from _thread import RLock
 * except ImportError:             # <<<<<<<<<<<<<<
 *     from threading import RLock
 * 
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ImportError);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("cPyparsing", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_1, &__pyx_t_7) < 0) __PYX_ERR(0, 65, __pyx_L4_except_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_7);

      /* "cPyparsing.pyx":66
 *     from _thread import RLock
 * except ImportError:
 *     from threading import RLock             # <<<<<<<<<<<<<<
 * 
 * try:
 */
      __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 66, __pyx_L4_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_n_s_RLock);
      __Pyx_GIVEREF(__pyx_n_s_RLock);
      PyList_SET_ITEM(__pyx_t_8, 0, __pyx_n_s_RLock);
      __pyx_t_9 = __Pyx_Import(__pyx_n_s_threading, __pyx_t_8, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 66, __pyx_L4_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_ImportFrom(__pyx_t_9, __pyx_n_s_RLock); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 66, __pyx_L4_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_RLock, __pyx_t_8) < 0) __PYX_ERR(0, 66, __pyx_L4_except_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L3_exception_handled;
    }
    goto __pyx_L4_except_error;
    __pyx_L4_except_error:;

    /* "cPyparsing.pyx":63
 * import os.path
 * 
 * try:             # <<<<<<<<<<<<<<
 *     from _thread import RLock
 * except ImportError:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
    goto __pyx_L1_error;
    __pyx_L3_exception_handled:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
    __pyx_L9_try_end:;
  }

  /* "cPyparsing.pyx":68
 *     from threading import RLock
 * 
 * try:             # <<<<<<<<<<<<<<
 *     from collections import OrderedDict as _OrderedDict
 * except ImportError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_4, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "cPyparsing.pyx":69
 * 
 * try:
 *     from collections import OrderedDict as _OrderedDict             # <<<<<<<<<<<<<<
 * except ImportError:
 *     try:
 */
      __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 69, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_n_s_OrderedDict_2);
      __Pyx_GIVEREF(__pyx_n_s_OrderedDict_2);
      PyList_SET_ITEM(__pyx_t_7, 0, __pyx_n_s_OrderedDict_2);
      __pyx_t_1 = __Pyx_Import(__pyx_n_s_collections, __pyx_t_7, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 69, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_OrderedDict_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 69, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_OrderedDict, __pyx_t_7) < 0) __PYX_ERR(0, 69, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "cPyparsing.pyx":68
 *     from threading import RLock
 * 
 * try:             # <<<<<<<<<<<<<<
 *     from collections import OrderedDict as _OrderedDict
 * except ImportError:
 */
    }
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L19_try_end;
    __pyx_L12_error:;
    __Pyx_PyThreadState_assign
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":70
 * try:
 *     from collections import OrderedDict as _OrderedDict
 * except ImportError:             # <<<<<<<<<<<<<<
 *     try:
 *         from ordereddict import OrderedDict as _OrderedDict
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ImportError);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("cPyparsing", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_7, &__pyx_t_2) < 0) __PYX_ERR(0, 70, __pyx_L14_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_2);

      /* "cPyparsing.pyx":71
 *     from collections import OrderedDict as _OrderedDict
 * except ImportError:
 *     try:             # <<<<<<<<<<<<<<
 *         from ordereddict import OrderedDict as _OrderedDict
 *     except ImportError:
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
        __Pyx_XGOTREF(__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_11);
        __Pyx_XGOTREF(__pyx_t_12);
        /*try:*/ {

          /* "cPyparsing.pyx":72
 * except ImportError:
 *     try:
 *         from ordereddict import OrderedDict as _OrderedDict             # <<<<<<<<<<<<<<
 *     except ImportError:
 *         _OrderedDict = None
 */
          __pyx_t_9 = PyList_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 72, __pyx_L22_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_INCREF(__pyx_n_s_OrderedDict_2);
          __Pyx_GIVEREF(__pyx_n_s_OrderedDict_2);
          PyList_SET_ITEM(__pyx_t_9, 0, __pyx_n_s_OrderedDict_2);
          __pyx_t_8 = __Pyx_Import(__pyx_n_s_ordereddict, __pyx_t_9, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 72, __pyx_L22_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_9 = __Pyx_ImportFrom(__pyx_t_8, __pyx_n_s_OrderedDict_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 72, __pyx_L22_error)
          __Pyx_GOTREF(__pyx_t_9);
          if (PyDict_SetItem(__pyx_d, __pyx_n_s_OrderedDict, __pyx_t_9) < 0) __PYX_ERR(0, 72, __pyx_L22_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "cPyparsing.pyx":71
 *     from collections import OrderedDict as _OrderedDict
 * except ImportError:
 *     try:             # <<<<<<<<<<<<<<
 *         from ordereddict import OrderedDict as _OrderedDict
 *     except ImportError:
 */
        }
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        goto __pyx_L29_try_end;
        __pyx_L22_error:;
        __Pyx_PyThreadState_assign
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "cPyparsing.pyx":73
 *     try:
 *         from ordereddict import OrderedDict as _OrderedDict
 *     except ImportError:             # <<<<<<<<<<<<<<
 *         _OrderedDict = None
 * 
 */
        __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ImportError);
        if (__pyx_t_6) {
          __Pyx_AddTraceback("cPyparsing", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_8, &__pyx_t_9, &__pyx_t_13) < 0) __PYX_ERR(0, 73, __pyx_L24_except_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_GOTREF(__pyx_t_13);

          /* "cPyparsing.pyx":74
 *         from ordereddict import OrderedDict as _OrderedDict
 *     except ImportError:
 *         _OrderedDict = None             # <<<<<<<<<<<<<<
 * 
 * #-----------------------------------------------------------------------------------------------------------------------
 */
          if (PyDict_SetItem(__pyx_d, __pyx_n_s_OrderedDict, Py_None) < 0) __PYX_ERR(0, 74, __pyx_L24_except_error)
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          goto __pyx_L23_exception_handled;
        }
        goto __pyx_L24_except_error;
        __pyx_L24_except_error:;

        /* "cPyparsing.pyx":71
 *     from collections import OrderedDict as _OrderedDict
 * except ImportError:
 *     try:             # <<<<<<<<<<<<<<
 *         from ordereddict import OrderedDict as _OrderedDict
 *     except ImportError:
 */
        __Pyx_PyThreadState_assign
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
        goto __pyx_L14_except_error;
        __pyx_L23_exception_handled:;
        __Pyx_PyThreadState_assign
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
        __pyx_L29_try_end:;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L13_exception_handled;
    }
    goto __pyx_L14_except_error;
    __pyx_L14_except_error:;

    /* "cPyparsing.pyx":68
 *     from threading import RLock
 * 
 * try:             # <<<<<<<<<<<<<<
 *     from collections import OrderedDict as _OrderedDict
 * except ImportError:
 */
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_4, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L13_exception_handled:;
    __Pyx_PyThreadState_assign
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_4, __pyx_t_3);
    __pyx_L19_try_end:;
  }

  /* "cPyparsing.pyx":80
 * #-----------------------------------------------------------------------------------------------------------------------
 * 
 * __all__ = [             # <<<<<<<<<<<<<<
 *     'And', 'CaselessKeyword', 'CaselessLiteral', 'CharsNotIn', 'Combine', 'Dict', 'Each', 'Empty',
 *     'FollowedBy', 'Forward', 'GoToColumn', 'Group', 'Keyword', 'LineEnd', 'LineStart', 'Literal',
 */
  __pyx_t_2 = PyList_New(105); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_u_And);
  __Pyx_GIVEREF(__pyx_n_u_And);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_u_And);
  __Pyx_INCREF(__pyx_n_u_CaselessKeyword);
  __Pyx_GIVEREF(__pyx_n_u_CaselessKeyword);
  PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_u_CaselessKeyword);
  __Pyx_INCREF(__pyx_n_u_CaselessLiteral);
  __Pyx_GIVEREF(__pyx_n_u_CaselessLiteral);
  PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_u_CaselessLiteral);
  __Pyx_INCREF(__pyx_n_u_CharsNotIn);
  __Pyx_GIVEREF(__pyx_n_u_CharsNotIn);
  PyList_SET_ITEM(__pyx_t_2, 3, __pyx_n_u_CharsNotIn);
  __Pyx_INCREF(__pyx_n_u_Combine);
  __Pyx_GIVEREF(__pyx_n_u_Combine);
  PyList_SET_ITEM(__pyx_t_2, 4, __pyx_n_u_Combine);
  __Pyx_INCREF(__pyx_n_u_Dict);
  __Pyx_GIVEREF(__pyx_n_u_Dict);
  PyList_SET_ITEM(__pyx_t_2, 5, __pyx_n_u_Dict);
  __Pyx_INCREF(__pyx_n_u_Each);
  __Pyx_GIVEREF(__pyx_n_u_Each);
  PyList_SET_ITEM(__pyx_t_2, 6, __pyx_n_u_Each);
  __Pyx_INCREF(__pyx_n_u_Empty);
  __Pyx_GIVEREF(__pyx_n_u_Empty);
  PyList_SET_ITEM(__pyx_t_2, 7, __pyx_n_u_Empty);
  __Pyx_INCREF(__pyx_n_u_FollowedBy);
  __Pyx_GIVEREF(__pyx_n_u_FollowedBy);
  PyList_SET_ITEM(__pyx_t_2, 8, __pyx_n_u_FollowedBy);
  __Pyx_INCREF(__pyx_n_u_Forward);
  __Pyx_GIVEREF(__pyx_n_u_Forward);
  PyList_SET_ITEM(__pyx_t_2, 9, __pyx_n_u_Forward);
  __Pyx_INCREF(__pyx_n_u_GoToColumn);
  __Pyx_GIVEREF(__pyx_n_u_GoToColumn);
  PyList_SET_ITEM(__pyx_t_2, 10, __pyx_n_u_GoToColumn);
  __Pyx_INCREF(__pyx_n_u_Group);
  __Pyx_GIVEREF(__pyx_n_u_Group);
  PyList_SET_ITEM(__pyx_t_2, 11, __pyx_n_u_Group);
  __Pyx_INCREF(__pyx_n_u_Keyword);
  __Pyx_GIVEREF(__pyx_n_u_Keyword);
  PyList_SET_ITEM(__pyx_t_2, 12, __pyx_n_u_Keyword);
  __Pyx_INCREF(__pyx_n_u_LineEnd);
  __Pyx_GIVEREF(__pyx_n_u_LineEnd);
  PyList_SET_ITEM(__pyx_t_2, 13, __pyx_n_u_LineEnd);
  __Pyx_INCREF(__pyx_n_u_LineStart);
  __Pyx_GIVEREF(__pyx_n_u_LineStart);
  PyList_SET_ITEM(__pyx_t_2, 14, __pyx_n_u_LineStart);
  __Pyx_INCREF(__pyx_n_u_Literal);
  __Pyx_GIVEREF(__pyx_n_u_Literal);
  PyList_SET_ITEM(__pyx_t_2, 15, __pyx_n_u_Literal);
  __Pyx_INCREF(__pyx_n_u_MatchFirst);
  __Pyx_GIVEREF(__pyx_n_u_MatchFirst);
  PyList_SET_ITEM(__pyx_t_2, 16, __pyx_n_u_MatchFirst);
  __Pyx_INCREF(__pyx_n_u_NoMatch);
  __Pyx_GIVEREF(__pyx_n_u_NoMatch);
  PyList_SET_ITEM(__pyx_t_2, 17, __pyx_n_u_NoMatch);
  __Pyx_INCREF(__pyx_n_u_NotAny);
  __Pyx_GIVEREF(__pyx_n_u_NotAny);
  PyList_SET_ITEM(__pyx_t_2, 18, __pyx_n_u_NotAny);
  __Pyx_INCREF(__pyx_n_u_OneOrMore);
  __Pyx_GIVEREF(__pyx_n_u_OneOrMore);
  PyList_SET_ITEM(__pyx_t_2, 19, __pyx_n_u_OneOrMore);
  __Pyx_INCREF(__pyx_n_u_OnlyOnce);
  __Pyx_GIVEREF(__pyx_n_u_OnlyOnce);
  PyList_SET_ITEM(__pyx_t_2, 20, __pyx_n_u_OnlyOnce);
  __Pyx_INCREF(__pyx_n_u_Optional);
  __Pyx_GIVEREF(__pyx_n_u_Optional);
  PyList_SET_ITEM(__pyx_t_2, 21, __pyx_n_u_Optional);
  __Pyx_INCREF(__pyx_n_u_Or);
  __Pyx_GIVEREF(__pyx_n_u_Or);
  PyList_SET_ITEM(__pyx_t_2, 22, __pyx_n_u_Or);
  __Pyx_INCREF(__pyx_n_u_ParseBaseException);
  __Pyx_GIVEREF(__pyx_n_u_ParseBaseException);
  PyList_SET_ITEM(__pyx_t_2, 23, __pyx_n_u_ParseBaseException);
  __Pyx_INCREF(__pyx_n_u_ParseElementEnhance);
  __Pyx_GIVEREF(__pyx_n_u_ParseElementEnhance);
  PyList_SET_ITEM(__pyx_t_2, 24, __pyx_n_u_ParseElementEnhance);
  __Pyx_INCREF(__pyx_n_u_ParseException);
  __Pyx_GIVEREF(__pyx_n_u_ParseException);
  PyList_SET_ITEM(__pyx_t_2, 25, __pyx_n_u_ParseException);
  __Pyx_INCREF(__pyx_n_u_ParseExpression);
  __Pyx_GIVEREF(__pyx_n_u_ParseExpression);
  PyList_SET_ITEM(__pyx_t_2, 26, __pyx_n_u_ParseExpression);
  __Pyx_INCREF(__pyx_n_u_ParseFatalException);
  __Pyx_GIVEREF(__pyx_n_u_ParseFatalException);
  PyList_SET_ITEM(__pyx_t_2, 27, __pyx_n_u_ParseFatalException);
  __Pyx_INCREF(__pyx_n_u_ParseResults);
  __Pyx_GIVEREF(__pyx_n_u_ParseResults);
  PyList_SET_ITEM(__pyx_t_2, 28, __pyx_n_u_ParseResults);
  __Pyx_INCREF(__pyx_n_u_ParseSyntaxException);
  __Pyx_GIVEREF(__pyx_n_u_ParseSyntaxException);
  PyList_SET_ITEM(__pyx_t_2, 29, __pyx_n_u_ParseSyntaxException);
  __Pyx_INCREF(__pyx_n_u_ParserElement);
  __Pyx_GIVEREF(__pyx_n_u_ParserElement);
  PyList_SET_ITEM(__pyx_t_2, 30, __pyx_n_u_ParserElement);
  __Pyx_INCREF(__pyx_n_u_QuotedString);
  __Pyx_GIVEREF(__pyx_n_u_QuotedString);
  PyList_SET_ITEM(__pyx_t_2, 31, __pyx_n_u_QuotedString);
  __Pyx_INCREF(__pyx_n_u_RecursiveGrammarException);
  __Pyx_GIVEREF(__pyx_n_u_RecursiveGrammarException);
  PyList_SET_ITEM(__pyx_t_2, 32, __pyx_n_u_RecursiveGrammarException);
  __Pyx_INCREF(__pyx_n_u_Regex);
  __Pyx_GIVEREF(__pyx_n_u_Regex);
  PyList_SET_ITEM(__pyx_t_2, 33, __pyx_n_u_Regex);
  __Pyx_INCREF(__pyx_n_u_SkipTo);
  __Pyx_GIVEREF(__pyx_n_u_SkipTo);
  PyList_SET_ITEM(__pyx_t_2, 34, __pyx_n_u_SkipTo);
  __Pyx_INCREF(__pyx_n_u_StringEnd);
  __Pyx_GIVEREF(__pyx_n_u_StringEnd);
  PyList_SET_ITEM(__pyx_t_2, 35, __pyx_n_u_StringEnd);
  __Pyx_INCREF(__pyx_n_u_StringStart);
  __Pyx_GIVEREF(__pyx_n_u_StringStart);
  PyList_SET_ITEM(__pyx_t_2, 36, __pyx_n_u_StringStart);
  __Pyx_INCREF(__pyx_n_u_Suppress);
  __Pyx_GIVEREF(__pyx_n_u_Suppress);
  PyList_SET_ITEM(__pyx_t_2, 37, __pyx_n_u_Suppress);
  __Pyx_INCREF(__pyx_n_u_Token);
  __Pyx_GIVEREF(__pyx_n_u_Token);
  PyList_SET_ITEM(__pyx_t_2, 38, __pyx_n_u_Token);
  __Pyx_INCREF(__pyx_n_u_TokenConverter);
  __Pyx_GIVEREF(__pyx_n_u_TokenConverter);
  PyList_SET_ITEM(__pyx_t_2, 39, __pyx_n_u_TokenConverter);
  __Pyx_INCREF(__pyx_n_u_White);
  __Pyx_GIVEREF(__pyx_n_u_White);
  PyList_SET_ITEM(__pyx_t_2, 40, __pyx_n_u_White);
  __Pyx_INCREF(__pyx_n_u_Word);
  __Pyx_GIVEREF(__pyx_n_u_Word);
  PyList_SET_ITEM(__pyx_t_2, 41, __pyx_n_u_Word);
  __Pyx_INCREF(__pyx_n_u_WordEnd);
  __Pyx_GIVEREF(__pyx_n_u_WordEnd);
  PyList_SET_ITEM(__pyx_t_2, 42, __pyx_n_u_WordEnd);
  __Pyx_INCREF(__pyx_n_u_WordStart);
  __Pyx_GIVEREF(__pyx_n_u_WordStart);
  PyList_SET_ITEM(__pyx_t_2, 43, __pyx_n_u_WordStart);
  __Pyx_INCREF(__pyx_n_u_ZeroOrMore);
  __Pyx_GIVEREF(__pyx_n_u_ZeroOrMore);
  PyList_SET_ITEM(__pyx_t_2, 44, __pyx_n_u_ZeroOrMore);
  __Pyx_INCREF(__pyx_n_u_alphanums);
  __Pyx_GIVEREF(__pyx_n_u_alphanums);
  PyList_SET_ITEM(__pyx_t_2, 45, __pyx_n_u_alphanums);
  __Pyx_INCREF(__pyx_n_u_alphas);
  __Pyx_GIVEREF(__pyx_n_u_alphas);
  PyList_SET_ITEM(__pyx_t_2, 46, __pyx_n_u_alphas);
  __Pyx_INCREF(__pyx_n_u_alphas8bit);
  __Pyx_GIVEREF(__pyx_n_u_alphas8bit);
  PyList_SET_ITEM(__pyx_t_2, 47, __pyx_n_u_alphas8bit);
  __Pyx_INCREF(__pyx_n_u_anyCloseTag);
  __Pyx_GIVEREF(__pyx_n_u_anyCloseTag);
  PyList_SET_ITEM(__pyx_t_2, 48, __pyx_n_u_anyCloseTag);
  __Pyx_INCREF(__pyx_n_u_anyOpenTag);
  __Pyx_GIVEREF(__pyx_n_u_anyOpenTag);
  PyList_SET_ITEM(__pyx_t_2, 49, __pyx_n_u_anyOpenTag);
  __Pyx_INCREF(__pyx_n_u_cStyleComment);
  __Pyx_GIVEREF(__pyx_n_u_cStyleComment);
  PyList_SET_ITEM(__pyx_t_2, 50, __pyx_n_u_cStyleComment);
  __Pyx_INCREF(__pyx_n_u_col);
  __Pyx_GIVEREF(__pyx_n_u_col);
  PyList_SET_ITEM(__pyx_t_2, 51, __pyx_n_u_col);
  __Pyx_INCREF(__pyx_n_u_commaSeparatedList);
  __Pyx_GIVEREF(__pyx_n_u_commaSeparatedList);
  PyList_SET_ITEM(__pyx_t_2, 52, __pyx_n_u_commaSeparatedList);
  __Pyx_INCREF(__pyx_n_u_commonHTMLEntity);
  __Pyx_GIVEREF(__pyx_n_u_commonHTMLEntity);
  PyList_SET_ITEM(__pyx_t_2, 53, __pyx_n_u_commonHTMLEntity);
  __Pyx_INCREF(__pyx_n_u_countedArray);
  __Pyx_GIVEREF(__pyx_n_u_countedArray);
  PyList_SET_ITEM(__pyx_t_2, 54, __pyx_n_u_countedArray);
  __Pyx_INCREF(__pyx_n_u_cppStyleComment);
  __Pyx_GIVEREF(__pyx_n_u_cppStyleComment);
  PyList_SET_ITEM(__pyx_t_2, 55, __pyx_n_u_cppStyleComment);
  __Pyx_INCREF(__pyx_n_u_dblQuotedString);
  __Pyx_GIVEREF(__pyx_n_u_dblQuotedString);
  PyList_SET_ITEM(__pyx_t_2, 56, __pyx_n_u_dblQuotedString);
  __Pyx_INCREF(__pyx_n_u_dblSlashComment);
  __Pyx_GIVEREF(__pyx_n_u_dblSlashComment);
  PyList_SET_ITEM(__pyx_t_2, 57, __pyx_n_u_dblSlashComment);
  __Pyx_INCREF(__pyx_n_u_delimitedList);
  __Pyx_GIVEREF(__pyx_n_u_delimitedList);
  PyList_SET_ITEM(__pyx_t_2, 58, __pyx_n_u_delimitedList);
  __Pyx_INCREF(__pyx_n_u_dictOf);
  __Pyx_GIVEREF(__pyx_n_u_dictOf);
  PyList_SET_ITEM(__pyx_t_2, 59, __pyx_n_u_dictOf);
  __Pyx_INCREF(__pyx_n_u_downcaseTokens);
  __Pyx_GIVEREF(__pyx_n_u_downcaseTokens);
  PyList_SET_ITEM(__pyx_t_2, 60, __pyx_n_u_downcaseTokens);
  __Pyx_INCREF(__pyx_n_u_empty);
  __Pyx_GIVEREF(__pyx_n_u_empty);
  PyList_SET_ITEM(__pyx_t_2, 61, __pyx_n_u_empty);
  __Pyx_INCREF(__pyx_n_u_hexnums);
  __Pyx_GIVEREF(__pyx_n_u_hexnums);
  PyList_SET_ITEM(__pyx_t_2, 62, __pyx_n_u_hexnums);
  __Pyx_INCREF(__pyx_n_u_htmlComment);
  __Pyx_GIVEREF(__pyx_n_u_htmlComment);
  PyList_SET_ITEM(__pyx_t_2, 63, __pyx_n_u_htmlComment);
  __Pyx_INCREF(__pyx_n_u_javaStyleComment);
  __Pyx_GIVEREF(__pyx_n_u_javaStyleComment);
  PyList_SET_ITEM(__pyx_t_2, 64, __pyx_n_u_javaStyleComment);
  __Pyx_INCREF(__pyx_n_u_line);
  __Pyx_GIVEREF(__pyx_n_u_line);
  PyList_SET_ITEM(__pyx_t_2, 65, __pyx_n_u_line);
  __Pyx_INCREF(__pyx_n_u_lineEnd);
  __Pyx_GIVEREF(__pyx_n_u_lineEnd);
  PyList_SET_ITEM(__pyx_t_2, 66, __pyx_n_u_lineEnd);
  __Pyx_INCREF(__pyx_n_u_lineStart);
  __Pyx_GIVEREF(__pyx_n_u_lineStart);
  PyList_SET_ITEM(__pyx_t_2, 67, __pyx_n_u_lineStart);
  __Pyx_INCREF(__pyx_n_u_lineno);
  __Pyx_GIVEREF(__pyx_n_u_lineno);
  PyList_SET_ITEM(__pyx_t_2, 68, __pyx_n_u_lineno);
  __Pyx_INCREF(__pyx_n_u_makeHTMLTags);
  __Pyx_GIVEREF(__pyx_n_u_makeHTMLTags);
  PyList_SET_ITEM(__pyx_t_2, 69, __pyx_n_u_makeHTMLTags);
  __Pyx_INCREF(__pyx_n_u_makeXMLTags);
  __Pyx_GIVEREF(__pyx_n_u_makeXMLTags);
  PyList_SET_ITEM(__pyx_t_2, 70, __pyx_n_u_makeXMLTags);
  __Pyx_INCREF(__pyx_n_u_matchOnlyAtCol);
  __Pyx_GIVEREF(__pyx_n_u_matchOnlyAtCol);
  PyList_SET_ITEM(__pyx_t_2, 71, __pyx_n_u_matchOnlyAtCol);
  __Pyx_INCREF(__pyx_n_u_matchPreviousExpr);
  __Pyx_GIVEREF(__pyx_n_u_matchPreviousExpr);
  PyList_SET_ITEM(__pyx_t_2, 72, __pyx_n_u_matchPreviousExpr);
  __Pyx_INCREF(__pyx_n_u_matchPreviousLiteral);
  __Pyx_GIVEREF(__pyx_n_u_matchPreviousLiteral);
  PyList_SET_ITEM(__pyx_t_2, 73, __pyx_n_u_matchPreviousLiteral);
  __Pyx_INCREF(__pyx_n_u_nestedExpr);
  __Pyx_GIVEREF(__pyx_n_u_nestedExpr);
  PyList_SET_ITEM(__pyx_t_2, 74, __pyx_n_u_nestedExpr);
  __Pyx_INCREF(__pyx_n_u_nullDebugAction);
  __Pyx_GIVEREF(__pyx_n_u_nullDebugAction);
  PyList_SET_ITEM(__pyx_t_2, 75, __pyx_n_u_nullDebugAction);
  __Pyx_INCREF(__pyx_n_u_nums);
  __Pyx_GIVEREF(__pyx_n_u_nums);
  PyList_SET_ITEM(__pyx_t_2, 76, __pyx_n_u_nums);
  __Pyx_INCREF(__pyx_n_u_oneOf);
  __Pyx_GIVEREF(__pyx_n_u_oneOf);
  PyList_SET_ITEM(__pyx_t_2, 77, __pyx_n_u_oneOf);
  __Pyx_INCREF(__pyx_n_u_opAssoc);
  __Pyx_GIVEREF(__pyx_n_u_opAssoc);
  PyList_SET_ITEM(__pyx_t_2, 78, __pyx_n_u_opAssoc);
  __Pyx_INCREF(__pyx_n_u_operatorPrecedence);
  __Pyx_GIVEREF(__pyx_n_u_operatorPrecedence);
  PyList_SET_ITEM(__pyx_t_2, 79, __pyx_n_u_operatorPrecedence);
  __Pyx_INCREF(__pyx_n_u_printables);
  __Pyx_GIVEREF(__pyx_n_u_printables);
  PyList_SET_ITEM(__pyx_t_2, 80, __pyx_n_u_printables);
  __Pyx_INCREF(__pyx_n_u_punc8bit);
  __Pyx_GIVEREF(__pyx_n_u_punc8bit);
  PyList_SET_ITEM(__pyx_t_2, 81, __pyx_n_u_punc8bit);
  __Pyx_INCREF(__pyx_n_u_pythonStyleComment);
  __Pyx_GIVEREF(__pyx_n_u_pythonStyleComment);
  PyList_SET_ITEM(__pyx_t_2, 82, __pyx_n_u_pythonStyleComment);
  __Pyx_INCREF(__pyx_n_u_quotedString);
  __Pyx_GIVEREF(__pyx_n_u_quotedString);
  PyList_SET_ITEM(__pyx_t_2, 83, __pyx_n_u_quotedString);
  __Pyx_INCREF(__pyx_n_u_removeQuotes);
  __Pyx_GIVEREF(__pyx_n_u_removeQuotes);
  PyList_SET_ITEM(__pyx_t_2, 84, __pyx_n_u_removeQuotes);
  __Pyx_INCREF(__pyx_n_u_replaceHTMLEntity);
  __Pyx_GIVEREF(__pyx_n_u_replaceHTMLEntity);
  PyList_SET_ITEM(__pyx_t_2, 85, __pyx_n_u_replaceHTMLEntity);
  __Pyx_INCREF(__pyx_n_u_replaceWith);
  __Pyx_GIVEREF(__pyx_n_u_replaceWith);
  PyList_SET_ITEM(__pyx_t_2, 86, __pyx_n_u_replaceWith);
  __Pyx_INCREF(__pyx_n_u_restOfLine);
  __Pyx_GIVEREF(__pyx_n_u_restOfLine);
  PyList_SET_ITEM(__pyx_t_2, 87, __pyx_n_u_restOfLine);
  __Pyx_INCREF(__pyx_n_u_sglQuotedString);
  __Pyx_GIVEREF(__pyx_n_u_sglQuotedString);
  PyList_SET_ITEM(__pyx_t_2, 88, __pyx_n_u_sglQuotedString);
  __Pyx_INCREF(__pyx_n_u_srange);
  __Pyx_GIVEREF(__pyx_n_u_srange);
  PyList_SET_ITEM(__pyx_t_2, 89, __pyx_n_u_srange);
  __Pyx_INCREF(__pyx_n_u_stringEnd);
  __Pyx_GIVEREF(__pyx_n_u_stringEnd);
  PyList_SET_ITEM(__pyx_t_2, 90, __pyx_n_u_stringEnd);
  __Pyx_INCREF(__pyx_n_u_stringStart);
  __Pyx_GIVEREF(__pyx_n_u_stringStart);
  PyList_SET_ITEM(__pyx_t_2, 91, __pyx_n_u_stringStart);
  __Pyx_INCREF(__pyx_n_u_traceParseAction);
  __Pyx_GIVEREF(__pyx_n_u_traceParseAction);
  PyList_SET_ITEM(__pyx_t_2, 92, __pyx_n_u_traceParseAction);
  __Pyx_INCREF(__pyx_n_u_unicodeString);
  __Pyx_GIVEREF(__pyx_n_u_unicodeString);
  PyList_SET_ITEM(__pyx_t_2, 93, __pyx_n_u_unicodeString);
  __Pyx_INCREF(__pyx_n_u_upcaseTokens);
  __Pyx_GIVEREF(__pyx_n_u_upcaseTokens);
  PyList_SET_ITEM(__pyx_t_2, 94, __pyx_n_u_upcaseTokens);
  __Pyx_INCREF(__pyx_n_u_withAttribute);
  __Pyx_GIVEREF(__pyx_n_u_withAttribute);
  PyList_SET_ITEM(__pyx_t_2, 95, __pyx_n_u_withAttribute);
  __Pyx_INCREF(__pyx_n_u_indentedBlock);
  __Pyx_GIVEREF(__pyx_n_u_indentedBlock);
  PyList_SET_ITEM(__pyx_t_2, 96, __pyx_n_u_indentedBlock);
  __Pyx_INCREF(__pyx_n_u_originalTextFor);
  __Pyx_GIVEREF(__pyx_n_u_originalTextFor);
  PyList_SET_ITEM(__pyx_t_2, 97, __pyx_n_u_originalTextFor);
  __Pyx_INCREF(__pyx_n_u_ungroup);
  __Pyx_GIVEREF(__pyx_n_u_ungroup);
  PyList_SET_ITEM(__pyx_t_2, 98, __pyx_n_u_ungroup);
  __Pyx_INCREF(__pyx_n_u_infixNotation);
  __Pyx_GIVEREF(__pyx_n_u_infixNotation);
  PyList_SET_ITEM(__pyx_t_2, 99, __pyx_n_u_infixNotation);
  __Pyx_INCREF(__pyx_n_u_locatedExpr);
  __Pyx_GIVEREF(__pyx_n_u_locatedExpr);
  PyList_SET_ITEM(__pyx_t_2, 100, __pyx_n_u_locatedExpr);
  __Pyx_INCREF(__pyx_n_u_withClass);
  __Pyx_GIVEREF(__pyx_n_u_withClass);
  PyList_SET_ITEM(__pyx_t_2, 101, __pyx_n_u_withClass);
  __Pyx_INCREF(__pyx_n_u_CloseMatch);
  __Pyx_GIVEREF(__pyx_n_u_CloseMatch);
  PyList_SET_ITEM(__pyx_t_2, 102, __pyx_n_u_CloseMatch);
  __Pyx_INCREF(__pyx_n_u_tokenMap);
  __Pyx_GIVEREF(__pyx_n_u_tokenMap);
  PyList_SET_ITEM(__pyx_t_2, 103, __pyx_n_u_tokenMap);
  __Pyx_INCREF(__pyx_n_u_pyparsing_common);
  __Pyx_GIVEREF(__pyx_n_u_pyparsing_common);
  PyList_SET_ITEM(__pyx_t_2, 104, __pyx_n_u_pyparsing_common);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_all_2, __pyx_t_2) < 0) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":101
 * ]
 * 
 * _MAX_INT = sys.maxsize             # <<<<<<<<<<<<<<
 * py_str = str
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_maxsize); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_MAX_INT, __pyx_t_7) < 0) __PYX_ERR(0, 101, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":102
 * 
 * _MAX_INT = sys.maxsize
 * py_str = str             # <<<<<<<<<<<<<<
 * 
 * system_version = tuple(sys.version_info)[:3]
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_str); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_py_str, __pyx_t_7) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":104
 * py_str = str
 * 
 * system_version = tuple(sys.version_info)[:3]             # <<<<<<<<<<<<<<
 * PY_3 = system_version[0] == 3
 * if PY_3:
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_version_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PySequence_Tuple(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyTuple_GetSlice(__pyx_t_7, 0, 3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_system_version, __pyx_t_2) < 0) __PYX_ERR(0, 104, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":105
 * 
 * system_version = tuple(sys.version_info)[:3]
 * PY_3 = system_version[0] == 3             # <<<<<<<<<<<<<<
 * if PY_3:
 *     basestring = str
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_system_version); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_EqObjC(__pyx_t_7, __pyx_int_3, 3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_PY_3, __pyx_t_2) < 0) __PYX_ERR(0, 105, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":106
 * system_version = tuple(sys.version_info)[:3]
 * PY_3 = system_version[0] == 3
 * if PY_3:             # <<<<<<<<<<<<<<
 *     basestring = str
 *     unichr = chr
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_PY_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_14) {

    /* "cPyparsing.pyx":107
 * PY_3 = system_version[0] == 3
 * if PY_3:
 *     basestring = str             # <<<<<<<<<<<<<<
 *     unichr = chr
 *     _ustr = str
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_str); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 107, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_basestring, __pyx_t_2) < 0) __PYX_ERR(0, 107, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":108
 * if PY_3:
 *     basestring = str
 *     unichr = chr             # <<<<<<<<<<<<<<
 *     _ustr = str
 * 
 */
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_unichr, __pyx_builtin_chr) < 0) __PYX_ERR(0, 108, __pyx_L1_error)

    /* "cPyparsing.pyx":109
 *     basestring = str
 *     unichr = chr
 *     _ustr = str             # <<<<<<<<<<<<<<
 * 
 *     # build list of single arg builtins, that can be used as parse actions
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_str); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 109, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_ustr, __pyx_t_2) < 0) __PYX_ERR(0, 109, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cPyparsing.pyx":112
 * 
 *     # build list of single arg builtins, that can be used as parse actions
 *     singleArgBuiltins = [sum, len, sorted, reversed, list, tuple, set, any, all, min, max]             # <<<<<<<<<<<<<<
 * 
 * else:
 */
    __pyx_t_2 = __Pyx_GetBuiltinName(__pyx_n_s_len_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = PyList_New(11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_INCREF(__pyx_builtin_sum);
    __Pyx_GIVEREF(__pyx_builtin_sum);
    PyList_SET_ITEM(__pyx_t_7, 0, __pyx_builtin_sum);
    __Pyx_GIVEREF(__pyx_t_2);
    PyList_SET_ITEM(__pyx_t_7, 1, __pyx_t_2);
    __Pyx_INCREF(__pyx_builtin_sorted);
    __Pyx_GIVEREF(__pyx_builtin_sorted);
    PyList_SET_ITEM(__pyx_t_7, 2, __pyx_builtin_sorted);
    __Pyx_INCREF(__pyx_builtin_reversed);
    __Pyx_GIVEREF(__pyx_builtin_reversed);
    PyList_SET_ITEM(__pyx_t_7, 3, __pyx_builtin_reversed);
    __Pyx_INCREF(((PyObject *)(&PyList_Type)));
    __Pyx_GIVEREF(((PyObject *)(&PyList_Type)));
    PyList_SET_ITEM(__pyx_t_7, 4, ((PyObject *)(&PyList_Type)));
    __Pyx_INCREF(((PyObject *)(&PyTuple_Type)));
    __Pyx_GIVEREF(((PyObject *)(&PyTuple_Type)));
    PyList_SET_ITEM(__pyx_t_7, 5, ((PyObject *)(&PyTuple_Type)));
    __Pyx_INCREF(((PyObject *)(&PySet_Type)));
    __Pyx_GIVEREF(((PyObject *)(&PySet_Type)));
    PyList_SET_ITEM(__pyx_t_7, 6, ((PyObject *)(&PySet_Type)));
    __Pyx_INCREF(__pyx_builtin_any);
    __Pyx_GIVEREF(__pyx_builtin_any);
    PyList_SET_ITEM(__pyx_t_7, 7, __pyx_builtin_any);
    __Pyx_INCREF(__pyx_builtin_all);
    __Pyx_GIVEREF(__pyx_builtin_all);
    PyList_SET_ITEM(__pyx_t_7, 8, __pyx_builtin_all);
    __Pyx_INCREF(__pyx_builtin_min);
    __Pyx_GIVEREF(__pyx_builtin_min);
    PyList_SET_ITEM(__pyx_t_7, 9, __pyx_builtin_min);
    __Pyx_INCREF(__pyx_builtin_max);
    __Pyx_GIVEREF(__pyx_builtin_max);
    PyList_SET_ITEM(__pyx_t_7, 10, __pyx_builtin_max);
    __pyx_t_2 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_singleArgBuiltins, __pyx_t_7) < 0) __PYX_ERR(0, 112, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":106
 * system_version = tuple(sys.version_info)[:3]
 * PY_3 = system_version[0] == 3
 * if PY_3:             # <<<<<<<<<<<<<<
 *     basestring = str
 *     unichr = chr
 */
    goto __pyx_L32;
  }

  /* "cPyparsing.pyx":115
 * 
 * else:
 *     range = xrange             # <<<<<<<<<<<<<<
 * 
 *     _repr = repr
 */
  /*else*/ {
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_range, __pyx_builtin_xrange) < 0) __PYX_ERR(0, 115, __pyx_L1_error)

    /* "cPyparsing.pyx":117
 *     range = xrange
 * 
 *     _repr = repr             # <<<<<<<<<<<<<<
 *     def repr(obj):
 *         if isinstance(obj, unicode):
 */
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_repr_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_repr, __pyx_t_7) < 0) __PYX_ERR(0, 117, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":118
 * 
 *     _repr = repr
 *     def repr(obj):             # <<<<<<<<<<<<<<
 *         if isinstance(obj, unicode):
 *             return _repr(obj).lstrip("u")
 */
    __pyx_t_7 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_1repr, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 118, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_repr_2, __pyx_t_7) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":124
 *             return _repr(obj)
 * 
 *     str = unicode             # <<<<<<<<<<<<<<
 *     def _ustr(obj):
 *         if isinstance(obj, py_str):
 */
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_str, ((PyObject *)(&PyUnicode_Type))) < 0) __PYX_ERR(0, 124, __pyx_L1_error)

    /* "cPyparsing.pyx":125
 * 
 *     str = unicode
 *     def _ustr(obj):             # <<<<<<<<<<<<<<
 *         if isinstance(obj, py_str):
 *             obj = obj.decode("utf8")
 */
    __pyx_t_7 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_3_ustr, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_ustr, __pyx_t_7) < 0) __PYX_ERR(0, 125, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":150
 * 
 *     # build list of single arg builtins, tolerant of Python version, that can be used as parse actions
 *     singleArgBuiltins = []             # <<<<<<<<<<<<<<
 *     import __builtin__
 *     for fname in "sum len sorted reversed list tuple set any all min max".split():
 */
    __pyx_t_7 = PyList_New(0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 150, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_singleArgBuiltins, __pyx_t_7) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":151
 *     # build list of single arg builtins, tolerant of Python version, that can be used as parse actions
 *     singleArgBuiltins = []
 *     import __builtin__             # <<<<<<<<<<<<<<
 *     for fname in "sum len sorted reversed list tuple set any all min max".split():
 *         try:
 */
    __pyx_t_7 = __Pyx_Import(__pyx_n_s_builtin, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 151, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_builtin, __pyx_t_7) < 0) __PYX_ERR(0, 151, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":152
 *     singleArgBuiltins = []
 *     import __builtin__
 *     for fname in "sum len sorted reversed list tuple set any all min max".split():             # <<<<<<<<<<<<<<
 *         try:
 *             singleArgBuiltins.append(getattr(__builtin__, fname))
 */
    __pyx_t_7 = PyUnicode_Split(__pyx_kp_u_sum_len_sorted_reversed_list_tup, ((PyObject *)NULL), -1L); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_2 = __pyx_t_7; __Pyx_INCREF(__pyx_t_2); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    for (;;) {
      if (__pyx_t_15 >= PyList_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_7 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_15); __Pyx_INCREF(__pyx_t_7); __pyx_t_15++; if (unlikely(0 < 0)) __PYX_ERR(0, 152, __pyx_L1_error)
      #else
      __pyx_t_7 = PySequence_ITEM(__pyx_t_2, __pyx_t_15); __pyx_t_15++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 152, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      #endif
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_fname, __pyx_t_7) < 0) __PYX_ERR(0, 152, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "cPyparsing.pyx":153
 *     import __builtin__
 *     for fname in "sum len sorted reversed list tuple set any all min max".split():
 *         try:             # <<<<<<<<<<<<<<
 *             singleArgBuiltins.append(getattr(__builtin__, fname))
 *         except AttributeError:
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_3);
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_5);
        /*try:*/ {

          /* "cPyparsing.pyx":154
 *     for fname in "sum len sorted reversed list tuple set any all min max".split():
 *         try:
 *             singleArgBuiltins.append(getattr(__builtin__, fname))             # <<<<<<<<<<<<<<
 *         except AttributeError:
 *             continue
 */
          __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_singleArgBuiltins); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 154, __pyx_L35_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_builtin); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 154, __pyx_L35_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_fname); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 154, __pyx_L35_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_9 = __Pyx_GetAttr(__pyx_t_1, __pyx_t_13); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 154, __pyx_L35_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_16 = __Pyx_PyObject_Append(__pyx_t_7, __pyx_t_9); if (unlikely(__pyx_t_16 == -1)) __PYX_ERR(0, 154, __pyx_L35_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

          /* "cPyparsing.pyx":153
 *     import __builtin__
 *     for fname in "sum len sorted reversed list tuple set any all min max".split():
 *         try:             # <<<<<<<<<<<<<<
 *             singleArgBuiltins.append(getattr(__builtin__, fname))
 *         except AttributeError:
 */
        }
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        goto __pyx_L42_try_end;
        __pyx_L35_error:;
        __Pyx_PyThreadState_assign
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "cPyparsing.pyx":155
 *         try:
 *             singleArgBuiltins.append(getattr(__builtin__, fname))
 *         except AttributeError:             # <<<<<<<<<<<<<<
 *             continue
 * 
 */
        __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
        if (__pyx_t_6) {
          __Pyx_AddTraceback("cPyparsing", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_7, &__pyx_t_13) < 0) __PYX_ERR(0, 155, __pyx_L37_except_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_GOTREF(__pyx_t_13);

          /* "cPyparsing.pyx":156
 *             singleArgBuiltins.append(getattr(__builtin__, fname))
 *         except AttributeError:
 *             continue             # <<<<<<<<<<<<<<
 * 
 * _generatorType = type((y for y in range(1)))
 */
          goto __pyx_L44_except_continue;
          __pyx_L44_except_continue:;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          goto __pyx_L41_try_continue;
        }
        goto __pyx_L37_except_error;
        __pyx_L37_except_error:;

        /* "cPyparsing.pyx":153
 *     import __builtin__
 *     for fname in "sum len sorted reversed list tuple set any all min max".split():
 *         try:             # <<<<<<<<<<<<<<
 *             singleArgBuiltins.append(getattr(__builtin__, fname))
 *         except AttributeError:
 */
        __Pyx_PyThreadState_assign
        __Pyx_XGIVEREF(__pyx_t_3);
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
        goto __pyx_L1_error;
        __pyx_L41_try_continue:;
        __Pyx_PyThreadState_assign
        __Pyx_XGIVEREF(__pyx_t_3);
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
        goto __pyx_L33_continue;
        __pyx_L42_try_end:;
      }

      /* "cPyparsing.pyx":152
 *     singleArgBuiltins = []
 *     import __builtin__
 *     for fname in "sum len sorted reversed list tuple set any all min max".split():             # <<<<<<<<<<<<<<
 *         try:
 *             singleArgBuiltins.append(getattr(__builtin__, fname))
 */
      __pyx_L33_continue:;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L32:;

  /* "cPyparsing.pyx":158
 *             continue
 * 
 * _generatorType = type((y for y in range(1)))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __pyx_pf_10cPyparsing_72genexpr(NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_generatorType, ((PyObject *)Py_TYPE(__pyx_t_2))) < 0) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":161
 * 
 * 
 * def _xml_escape(data):             # <<<<<<<<<<<<<<
 *     """Escape &, <, >, ", ', etc. in a string of data."""
 * 
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_5_xml_escape, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_xml_escape, __pyx_t_2) < 0) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":172
 * 
 * 
 * class _Constants(object):             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_builtin_object);
  __Pyx_GIVEREF(__pyx_builtin_object);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_builtin_object);
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_7 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_Constants, __pyx_n_s_Constants, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_9 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_Constants, __pyx_t_2, __pyx_t_7, NULL, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Constants, __pyx_t_9) < 0) __PYX_ERR(0, 172, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":176
 * 
 * 
 * alphas = string.ascii_uppercase + string.ascii_lowercase             # <<<<<<<<<<<<<<
 * nums = "0123456789"
 * hexnums = nums + "ABCDEFabcdef"
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_string); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_ascii_uppercase); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_string); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_ascii_lowercase); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_13, __pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_alphas, __pyx_t_2) < 0) __PYX_ERR(0, 176, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":177
 * 
 * alphas = string.ascii_uppercase + string.ascii_lowercase
 * nums = "0123456789"             # <<<<<<<<<<<<<<
 * hexnums = nums + "ABCDEFabcdef"
 * alphanums = alphas + nums
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_nums, __pyx_kp_u_0123456789) < 0) __PYX_ERR(0, 177, __pyx_L1_error)

  /* "cPyparsing.pyx":178
 * alphas = string.ascii_uppercase + string.ascii_lowercase
 * nums = "0123456789"
 * hexnums = nums + "ABCDEFabcdef"             # <<<<<<<<<<<<<<
 * alphanums = alphas + nums
 * _bslash = chr(92)
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_nums); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = PyNumber_Add(__pyx_t_2, __pyx_n_u_ABCDEFabcdef); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_hexnums, __pyx_t_7) < 0) __PYX_ERR(0, 178, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":179
 * nums = "0123456789"
 * hexnums = nums + "ABCDEFabcdef"
 * alphanums = alphas + nums             # <<<<<<<<<<<<<<
 * _bslash = chr(92)
 * printables = "".join(c for c in string.printable if c not in string.whitespace)
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_alphas); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_nums); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = PyNumber_Add(__pyx_t_7, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_alphanums, __pyx_t_13) < 0) __PYX_ERR(0, 179, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":180
 * hexnums = nums + "ABCDEFabcdef"
 * alphanums = alphas + nums
 * _bslash = chr(92)             # <<<<<<<<<<<<<<
 * printables = "".join(c for c in string.printable if c not in string.whitespace)
 * 
 */
  __pyx_t_13 = __Pyx_PyObject_Call(__pyx_builtin_chr, __pyx_tuple__221, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_bslash, __pyx_t_13) < 0) __PYX_ERR(0, 180, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":181
 * alphanums = alphas + nums
 * _bslash = chr(92)
 * printables = "".join(c for c in string.printable if c not in string.whitespace)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_13 = __pyx_pf_10cPyparsing_75genexpr(NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = __Pyx_Generator_Next(__pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = PyUnicode_Join(__pyx_kp_u__9, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_printables, __pyx_t_13) < 0) __PYX_ERR(0, 181, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":184
 * 
 * 
 * class ParseBaseException(Exception):             # <<<<<<<<<<<<<<
 *     """base exception class for all parsing runtime exceptions"""
 *     # Performance tuning: we construct a *lot* of these, so keep this
 */
  __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_INCREF(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
  __Pyx_GIVEREF(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
  PyTuple_SET_ITEM(__pyx_t_13, 0, ((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_13, __pyx_n_s_ParseBaseException, __pyx_n_s_ParseBaseException, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_base_exception_class_for_all_par); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);

  /* "cPyparsing.pyx":189
 *     # constructor as small and fast as possible
 * 
 *     def __init__(self, pstr, loc=0, msg=None, elem=None):             # <<<<<<<<<<<<<<
 *         self.loc = loc
 *         if msg is None:
 */
  __pyx_t_9 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_18ParseBaseException_1__init__, 0, __pyx_n_s_ParseBaseException___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__223)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_9, __pyx_tuple__224);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_init, __pyx_t_9) < 0) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":201
 * 
 *     @classmethod
 *     def _from_exception(cls, pe):             # <<<<<<<<<<<<<<
 *         """
 *         internal factory method to simplify creating one type of ParseException
 */
  __pyx_t_9 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_18ParseBaseException_3_from_exception, __Pyx_CYFUNCTION_CLASSMETHOD, __pyx_n_s_ParseBaseException__from_excepti, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__226)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":200
 *         self.args = (pstr, loc, msg)
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_exception(cls, pe):
 *         """
 */
  __pyx_t_1 = __Pyx_Method_ClassMethod(__pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_from_exception, __pyx_t_1) < 0) __PYX_ERR(0, 201, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":208
 *         return cls(pe.pstr, pe.loc, pe.msg, pe.parserElement)
 * 
 *     def __getattr__(self, aname):             # <<<<<<<<<<<<<<
 *         """supported attributes by name are:
 *             - lineno - returns the line number of the exception text
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_18ParseBaseException_5__getattr__, 0, __pyx_n_s_ParseBaseException___getattr, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__228)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_getattr, __pyx_t_1) < 0) __PYX_ERR(0, 208, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":223
 *             raise AttributeError(aname)
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "%s (at char %d), (line:%d, col:%d)" % \
 *             (self.msg, self.loc, self.lineno, self.column)
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_18ParseBaseException_7__str__, 0, __pyx_n_s_ParseBaseException___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__230)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_str_2, __pyx_t_1) < 0) __PYX_ERR(0, 223, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":227
 *             (self.msg, self.loc, self.lineno, self.column)
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return _ustr(self)
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_18ParseBaseException_9__repr__, 0, __pyx_n_s_ParseBaseException___repr, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__232)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_repr_3, __pyx_t_1) < 0) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":230
 *         return _ustr(self)
 * 
 *     def markInputline(self, markerString=">!<"):             # <<<<<<<<<<<<<<
 *         """Extracts the exception line from the input string, and marks
 *            the location of the exception with a special symbol.
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_18ParseBaseException_11markInputline, 0, __pyx_n_s_ParseBaseException_markInputline, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__234)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__235);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_markInputline, __pyx_t_1) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":241
 *         return line_str.strip()
 * 
 *     def __dir__(self):             # <<<<<<<<<<<<<<
 *         return "lineno col line".split() + dir(type(self))
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_18ParseBaseException_13__dir__, 0, __pyx_n_s_ParseBaseException___dir, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__237)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_dir, __pyx_t_1) < 0) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":184
 * 
 * 
 * class ParseBaseException(Exception):             # <<<<<<<<<<<<<<
 *     """base exception class for all parsing runtime exceptions"""
 *     # Performance tuning: we construct a *lot* of these, so keep this
 */
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_ParseBaseException, __pyx_t_13, __pyx_t_7, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ParseBaseException, __pyx_t_1) < 0) __PYX_ERR(0, 184, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":245
 * 
 * 
 * class ParseException(ParseBaseException):             # <<<<<<<<<<<<<<
 *     """
 *     Exception thrown when parse expressions don't match class;
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_7 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_ParseException, __pyx_n_s_ParseException, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Exception_thrown_when_parse_exp); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_ParseException, __pyx_t_2, __pyx_t_7, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ParseException, __pyx_t_1) < 0) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":267
 * 
 * 
 * class ParseFatalException(ParseBaseException):             # <<<<<<<<<<<<<<
 *     """user-throwable exception thrown when inconsistent parse content
 *        is found; stops all parsing immediately"""
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseBaseException); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_13, __pyx_n_s_ParseFatalException, __pyx_n_s_ParseFatalException, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_user_throwable_exception_thrown); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_ParseFatalException, __pyx_t_13, __pyx_t_7, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ParseFatalException, __pyx_t_1) < 0) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":273
 * 
 * 
 * class ParseSyntaxException(ParseFatalException):             # <<<<<<<<<<<<<<
 *     """just like L{ParseFatalException}, but thrown internally when an
 *        L{ErrorStop<And._ErrorStop>} ('-' operator) indicates that parsing is to stop
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseFatalException); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_7 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_ParseSyntaxException, __pyx_n_s_ParseSyntaxException, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_just_like_L_ParseFatalException); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_ParseSyntaxException, __pyx_t_2, __pyx_t_7, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ParseSyntaxException, __pyx_t_1) < 0) __PYX_ERR(0, 273, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":293
 * 
 * 
 * class RecursiveGrammarException(Exception):             # <<<<<<<<<<<<<<
 *     """exception thrown by L{ParserElement.validate} if the grammar could be improperly recursive"""
 * 
 */
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
  __Pyx_GIVEREF(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_7 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_RecursiveGrammarException, __pyx_n_s_RecursiveGrammarException, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_exception_thrown_by_L_ParserElem); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);

  /* "cPyparsing.pyx":296
 *     """exception thrown by L{ParserElement.validate} if the grammar could be improperly recursive"""
 * 
 *     def __init__(self, parseElementList):             # <<<<<<<<<<<<<<
 *         self.parseElementTrace = parseElementList
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_25RecursiveGrammarException_1__init__, 0, __pyx_n_s_RecursiveGrammarException___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__239)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_init, __pyx_t_1) < 0) __PYX_ERR(0, 296, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":299
 *         self.parseElementTrace = parseElementList
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "RecursiveGrammarException: %s" % self.parseElementTrace
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_25RecursiveGrammarException_3__str__, 0, __pyx_n_s_RecursiveGrammarException___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__241)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_str_2, __pyx_t_1) < 0) __PYX_ERR(0, 299, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":293
 * 
 * 
 * class RecursiveGrammarException(Exception):             # <<<<<<<<<<<<<<
 *     """exception thrown by L{ParserElement.validate} if the grammar could be improperly recursive"""
 * 
 */
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_RecursiveGrammarException, __pyx_t_2, __pyx_t_7, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_RecursiveGrammarException, __pyx_t_1) < 0) __PYX_ERR(0, 293, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":303
 * 
 * 
 * class _ParseResultsWithOffset(object):             # <<<<<<<<<<<<<<
 *     def __init__(self, p1, p2):
 *         self.tup = (p1, p2)
 */
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_builtin_object);
  __Pyx_GIVEREF(__pyx_builtin_object);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_builtin_object);
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_7 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_ParseResultsWithOffset, __pyx_n_s_ParseResultsWithOffset, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);

  /* "cPyparsing.pyx":304
 * 
 * class _ParseResultsWithOffset(object):
 *     def __init__(self, p1, p2):             # <<<<<<<<<<<<<<
 *         self.tup = (p1, p2)
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_23_ParseResultsWithOffset_1__init__, 0, __pyx_n_s_ParseResultsWithOffset___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__243)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_init, __pyx_t_1) < 0) __PYX_ERR(0, 304, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":307
 *         self.tup = (p1, p2)
 * 
 *     def __getitem__(self, i):             # <<<<<<<<<<<<<<
 *         return self.tup[i]
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_23_ParseResultsWithOffset_3__getitem__, 0, __pyx_n_s_ParseResultsWithOffset___getite, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__245)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_getitem, __pyx_t_1) < 0) __PYX_ERR(0, 307, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":310
 *         return self.tup[i]
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return repr(self.tup[0])
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_23_ParseResultsWithOffset_5__repr__, 0, __pyx_n_s_ParseResultsWithOffset___repr, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__247)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_repr_3, __pyx_t_1) < 0) __PYX_ERR(0, 310, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":313
 *         return repr(self.tup[0])
 * 
 *     def setOffset(self, i):             # <<<<<<<<<<<<<<
 *         self.tup = (self.tup[0], i)
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_23_ParseResultsWithOffset_7setOffset, 0, __pyx_n_s_ParseResultsWithOffset_setOffse, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__249)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_setOffset, __pyx_t_1) < 0) __PYX_ERR(0, 313, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":303
 * 
 * 
 * class _ParseResultsWithOffset(object):             # <<<<<<<<<<<<<<
 *     def __init__(self, p1, p2):
 *         self.tup = (p1, p2)
 */
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_ParseResultsWithOffset, __pyx_t_2, __pyx_t_7, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ParseResultsWithOffset, __pyx_t_1) < 0) __PYX_ERR(0, 303, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":317
 * 
 * 
 * class ParseResults(object):             # <<<<<<<<<<<<<<
 *     """
 *     Structured parse results, to provide multiple means of access to the parsed data:
 */
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_builtin_object);
  __Pyx_GIVEREF(__pyx_builtin_object);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_builtin_object);
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_7 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_ParseResults, __pyx_n_s_ParseResults, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Structured_parse_results_to_pro); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);

  /* "cPyparsing.pyx":356
 *         - year: 1999
 *     """
 *     def __new__(cls, toklist=None, name=None, asList=True, modal=True):             # <<<<<<<<<<<<<<
 *         if isinstance(toklist, cls):
 *             return toklist
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_1__new__, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_ParseResults___new, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__251)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__252);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_new, __pyx_t_1) < 0) __PYX_ERR(0, 356, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":365
 *     # Performance tuning: we construct a *lot* of these, so keep this
 *     # constructor as small and fast as possible
 *     def __init__(self, toklist=None, name=None, asList=True, modal=True, isinstance=isinstance):             # <<<<<<<<<<<<<<
 *         if self.__doinit:
 *             self.__doinit = False
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_3__init__, 0, __pyx_n_s_ParseResults___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__254)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_1, sizeof(__pyx_defaults), 1)) __PYX_ERR(0, 365, __pyx_L1_error)
  __pyx_t_9 = __Pyx_GetBuiltinName(__pyx_n_s_isinstance); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_t_1)->__pyx_arg_isinstance = __pyx_t_9;
  __Pyx_GIVEREF(__pyx_t_9);
  __pyx_t_9 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_1, __pyx_pf_10cPyparsing_83__defaults__);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_init, __pyx_t_1) < 0) __PYX_ERR(0, 365, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":404
 *                         self[name] = toklist
 * 
 *     def __getitem__(self, i):             # <<<<<<<<<<<<<<
 *         if isinstance(i, (int, slice)):
 *             return self.__toklist[i]
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_5__getitem__, 0, __pyx_n_s_ParseResults___getitem, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__256)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_getitem, __pyx_t_1) < 0) __PYX_ERR(0, 404, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":413
 *                 return ParseResults([v[0] for v in self.__tokdict[i]])
 * 
 *     def __setitem__(self, k, v, isinstance=isinstance):             # <<<<<<<<<<<<<<
 *         if isinstance(v, _ParseResultsWithOffset):
 *             self.__tokdict[k] = self.__tokdict.get(k, list()) + [v]
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_7__setitem__, 0, __pyx_n_s_ParseResults___setitem, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__258)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_1, sizeof(__pyx_defaults1), 1)) __PYX_ERR(0, 413, __pyx_L1_error)
  __pyx_t_9 = __Pyx_GetBuiltinName(__pyx_n_s_isinstance); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_t_1)->__pyx_arg_isinstance = __pyx_t_9;
  __Pyx_GIVEREF(__pyx_t_9);
  __pyx_t_9 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_1, __pyx_pf_10cPyparsing_85__defaults__);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_setitem, __pyx_t_1) < 0) __PYX_ERR(0, 413, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":426
 *             sub.__parent = wkref(self)
 * 
 *     def __delitem__(self, i):             # <<<<<<<<<<<<<<
 *         if isinstance(i, (int, slice)):
 *             mylen = len(self.__toklist)
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_9__delitem__, 0, __pyx_n_s_ParseResults___delitem, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__260)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_delitem, __pyx_t_1) < 0) __PYX_ERR(0, 426, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":447
 *             del self.__tokdict[i]
 * 
 *     def __contains__(self, k):             # <<<<<<<<<<<<<<
 *         return k in self.__tokdict
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_11__contains__, 0, __pyx_n_s_ParseResults___contains, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__262)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_contains, __pyx_t_1) < 0) __PYX_ERR(0, 447, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":450
 *         return k in self.__tokdict
 * 
 *     def __len__(self): return len(self.__toklist)             # <<<<<<<<<<<<<<
 * 
 *     def __bool__(self): return (not not self.__toklist)
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_13__len__, 0, __pyx_n_s_ParseResults___len, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__264)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_len, __pyx_t_1) < 0) __PYX_ERR(0, 450, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":452
 *     def __len__(self): return len(self.__toklist)
 * 
 *     def __bool__(self): return (not not self.__toklist)             # <<<<<<<<<<<<<<
 *     __nonzero__ = __bool__
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_15__bool__, 0, __pyx_n_s_ParseResults___bool, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__266)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_bool, __pyx_t_1) < 0) __PYX_ERR(0, 452, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":453
 * 
 *     def __bool__(self): return (not not self.__toklist)
 *     __nonzero__ = __bool__             # <<<<<<<<<<<<<<
 * 
 *     def __iter__(self): return iter(self.__toklist)
 */
  __pyx_t_1 = PyObject_GetItem(__pyx_t_7, __pyx_n_s_bool);
  if (unlikely(!__pyx_t_1)) {
    PyErr_Clear();
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_bool);
  }
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_nonzero, __pyx_t_1) < 0) __PYX_ERR(0, 453, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":455
 *     __nonzero__ = __bool__
 * 
 *     def __iter__(self): return iter(self.__toklist)             # <<<<<<<<<<<<<<
 * 
 *     def __reversed__(self): return iter(self.__toklist[::-1])
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_17__iter__, 0, __pyx_n_s_ParseResults___iter, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__268)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_iter, __pyx_t_1) < 0) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":457
 *     def __iter__(self): return iter(self.__toklist)
 * 
 *     def __reversed__(self): return iter(self.__toklist[::-1])             # <<<<<<<<<<<<<<
 * 
 *     def _iterkeys(self):
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_19__reversed__, 0, __pyx_n_s_ParseResults___reversed, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__270)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_reversed_2, __pyx_t_1) < 0) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":459
 *     def __reversed__(self): return iter(self.__toklist[::-1])
 * 
 *     def _iterkeys(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self.__tokdict, "iterkeys"):
 *             return self.__tokdict.iterkeys()
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_21_iterkeys, 0, __pyx_n_s_ParseResults__iterkeys, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__272)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_iterkeys_2, __pyx_t_1) < 0) __PYX_ERR(0, 459, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":465
 *             return iter(self.__tokdict)
 * 
 *     def _itervalues(self):             # <<<<<<<<<<<<<<
 *         return (self[k] for k in self._iterkeys())
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_23_itervalues, 0, __pyx_n_s_ParseResults__itervalues, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__274)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_itervalues_2, __pyx_t_1) < 0) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":468
 *         return (self[k] for k in self._iterkeys())
 * 
 *     def _iteritems(self):             # <<<<<<<<<<<<<<
 *         return ((k, self[k]) for k in self._iterkeys())
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_25_iteritems, 0, __pyx_n_s_ParseResults__iteritems, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__276)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_iteritems_2, __pyx_t_1) < 0) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":471
 *         return ((k, self[k]) for k in self._iterkeys())
 * 
 *     if PY_3:             # <<<<<<<<<<<<<<
 *         keys = _iterkeys
 *         """Returns an iterator of all named result keys (Python 3.x only)."""
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_PY_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_14 < 0)) __PYX_ERR(0, 471, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_14) {

    /* "cPyparsing.pyx":472
 * 
 *     if PY_3:
 *         keys = _iterkeys             # <<<<<<<<<<<<<<
 *         """Returns an iterator of all named result keys (Python 3.x only)."""
 * 
 */
    __pyx_t_1 = PyObject_GetItem(__pyx_t_7, __pyx_n_s_iterkeys_2);
    if (unlikely(!__pyx_t_1)) {
      PyErr_Clear();
      __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_iterkeys_2);
    }
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 472, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_keys, __pyx_t_1) < 0) __PYX_ERR(0, 472, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":475
 *         """Returns an iterator of all named result keys (Python 3.x only)."""
 * 
 *         values = _itervalues             # <<<<<<<<<<<<<<
 *         """Returns an iterator of all named result values (Python 3.x only)."""
 * 
 */
    __pyx_t_1 = PyObject_GetItem(__pyx_t_7, __pyx_n_s_itervalues_2);
    if (unlikely(!__pyx_t_1)) {
      PyErr_Clear();
      __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_itervalues_2);
    }
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_values, __pyx_t_1) < 0) __PYX_ERR(0, 475, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":478
 *         """Returns an iterator of all named result values (Python 3.x only)."""
 * 
 *         items = _iteritems             # <<<<<<<<<<<<<<
 *         """Returns an iterator of all named result key-value tuples (Python 3.x only)."""
 * 
 */
    __pyx_t_1 = PyObject_GetItem(__pyx_t_7, __pyx_n_s_iteritems_2);
    if (unlikely(!__pyx_t_1)) {
      PyErr_Clear();
      __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_iteritems_2);
    }
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 478, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_items, __pyx_t_1) < 0) __PYX_ERR(0, 478, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":471
 *         return ((k, self[k]) for k in self._iterkeys())
 * 
 *     if PY_3:             # <<<<<<<<<<<<<<
 *         keys = _iterkeys
 *         """Returns an iterator of all named result keys (Python 3.x only)."""
 */
    goto __pyx_L45;
  }

  /* "cPyparsing.pyx":482
 * 
 *     else:
 *         iterkeys = _iterkeys             # <<<<<<<<<<<<<<
 *         """Returns an iterator of all named result keys (Python 2.x only)."""
 * 
 */
  /*else*/ {
    __pyx_t_1 = PyObject_GetItem(__pyx_t_7, __pyx_n_s_iterkeys_2);
    if (unlikely(!__pyx_t_1)) {
      PyErr_Clear();
      __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_iterkeys_2);
    }
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 482, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_iterkeys, __pyx_t_1) < 0) __PYX_ERR(0, 482, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":485
 *         """Returns an iterator of all named result keys (Python 2.x only)."""
 * 
 *         itervalues = _itervalues             # <<<<<<<<<<<<<<
 *         """Returns an iterator of all named result values (Python 2.x only)."""
 * 
 */
    __pyx_t_1 = PyObject_GetItem(__pyx_t_7, __pyx_n_s_itervalues_2);
    if (unlikely(!__pyx_t_1)) {
      PyErr_Clear();
      __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_itervalues_2);
    }
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 485, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_itervalues, __pyx_t_1) < 0) __PYX_ERR(0, 485, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":488
 *         """Returns an iterator of all named result values (Python 2.x only)."""
 * 
 *         iteritems = _iteritems             # <<<<<<<<<<<<<<
 *         """Returns an iterator of all named result key-value tuples (Python 2.x only)."""
 * 
 */
    __pyx_t_1 = PyObject_GetItem(__pyx_t_7, __pyx_n_s_iteritems_2);
    if (unlikely(!__pyx_t_1)) {
      PyErr_Clear();
      __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_iteritems_2);
    }
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 488, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_iteritems, __pyx_t_1) < 0) __PYX_ERR(0, 488, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":491
 *         """Returns an iterator of all named result key-value tuples (Python 2.x only)."""
 * 
 *         def keys(self):             # <<<<<<<<<<<<<<
 *             """Returns all named result keys (as a list in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.iterkeys())
 */
    __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_27keys, 0, __pyx_n_s_ParseResults_keys, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__278)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 491, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_keys, __pyx_t_1) < 0) __PYX_ERR(0, 491, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":495
 *             return list(self.iterkeys())
 * 
 *         def values(self):             # <<<<<<<<<<<<<<
 *             """Returns all named result values (as a list in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.itervalues())
 */
    __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_29values, 0, __pyx_n_s_ParseResults_values, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__280)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 495, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_values, __pyx_t_1) < 0) __PYX_ERR(0, 495, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":499
 *             return list(self.itervalues())
 * 
 *         def items(self):             # <<<<<<<<<<<<<<
 *             """Returns all named result key-values (as a list of tuples in Python 2.x, as an iterator in Python 3.x)."""
 *             return list(self.iteritems())
 */
    __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_31items, 0, __pyx_n_s_ParseResults_items, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__282)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 499, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_items, __pyx_t_1) < 0) __PYX_ERR(0, 499, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L45:;

  /* "cPyparsing.pyx":503
 *             return list(self.iteritems())
 * 
 *     def haskeys(self):             # <<<<<<<<<<<<<<
 *         """Since keys() returns an iterator, this method is helpful in bypassing
 *            code that looks for the existence of any defined results names."""
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_33haskeys, 0, __pyx_n_s_ParseResults_haskeys, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__284)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_haskeys, __pyx_t_1) < 0) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":508
 *         return bool(self.__tokdict)
 * 
 *     def pop(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Removes and returns item at specified index (default=C{last}).
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_35pop, 0, __pyx_n_s_ParseResults_pop, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__286)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_pop, __pyx_t_1) < 0) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":560
 *             return defaultvalue
 * 
 *     def get(self, key, defaultValue=None):             # <<<<<<<<<<<<<<
 *         """
 *         Returns named result matching the given key, or if there is no
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_37get, 0, __pyx_n_s_ParseResults_get, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__288)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__289);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_get, __pyx_t_1) < 0) __PYX_ERR(0, 560, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":582
 *             return defaultValue
 * 
 *     def insert(self, index, insStr):             # <<<<<<<<<<<<<<
 *         """
 *         Inserts new element at location index in the list of parsed tokens.
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_39insert, 0, __pyx_n_s_ParseResults_insert, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__291)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_insert, __pyx_t_1) < 0) __PYX_ERR(0, 582, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":602
 *                 occurrences[k] = _ParseResultsWithOffset(value, position + (position > index))
 * 
 *     def append(self, item):             # <<<<<<<<<<<<<<
 *         """
 *         Add single element to end of ParseResults list of elements.
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_41append, 0, __pyx_n_s_ParseResults_append, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__293)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_append, __pyx_t_1) < 0) __PYX_ERR(0, 602, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":616
 *         self.__toklist.append(item)
 * 
 *     def extend(self, itemseq):             # <<<<<<<<<<<<<<
 *         """
 *         Add sequence of elements to end of ParseResults list of elements.
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_43extend, 0, __pyx_n_s_ParseResults_extend, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__295)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_extend, __pyx_t_1) < 0) __PYX_ERR(0, 616, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":634
 *             self.__toklist.extend(itemseq)
 * 
 *     def clear(self):             # <<<<<<<<<<<<<<
 *         """
 *         Clear all elements and results names.
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_45clear, 0, __pyx_n_s_ParseResults_clear, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__297)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_clear, __pyx_t_1) < 0) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":641
 *         self.__tokdict.clear()
 * 
 *     def __getattr__(self, name):             # <<<<<<<<<<<<<<
 *         try:
 *             return self[name]
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_47__getattr__, 0, __pyx_n_s_ParseResults___getattr, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__299)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_getattr, __pyx_t_1) < 0) __PYX_ERR(0, 641, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":655
 *         #     return ""
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         ret = self.copy()
 *         ret += other
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_49__add__, 0, __pyx_n_s_ParseResults___add, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__301)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_add, __pyx_t_1) < 0) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":660
 *         return ret
 * 
 *     def __iadd__(self, other):             # <<<<<<<<<<<<<<
 *         if other.__tokdict:
 *             offset = len(self.__toklist)
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_51__iadd__, 0, __pyx_n_s_ParseResults___iadd, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__303)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_iadd, __pyx_t_1) < 0) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":677
 *         return self
 * 
 *     def __radd__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, int) and other == 0:
 *             # useful for merging many ParseResults using sum() builtin
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_53__radd__, 0, __pyx_n_s_ParseResults___radd, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__305)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_radd, __pyx_t_1) < 0) __PYX_ERR(0, 677, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":685
 *             return other + self
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "(%s, %s)" % (repr(self.__toklist), repr(self.__tokdict))
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_55__repr__, 0, __pyx_n_s_ParseResults___repr, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__307)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_repr_3, __pyx_t_1) < 0) __PYX_ERR(0, 685, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":688
 *         return "(%s, %s)" % (repr(self.__toklist), repr(self.__tokdict))
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_57__str__, 0, __pyx_n_s_ParseResults___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__309)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_str_2, __pyx_t_1) < 0) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":691
 *         return '[' + ', '.join(_ustr(i) if isinstance(i, ParseResults) else repr(i) for i in self.__toklist) + ']'
 * 
 *     def _asStringList(self, sep=''):             # <<<<<<<<<<<<<<
 *         out = []
 *         for item in self.__toklist:
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_59_asStringList, 0, __pyx_n_s_ParseResults__asStringList, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__311)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__312);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_asStringList, __pyx_t_1) < 0) __PYX_ERR(0, 691, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":702
 *         return out
 * 
 *     def asList(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the parse results as a nested list of matching tokens, all converted to strings.
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_61asList, 0, __pyx_n_s_ParseResults_asList, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__314)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_asList, __pyx_t_1) < 0) __PYX_ERR(0, 702, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":718
 *         return [res.asList() if isinstance(res, ParseResults) else res for res in self.__toklist]
 * 
 *     def asDict(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns the named parse results as a nested dictionary.
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_63asDict, 0, __pyx_n_s_ParseResults_asDict, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__316)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_asDict, __pyx_t_1) < 0) __PYX_ERR(0, 718, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":753
 *         return dict((k, toItem(v)) for k, v in item_fn())
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         """
 *         Returns a new copy of a C{ParseResults} object.
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_65copy, 0, __pyx_n_s_ParseResults_copy, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__318)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_copy, __pyx_t_1) < 0) __PYX_ERR(0, 753, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":764
 *         return ret
 * 
 *     def asXML(self, doctag=None, namedItemsOnly=False, indent="", formatted=True):             # <<<<<<<<<<<<<<
 *         """
 *         (Deprecated) Returns the parse results as XML. Tags are created for tokens and lists that have defined results names.
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_67asXML, 0, __pyx_n_s_ParseResults_asXML, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__320)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__321);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_asXML, __pyx_t_1) < 0) __PYX_ERR(0, 764, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":825
 *         return "".join(out)
 * 
 *     def __lookup(self, sub):             # <<<<<<<<<<<<<<
 *         for k, vlist in self.__tokdict.items():
 *             for v, loc in vlist:
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_69__lookup, 0, __pyx_n_s_ParseResults___lookup, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__323)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_ParseResults__lookup, __pyx_t_1) < 0) __PYX_ERR(0, 825, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":832
 *         return None
 * 
 *     def getName(self):             # <<<<<<<<<<<<<<
 *         r"""
 *         Returns the results name for this token expression. Useful when several
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_71getName, 0, __pyx_n_s_ParseResults_getName, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__325)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_getName, __pyx_t_1) < 0) __PYX_ERR(0, 832, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":869
 *             return None
 * 
 *     def dump(self, indent='', depth=0, full=True):             # <<<<<<<<<<<<<<
 *         """
 *         Diagnostic method for listing out the contents of a C{ParseResults}.
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_73dump, 0, __pyx_n_s_ParseResults_dump, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__327)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__328);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_dump, __pyx_t_1) < 0) __PYX_ERR(0, 869, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":914
 *         return "".join(out)
 * 
 *     def pprint(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Pretty-printer for parsed results as a list, using the C{pprint} module.
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_75pprint, 0, __pyx_n_s_ParseResults_pprint, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__330)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_pprint, __pyx_t_1) < 0) __PYX_ERR(0, 914, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":938
 * 
 *     # add support for pickle protocol
 *     def __getstate__(self):             # <<<<<<<<<<<<<<
 *         return (self.__toklist,
 *                 (self.__tokdict.copy(),
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_77__getstate__, 0, __pyx_n_s_ParseResults___getstate, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__332)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_getstate, __pyx_t_1) < 0) __PYX_ERR(0, 938, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":945
 *                  self.__name))
 * 
 *     def __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.__toklist = state[0]
 *         (self.__tokdict,
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_79__setstate__, 0, __pyx_n_s_ParseResults___setstate, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__334)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 945, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_setstate, __pyx_t_1) < 0) __PYX_ERR(0, 945, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":958
 *             self.__parent = None
 * 
 *     def __getnewargs__(self):             # <<<<<<<<<<<<<<
 *         return self.__toklist, self.__name, self.__asList, self.__modal
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_81__getnewargs__, 0, __pyx_n_s_ParseResults___getnewargs, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__336)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_getnewargs, __pyx_t_1) < 0) __PYX_ERR(0, 958, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":961
 *         return self.__toklist, self.__name, self.__asList, self.__modal
 * 
 *     def __dir__(self):             # <<<<<<<<<<<<<<
 *         return (dir(type(self)) + list(self.keys()))
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12ParseResults_83__dir__, 0, __pyx_n_s_ParseResults___dir, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__338)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_dir, __pyx_t_1) < 0) __PYX_ERR(0, 961, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":317
 * 
 * 
 * class ParseResults(object):             # <<<<<<<<<<<<<<
 *     """
 *     Structured parse results, to provide multiple means of access to the parsed data:
 */
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_ParseResults, __pyx_t_2, __pyx_t_7, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ParseResults, __pyx_t_1) < 0) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":965
 * 
 * 
 * collections.MutableMapping.register(ParseResults)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_collections); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_MutableMapping); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_register); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseResults); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  if (!__pyx_t_1) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 965, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_7};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 965, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_7};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 965, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 965, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_1); __pyx_t_1 = NULL;
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_7);
      __pyx_t_7 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_9, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 965, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":968
 * 
 * 
 * def col(int loc, strg):             # <<<<<<<<<<<<<<
 *     """Returns current column within a string, counting newlines as line separators.
 *     The first column is number 1.
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_7col, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_col, __pyx_t_2) < 0) __PYX_ERR(0, 968, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":982
 * 
 * 
 * def lineno(int loc, strg):             # <<<<<<<<<<<<<<
 *     """Returns current line number within a string, counting newlines as line separators.
 *     The first line is number 1.
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_9lineno, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 982, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_lineno, __pyx_t_2) < 0) __PYX_ERR(0, 982, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":995
 * 
 * 
 * def line(int loc, strg):             # <<<<<<<<<<<<<<
 *     """Returns the line of text containing loc within a string, counting newlines as line separators.
 *     """
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_11line, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_line, __pyx_t_2) < 0) __PYX_ERR(0, 995, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1006
 * 
 * 
 * def _defaultStartDebugAction(instring, loc, expr):             # <<<<<<<<<<<<<<
 *     print(("Match " + _ustr(expr) + " at loc " + _ustr(loc) + "(%d,%d)" % (lineno(loc, instring), col(loc, instring))))
 * 
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_13_defaultStartDebugAction, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1006, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_defaultStartDebugAction, __pyx_t_2) < 0) __PYX_ERR(0, 1006, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1010
 * 
 * 
 * def _defaultSuccessDebugAction(instring, startloc, endloc, expr, toks):             # <<<<<<<<<<<<<<
 *     print("Matched " + _ustr(expr) + " -> " + str(toks.asList()))
 * 
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_15_defaultSuccessDebugAction, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1010, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_defaultSuccessDebugAction, __pyx_t_2) < 0) __PYX_ERR(0, 1010, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1014
 * 
 * 
 * def _defaultExceptionDebugAction(instring, loc, expr, exc):             # <<<<<<<<<<<<<<
 *     print("Exception raised:" + _ustr(exc))
 * 
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_17_defaultExceptionDebugAction, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_defaultExceptionDebugAction, __pyx_t_2) < 0) __PYX_ERR(0, 1014, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1018
 * 
 * 
 * def nullDebugAction(*args):             # <<<<<<<<<<<<<<
 *     """'Do-nothing' debug action, to suppress debugging output during parsing."""
 *     pass
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_19nullDebugAction, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_nullDebugAction, __pyx_t_2) < 0) __PYX_ERR(0, 1018, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1023
 * 
 * 
 * def _trim_arity(func, maxargs=2):             # <<<<<<<<<<<<<<
 *     """decorator to trim function calls to match the arity of the target"""
 * 
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_21_trim_arity, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1023, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_trim_arity, __pyx_t_2) < 0) __PYX_ERR(0, 1023, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":1089
 * 
 * 
 * class ParserElement(object):             # <<<<<<<<<<<<<<
 *     """Abstract base level parser element class."""
 *     DEFAULT_WHITE_CHARS = " \n\t\r"
 */
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1089, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_builtin_object);
  __Pyx_GIVEREF(__pyx_builtin_object);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_builtin_object);
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1089, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_ParserElement, __pyx_n_s_ParserElement, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Abstract_base_level_parser_eleme); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1089, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":1091
 * class ParserElement(object):
 *     """Abstract base level parser element class."""
 *     DEFAULT_WHITE_CHARS = " \n\t\r"             # <<<<<<<<<<<<<<
 *     verbose_stacktrace = False
 * 
 */
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_DEFAULT_WHITE_CHARS, __pyx_kp_u__355) < 0) __PYX_ERR(0, 1091, __pyx_L1_error)

  /* "cPyparsing.pyx":1092
 *     """Abstract base level parser element class."""
 *     DEFAULT_WHITE_CHARS = " \n\t\r"
 *     verbose_stacktrace = False             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_verbose_stacktrace, Py_False) < 0) __PYX_ERR(0, 1092, __pyx_L1_error)

  /* "cPyparsing.pyx":1095
 * 
 *     @staticmethod
 *     def setDefaultWhitespaceChars(chars):             # <<<<<<<<<<<<<<
 *         r"""
 *         Overrides the default whitespace chars
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_1setDefaultWhitespaceChars, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_ParserElement_setDefaultWhitespa, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__357)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1095, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);

  /* "cPyparsing.pyx":1094
 *     verbose_stacktrace = False
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def setDefaultWhitespaceChars(chars):
 *         r"""
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_7);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_staticmethod, __pyx_t_1, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_setDefaultWhitespaceChars, __pyx_t_7) < 0) __PYX_ERR(0, 1095, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1110
 * 
 *     @staticmethod
 *     def inlineLiteralsUsing(cls):             # <<<<<<<<<<<<<<
 *         """
 *         Set class to be used for inclusion of string literals into a parser.
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_3inlineLiteralsUsing, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_ParserElement_inlineLiteralsUsin, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__359)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);

  /* "cPyparsing.pyx":1109
 *         ParserElement.DEFAULT_WHITE_CHARS = chars
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def inlineLiteralsUsing(cls):
 *         """
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_7);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_staticmethod, __pyx_t_1, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_inlineLiteralsUsing, __pyx_t_7) < 0) __PYX_ERR(0, 1110, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1130
 *         ParserElement._literalStringClass = cls
 * 
 *     def __init__(self, savelist=False):             # <<<<<<<<<<<<<<
 *         self.parseAction = list()
 *         self.failAction = None
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_5__init__, 0, __pyx_n_s_ParserElement___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__361)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__362);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(0, 1130, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1153
 *         self.callDuringTry = False
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         """
 *         Make a copy of this C{ParserElement}.  Useful for defining different parse actions
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_7copy, 0, __pyx_n_s_ParserElement_copy, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__364)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_copy, __pyx_t_7) < 0) __PYX_ERR(0, 1153, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1176
 *         return cpy
 * 
 *     def setName(self, name):             # <<<<<<<<<<<<<<
 *         """
 *         Define name for this expression, makes debugging and exception messages clearer.
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_9setName, 0, __pyx_n_s_ParserElement_setName, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__366)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_setName, __pyx_t_7) < 0) __PYX_ERR(0, 1176, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1190
 *         return self
 * 
 *     def setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         """
 *         Define name for referencing matching tokens as a nested attribute
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_11setResultsName, 0, __pyx_n_s_ParserElement_setResultsName, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__368)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__369);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_setResultsName, __pyx_t_7) < 0) __PYX_ERR(0, 1190, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1218
 *         return newself
 * 
 *     def setBreak(self, breakFlag=True):             # <<<<<<<<<<<<<<
 *         """Method to invoke the Python pdb debugger when this element is
 *            about to be parsed. Set C{breakFlag} to True to enable, False to
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_13setBreak, 0, __pyx_n_s_ParserElement_setBreak, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__371)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__372);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_setBreak, __pyx_t_7) < 0) __PYX_ERR(0, 1218, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1237
 *         return self
 * 
 *     def setParseAction(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Define one or more actions to perform when successfully matching parse element definition.
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_15setParseAction, 0, __pyx_n_s_ParserElement_setParseAction, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__374)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_setParseAction, __pyx_t_7) < 0) __PYX_ERR(0, 1237, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1275
 *         return self
 * 
 *     def addParseAction(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """
 *         Add one or more parse actions to expression's list of parse actions. See L{I{setParseAction}<setParseAction>}.
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_17addParseAction, 0, __pyx_n_s_ParserElement_addParseAction, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__376)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1275, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_addParseAction, __pyx_t_7) < 0) __PYX_ERR(0, 1275, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1285
 *         return self
 * 
 *     def addCondition(self, *fns, **kwargs):             # <<<<<<<<<<<<<<
 *         """Add a boolean predicate function to expression's list of parse actions. See
 *         L{I{setParseAction}<setParseAction>} for function call signatures. Unlike C{setParseAction},
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_19addCondition, 0, __pyx_n_s_ParserElement_addCondition, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__378)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_addCondition, __pyx_t_7) < 0) __PYX_ERR(0, 1285, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1312
 *         return self
 * 
 *     def setFailAction(self, fn):             # <<<<<<<<<<<<<<
 *         """Define action to perform if parsing fails at this expression.
 *            Fail acton fn is a callable function that takes the arguments
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_21setFailAction, 0, __pyx_n_s_ParserElement_setFailAction, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__380)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_setFailAction, __pyx_t_7) < 0) __PYX_ERR(0, 1312, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1325
 *         return self
 * 
 *     def _skipIgnorables(self, instring, loc):             # <<<<<<<<<<<<<<
 *         exprsFound = True
 *         while exprsFound:
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_23_skipIgnorables, 0, __pyx_n_s_ParserElement__skipIgnorables, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__382)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_skipIgnorables, __pyx_t_7) < 0) __PYX_ERR(0, 1325, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1338
 *         return loc
 * 
 *     def preParse(self, instring, int loc):             # <<<<<<<<<<<<<<
 *         if self.ignoreExprs:
 *             loc = self._skipIgnorables(instring, loc)
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_25preParse, 0, __pyx_n_s_ParserElement_preParse, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__384)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_preParse, __pyx_t_7) < 0) __PYX_ERR(0, 1338, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1350
 *         return loc
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         return loc, []
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_27parseImpl, 0, __pyx_n_s_ParserElement_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__386)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__387);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_7) < 0) __PYX_ERR(0, 1350, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1353
 *         return loc, []
 * 
 *     def postParse(self, instring, int loc, tokenlist):             # <<<<<<<<<<<<<<
 *         return tokenlist
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_29postParse, 0, __pyx_n_s_ParserElement_postParse, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__389)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_postParse, __pyx_t_7) < 0) __PYX_ERR(0, 1353, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1357
 * 
 *     #~ @profile
 *     def _parseNoCache(self, instring, int loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *         debugging = (self.debug)  # and doActions )
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_31_parseNoCache, 0, __pyx_n_s_ParserElement__parseNoCache, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__391)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__392);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseNoCache, __pyx_t_7) < 0) __PYX_ERR(0, 1357, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1429
 *         return loc, retTokens
 * 
 *     def tryParse(self, instring, int loc):             # <<<<<<<<<<<<<<
 *         try:
 *             return self._parse(instring, loc, doActions=False)[0]
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_33tryParse, 0, __pyx_n_s_ParserElement_tryParse, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__394)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_tryParse, __pyx_t_7) < 0) __PYX_ERR(0, 1429, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1435
 *             raise ParseException(instring, loc, self.errmsg, self)
 * 
 *     def canParseNext(self, instring, int loc):             # <<<<<<<<<<<<<<
 *         try:
 *             self.tryParse(instring, loc)
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_35canParseNext, 0, __pyx_n_s_ParserElement_canParseNext, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__396)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_canParseNext, __pyx_t_7) < 0) __PYX_ERR(0, 1435, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1443
 *             return True
 * 
 *     class _UnboundedCache(object):             # <<<<<<<<<<<<<<
 *         def __init__(self):
 *             cache = {}
 */
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_builtin_object);
  __Pyx_GIVEREF(__pyx_builtin_object);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_builtin_object);
  __pyx_t_1 = __Pyx_CalculateMetaclass(NULL, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_8 = __Pyx_Py3MetaclassPrepare(__pyx_t_1, __pyx_t_7, __pyx_n_s_UnboundedCache, __pyx_n_s_ParserElement__UnboundedCache_5, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);

  /* "cPyparsing.pyx":1444
 * 
 *     class _UnboundedCache(object):
 *         def __init__(self):             # <<<<<<<<<<<<<<
 *             cache = {}
 *             self.not_in_cache = not_in_cache = object()
 */
  __pyx_t_17 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_15_UnboundedCache_1__init__, 0, __pyx_n_s_ParserElement__UnboundedCache_6, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__398)); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  if (PyObject_SetItem(__pyx_t_8, __pyx_n_s_init, __pyx_t_17) < 0) __PYX_ERR(0, 1444, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

  /* "cPyparsing.pyx":1443
 *             return True
 * 
 *     class _UnboundedCache(object):             # <<<<<<<<<<<<<<
 *         def __init__(self):
 *             cache = {}
 */
  __pyx_t_17 = __Pyx_Py3ClassCreate(__pyx_t_1, __pyx_n_s_UnboundedCache, __pyx_t_7, __pyx_t_8, NULL, 0, 0); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_UnboundedCache, __pyx_t_17) < 0) __PYX_ERR(0, 1443, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1465
 *             self.__len__ = types.MethodType(cache_len, self)
 * 
 *     if _OrderedDict is not None:             # <<<<<<<<<<<<<<
 *         class _FifoCache(object):
 *             def __init__(self, size):
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_OrderedDict); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_14 = (__pyx_t_7 != Py_None);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_18 = (__pyx_t_14 != 0);
  if (__pyx_t_18) {

    /* "cPyparsing.pyx":1466
 * 
 *     if _OrderedDict is not None:
 *         class _FifoCache(object):             # <<<<<<<<<<<<<<
 *             def __init__(self, size):
 *                 self.not_in_cache = not_in_cache = object()
 */
    __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1466, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_INCREF(__pyx_builtin_object);
    __Pyx_GIVEREF(__pyx_builtin_object);
    PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_builtin_object);
    __pyx_t_1 = __Pyx_CalculateMetaclass(NULL, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1466, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = __Pyx_Py3MetaclassPrepare(__pyx_t_1, __pyx_t_7, __pyx_n_s_FifoCache, __pyx_n_s_ParserElement__FifoCache, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1466, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);

    /* "cPyparsing.pyx":1467
 *     if _OrderedDict is not None:
 *         class _FifoCache(object):
 *             def __init__(self, size):             # <<<<<<<<<<<<<<
 *                 self.not_in_cache = not_in_cache = object()
 * 
 */
    __pyx_t_17 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10_FifoCache_1__init__, 0, __pyx_n_s_ParserElement__FifoCache___init_5, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__400)); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1467, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    if (PyObject_SetItem(__pyx_t_8, __pyx_n_s_init, __pyx_t_17) < 0) __PYX_ERR(0, 1467, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

    /* "cPyparsing.pyx":1466
 * 
 *     if _OrderedDict is not None:
 *         class _FifoCache(object):             # <<<<<<<<<<<<<<
 *             def __init__(self, size):
 *                 self.not_in_cache = not_in_cache = object()
 */
    __pyx_t_17 = __Pyx_Py3ClassCreate(__pyx_t_1, __pyx_n_s_FifoCache, __pyx_t_7, __pyx_t_8, NULL, 0, 0); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1466, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_FifoCache, __pyx_t_17) < 0) __PYX_ERR(0, 1466, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "cPyparsing.pyx":1465
 *             self.__len__ = types.MethodType(cache_len, self)
 * 
 *     if _OrderedDict is not None:             # <<<<<<<<<<<<<<
 *         class _FifoCache(object):
 *             def __init__(self, size):
 */
    goto __pyx_L46;
  }

  /* "cPyparsing.pyx":1495
 * 
 *     else:
 *         class _FifoCache(object):             # <<<<<<<<<<<<<<
 *             def __init__(self, size):
 *                 self.not_in_cache = not_in_cache = object()
 */
  /*else*/ {
    __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1495, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_INCREF(__pyx_builtin_object);
    __Pyx_GIVEREF(__pyx_builtin_object);
    PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_builtin_object);
    __pyx_t_1 = __Pyx_CalculateMetaclass(NULL, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1495, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = __Pyx_Py3MetaclassPrepare(__pyx_t_1, __pyx_t_7, __pyx_n_s_FifoCache, __pyx_n_s_ParserElement__FifoCache, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1495, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);

    /* "cPyparsing.pyx":1496
 *     else:
 *         class _FifoCache(object):
 *             def __init__(self, size):             # <<<<<<<<<<<<<<
 *                 self.not_in_cache = not_in_cache = object()
 * 
 */
    __pyx_t_17 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10_FifoCache_3__init__, 0, __pyx_n_s_ParserElement__FifoCache___init_5, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__402)); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1496, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    if (PyObject_SetItem(__pyx_t_8, __pyx_n_s_init, __pyx_t_17) < 0) __PYX_ERR(0, 1496, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

    /* "cPyparsing.pyx":1495
 * 
 *     else:
 *         class _FifoCache(object):             # <<<<<<<<<<<<<<
 *             def __init__(self, size):
 *                 self.not_in_cache = not_in_cache = object()
 */
    __pyx_t_17 = __Pyx_Py3ClassCreate(__pyx_t_1, __pyx_n_s_FifoCache, __pyx_t_7, __pyx_t_8, NULL, 0, 0); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1495, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_FifoCache, __pyx_t_17) < 0) __PYX_ERR(0, 1495, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_L46:;

  /* "cPyparsing.pyx":1524
 * 
 *     # argument cache for optimizing repeated calls when backtracking through recursive expressions
 *     packrat_cache = {}  # this is set later by enabledPackrat(); this is here so that resetCache() doesn't fail             # <<<<<<<<<<<<<<
 *     packrat_cache_lock = RLock()
 *     packrat_cache_stats = [0, 0]
 */
  __pyx_t_7 = PyDict_New(); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_packrat_cache, __pyx_t_7) < 0) __PYX_ERR(0, 1524, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1525
 *     # argument cache for optimizing repeated calls when backtracking through recursive expressions
 *     packrat_cache = {}  # this is set later by enabledPackrat(); this is here so that resetCache() doesn't fail
 *     packrat_cache_lock = RLock()             # <<<<<<<<<<<<<<
 *     packrat_cache_stats = [0, 0]
 * 
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_RLock); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (__pyx_t_8) {
    __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_8); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1525, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  } else {
    __pyx_t_7 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1525, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_packrat_cache_lock, __pyx_t_7) < 0) __PYX_ERR(0, 1525, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1526
 *     packrat_cache = {}  # this is set later by enabledPackrat(); this is here so that resetCache() doesn't fail
 *     packrat_cache_lock = RLock()
 *     packrat_cache_stats = [0, 0]             # <<<<<<<<<<<<<<
 * 
 *     # this method gets repeatedly called during backtracking with the same arguments -
 */
  __pyx_t_7 = PyList_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_7, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyList_SET_ITEM(__pyx_t_7, 1, __pyx_int_0);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_packrat_cache_stats, __pyx_t_7) < 0) __PYX_ERR(0, 1526, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1530
 *     # this method gets repeatedly called during backtracking with the same arguments -
 *     # we can cache these arguments and save ourselves the trouble of re-parsing the contained expression
 *     def _parseCache(self, instring, int loc, doActions=True, callPreParse=True):             # <<<<<<<<<<<<<<
 *         HIT, MISS = 0, 1
 *         lookup = (self, instring, loc, callPreParse, doActions)
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_37_parseCache, 0, __pyx_n_s_ParserElement__parseCache, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__404)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__405);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseCache, __pyx_t_7) < 0) __PYX_ERR(0, 1530, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1553
 *                 return (value[0], value[1].copy())
 * 
 *     _parse = _parseNoCache             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
  __pyx_t_7 = PyObject_GetItem(__pyx_t_9, __pyx_n_s_parseNoCache);
  if (unlikely(!__pyx_t_7)) {
    PyErr_Clear();
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_parseNoCache);
  }
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parse, __pyx_t_7) < 0) __PYX_ERR(0, 1553, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1556
 * 
 *     @staticmethod
 *     def resetCache():             # <<<<<<<<<<<<<<
 *         ParserElement.packrat_cache.clear()
 *         ParserElement.packrat_cache_stats[:] = [0] * len(ParserElement.packrat_cache_stats)
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_39resetCache, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_ParserElement_resetCache, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__406)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);

  /* "cPyparsing.pyx":1555
 *     _parse = _parseNoCache
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def resetCache():
 *         ParserElement.packrat_cache.clear()
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_7);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_staticmethod, __pyx_t_1, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_resetCache, __pyx_t_7) < 0) __PYX_ERR(0, 1556, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1560
 *         ParserElement.packrat_cache_stats[:] = [0] * len(ParserElement.packrat_cache_stats)
 * 
 *     _packratEnabled = False             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_packratEnabled, Py_False) < 0) __PYX_ERR(0, 1560, __pyx_L1_error)

  /* "cPyparsing.pyx":1563
 * 
 *     @staticmethod
 *     def enablePackrat(cache_size_limit=128):             # <<<<<<<<<<<<<<
 *         """Enables "packrat" parsing, which adds memoizing to the parsing logic.
 *            Repeated parse attempts at the same string location (which happens
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_41enablePackrat, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_ParserElement_enablePackrat, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__408)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__409);

  /* "cPyparsing.pyx":1562
 *     _packratEnabled = False
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def enablePackrat(cache_size_limit=128):
 *         """Enables "packrat" parsing, which adds memoizing to the parsing logic.
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_7);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_staticmethod, __pyx_t_1, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_enablePackrat, __pyx_t_7) < 0) __PYX_ERR(0, 1563, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1597
 *             ParserElement._parse = ParserElement._parseCache
 * 
 *     def parseString(self, instring, parseAll=False):             # <<<<<<<<<<<<<<
 *         """
 *         Execute the parse expression with the given string.
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_43parseString, 0, __pyx_n_s_ParserElement_parseString, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__411)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__412);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseString, __pyx_t_7) < 0) __PYX_ERR(0, 1597, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1647
 *             return tokens
 * 
 *     def scanString(self, instring, maxMatches=_MAX_INT, overlap=False):             # <<<<<<<<<<<<<<
 *         """
 *         Scan the input string for expression matches.  Each match will return the
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_45scanString, 0, __pyx_n_s_ParserElement_scanString, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__414)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_7, sizeof(__pyx_defaults2), 1)) __PYX_ERR(0, 1647, __pyx_L1_error)
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_MAX_INT); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_Defaults(__pyx_defaults2, __pyx_t_7)->__pyx_arg_maxMatches = __pyx_t_1;
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_7, __pyx_pf_10cPyparsing_87__defaults__);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_scanString, __pyx_t_7) < 0) __PYX_ERR(0, 1647, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1718
 *                 raise exc
 * 
 *     def transformString(self, instring):             # <<<<<<<<<<<<<<
 *         """
 *         Extension to C{L{scanString}}, to modify matching text with modified tokens that may
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_48transformString, 0, __pyx_n_s_ParserElement_transformString, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__416)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_transformString, __pyx_t_7) < 0) __PYX_ERR(0, 1718, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1761
 *                 raise exc
 * 
 *     def searchString(self, instring, maxMatches=_MAX_INT):             # <<<<<<<<<<<<<<
 *         """
 *         Another extension to C{L{scanString}}, simplifying the access to the tokens found
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_50searchString, 0, __pyx_n_s_ParserElement_searchString, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__418)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_7, sizeof(__pyx_defaults3), 1)) __PYX_ERR(0, 1761, __pyx_L1_error)
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_MAX_INT); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_Defaults(__pyx_defaults3, __pyx_t_7)->__pyx_arg_maxMatches = __pyx_t_1;
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_7, __pyx_pf_10cPyparsing_89__defaults__);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_searchString, __pyx_t_7) < 0) __PYX_ERR(0, 1761, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1788
 *                 raise exc
 * 
 *     def split(self, instring, maxsplit=_MAX_INT, includeSeparators=False):             # <<<<<<<<<<<<<<
 *         """
 *         Generator method to split a string using the given expression as a separator.
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_52split, 0, __pyx_n_s_ParserElement_split, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__420)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_7, sizeof(__pyx_defaults4), 1)) __PYX_ERR(0, 1788, __pyx_L1_error)
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_MAX_INT); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_Defaults(__pyx_defaults4, __pyx_t_7)->__pyx_arg_maxsplit = __pyx_t_1;
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_7, __pyx_pf_10cPyparsing_91__defaults__);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_split, __pyx_t_7) < 0) __PYX_ERR(0, 1788, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1810
 *         yield instring[last:]
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of + operator - returns C{L{And}}. Adding strings to a ParserElement
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_55__add__, 0, __pyx_n_s_ParserElement___add, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__422)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_add, __pyx_t_7) < 0) __PYX_ERR(0, 1810, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1830
 *         return And([self, other])
 * 
 *     def __radd__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of + operator when left operand is not a C{L{ParserElement}}
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_57__radd__, 0, __pyx_n_s_ParserElement___radd, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__424)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_radd, __pyx_t_7) < 0) __PYX_ERR(0, 1830, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1842
 *         return other + self
 * 
 *     def __sub__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of - operator, returns C{L{And}} with error stop
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_59__sub__, 0, __pyx_n_s_ParserElement___sub, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__426)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_sub_2, __pyx_t_7) < 0) __PYX_ERR(0, 1842, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1854
 *         return self + And._ErrorStop() + other
 * 
 *     def __rsub__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of - operator when left operand is not a C{L{ParserElement}}
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_61__rsub__, 0, __pyx_n_s_ParserElement___rsub, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__428)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_rsub, __pyx_t_7) < 0) __PYX_ERR(0, 1854, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1866
 *         return other - self
 * 
 *     def __mul__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of * operator, allows use of C{expr * 3} in place of
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_63__mul__, 0, __pyx_n_s_ParserElement___mul, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__430)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_mul, __pyx_t_7) < 0) __PYX_ERR(0, 1866, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1934
 *         return ret
 * 
 *     def __rmul__(self, other):             # <<<<<<<<<<<<<<
 *         return self.__mul__(other)
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_65__rmul__, 0, __pyx_n_s_ParserElement___rmul, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__432)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_rmul, __pyx_t_7) < 0) __PYX_ERR(0, 1934, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1937
 *         return self.__mul__(other)
 * 
 *     def __or__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of | operator - returns C{L{MatchFirst}}
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_67__or__, 0, __pyx_n_s_ParserElement___or, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__434)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1937, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_or, __pyx_t_7) < 0) __PYX_ERR(0, 1937, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1949
 *         return MatchFirst([self, other])
 * 
 *     def __ror__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of | operator when left operand is not a C{L{ParserElement}}
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_69__ror__, 0, __pyx_n_s_ParserElement___ror, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__436)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1949, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_ror, __pyx_t_7) < 0) __PYX_ERR(0, 1949, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1961
 *         return other | self
 * 
 *     def __xor__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of ^ operator - returns C{L{Or}}
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_71__xor__, 0, __pyx_n_s_ParserElement___xor, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__438)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_xor, __pyx_t_7) < 0) __PYX_ERR(0, 1961, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1973
 *         return Or([self, other])
 * 
 *     def __rxor__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of ^ operator when left operand is not a C{L{ParserElement}}
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_73__rxor__, 0, __pyx_n_s_ParserElement___rxor, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__440)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_rxor, __pyx_t_7) < 0) __PYX_ERR(0, 1973, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1985
 *         return other ^ self
 * 
 *     def __and__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of & operator - returns C{L{Each}}
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_75__and__, 0, __pyx_n_s_ParserElement___and, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__442)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_and, __pyx_t_7) < 0) __PYX_ERR(0, 1985, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1997
 *         return Each([self, other])
 * 
 *     def __rand__(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of & operator when left operand is not a C{L{ParserElement}}
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_77__rand__, 0, __pyx_n_s_ParserElement___rand, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__444)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_rand, __pyx_t_7) < 0) __PYX_ERR(0, 1997, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2009
 *         return other & self
 * 
 *     def __invert__(self):             # <<<<<<<<<<<<<<
 *         """
 *         Implementation of ~ operator - returns C{L{NotAny}}
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_79__invert__, 0, __pyx_n_s_ParserElement___invert, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__446)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_invert, __pyx_t_7) < 0) __PYX_ERR(0, 2009, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2015
 *         return NotAny(self)
 * 
 *     def __call__(self, name=None):             # <<<<<<<<<<<<<<
 *         """
 *         Shortcut for C{L{setResultsName}}, with C{listAllMatches=False}.
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_81__call__, 0, __pyx_n_s_ParserElement___call, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__448)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__449);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_call, __pyx_t_7) < 0) __PYX_ERR(0, 2015, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2034
 *             return self.copy()
 * 
 *     def suppress(self):             # <<<<<<<<<<<<<<
 *         """
 *         Suppresses the output of this C{ParserElement}; useful to keep punctuation from
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_83suppress, 0, __pyx_n_s_ParserElement_suppress, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__451)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_suppress, __pyx_t_7) < 0) __PYX_ERR(0, 2034, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2041
 *         return Suppress(self)
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         """
 *         Disables the skipping of whitespace before matching the characters in the
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_85leaveWhitespace, 0, __pyx_n_s_ParserElement_leaveWhitespace, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__453)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_leaveWhitespace, __pyx_t_7) < 0) __PYX_ERR(0, 2041, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2050
 *         return self
 * 
 *     def setWhitespaceChars(self, chars):             # <<<<<<<<<<<<<<
 *         """
 *         Overrides the default whitespace chars
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_87setWhitespaceChars, 0, __pyx_n_s_ParserElement_setWhitespaceChars, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__455)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2050, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_setWhitespaceChars, __pyx_t_7) < 0) __PYX_ERR(0, 2050, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2059
 *         return self
 * 
 *     def parseWithTabs(self):             # <<<<<<<<<<<<<<
 *         """
 *         Overrides default behavior to expand C{<TAB>}s to spaces before parsing the input string.
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_89parseWithTabs, 0, __pyx_n_s_ParserElement_parseWithTabs, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__457)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2059, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseWithTabs, __pyx_t_7) < 0) __PYX_ERR(0, 2059, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2068
 *         return self
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         """
 *         Define expression to be ignored (e.g., comments) while doing pattern
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_91ignore, 0, __pyx_n_s_ParserElement_ignore, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__459)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_ignore, __pyx_t_7) < 0) __PYX_ERR(0, 2068, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2091
 *         return self
 * 
 *     def setDebugActions(self, startAction, successAction, exceptionAction):             # <<<<<<<<<<<<<<
 *         """
 *         Enable display of debugging messages while doing pattern matching.
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_93setDebugActions, 0, __pyx_n_s_ParserElement_setDebugActions, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__461)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2091, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_setDebugActions, __pyx_t_7) < 0) __PYX_ERR(0, 2091, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2101
 *         return self
 * 
 *     def setDebug(self, flag=True):             # <<<<<<<<<<<<<<
 *         """
 *         Enable display of debugging messages while doing pattern matching.
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_95setDebug, 0, __pyx_n_s_ParserElement_setDebug, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__463)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__464);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_setDebug, __pyx_t_7) < 0) __PYX_ERR(0, 2101, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2142
 *         return self
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return self.name
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_97__str__, 0, __pyx_n_s_ParserElement___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__466)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_str_2, __pyx_t_7) < 0) __PYX_ERR(0, 2142, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2145
 *         return self.name
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return _ustr(self)
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_99__repr__, 0, __pyx_n_s_ParserElement___repr, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__468)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_repr_3, __pyx_t_7) < 0) __PYX_ERR(0, 2145, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2148
 *         return _ustr(self)
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         self.streamlined = True
 *         self.strRepr = None
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_101streamline, 0, __pyx_n_s_ParserElement_streamline, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__470)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_streamline, __pyx_t_7) < 0) __PYX_ERR(0, 2148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2153
 *         return self
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         pass
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_103checkRecursion, 0, __pyx_n_s_ParserElement_checkRecursion, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__472)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_checkRecursion, __pyx_t_7) < 0) __PYX_ERR(0, 2153, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2156
 *         pass
 * 
 *     def validate(self, validateTrace=[]):             # <<<<<<<<<<<<<<
 *         """
 *         Check defined expressions for valid structure, check for infinite recursive definitions.
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_105validate, 0, __pyx_n_s_ParserElement_validate, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__474)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_7, sizeof(__pyx_defaults5), 1)) __PYX_ERR(0, 2156, __pyx_L1_error)
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_Defaults(__pyx_defaults5, __pyx_t_7)->__pyx_arg_validateTrace = __pyx_t_1;
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_7, __pyx_pf_10cPyparsing_93__defaults__);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_validate, __pyx_t_7) < 0) __PYX_ERR(0, 2156, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2162
 *         self.checkRecursion([])
 * 
 *     def parseFile(self, file_or_filename, parseAll=False):             # <<<<<<<<<<<<<<
 *         """
 *         Execute the parse expression on the given file or filename.
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_107parseFile, 0, __pyx_n_s_ParserElement_parseFile, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__476)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__477);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseFile, __pyx_t_7) < 0) __PYX_ERR(0, 2162, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2182
 *                 raise exc
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, ParserElement):
 *             return self is other or vars(self) == vars(other)
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_109__eq__, 0, __pyx_n_s_ParserElement___eq, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__479)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_eq, __pyx_t_7) < 0) __PYX_ERR(0, 2182, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2190
 *             return super(ParserElement, self) == other
 * 
 *     def __ne__(self, other):             # <<<<<<<<<<<<<<
 *         return not (self == other)
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_111__ne__, 0, __pyx_n_s_ParserElement___ne, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__481)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_ne, __pyx_t_7) < 0) __PYX_ERR(0, 2190, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2193
 *         return not (self == other)
 * 
 *     def __hash__(self):             # <<<<<<<<<<<<<<
 *         return hash(id(self))
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_113__hash__, 0, __pyx_n_s_ParserElement___hash, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__483)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_hash, __pyx_t_7) < 0) __PYX_ERR(0, 2193, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2196
 *         return hash(id(self))
 * 
 *     def __req__(self, other):             # <<<<<<<<<<<<<<
 *         return self == other
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_115__req__, 0, __pyx_n_s_ParserElement___req, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__485)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_req, __pyx_t_7) < 0) __PYX_ERR(0, 2196, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2199
 *         return self == other
 * 
 *     def __rne__(self, other):             # <<<<<<<<<<<<<<
 *         return not (self == other)
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_117__rne__, 0, __pyx_n_s_ParserElement___rne, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__487)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_rne, __pyx_t_7) < 0) __PYX_ERR(0, 2199, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2202
 *         return not (self == other)
 * 
 *     def matches(self, testString, parseAll=True):             # <<<<<<<<<<<<<<
 *         """
 *         Method for quick testing of a parser against a test string. Good for simple
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_119matches, 0, __pyx_n_s_ParserElement_matches, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__489)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__490);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_matches, __pyx_t_7) < 0) __PYX_ERR(0, 2202, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2221
 *             return False
 * 
 *     def runTests(self, tests, parseAll=True, comment='#', fullDump=True, printResults=True, failureTests=False):             # <<<<<<<<<<<<<<
 *         """
 *         Execute the parse expression on a series of test strings, showing each
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13ParserElement_121runTests, 0, __pyx_n_s_ParserElement_runTests, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__492)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__493);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_runTests, __pyx_t_7) < 0) __PYX_ERR(0, 2221, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":1089
 * 
 * 
 * class ParserElement(object):             # <<<<<<<<<<<<<<
 *     """Abstract base level parser element class."""
 *     DEFAULT_WHITE_CHARS = " \n\t\r"
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_ParserElement, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1089, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ParserElement, __pyx_t_7) < 0) __PYX_ERR(0, 1089, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2353
 * 
 * 
 * class Token(ParserElement):             # <<<<<<<<<<<<<<
 *     """
 *     Abstract C{ParserElement} subclass, for defining atomic matching patterns.
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_13, __pyx_n_s_Token, __pyx_n_s_Token, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Abstract_C_ParserElement_subcla); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":2358
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(Token, self).__init__(savelist=False)
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_5Token_1__init__, 0, __pyx_n_s_Token___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__495)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2358, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(0, 2358, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2353
 * 
 * 
 * class Token(ParserElement):             # <<<<<<<<<<<<<<
 *     """
 *     Abstract C{ParserElement} subclass, for defining atomic matching patterns.
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_Token, __pyx_t_13, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Token, __pyx_t_7) < 0) __PYX_ERR(0, 2353, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":2362
 * 
 * 
 * class Empty(Token):             # <<<<<<<<<<<<<<
 *     """
 *     An empty token, will always match.
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_Token); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2362, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2362, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2362, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_Empty, __pyx_n_s_Empty, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_An_empty_token_will_always_matc); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2362, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":2367
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(Empty, self).__init__()
 *         self.name = "Empty"
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_5Empty_1__init__, 0, __pyx_n_s_Empty___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__497)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(0, 2367, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2362
 * 
 * 
 * class Empty(Token):             # <<<<<<<<<<<<<<
 *     """
 *     An empty token, will always match.
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_Empty, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2362, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Empty, __pyx_t_7) < 0) __PYX_ERR(0, 2362, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2374
 * 
 * 
 * class NoMatch(Token):             # <<<<<<<<<<<<<<
 *     """
 *     A token that will never match.
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Token); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_13, __pyx_n_s_NoMatch, __pyx_n_s_NoMatch, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_A_token_that_will_never_match); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":2379
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(NoMatch, self).__init__()
 *         self.name = "NoMatch"
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_7NoMatch_1__init__, 0, __pyx_n_s_NoMatch___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__499)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(0, 2379, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2386
 *         self.errmsg = "Unmatchable token"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_7NoMatch_3parseImpl, 0, __pyx_n_s_NoMatch_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__501)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__502);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_7) < 0) __PYX_ERR(0, 2386, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2374
 * 
 * 
 * class NoMatch(Token):             # <<<<<<<<<<<<<<
 *     """
 *     A token that will never match.
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_NoMatch, __pyx_t_13, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NoMatch, __pyx_t_7) < 0) __PYX_ERR(0, 2374, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":2390
 * 
 * 
 * class Literal(Token):             # <<<<<<<<<<<<<<
 *     """
 *     Token to exactly match a specified string.
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_Token); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_Literal, __pyx_n_s_Literal, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Token_to_exactly_match_a_specif); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":2405
 *     """
 * 
 *     def __init__(self, matchString):             # <<<<<<<<<<<<<<
 *         super(Literal, self).__init__()
 *         self.match = matchString
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_7Literal_1__init__, 0, __pyx_n_s_Literal___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__504)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(0, 2405, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2424
 *     # short-circuit as quickly as possible, and avoid calling startswith
 *     #~ @profile
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if (instring[loc] == self.firstMatchChar and
 *                 (self.matchLen == 1 or instring.startswith(self.match, loc))):
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_7Literal_3parseImpl, 0, __pyx_n_s_Literal_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__506)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__507);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_7) < 0) __PYX_ERR(0, 2424, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":2390
 * 
 * 
 * class Literal(Token):             # <<<<<<<<<<<<<<
 *     """
 *     Token to exactly match a specified string.
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_Literal, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Literal, __pyx_t_7) < 0) __PYX_ERR(0, 2390, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2431
 * 
 * 
 * _L = Literal             # <<<<<<<<<<<<<<
 * ParserElement._literalStringClass = Literal
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Literal); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_L, __pyx_t_2) < 0) __PYX_ERR(0, 2431, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2432
 * 
 * _L = Literal
 * ParserElement._literalStringClass = Literal             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Literal); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_13, __pyx_n_s_literalStringClass, __pyx_t_2) < 0) __PYX_ERR(0, 2432, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":2435
 * 
 * 
 * class Keyword(Token):             # <<<<<<<<<<<<<<
 *     """
 *     Token to exactly match a specified string as a keyword, that is, it must be
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_Token); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_Keyword, __pyx_n_s_Keyword, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Token_to_exactly_match_a_specif_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":2452
 *     For case-insensitive matching, use L{CaselessKeyword}.
 *     """
 *     DEFAULT_KEYWORD_CHARS = alphanums + "_$"             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, matchString, identChars=None, caseless=False):
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_alphanums); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = PyNumber_Add(__pyx_t_7, __pyx_kp_u__508); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_DEFAULT_KEYWORD_CHARS, __pyx_t_1) < 0) __PYX_ERR(0, 2452, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2454
 *     DEFAULT_KEYWORD_CHARS = alphanums + "_$"
 * 
 *     def __init__(self, matchString, identChars=None, caseless=False):             # <<<<<<<<<<<<<<
 *         super(Keyword, self).__init__()
 *         if identChars is None:
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_7Keyword_1__init__, 0, __pyx_n_s_Keyword___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__510)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__511);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_1) < 0) __PYX_ERR(0, 2454, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2475
 *         self.identChars = set(identChars)
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.caseless:
 *             if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch) and
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_7Keyword_3parseImpl, 0, __pyx_n_s_Keyword_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__513)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__514);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_1) < 0) __PYX_ERR(0, 2475, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2489
 *         raise ParseException(instring, loc, self.errmsg, self)
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         c = super(Keyword, self).copy()
 *         c.identChars = Keyword.DEFAULT_KEYWORD_CHARS
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_7Keyword_5copy, 0, __pyx_n_s_Keyword_copy, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__516)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_copy, __pyx_t_1) < 0) __PYX_ERR(0, 2489, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2495
 * 
 *     @staticmethod
 *     def setDefaultKeywordChars(chars):             # <<<<<<<<<<<<<<
 *         """Overrides the default Keyword chars
 *         """
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_7Keyword_7setDefaultKeywordChars, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_Keyword_setDefaultKeywordChars, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__518)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "cPyparsing.pyx":2494
 *         return c
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def setDefaultKeywordChars(chars):
 *         """Overrides the default Keyword chars
 */
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_staticmethod, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_setDefaultKeywordChars, __pyx_t_1) < 0) __PYX_ERR(0, 2495, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2435
 * 
 * 
 * class Keyword(Token):             # <<<<<<<<<<<<<<
 *     """
 *     Token to exactly match a specified string as a keyword, that is, it must be
 */
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_Keyword, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Keyword, __pyx_t_1) < 0) __PYX_ERR(0, 2435, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2501
 * 
 * 
 * class CaselessLiteral(Literal):             # <<<<<<<<<<<<<<
 *     """
 *     Token to match a specified string, ignoring case of letters.
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Literal); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_13, __pyx_n_s_CaselessLiteral, __pyx_n_s_CaselessLiteral, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Token_to_match_a_specified_stri); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":2513
 *     """
 * 
 *     def __init__(self, matchString):             # <<<<<<<<<<<<<<
 *         super(CaselessLiteral, self).__init__(matchString.upper())
 *         # Preserve the defining literal.
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_15CaselessLiteral_1__init__, 0, __pyx_n_s_CaselessLiteral___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__520)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_1) < 0) __PYX_ERR(0, 2513, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2520
 *         self.errmsg = "Expected " + self.name
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc:loc + self.matchLen].upper() == self.match:
 *             return loc + self.matchLen, self.returnString
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_15CaselessLiteral_3parseImpl, 0, __pyx_n_s_CaselessLiteral_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__522)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__523);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_1) < 0) __PYX_ERR(0, 2520, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2501
 * 
 * 
 * class CaselessLiteral(Literal):             # <<<<<<<<<<<<<<
 *     """
 *     Token to match a specified string, ignoring case of letters.
 */
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_CaselessLiteral, __pyx_t_13, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CaselessLiteral, __pyx_t_1) < 0) __PYX_ERR(0, 2501, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":2526
 * 
 * 
 * class CaselessKeyword(Keyword):             # <<<<<<<<<<<<<<
 *     """
 *     Caseless version of L{Keyword}.
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_Keyword); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_CaselessKeyword, __pyx_n_s_CaselessKeyword, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Caseless_version_of_L_Keyword_E); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":2536
 *     """
 * 
 *     def __init__(self, matchString, identChars=None):             # <<<<<<<<<<<<<<
 *         super(CaselessKeyword, self).__init__(matchString, identChars, caseless=True)
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_15CaselessKeyword_1__init__, 0, __pyx_n_s_CaselessKeyword___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__525)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__526);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_1) < 0) __PYX_ERR(0, 2536, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2539
 *         super(CaselessKeyword, self).__init__(matchString, identChars, caseless=True)
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if ((instring[loc:loc + self.matchLen].upper() == self.caselessmatch) and
 *                 (loc >= len(instring) - self.matchLen or instring[loc + self.matchLen].upper() not in self.identChars)):
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_15CaselessKeyword_3parseImpl, 0, __pyx_n_s_CaselessKeyword_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__528)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__529);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_1) < 0) __PYX_ERR(0, 2539, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2526
 * 
 * 
 * class CaselessKeyword(Keyword):             # <<<<<<<<<<<<<<
 *     """
 *     Caseless version of L{Keyword}.
 */
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_CaselessKeyword, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CaselessKeyword, __pyx_t_1) < 0) __PYX_ERR(0, 2526, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2546
 * 
 * 
 * class CloseMatch(Token):             # <<<<<<<<<<<<<<
 *     """
 *     A variation on L{Literal} which matches "close" matches, that is,
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Token); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_13, __pyx_n_s_CloseMatch, __pyx_n_s_CloseMatch, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_A_variation_on_L_Literal_which); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":2572
 *     """
 * 
 *     def __init__(self, match_string, maxMismatches=1):             # <<<<<<<<<<<<<<
 *         super(CloseMatch, self).__init__()
 *         self.name = match_string
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10CloseMatch_1__init__, 0, __pyx_n_s_CloseMatch___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__531)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__532);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_1) < 0) __PYX_ERR(0, 2572, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2581
 *         self.mayReturnEmpty = False
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         start = loc
 *         instrlen = len(instring)
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10CloseMatch_3parseImpl, 0, __pyx_n_s_CloseMatch_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__534)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2581, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__535);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_1) < 0) __PYX_ERR(0, 2581, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2546
 * 
 * 
 * class CloseMatch(Token):             # <<<<<<<<<<<<<<
 *     """
 *     A variation on L{Literal} which matches "close" matches, that is,
 */
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_CloseMatch, __pyx_t_13, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CloseMatch, __pyx_t_1) < 0) __PYX_ERR(0, 2546, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":2608
 * 
 * 
 * class Word(Token):             # <<<<<<<<<<<<<<
 *     """
 *     Token for matching words composed of allowed character sets.
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_Token); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_Word, __pyx_n_s_Word, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Token_for_matching_words_compos); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":2656
 *     """
 * 
 *     def __init__(self, initChars, bodyChars=None, min=1, max=0, exact=0, asKeyword=False, excludeChars=None):             # <<<<<<<<<<<<<<
 *         super(Word, self).__init__()
 *         if excludeChars:
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_4Word_1__init__, 0, __pyx_n_s_Word___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__537)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__538);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_1) < 0) __PYX_ERR(0, 2656, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2710
 *                 self.re = None
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.re:
 *             result = self.re.match(instring, loc)
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_4Word_3parseImpl, 0, __pyx_n_s_Word_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__540)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__541);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_1) < 0) __PYX_ERR(0, 2710, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2745
 *         return loc, instring[start:loc]
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(Word, self).__str__()
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_4Word_5__str__, 0, __pyx_n_s_Word___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__543)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_str_2, __pyx_t_1) < 0) __PYX_ERR(0, 2745, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2608
 * 
 * 
 * class Word(Token):             # <<<<<<<<<<<<<<
 *     """
 *     Token for matching words composed of allowed character sets.
 */
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_Word, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Word, __pyx_t_1) < 0) __PYX_ERR(0, 2608, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2767
 * 
 * 
 * class Regex(Token):             # <<<<<<<<<<<<<<
 *     r"""
 *     Token for matching strings that match a given regular expression.
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Token); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_13, __pyx_n_s_Regex, __pyx_n_s_Regex, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Token_for_matching_strings_that); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":2780
 *         roman = Regex(r"M{0,4}(CM|CD|D?C{0,3})(XC|XL|L?X{0,3})(IX|IV|V?I{0,3})")
 *     """
 *     compiledREtype = type(re.compile("[A-Z]"))             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, pattern, flags=0):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_re); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_compile); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__544, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_compiledREtype, ((PyObject *)Py_TYPE(__pyx_t_1))) < 0) __PYX_ERR(0, 2780, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2782
 *     compiledREtype = type(re.compile("[A-Z]"))
 * 
 *     def __init__(self, pattern, flags=0):             # <<<<<<<<<<<<<<
 *         """The parameters C{pattern} and C{flags} are passed to the C{re.compile()} function as-is. See the Python C{re} module for an explanation of the acceptable patterns and flags."""
 *         super(Regex, self).__init__()
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_5Regex_1__init__, 0, __pyx_n_s_Regex___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__546)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__547);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_1) < 0) __PYX_ERR(0, 2782, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2816
 *         self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = self.re.match(instring, loc)
 *         if not result:
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_5Regex_3parseImpl, 0, __pyx_n_s_Regex_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__549)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__550);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_1) < 0) __PYX_ERR(0, 2816, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2829
 *         return loc, ret
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(Regex, self).__str__()
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_5Regex_5__str__, 0, __pyx_n_s_Regex___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__552)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_str_2, __pyx_t_1) < 0) __PYX_ERR(0, 2829, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2767
 * 
 * 
 * class Regex(Token):             # <<<<<<<<<<<<<<
 *     r"""
 *     Token for matching strings that match a given regular expression.
 */
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_Regex, __pyx_t_13, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Regex, __pyx_t_1) < 0) __PYX_ERR(0, 2767, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":2841
 * 
 * 
 * class QuotedString(Token):             # <<<<<<<<<<<<<<
 *     r"""
 *     Token for matching strings that are delimited by quoting characters.
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_Token); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_QuotedString, __pyx_n_s_QuotedString, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Token_for_matching_strings_that_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":2867
 *     """
 * 
 *     def __init__(self, quoteChar, escChar=None, escQuote=None, multiline=False, unquoteResults=True, endQuoteChar=None, convertWhitespaceEscapes=True):             # <<<<<<<<<<<<<<
 *         super(QuotedString, self).__init__()
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12QuotedString_1__init__, 0, __pyx_n_s_QuotedString___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__554)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__555);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_1) < 0) __PYX_ERR(0, 2867, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2932
 *         self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         result = instring[loc] == self.firstQuoteChar and self.re.match(instring, loc) or None
 *         if not result:
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12QuotedString_3parseImpl, 0, __pyx_n_s_QuotedString_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__557)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__558);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_1) < 0) __PYX_ERR(0, 2932, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2967
 *         return loc, ret
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(QuotedString, self).__str__()
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_12QuotedString_5__str__, 0, __pyx_n_s_QuotedString___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__560)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_str_2, __pyx_t_1) < 0) __PYX_ERR(0, 2967, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2841
 * 
 * 
 * class QuotedString(Token):             # <<<<<<<<<<<<<<
 *     r"""
 *     Token for matching strings that are delimited by quoting characters.
 */
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_QuotedString, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_QuotedString, __pyx_t_1) < 0) __PYX_ERR(0, 2841, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":2979
 * 
 * 
 * class CharsNotIn(Token):             # <<<<<<<<<<<<<<
 *     """
 *     Token for matching words composed of characters I{not} in a given set (will
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Token); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 2979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_13, __pyx_n_s_CharsNotIn, __pyx_n_s_CharsNotIn, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Token_for_matching_words_compos_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":2996
 *     """
 * 
 *     def __init__(self, notChars, min=1, max=0, exact=0):             # <<<<<<<<<<<<<<
 *         super(CharsNotIn, self).__init__()
 *         self.skipWhitespace = False
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10CharsNotIn_1__init__, 0, __pyx_n_s_CharsNotIn___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__562)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__563);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_1) < 0) __PYX_ERR(0, 2996, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3020
 *         self.mayIndexError = False
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if instring[loc] in self.notChars:
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10CharsNotIn_3parseImpl, 0, __pyx_n_s_CharsNotIn_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__565)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__566);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_1) < 0) __PYX_ERR(0, 3020, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3037
 *         return loc, instring[start:loc]
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(CharsNotIn, self).__str__()
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10CharsNotIn_5__str__, 0, __pyx_n_s_CharsNotIn___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__568)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_str_2, __pyx_t_1) < 0) __PYX_ERR(0, 3037, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":2979
 * 
 * 
 * class CharsNotIn(Token):             # <<<<<<<<<<<<<<
 *     """
 *     Token for matching words composed of characters I{not} in a given set (will
 */
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_CharsNotIn, __pyx_t_13, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CharsNotIn, __pyx_t_1) < 0) __PYX_ERR(0, 2979, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":3052
 * 
 * 
 * class White(Token):             # <<<<<<<<<<<<<<
 *     """
 *     Special matching class for matching whitespace.  Normally, whitespace is ignored
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_Token); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_White, __pyx_n_s_White, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Special_matching_class_for_matc); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":3061
 *     """
 *     whiteStrs = {
 *         " ": "<SPC>",             # <<<<<<<<<<<<<<
 *         "\t": "<TAB>",
 *         "\n": "<LF>",
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3061, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u__84, __pyx_kp_u_SPC) < 0) __PYX_ERR(0, 3061, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u__97, __pyx_kp_u_TAB) < 0) __PYX_ERR(0, 3061, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u__21, __pyx_kp_u_LF) < 0) __PYX_ERR(0, 3061, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u__99, __pyx_kp_u_CR) < 0) __PYX_ERR(0, 3061, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u__98, __pyx_kp_u_FF) < 0) __PYX_ERR(0, 3061, __pyx_L1_error)
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_whiteStrs, __pyx_t_1) < 0) __PYX_ERR(0, 3060, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3068
 *     }
 * 
 *     def __init__(self, ws=" \t\r\n", min=1, max=0, exact=0):             # <<<<<<<<<<<<<<
 *         super(White, self).__init__()
 *         self.matchWhite = ws
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_5White_1__init__, 0, __pyx_n_s_White___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__570)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__571);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_1) < 0) __PYX_ERR(0, 3068, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3088
 *             self.minLen = exact
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if not(instring[loc] in self.matchWhite):
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_5White_3parseImpl, 0, __pyx_n_s_White_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__573)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__574);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_1) < 0) __PYX_ERR(0, 3088, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3052
 * 
 * 
 * class White(Token):             # <<<<<<<<<<<<<<
 *     """
 *     Special matching class for matching whitespace.  Normally, whitespace is ignored
 */
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_White, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_White, __pyx_t_1) < 0) __PYX_ERR(0, 3052, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3104
 * 
 * 
 * class _PositionToken(Token):             # <<<<<<<<<<<<<<
 *     def __init__(self):
 *         super(_PositionToken, self).__init__()
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Token); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_13, __pyx_n_s_PositionToken, __pyx_n_s_PositionToken, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":3105
 * 
 * class _PositionToken(Token):
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(_PositionToken, self).__init__()
 *         self.name = self.__class__.__name__
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_14_PositionToken_1__init__, 0, __pyx_n_s_PositionToken___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__576)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_1) < 0) __PYX_ERR(0, 3105, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3104
 * 
 * 
 * class _PositionToken(Token):             # <<<<<<<<<<<<<<
 *     def __init__(self):
 *         super(_PositionToken, self).__init__()
 */
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_PositionToken, __pyx_t_13, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_PositionToken, __pyx_t_1) < 0) __PYX_ERR(0, 3104, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":3112
 * 
 * 
 * class GoToColumn(_PositionToken):             # <<<<<<<<<<<<<<
 *     """
 *     Token to advance to a specific column of input text; useful for tabular report scraping.
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_PositionToken); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_GoToColumn, __pyx_n_s_GoToColumn, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Token_to_advance_to_a_specific); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":3117
 *     """
 * 
 *     def __init__(self, colno):             # <<<<<<<<<<<<<<
 *         super(GoToColumn, self).__init__()
 *         self.col = colno
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10GoToColumn_1__init__, 0, __pyx_n_s_GoToColumn___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__578)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_1) < 0) __PYX_ERR(0, 3117, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3121
 *         self.col = colno
 * 
 *     def preParse(self, instring, int loc):             # <<<<<<<<<<<<<<
 *         if col(loc, instring) != self.col:
 *             instrlen = len(instring)
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10GoToColumn_3preParse, 0, __pyx_n_s_GoToColumn_preParse, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__580)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_preParse, __pyx_t_1) < 0) __PYX_ERR(0, 3121, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3130
 *         return loc
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         thiscol = col(loc, instring)
 *         if thiscol > self.col:
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10GoToColumn_5parseImpl, 0, __pyx_n_s_GoToColumn_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__582)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__583);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_1) < 0) __PYX_ERR(0, 3130, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3112
 * 
 * 
 * class GoToColumn(_PositionToken):             # <<<<<<<<<<<<<<
 *     """
 *     Token to advance to a specific column of input text; useful for tabular report scraping.
 */
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_GoToColumn, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_GoToColumn, __pyx_t_1) < 0) __PYX_ERR(0, 3112, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3139
 * 
 * 
 * class LineStart(_PositionToken):             # <<<<<<<<<<<<<<
 *     """
 *     Matches if current position is at the beginning of a line within the parse string
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_PositionToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_13, __pyx_n_s_LineStart, __pyx_n_s_LineStart, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Matches_if_current_position_is); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":3161
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(LineStart, self).__init__()
 *         self.errmsg = "Expected start of line"
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_9LineStart_1__init__, 0, __pyx_n_s_LineStart___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__585)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_1) < 0) __PYX_ERR(0, 3161, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3165
 *         self.errmsg = "Expected start of line"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if col(loc, instring) == 1:
 *             return loc, []
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_9LineStart_3parseImpl, 0, __pyx_n_s_LineStart_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__587)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__588);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_1) < 0) __PYX_ERR(0, 3165, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3139
 * 
 * 
 * class LineStart(_PositionToken):             # <<<<<<<<<<<<<<
 *     """
 *     Matches if current position is at the beginning of a line within the parse string
 */
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_LineStart, __pyx_t_13, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_LineStart, __pyx_t_1) < 0) __PYX_ERR(0, 3139, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":3171
 * 
 * 
 * class LineEnd(_PositionToken):             # <<<<<<<<<<<<<<
 *     """
 *     Matches if current position is at the end of a line within the parse string
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_PositionToken); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_LineEnd, __pyx_n_s_LineEnd, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Matches_if_current_position_is_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":3176
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(LineEnd, self).__init__()
 *         self.setWhitespaceChars(ParserElement.DEFAULT_WHITE_CHARS.replace("\n", ""))
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_7LineEnd_1__init__, 0, __pyx_n_s_LineEnd___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__590)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_1) < 0) __PYX_ERR(0, 3176, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3181
 *         self.errmsg = "Expected end of line"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc < len(instring):
 *             if instring[loc] == "\n":
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_7LineEnd_3parseImpl, 0, __pyx_n_s_LineEnd_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__592)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__593);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_1) < 0) __PYX_ERR(0, 3181, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3171
 * 
 * 
 * class LineEnd(_PositionToken):             # <<<<<<<<<<<<<<
 *     """
 *     Matches if current position is at the end of a line within the parse string
 */
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_LineEnd, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_LineEnd, __pyx_t_1) < 0) __PYX_ERR(0, 3171, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3193
 * 
 * 
 * class StringStart(_PositionToken):             # <<<<<<<<<<<<<<
 *     """
 *     Matches if current position is at the beginning of the parse string
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_PositionToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_13, __pyx_n_s_StringStart, __pyx_n_s_StringStart, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Matches_if_current_position_is_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":3198
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(StringStart, self).__init__()
 *         self.errmsg = "Expected start of text"
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_11StringStart_1__init__, 0, __pyx_n_s_StringStart___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__595)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_1) < 0) __PYX_ERR(0, 3198, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3202
 *         self.errmsg = "Expected start of text"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc != 0:
 *             # see if entire string up to here is just whitespace and ignoreables
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_11StringStart_3parseImpl, 0, __pyx_n_s_StringStart_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__597)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__598);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_1) < 0) __PYX_ERR(0, 3202, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3193
 * 
 * 
 * class StringStart(_PositionToken):             # <<<<<<<<<<<<<<
 *     """
 *     Matches if current position is at the beginning of the parse string
 */
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_StringStart, __pyx_t_13, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_StringStart, __pyx_t_1) < 0) __PYX_ERR(0, 3193, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":3210
 * 
 * 
 * class StringEnd(_PositionToken):             # <<<<<<<<<<<<<<
 *     """
 *     Matches if current position is at the end of the parse string
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_PositionToken); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_StringEnd, __pyx_n_s_StringEnd, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Matches_if_current_position_is_4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":3215
 *     """
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         super(StringEnd, self).__init__()
 *         self.errmsg = "Expected end of text"
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_9StringEnd_1__init__, 0, __pyx_n_s_StringEnd___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__600)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_1) < 0) __PYX_ERR(0, 3215, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3219
 *         self.errmsg = "Expected end of text"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc < len(instring):
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_9StringEnd_3parseImpl, 0, __pyx_n_s_StringEnd_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__602)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__603);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_1) < 0) __PYX_ERR(0, 3219, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3210
 * 
 * 
 * class StringEnd(_PositionToken):             # <<<<<<<<<<<<<<
 *     """
 *     Matches if current position is at the end of the parse string
 */
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_StringEnd, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_StringEnd, __pyx_t_1) < 0) __PYX_ERR(0, 3210, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3230
 * 
 * 
 * class WordStart(_PositionToken):             # <<<<<<<<<<<<<<
 *     """
 *     Matches if the current position is at the beginning of a Word, and
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_PositionToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_13, __pyx_n_s_WordStart, __pyx_n_s_WordStart, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Matches_if_the_current_position); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":3239
 *     """
 * 
 *     def __init__(self, wordChars=printables):             # <<<<<<<<<<<<<<
 *         super(WordStart, self).__init__()
 *         self.wordChars = set(wordChars)
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_9WordStart_1__init__, 0, __pyx_n_s_WordStart___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__605)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_1, sizeof(__pyx_defaults6), 1)) __PYX_ERR(0, 3239, __pyx_L1_error)
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_printables); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_Defaults(__pyx_defaults6, __pyx_t_1)->__pyx_arg_wordChars = __pyx_t_7;
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_1, __pyx_pf_10cPyparsing_95__defaults__);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_1) < 0) __PYX_ERR(0, 3239, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3244
 *         self.errmsg = "Not at the start of a word"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if loc != 0:
 *             if (instring[loc - 1] in self.wordChars or
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_9WordStart_3parseImpl, 0, __pyx_n_s_WordStart_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__607)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__608);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_1) < 0) __PYX_ERR(0, 3244, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3230
 * 
 * 
 * class WordStart(_PositionToken):             # <<<<<<<<<<<<<<
 *     """
 *     Matches if the current position is at the beginning of a Word, and
 */
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_WordStart, __pyx_t_13, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_WordStart, __pyx_t_1) < 0) __PYX_ERR(0, 3230, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":3252
 * 
 * 
 * class WordEnd(_PositionToken):             # <<<<<<<<<<<<<<
 *     """
 *     Matches if the current position is at the end of a Word, and
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_PositionToken); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_WordEnd, __pyx_n_s_WordEnd, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Matches_if_the_current_position_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":3261
 *     """
 * 
 *     def __init__(self, wordChars=printables):             # <<<<<<<<<<<<<<
 *         super(WordEnd, self).__init__()
 *         self.wordChars = set(wordChars)
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_7WordEnd_1__init__, 0, __pyx_n_s_WordEnd___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__610)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_1, sizeof(__pyx_defaults7), 1)) __PYX_ERR(0, 3261, __pyx_L1_error)
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_printables); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_Defaults(__pyx_defaults7, __pyx_t_1)->__pyx_arg_wordChars = __pyx_t_7;
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_1, __pyx_pf_10cPyparsing_97__defaults__);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_1) < 0) __PYX_ERR(0, 3261, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3267
 *         self.errmsg = "Not at the end of a word"
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         instrlen = len(instring)
 *         if instrlen > 0 and loc < instrlen:
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_7WordEnd_3parseImpl, 0, __pyx_n_s_WordEnd_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__612)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__613);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_1) < 0) __PYX_ERR(0, 3267, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3252
 * 
 * 
 * class WordEnd(_PositionToken):             # <<<<<<<<<<<<<<
 *     """
 *     Matches if the current position is at the end of a Word, and
 */
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_WordEnd, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_WordEnd, __pyx_t_1) < 0) __PYX_ERR(0, 3252, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3276
 * 
 * 
 * class ParseExpression(ParserElement):             # <<<<<<<<<<<<<<
 *     """
 *     Abstract subclass of ParserElement, for combining and post-processing parsed tokens.
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_13, __pyx_n_s_ParseExpression, __pyx_n_s_ParseExpression, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Abstract_subclass_of_ParserElem); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":3281
 *     """
 * 
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(ParseExpression, self).__init__(savelist)
 *         if isinstance(exprs, _generatorType):
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_15ParseExpression_1__init__, 0, __pyx_n_s_ParseExpression___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__615)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__616);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_1) < 0) __PYX_ERR(0, 3281, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3301
 *         self.callPreparse = False
 * 
 *     def __getitem__(self, i):             # <<<<<<<<<<<<<<
 *         return self.exprs[i]
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_15ParseExpression_3__getitem__, 0, __pyx_n_s_ParseExpression___getitem, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__618)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_getitem, __pyx_t_1) < 0) __PYX_ERR(0, 3301, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3304
 *         return self.exprs[i]
 * 
 *     def append(self, other):             # <<<<<<<<<<<<<<
 *         self.exprs.append(other)
 *         self.strRepr = None
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_15ParseExpression_5append, 0, __pyx_n_s_ParseExpression_append, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__620)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_append, __pyx_t_1) < 0) __PYX_ERR(0, 3304, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3309
 *         return self
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         """Extends C{leaveWhitespace} defined in base class, and also invokes C{leaveWhitespace} on
 *            all contained expressions."""
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_15ParseExpression_7leaveWhitespace, 0, __pyx_n_s_ParseExpression_leaveWhitespace, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__622)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_leaveWhitespace, __pyx_t_1) < 0) __PYX_ERR(0, 3309, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3318
 *         return self
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_15ParseExpression_9ignore, 0, __pyx_n_s_ParseExpression_ignore, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__624)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_ignore, __pyx_t_1) < 0) __PYX_ERR(0, 3318, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3330
 *         return self
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(ParseExpression, self).__str__()
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_15ParseExpression_11__str__, 0, __pyx_n_s_ParseExpression___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__626)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_str_2, __pyx_t_1) < 0) __PYX_ERR(0, 3330, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3340
 *         return self.strRepr
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(ParseExpression, self).streamline()
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_15ParseExpression_13streamline, 0, __pyx_n_s_ParseExpression_streamline, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__628)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_streamline, __pyx_t_1) < 0) __PYX_ERR(0, 3340, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3374
 *         return self
 * 
 *     def setResultsName(self, name, listAllMatches=False):             # <<<<<<<<<<<<<<
 *         ret = super(ParseExpression, self).setResultsName(name, listAllMatches)
 *         return ret
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_15ParseExpression_15setResultsName, 0, __pyx_n_s_ParseExpression_setResultsName, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__630)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__631);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_setResultsName, __pyx_t_1) < 0) __PYX_ERR(0, 3374, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3378
 *         return ret
 * 
 *     def validate(self, validateTrace=[]):             # <<<<<<<<<<<<<<
 *         tmp = validateTrace[:] + [self]
 *         for e in self.exprs:
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_15ParseExpression_17validate, 0, __pyx_n_s_ParseExpression_validate, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__633)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_1, sizeof(__pyx_defaults8), 1)) __PYX_ERR(0, 3378, __pyx_L1_error)
  __pyx_t_7 = PyList_New(0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_Defaults(__pyx_defaults8, __pyx_t_1)->__pyx_arg_validateTrace = __pyx_t_7;
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_1, __pyx_pf_10cPyparsing_99__defaults__);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_validate, __pyx_t_1) < 0) __PYX_ERR(0, 3378, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3384
 *         self.checkRecursion([])
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         ret = super(ParseExpression, self).copy()
 *         ret.exprs = [e.copy() for e in self.exprs]
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_15ParseExpression_19copy, 0, __pyx_n_s_ParseExpression_copy, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__635)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_copy, __pyx_t_1) < 0) __PYX_ERR(0, 3384, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":3276
 * 
 * 
 * class ParseExpression(ParserElement):             # <<<<<<<<<<<<<<
 *     """
 *     Abstract subclass of ParserElement, for combining and post-processing parsed tokens.
 */
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_ParseExpression, __pyx_t_13, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ParseExpression, __pyx_t_1) < 0) __PYX_ERR(0, 3276, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":3390
 * 
 * 
 * class And(ParseExpression):             # <<<<<<<<<<<<<<
 *     """
 *     Requires all given C{ParseExpression}s to be found in the given order.
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseExpression); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_And, __pyx_n_s_And, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Requires_all_given_C_ParseExpre); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":3406
 *     """
 * 
 *     class _ErrorStop(Empty):             # <<<<<<<<<<<<<<
 *         def __init__(self, *args, **kwargs):
 *             super(And._ErrorStop, self).__init__(*args, **kwargs)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Empty); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_CalculateMetaclass(NULL, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_8 = __Pyx_Py3MetaclassPrepare(__pyx_t_1, __pyx_t_7, __pyx_n_s_ErrorStop, __pyx_n_s_And__ErrorStop, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);

  /* "cPyparsing.pyx":3407
 * 
 *     class _ErrorStop(Empty):
 *         def __init__(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *             super(And._ErrorStop, self).__init__(*args, **kwargs)
 *             self.name = '-'
 */
  __pyx_t_17 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10_ErrorStop_1__init__, 0, __pyx_n_s_And__ErrorStop___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__637)); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 3407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  if (PyObject_SetItem(__pyx_t_8, __pyx_n_s_init, __pyx_t_17) < 0) __PYX_ERR(0, 3407, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

  /* "cPyparsing.pyx":3406
 *     """
 * 
 *     class _ErrorStop(Empty):             # <<<<<<<<<<<<<<
 *         def __init__(self, *args, **kwargs):
 *             super(And._ErrorStop, self).__init__(*args, **kwargs)
 */
  __pyx_t_17 = __Pyx_Py3ClassCreate(__pyx_t_1, __pyx_n_s_ErrorStop, __pyx_t_7, __pyx_t_8, NULL, 0, 0); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 3406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_ErrorStop, __pyx_t_17) < 0) __PYX_ERR(0, 3406, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3412
 *             self.leaveWhitespace()
 * 
 *     def __init__(self, exprs, savelist=True):             # <<<<<<<<<<<<<<
 *         super(And, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_3And_1__init__, 0, __pyx_n_s_And___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__639)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__640);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(0, 3412, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3419
 *         self.callPreparse = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         # pass False as last arg to _parse for first element, since we already
 *         # pre-parsed the string as part of our And pre-parsing
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_3And_3parseImpl, 0, __pyx_n_s_And_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__642)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__643);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_7) < 0) __PYX_ERR(0, 3419, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3444
 *         return loc, resultlist
 * 
 *     def __iadd__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_3And_5__iadd__, 0, __pyx_n_s_And___iadd, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__645)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_iadd, __pyx_t_7) < 0) __PYX_ERR(0, 3444, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3449
 *         return self.append(other)  # And( [ self, other ] )
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_3And_7checkRecursion, 0, __pyx_n_s_And_checkRecursion, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__647)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_checkRecursion, __pyx_t_7) < 0) __PYX_ERR(0, 3449, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3456
 *                 break
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_3And_9__str__, 0, __pyx_n_s_And___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__649)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_str_2, __pyx_t_7) < 0) __PYX_ERR(0, 3456, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3390
 * 
 * 
 * class And(ParseExpression):             # <<<<<<<<<<<<<<
 *     """
 *     Requires all given C{ParseExpression}s to be found in the given order.
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_And, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_And, __pyx_t_7) < 0) __PYX_ERR(0, 3390, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3466
 * 
 * 
 * class Or(ParseExpression):             # <<<<<<<<<<<<<<
 *     """
 *     Requires that at least one C{ParseExpression} is found.
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseExpression); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_13, __pyx_n_s_Or, __pyx_n_s_Or, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Requires_that_at_least_one_C_Pa); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":3481
 *     """
 * 
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(Or, self).__init__(exprs, savelist)
 *         if self.exprs:
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_2Or_1__init__, 0, __pyx_n_s_Or___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__651)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__652);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(0, 3481, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3488
 *             self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         maxExcLoc = -1
 *         maxException = None
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_2Or_3parseImpl, 0, __pyx_n_s_Or_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__655)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__656);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_7) < 0) __PYX_ERR(0, 3488, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3525
 *             raise ParseException(instring, loc, "no defined alternatives to match", self)
 * 
 *     def __ixor__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_2Or_5__ixor__, 0, __pyx_n_s_Or___ixor, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__658)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_ixor, __pyx_t_7) < 0) __PYX_ERR(0, 3525, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3530
 *         return self.append(other)  # Or( [ self, other ] )
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_2Or_7__str__, 0, __pyx_n_s_Or___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__660)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_str_2, __pyx_t_7) < 0) __PYX_ERR(0, 3530, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3539
 *         return self.strRepr
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_2Or_9checkRecursion, 0, __pyx_n_s_Or_checkRecursion, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__662)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_checkRecursion, __pyx_t_7) < 0) __PYX_ERR(0, 3539, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3466
 * 
 * 
 * class Or(ParseExpression):             # <<<<<<<<<<<<<<
 *     """
 *     Requires that at least one C{ParseExpression} is found.
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_Or, __pyx_t_13, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Or, __pyx_t_7) < 0) __PYX_ERR(0, 3466, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":3545
 * 
 * 
 * class MatchFirst(ParseExpression):             # <<<<<<<<<<<<<<
 *     """
 *     Requires that at least one C{ParseExpression} is found.
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseExpression); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_MatchFirst, __pyx_n_s_MatchFirst, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Requires_that_at_least_one_C_Pa_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":3563
 *     """
 * 
 *     def __init__(self, exprs, savelist=False):             # <<<<<<<<<<<<<<
 *         super(MatchFirst, self).__init__(exprs, savelist)
 *         if self.exprs:
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10MatchFirst_1__init__, 0, __pyx_n_s_MatchFirst___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__664)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__665);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(0, 3563, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3570
 *             self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         maxExcLoc = -1
 *         maxException = None
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10MatchFirst_3parseImpl, 0, __pyx_n_s_MatchFirst_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__667)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__668);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_7) < 0) __PYX_ERR(0, 3570, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3594
 *                 raise ParseException(instring, loc, "no defined alternatives to match", self)
 * 
 *     def __ior__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10MatchFirst_5__ior__, 0, __pyx_n_s_MatchFirst___ior, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__670)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_ior, __pyx_t_7) < 0) __PYX_ERR(0, 3594, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3599
 *         return self.append(other)  # MatchFirst( [ self, other ] )
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10MatchFirst_7__str__, 0, __pyx_n_s_MatchFirst___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__672)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_str_2, __pyx_t_7) < 0) __PYX_ERR(0, 3599, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3608
 *         return self.strRepr
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10MatchFirst_9checkRecursion, 0, __pyx_n_s_MatchFirst_checkRecursion, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__674)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_checkRecursion, __pyx_t_7) < 0) __PYX_ERR(0, 3608, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3545
 * 
 * 
 * class MatchFirst(ParseExpression):             # <<<<<<<<<<<<<<
 *     """
 *     Requires that at least one C{ParseExpression} is found.
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_MatchFirst, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_MatchFirst, __pyx_t_7) < 0) __PYX_ERR(0, 3545, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3614
 * 
 * 
 * class Each(ParseExpression):             # <<<<<<<<<<<<<<
 *     """
 *     Requires all given C{ParseExpression}s to be found, but in any order.
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseExpression); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_13, __pyx_n_s_Each, __pyx_n_s_Each, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Requires_all_given_C_ParseExpre_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":3669
 *     """
 * 
 *     def __init__(self, exprs, savelist=True):             # <<<<<<<<<<<<<<
 *         super(Each, self).__init__(exprs, savelist)
 *         self.mayReturnEmpty = all(e.mayReturnEmpty for e in self.exprs)
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_4Each_1__init__, 0, __pyx_n_s_Each___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__676)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__677);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(0, 3669, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3675
 *         self.initExprGroups = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.initExprGroups:
 *             self.opt1map = dict((id(e.expr), e) for e in self.exprs if isinstance(e, Optional))
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_4Each_3parseImpl, 0, __pyx_n_s_Each_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__679)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__680);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_7) < 0) __PYX_ERR(0, 3675, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3724
 *         return loc, finalResults
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_4Each_5__str__, 0, __pyx_n_s_Each___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__682)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_str_2, __pyx_t_7) < 0) __PYX_ERR(0, 3724, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3733
 *         return self.strRepr
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         subRecCheckList = parseElementList[:] + [self]
 *         for e in self.exprs:
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_4Each_7checkRecursion, 0, __pyx_n_s_Each_checkRecursion, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__684)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_checkRecursion, __pyx_t_7) < 0) __PYX_ERR(0, 3733, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3614
 * 
 * 
 * class Each(ParseExpression):             # <<<<<<<<<<<<<<
 *     """
 *     Requires all given C{ParseExpression}s to be found, but in any order.
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_Each, __pyx_t_13, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Each, __pyx_t_7) < 0) __PYX_ERR(0, 3614, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":3739
 * 
 * 
 * class ParseElementEnhance(ParserElement):             # <<<<<<<<<<<<<<
 *     """
 *     Abstract subclass of C{ParserElement}, for combining and post-processing parsed tokens.
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParserElement); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_ParseElementEnhance, __pyx_n_s_ParseElementEnhance, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Abstract_subclass_of_C_ParserEl); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":3744
 *     """
 * 
 *     def __init__(self, expr, savelist=False):             # <<<<<<<<<<<<<<
 *         super(ParseElementEnhance, self).__init__(savelist)
 *         if isinstance(expr, basestring):
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_19ParseElementEnhance_1__init__, 0, __pyx_n_s_ParseElementEnhance___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__686)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__687);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(0, 3744, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3762
 *             self.ignoreExprs.extend(expr.ignoreExprs)
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             return self.expr._parse(instring, loc, doActions, callPreParse=False)
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_19ParseElementEnhance_3parseImpl, 0, __pyx_n_s_ParseElementEnhance_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__689)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__690);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_7) < 0) __PYX_ERR(0, 3762, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3768
 *             raise ParseException("", loc, self.errmsg, self)
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = False
 *         self.expr = self.expr.copy()
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_19ParseElementEnhance_5leaveWhitespace, 0, __pyx_n_s_ParseElementEnhance_leaveWhitesp, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__692)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_leaveWhitespace, __pyx_t_7) < 0) __PYX_ERR(0, 3768, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3775
 *         return self
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, Suppress):
 *             if other not in self.ignoreExprs:
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_19ParseElementEnhance_7ignore, 0, __pyx_n_s_ParseElementEnhance_ignore, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__694)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_ignore, __pyx_t_7) < 0) __PYX_ERR(0, 3775, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3787
 *         return self
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         super(ParseElementEnhance, self).streamline()
 *         if self.expr is not None:
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_19ParseElementEnhance_9streamline, 0, __pyx_n_s_ParseElementEnhance_streamline, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__696)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3787, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_streamline, __pyx_t_7) < 0) __PYX_ERR(0, 3787, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3793
 *         return self
 * 
 *     def checkRecursion(self, parseElementList):             # <<<<<<<<<<<<<<
 *         if self in parseElementList:
 *             raise RecursiveGrammarException(parseElementList + [self])
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_19ParseElementEnhance_11checkRecursion, 0, __pyx_n_s_ParseElementEnhance_checkRecursi, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__698)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_checkRecursion, __pyx_t_7) < 0) __PYX_ERR(0, 3793, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3800
 *             self.expr.checkRecursion(subRecCheckList)
 * 
 *     def validate(self, validateTrace=[]):             # <<<<<<<<<<<<<<
 *         tmp = validateTrace[:] + [self]
 *         if self.expr is not None:
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_19ParseElementEnhance_13validate, 0, __pyx_n_s_ParseElementEnhance_validate, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__700)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_7, sizeof(__pyx_defaults9), 1)) __PYX_ERR(0, 3800, __pyx_L1_error)
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_Defaults(__pyx_defaults9, __pyx_t_7)->__pyx_arg_validateTrace = __pyx_t_1;
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_7, __pyx_pf_10cPyparsing_101__defaults__);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_validate, __pyx_t_7) < 0) __PYX_ERR(0, 3800, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3806
 *         self.checkRecursion([])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(ParseElementEnhance, self).__str__()
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_19ParseElementEnhance_15__str__, 0, __pyx_n_s_ParseElementEnhance___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__702)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_str_2, __pyx_t_7) < 0) __PYX_ERR(0, 3806, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3739
 * 
 * 
 * class ParseElementEnhance(ParserElement):             # <<<<<<<<<<<<<<
 *     """
 *     Abstract subclass of C{ParserElement}, for combining and post-processing parsed tokens.
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_ParseElementEnhance, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ParseElementEnhance, __pyx_t_7) < 0) __PYX_ERR(0, 3739, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3817
 * 
 * 
 * class FollowedBy(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """
 *     Lookahead matching of the given parse expression.  C{FollowedBy}
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_13, __pyx_n_s_FollowedBy, __pyx_n_s_FollowedBy, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Lookahead_matching_of_the_given); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":3835
 *     """
 * 
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(FollowedBy, self).__init__(expr)
 *         self.mayReturnEmpty = True
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10FollowedBy_1__init__, 0, __pyx_n_s_FollowedBy___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__704)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(0, 3835, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3839
 *         self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         self.expr.tryParse(instring, loc)
 *         return loc, []
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10FollowedBy_3parseImpl, 0, __pyx_n_s_FollowedBy_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__706)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__707);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_7) < 0) __PYX_ERR(0, 3839, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3817
 * 
 * 
 * class FollowedBy(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """
 *     Lookahead matching of the given parse expression.  C{FollowedBy}
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_FollowedBy, __pyx_t_13, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_FollowedBy, __pyx_t_7) < 0) __PYX_ERR(0, 3817, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":3844
 * 
 * 
 * class NotAny(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """
 *     Lookahead to disallow matching with the given parse expression.  C{NotAny}
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3844, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3844, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3844, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_NotAny, __pyx_n_s_NotAny, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Lookahead_to_disallow_matching); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3844, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":3856
 *     """
 * 
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(NotAny, self).__init__(expr)
 *         #~ self.leaveWhitespace()
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_6NotAny_1__init__, 0, __pyx_n_s_NotAny___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__709)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3856, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(0, 3856, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3863
 *         self.errmsg = "Found unwanted token, " + _ustr(self.expr)
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         if self.expr.canParseNext(instring, loc):
 *             raise ParseException(instring, loc, self.errmsg, self)
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_6NotAny_3parseImpl, 0, __pyx_n_s_NotAny_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__711)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__712);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_7) < 0) __PYX_ERR(0, 3863, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3868
 *         return loc, []
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_6NotAny_5__str__, 0, __pyx_n_s_NotAny___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__714)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_str_2, __pyx_t_7) < 0) __PYX_ERR(0, 3868, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3844
 * 
 * 
 * class NotAny(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """
 *     Lookahead to disallow matching with the given parse expression.  C{NotAny}
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_NotAny, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3844, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NotAny, __pyx_t_7) < 0) __PYX_ERR(0, 3844, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3878
 * 
 * 
 * class _MultipleMatch(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     def __init__(self, expr, stopOn=None):
 *         super(_MultipleMatch, self).__init__(expr)
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_13, __pyx_n_s_MultipleMatch, __pyx_n_s_MultipleMatch, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":3879
 * 
 * class _MultipleMatch(ParseElementEnhance):
 *     def __init__(self, expr, stopOn=None):             # <<<<<<<<<<<<<<
 *         super(_MultipleMatch, self).__init__(expr)
 *         self.saveAsList = True
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_14_MultipleMatch_1__init__, 0, __pyx_n_s_MultipleMatch___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__716)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__717);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(0, 3879, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3887
 *         self.not_ender = ~ender if ender is not None else None
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         self_expr_parse = self.expr._parse
 *         self_skip_ignorables = self._skipIgnorables
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_14_MultipleMatch_3parseImpl, 0, __pyx_n_s_MultipleMatch_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__719)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__720);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_7) < 0) __PYX_ERR(0, 3887, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3878
 * 
 * 
 * class _MultipleMatch(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     def __init__(self, expr, stopOn=None):
 *         super(_MultipleMatch, self).__init__(expr)
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_MultipleMatch, __pyx_t_13, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_MultipleMatch, __pyx_t_7) < 0) __PYX_ERR(0, 3878, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":3917
 * 
 * 
 * class OneOrMore(_MultipleMatch):             # <<<<<<<<<<<<<<
 *     """
 *     Repetition of one or more of the given expression.
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_MultipleMatch); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3917, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3917, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3917, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_OneOrMore, __pyx_n_s_OneOrMore, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Repetition_of_one_or_more_of_th); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3917, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":3943
 *     """
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_9OneOrMore_1__str__, 0, __pyx_n_s_OneOrMore___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__722)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_str_2, __pyx_t_7) < 0) __PYX_ERR(0, 3943, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3917
 * 
 * 
 * class OneOrMore(_MultipleMatch):             # <<<<<<<<<<<<<<
 *     """
 *     Repetition of one or more of the given expression.
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_OneOrMore, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3917, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_OneOrMore, __pyx_t_7) < 0) __PYX_ERR(0, 3917, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":3953
 * 
 * 
 * class ZeroOrMore(_MultipleMatch):             # <<<<<<<<<<<<<<
 *     """
 *     Optional repetition of zero or more of the given expression.
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_MultipleMatch); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_13, __pyx_n_s_ZeroOrMore, __pyx_n_s_ZeroOrMore, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Optional_repetition_of_zero_or); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":3966
 *     """
 * 
 *     def __init__(self, expr, stopOn=None):             # <<<<<<<<<<<<<<
 *         super(ZeroOrMore, self).__init__(expr, stopOn=stopOn)
 *         self.mayReturnEmpty = True
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10ZeroOrMore_1__init__, 0, __pyx_n_s_ZeroOrMore___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__724)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__725);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(0, 3966, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3970
 *         self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         try:
 *             return super(ZeroOrMore, self).parseImpl(instring, loc, doActions)
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10ZeroOrMore_3parseImpl, 0, __pyx_n_s_ZeroOrMore_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__727)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__728);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_7) < 0) __PYX_ERR(0, 3970, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3976
 *             return loc, []
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10ZeroOrMore_5__str__, 0, __pyx_n_s_ZeroOrMore___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__730)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_str_2, __pyx_t_7) < 0) __PYX_ERR(0, 3976, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3953
 * 
 * 
 * class ZeroOrMore(_MultipleMatch):             # <<<<<<<<<<<<<<
 *     """
 *     Optional repetition of zero or more of the given expression.
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_ZeroOrMore, __pyx_t_13, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ZeroOrMore, __pyx_t_7) < 0) __PYX_ERR(0, 3953, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":3986
 * 
 * 
 * class _NullToken(object):             # <<<<<<<<<<<<<<
 *     def __bool__(self):
 *         return False
 */
  __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_INCREF(__pyx_builtin_object);
  __Pyx_GIVEREF(__pyx_builtin_object);
  PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_builtin_object);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_13, __pyx_n_s_NullToken, __pyx_n_s_NullToken, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":3987
 * 
 * class _NullToken(object):
 *     def __bool__(self):             # <<<<<<<<<<<<<<
 *         return False
 *     __nonzero__ = __bool__
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10_NullToken_1__bool__, 0, __pyx_n_s_NullToken___bool, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__732)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3987, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_bool, __pyx_t_7) < 0) __PYX_ERR(0, 3987, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3989
 *     def __bool__(self):
 *         return False
 *     __nonzero__ = __bool__             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __pyx_t_7 = PyObject_GetItem(__pyx_t_9, __pyx_n_s_bool);
  if (unlikely(!__pyx_t_7)) {
    PyErr_Clear();
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_bool);
  }
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_nonzero, __pyx_t_7) < 0) __PYX_ERR(0, 3989, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3991
 *     __nonzero__ = __bool__
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_10_NullToken_3__str__, 0, __pyx_n_s_NullToken___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__734)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3991, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_str_2, __pyx_t_7) < 0) __PYX_ERR(0, 3991, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3986
 * 
 * 
 * class _NullToken(object):             # <<<<<<<<<<<<<<
 *     def __bool__(self):
 *         return False
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_NullToken, __pyx_t_13, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NullToken, __pyx_t_7) < 0) __PYX_ERR(0, 3986, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":3995
 * 
 * 
 * _optionalNotMatched = _NullToken()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_NullToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_9) {
    __pyx_t_13 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_9); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3995, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  } else {
    __pyx_t_13 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3995, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_optionalNotMatched, __pyx_t_13) < 0) __PYX_ERR(0, 3995, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":3998
 * 
 * 
 * class Optional(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """
 *     Optional matching of the given expression.
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_Optional, __pyx_n_s_Optional, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Optional_matching_of_the_given); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":4034
 *     """
 * 
 *     def __init__(self, expr, default=_optionalNotMatched):             # <<<<<<<<<<<<<<
 *         super(Optional, self).__init__(expr, savelist=False)
 *         self.saveAsList = self.expr.saveAsList
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_8Optional_1__init__, 0, __pyx_n_s_Optional___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__736)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_7, sizeof(__pyx_defaults10), 1)) __PYX_ERR(0, 4034, __pyx_L1_error)
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_optionalNotMatched); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_Defaults(__pyx_defaults10, __pyx_t_7)->__pyx_arg_default = __pyx_t_1;
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_7, __pyx_pf_10cPyparsing_103__defaults__);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(0, 4034, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4040
 *         self.mayReturnEmpty = True
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         try:
 *             loc, tokens = self.expr._parse(instring, loc, doActions, callPreParse=False)
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_8Optional_3parseImpl, 0, __pyx_n_s_Optional_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__738)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4040, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__739);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_7) < 0) __PYX_ERR(0, 4040, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4054
 *         return loc, tokens
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_8Optional_5__str__, 0, __pyx_n_s_Optional___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__741)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_str_2, __pyx_t_7) < 0) __PYX_ERR(0, 4054, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":3998
 * 
 * 
 * class Optional(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """
 *     Optional matching of the given expression.
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_Optional, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Optional, __pyx_t_7) < 0) __PYX_ERR(0, 3998, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4064
 * 
 * 
 * class SkipTo(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """
 *     Token for skipping over all undefined text until the matched expression is found.
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_13, __pyx_n_s_SkipTo, __pyx_n_s_SkipTo, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Token_for_skipping_over_all_und); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":4120
 *     """
 * 
 *     def __init__(self, other, *args, **kwargs):  # include=False, ignore=None, failOn=None             # <<<<<<<<<<<<<<
 *         super(SkipTo, self).__init__(other)
 *         # include is a reserved word, so we have to get creative to allow it as an argument
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_6SkipTo_1__init__, 0, __pyx_n_s_SkipTo___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__743)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(0, 4120, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4137
 *         self.errmsg = "No match found for " + _ustr(self.expr)
 * 
 *     def parseImpl(self, instring, int loc, doActions=True):             # <<<<<<<<<<<<<<
 *         startloc = loc
 *         instrlen = len(instring)
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_6SkipTo_3parseImpl, 0, __pyx_n_s_SkipTo_parseImpl, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__745)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__746);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_parseImpl, __pyx_t_7) < 0) __PYX_ERR(0, 4137, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4064
 * 
 * 
 * class SkipTo(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """
 *     Token for skipping over all undefined text until the matched expression is found.
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_SkipTo, __pyx_t_13, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_SkipTo, __pyx_t_7) < 0) __PYX_ERR(0, 4064, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":4185
 * 
 * 
 * class Forward(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """
 *     Forward declaration of an expression to be defined later -
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_Forward, __pyx_n_s_Forward, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Forward_declaration_of_an_expre); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":4205
 *     """
 * 
 *     def __init__(self, other=None):             # <<<<<<<<<<<<<<
 *         super(Forward, self).__init__(other, savelist=False)
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_7Forward_1__init__, 0, __pyx_n_s_Forward___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__748)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__749);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(0, 4205, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4208
 *         super(Forward, self).__init__(other, savelist=False)
 * 
 *     def __lshift__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, basestring):
 *             other = ParserElement._literalStringClass(other)
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_7Forward_3__lshift__, 0, __pyx_n_s_Forward___lshift, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__751)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_lshift, __pyx_t_7) < 0) __PYX_ERR(0, 4208, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4221
 *         return self
 * 
 *     def __ilshift__(self, other):             # <<<<<<<<<<<<<<
 *         return self << other
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_7Forward_5__ilshift__, 0, __pyx_n_s_Forward___ilshift, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__753)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_ilshift, __pyx_t_7) < 0) __PYX_ERR(0, 4221, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4224
 *         return self << other
 * 
 *     def leaveWhitespace(self):             # <<<<<<<<<<<<<<
 *         self.skipWhitespace = False
 *         return self
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_7Forward_7leaveWhitespace, 0, __pyx_n_s_Forward_leaveWhitespace, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__755)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_leaveWhitespace, __pyx_t_7) < 0) __PYX_ERR(0, 4224, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4228
 *         return self
 * 
 *     def streamline(self):             # <<<<<<<<<<<<<<
 *         if not self.streamlined:
 *             self.streamlined = True
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_7Forward_9streamline, 0, __pyx_n_s_Forward_streamline, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__757)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_streamline, __pyx_t_7) < 0) __PYX_ERR(0, 4228, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4235
 *         return self
 * 
 *     def validate(self, validateTrace=[]):             # <<<<<<<<<<<<<<
 *         if self not in validateTrace:
 *             tmp = validateTrace[:] + [self]
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_7Forward_11validate, 0, __pyx_n_s_Forward_validate, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__759)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_7, sizeof(__pyx_defaults11), 1)) __PYX_ERR(0, 4235, __pyx_L1_error)
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_Defaults(__pyx_defaults11, __pyx_t_7)->__pyx_arg_validateTrace = __pyx_t_1;
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_7, __pyx_pf_10cPyparsing_105__defaults__);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_validate, __pyx_t_7) < 0) __PYX_ERR(0, 4235, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4242
 *         self.checkRecursion([])
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         if hasattr(self, "name"):
 *             return self.name
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_7Forward_13__str__, 0, __pyx_n_s_Forward___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__761)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_str_2, __pyx_t_7) < 0) __PYX_ERR(0, 4242, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4259
 *         # return self.__class__.__name__ + ": " + retString
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         if self.expr is not None:
 *             return super(Forward, self).copy()
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_7Forward_15copy, 0, __pyx_n_s_Forward_copy, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__763)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_copy, __pyx_t_7) < 0) __PYX_ERR(0, 4259, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4185
 * 
 * 
 * class Forward(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """
 *     Forward declaration of an expression to be defined later -
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_Forward, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Forward, __pyx_t_7) < 0) __PYX_ERR(0, 4185, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4268
 * 
 * 
 * class _ForwardNoRecurse(Forward):             # <<<<<<<<<<<<<<
 *     def __str__(self):
 *         return "..."
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Forward); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_13, __pyx_n_s_ForwardNoRecurse, __pyx_n_s_ForwardNoRecurse, (PyObject *) NULL, __pyx_n_s_cPyparsing, (PyObject *) NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":4269
 * 
 * class _ForwardNoRecurse(Forward):
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "..."
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_17_ForwardNoRecurse_1__str__, 0, __pyx_n_s_ForwardNoRecurse___str, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__765)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_str_2, __pyx_t_7) < 0) __PYX_ERR(0, 4269, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4268
 * 
 * 
 * class _ForwardNoRecurse(Forward):             # <<<<<<<<<<<<<<
 *     def __str__(self):
 *         return "..."
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_ForwardNoRecurse, __pyx_t_13, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ForwardNoRecurse, __pyx_t_7) < 0) __PYX_ERR(0, 4268, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":4273
 * 
 * 
 * class TokenConverter(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """
 *     Abstract subclass of C{ParseExpression}, for converting parsed results.
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_ParseElementEnhance); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_TokenConverter, __pyx_n_s_TokenConverter, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Abstract_subclass_of_C_ParseExp); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":4278
 *     """
 * 
 *     def __init__(self, expr, savelist=False):             # <<<<<<<<<<<<<<
 *         super(TokenConverter, self).__init__(expr)  # , savelist )
 *         self.saveAsList = False
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_14TokenConverter_1__init__, 0, __pyx_n_s_TokenConverter___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__767)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__768);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(0, 4278, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4273
 * 
 * 
 * class TokenConverter(ParseElementEnhance):             # <<<<<<<<<<<<<<
 *     """
 *     Abstract subclass of C{ParseExpression}, for converting parsed results.
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_TokenConverter, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_TokenConverter, __pyx_t_7) < 0) __PYX_ERR(0, 4273, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4283
 * 
 * 
 * class Combine(TokenConverter):             # <<<<<<<<<<<<<<
 *     """
 *     Converter to concatenate all matching tokens to a single string.
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_TokenConverter); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_13, __pyx_n_s_Combine, __pyx_n_s_Combine, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Converter_to_concatenate_all_ma); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":4301
 *     """
 * 
 *     def __init__(self, expr, joinString="", adjacent=True):             # <<<<<<<<<<<<<<
 *         super(Combine, self).__init__(expr)
 *         # suppress whitespace-stripping in contained parse expressions, but re-enable it on the Combine itself
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_7Combine_1__init__, 0, __pyx_n_s_Combine___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__770)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__771);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(0, 4301, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4311
 *         self.callPreparse = True
 * 
 *     def ignore(self, other):             # <<<<<<<<<<<<<<
 *         if self.adjacent:
 *             ParserElement.ignore(self, other)
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_7Combine_3ignore, 0, __pyx_n_s_Combine_ignore, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__773)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_ignore, __pyx_t_7) < 0) __PYX_ERR(0, 4311, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4318
 *         return self
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         retToks = tokenlist.copy()
 *         del retToks[:]
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_7Combine_5postParse, 0, __pyx_n_s_Combine_postParse, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__775)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_postParse, __pyx_t_7) < 0) __PYX_ERR(0, 4318, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4283
 * 
 * 
 * class Combine(TokenConverter):             # <<<<<<<<<<<<<<
 *     """
 *     Converter to concatenate all matching tokens to a single string.
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_Combine, __pyx_t_13, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Combine, __pyx_t_7) < 0) __PYX_ERR(0, 4283, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":4329
 * 
 * 
 * class Group(TokenConverter):             # <<<<<<<<<<<<<<
 *     """
 *     Converter to return the matched tokens as a list - useful for returning tokens of C{L{ZeroOrMore}} and C{L{OneOrMore}} expressions.
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_TokenConverter); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_Group, __pyx_n_s_Group, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Converter_to_return_the_matched); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":4344
 *     """
 * 
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(Group, self).__init__(expr)
 *         self.saveAsList = True
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_5Group_1__init__, 0, __pyx_n_s_Group___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__777)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(0, 4344, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4348
 *         self.saveAsList = True
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         return [tokenlist]
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_5Group_3postParse, 0, __pyx_n_s_Group_postParse, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__779)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_postParse, __pyx_t_7) < 0) __PYX_ERR(0, 4348, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4329
 * 
 * 
 * class Group(TokenConverter):             # <<<<<<<<<<<<<<
 *     """
 *     Converter to return the matched tokens as a list - useful for returning tokens of C{L{ZeroOrMore}} and C{L{OneOrMore}} expressions.
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_Group, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Group, __pyx_t_7) < 0) __PYX_ERR(0, 4329, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4352
 * 
 * 
 * class Dict(TokenConverter):             # <<<<<<<<<<<<<<
 *     """
 *     Converter to return a repetitive expression as a list, but also as a dictionary.
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_TokenConverter); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_13, __pyx_n_s_Dict, __pyx_n_s_Dict, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Converter_to_return_a_repetitiv); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":4389
 *     """
 * 
 *     def __init__(self, expr):             # <<<<<<<<<<<<<<
 *         super(Dict, self).__init__(expr)
 *         self.saveAsList = True
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_4Dict_1__init__, 0, __pyx_n_s_Dict___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__781)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(0, 4389, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4393
 *         self.saveAsList = True
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         for i, tok in enumerate(tokenlist):
 *             if len(tok) == 0:
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_4Dict_3postParse, 0, __pyx_n_s_Dict_postParse, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__783)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_postParse, __pyx_t_7) < 0) __PYX_ERR(0, 4393, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4352
 * 
 * 
 * class Dict(TokenConverter):             # <<<<<<<<<<<<<<
 *     """
 *     Converter to return a repetitive expression as a list, but also as a dictionary.
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_Dict, __pyx_t_13, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Dict, __pyx_t_7) < 0) __PYX_ERR(0, 4352, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":4418
 * 
 * 
 * class Suppress(TokenConverter):             # <<<<<<<<<<<<<<
 *     """
 *     Converter for ignoring the results of a parsed expression.
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_TokenConverter); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_Suppress, __pyx_n_s_Suppress, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Converter_for_ignoring_the_resu); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":4438
 *     """
 * 
 *     def postParse(self, instring, loc, tokenlist):             # <<<<<<<<<<<<<<
 *         return []
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_8Suppress_1postParse, 0, __pyx_n_s_Suppress_postParse, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__785)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_postParse, __pyx_t_7) < 0) __PYX_ERR(0, 4438, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4441
 *         return []
 * 
 *     def suppress(self):             # <<<<<<<<<<<<<<
 *         return self
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_8Suppress_3suppress, 0, __pyx_n_s_Suppress_suppress, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__787)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4441, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_suppress, __pyx_t_7) < 0) __PYX_ERR(0, 4441, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4418
 * 
 * 
 * class Suppress(TokenConverter):             # <<<<<<<<<<<<<<
 *     """
 *     Converter for ignoring the results of a parsed expression.
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_Suppress, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Suppress, __pyx_t_7) < 0) __PYX_ERR(0, 4418, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4445
 * 
 * 
 * class OnlyOnce(object):             # <<<<<<<<<<<<<<
 *     """
 *     Wrapper for parse actions, to ensure they are only called once.
 */
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_builtin_object);
  __Pyx_GIVEREF(__pyx_builtin_object);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_builtin_object);
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_2, __pyx_n_s_OnlyOnce, __pyx_n_s_OnlyOnce, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Wrapper_for_parse_actions_to_en); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "cPyparsing.pyx":4450
 *     """
 * 
 *     def __init__(self, methodCall):             # <<<<<<<<<<<<<<
 *         self.callable = _trim_arity(methodCall)
 *         self.called = False
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_8OnlyOnce_1__init__, 0, __pyx_n_s_OnlyOnce___init, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__789)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(0, 4450, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4454
 *         self.called = False
 * 
 *     def __call__(self, s, l, t):             # <<<<<<<<<<<<<<
 *         if not self.called:
 *             results = self.callable(s, l, t)
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_8OnlyOnce_3__call__, 0, __pyx_n_s_OnlyOnce___call, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__791)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_call, __pyx_t_7) < 0) __PYX_ERR(0, 4454, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4461
 *         raise ParseException(s, l, "")
 * 
 *     def reset(self):             # <<<<<<<<<<<<<<
 *         self.called = False
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_8OnlyOnce_5reset, 0, __pyx_n_s_OnlyOnce_reset, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__793)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyObject_SetItem(__pyx_t_9, __pyx_n_s_reset, __pyx_t_7) < 0) __PYX_ERR(0, 4461, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":4445
 * 
 * 
 * class OnlyOnce(object):             # <<<<<<<<<<<<<<
 *     """
 *     Wrapper for parse actions, to ensure they are only called once.
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_OnlyOnce, __pyx_t_2, __pyx_t_9, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_OnlyOnce, __pyx_t_7) < 0) __PYX_ERR(0, 4445, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4465
 * 
 * 
 * def traceParseAction(f):             # <<<<<<<<<<<<<<
 *     """
 *     Decorator for debugging parse actions.
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_23traceParseAction, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_traceParseAction, __pyx_t_2) < 0) __PYX_ERR(0, 4465, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4512
 * 
 * 
 * def delimitedList(expr, delim=",", combine=False):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define a delimited list of expressions - the delimiter defaults to ','.
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_25delimitedList, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_delimitedList, __pyx_t_2) < 0) __PYX_ERR(0, 4512, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4532
 * 
 * 
 * def countedArray(expr, intExpr=None):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define a counted list of expressions.
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_27countedArray, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_countedArray, __pyx_t_2) < 0) __PYX_ERR(0, 4532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4565
 * 
 * 
 * def _flatten(L):             # <<<<<<<<<<<<<<
 *     ret = []
 *     for i in L:
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_29_flatten, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_flatten, __pyx_t_2) < 0) __PYX_ERR(0, 4565, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4575
 * 
 * 
 * def matchPreviousLiteral(expr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define an expression that is indirectly defined from
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_31matchPreviousLiteral, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_matchPreviousLiteral, __pyx_t_2) < 0) __PYX_ERR(0, 4575, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4605
 * 
 * 
 * def matchPreviousExpr(expr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define an expression that is indirectly defined from
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_33matchPreviousExpr, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_matchPreviousExpr, __pyx_t_2) < 0) __PYX_ERR(0, 4605, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4636
 * 
 * 
 * def _escapeRegexRangeChars(s):             # <<<<<<<<<<<<<<
 *     #~  escape these chars: ^-]
 *     for c in r"\^-]":
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_35_escapeRegexRangeChars, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_escapeRegexRangeChars, __pyx_t_2) < 0) __PYX_ERR(0, 4636, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4645
 * 
 * 
 * def oneOf(strs, caseless=False, useRegex=True):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to quickly define a set of alternative Literals, and makes sure to do
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_37oneOf, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_oneOf, __pyx_t_2) < 0) __PYX_ERR(0, 4645, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4718
 * 
 * 
 * def dictOf(key, value):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to easily and clearly define a dictionary by specifying the respective patterns
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_39dictOf, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_dictOf, __pyx_t_2) < 0) __PYX_ERR(0, 4718, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4754
 * 
 * 
 * def originalTextFor(expr, asString=True):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to return the original, untokenized text for a given expression.  Useful to
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_41originalTextFor, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_originalTextFor, __pyx_t_2) < 0) __PYX_ERR(0, 4754, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4792
 * 
 * 
 * def ungroup(expr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to undo pyparsing's default grouping of And expressions, even
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_43ungroup, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ungroup, __pyx_t_2) < 0) __PYX_ERR(0, 4792, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4800
 * 
 * 
 * def locatedExpr(expr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to decorate a returned token with its starting and ending locations in the input string.
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_45locatedExpr, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_locatedExpr, __pyx_t_2) < 0) __PYX_ERR(0, 4800, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4825
 * 
 * # convenience constants for positional expressions
 * empty = Empty().setName("empty")             # <<<<<<<<<<<<<<
 * lineStart = LineStart().setName("lineStart")
 * lineEnd = LineEnd().setName("lineEnd")
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_Empty); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  if (__pyx_t_9) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4825, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4825, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setName); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_tuple__818, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_empty, __pyx_t_2) < 0) __PYX_ERR(0, 4825, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4826
 * # convenience constants for positional expressions
 * empty = Empty().setName("empty")
 * lineStart = LineStart().setName("lineStart")             # <<<<<<<<<<<<<<
 * lineEnd = LineEnd().setName("lineEnd")
 * stringStart = StringStart().setName("stringStart")
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_LineStart); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  if (__pyx_t_9) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4826, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4826, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setName); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_tuple__819, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_lineStart, __pyx_t_2) < 0) __PYX_ERR(0, 4826, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4827
 * empty = Empty().setName("empty")
 * lineStart = LineStart().setName("lineStart")
 * lineEnd = LineEnd().setName("lineEnd")             # <<<<<<<<<<<<<<
 * stringStart = StringStart().setName("stringStart")
 * stringEnd = StringEnd().setName("stringEnd")
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_LineEnd); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  if (__pyx_t_9) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4827, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4827, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setName); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_tuple__820, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_lineEnd, __pyx_t_2) < 0) __PYX_ERR(0, 4827, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4828
 * lineStart = LineStart().setName("lineStart")
 * lineEnd = LineEnd().setName("lineEnd")
 * stringStart = StringStart().setName("stringStart")             # <<<<<<<<<<<<<<
 * stringEnd = StringEnd().setName("stringEnd")
 * 
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_StringStart); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  if (__pyx_t_9) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4828, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4828, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setName); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_tuple__821, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_stringStart, __pyx_t_2) < 0) __PYX_ERR(0, 4828, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4829
 * lineEnd = LineEnd().setName("lineEnd")
 * stringStart = StringStart().setName("stringStart")
 * stringEnd = StringEnd().setName("stringEnd")             # <<<<<<<<<<<<<<
 * 
 * _escapedPunc = Word(_bslash, r"\[]-*.$+^?()~ ", exact=2).setParseAction(lambda s, l, t: t[0][1])
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_StringEnd); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  if (__pyx_t_9) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4829, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4829, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setName); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_tuple__822, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_stringEnd, __pyx_t_2) < 0) __PYX_ERR(0, 4829, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4831
 * stringEnd = StringEnd().setName("stringEnd")
 * 
 * _escapedPunc = Word(_bslash, r"\[]-*.$+^?()~ ", exact=2).setParseAction(lambda s, l, t: t[0][1])             # <<<<<<<<<<<<<<
 * _escapedHexChar = Regex(r"\\0?[xX][0-9a-fA-F]+").setParseAction(lambda s, l, t: unichr(int(t[0].lstrip(r'\0x'), 16)))
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_Word); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_bslash); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_9);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_9);
  __Pyx_INCREF(__pyx_kp_u__823);
  __Pyx_GIVEREF(__pyx_kp_u__823);
  PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_kp_u__823);
  __pyx_t_9 = 0;
  __pyx_t_9 = PyDict_New(); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_exact, __pyx_int_2) < 0) __PYX_ERR(0, 4831, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_7, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_78lambda40, 0, __pyx_n_s_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  if (!__pyx_t_7) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4831, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_1};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4831, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_1};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4831, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    {
      __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4831, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_7); __pyx_t_7 = NULL;
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_13, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4831, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_escapedPunc, __pyx_t_2) < 0) __PYX_ERR(0, 4831, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4832
 * 
 * _escapedPunc = Word(_bslash, r"\[]-*.$+^?()~ ", exact=2).setParseAction(lambda s, l, t: t[0][1])
 * _escapedHexChar = Regex(r"\\0?[xX][0-9a-fA-F]+").setParseAction(lambda s, l, t: unichr(int(t[0].lstrip(r'\0x'), 16)))             # <<<<<<<<<<<<<<
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | Word(printables, excludeChars=r'\]', exact=1) | Regex(r"\w", re.UNICODE)
 */
  __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__824, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_79lambda41, 0, __pyx_n_s_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  if (!__pyx_t_1) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4832, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_13};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4832, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_13};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4832, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4832, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_1); __pyx_t_1 = NULL;
      __Pyx_GIVEREF(__pyx_t_13);
      PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_13);
      __pyx_t_13 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4832, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_escapedHexChar, __pyx_t_2) < 0) __PYX_ERR(0, 4832, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4833
 * _escapedPunc = Word(_bslash, r"\[]-*.$+^?()~ ", exact=2).setParseAction(lambda s, l, t: t[0][1])
 * _escapedHexChar = Regex(r"\\0?[xX][0-9a-fA-F]+").setParseAction(lambda s, l, t: unichr(int(t[0].lstrip(r'\0x'), 16)))
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))             # <<<<<<<<<<<<<<
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | Word(printables, excludeChars=r'\]', exact=1) | Regex(r"\w", re.UNICODE)
 * _charRange = Group(_singleChar + Suppress("-") + _singleChar)
 */
  __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__825, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_80lambda42, 0, __pyx_n_s_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  if (!__pyx_t_13) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4833, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_7};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4833, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_7};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4833, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else
    #endif
    {
      __pyx_t_1 = PyTuple_New(1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4833, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_13); __pyx_t_13 = NULL;
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_1, 0+1, __pyx_t_7);
      __pyx_t_7 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4833, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_escapedOctChar, __pyx_t_2) < 0) __PYX_ERR(0, 4833, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4834
 * _escapedHexChar = Regex(r"\\0?[xX][0-9a-fA-F]+").setParseAction(lambda s, l, t: unichr(int(t[0].lstrip(r'\0x'), 16)))
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | Word(printables, excludeChars=r'\]', exact=1) | Regex(r"\w", re.UNICODE)             # <<<<<<<<<<<<<<
 * _charRange = Group(_singleChar + Suppress("-") + _singleChar)
 * _reBracketExpr = Literal("[") + Optional("^").setResultsName("negate") + Group(OneOrMore(_charRange | _singleChar)).setResultsName("body") + "]"
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_escapedPunc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_escapedHexChar); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_1 = PyNumber_Or(__pyx_t_2, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_escapedOctChar); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_2 = PyNumber_Or(__pyx_t_1, __pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_Word); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_printables); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_excludeChars, __pyx_kp_u__826) < 0) __PYX_ERR(0, 4834, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_exact, __pyx_int_1) < 0) __PYX_ERR(0, 4834, __pyx_L1_error)
  __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_7, __pyx_t_1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Or(__pyx_t_2, __pyx_t_13); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_UNICODE); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_kp_u_w, __pyx_t_9};
    __pyx_t_13 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4834, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_kp_u_w, __pyx_t_9};
    __pyx_t_13 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4834, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  } else
  #endif
  {
    __pyx_t_8 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4834, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__pyx_t_7) {
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_7); __pyx_t_7 = NULL;
    }
    __Pyx_INCREF(__pyx_kp_u_w);
    __Pyx_GIVEREF(__pyx_kp_u_w);
    PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_6, __pyx_kp_u_w);
    __Pyx_GIVEREF(__pyx_t_9);
    PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_6, __pyx_t_9);
    __pyx_t_9 = 0;
    __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_8, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4834, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Or(__pyx_t_1, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_singleChar, __pyx_t_2) < 0) __PYX_ERR(0, 4834, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4835
 * _escapedOctChar = Regex(r"\\0[0-7]+").setParseAction(lambda s, l, t: unichr(int(t[0][1:], 8)))
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | Word(printables, excludeChars=r'\]', exact=1) | Regex(r"\w", re.UNICODE)
 * _charRange = Group(_singleChar + Suppress("-") + _singleChar)             # <<<<<<<<<<<<<<
 * _reBracketExpr = Literal("[") + Optional("^").setResultsName("negate") + Group(OneOrMore(_charRange | _singleChar)).setResultsName("body") + "]"
 * 
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_singleChar); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_Suppress); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_tuple__827, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = PyNumber_Add(__pyx_t_1, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_singleChar); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_1 = PyNumber_Add(__pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  if (!__pyx_t_9) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4835, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_1};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4835, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_1};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4835, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    {
      __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4835, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_9); __pyx_t_9 = NULL;
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_8, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4835, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_charRange, __pyx_t_2) < 0) __PYX_ERR(0, 4835, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":4836
 * _singleChar = _escapedPunc | _escapedHexChar | _escapedOctChar | Word(printables, excludeChars=r'\]', exact=1) | Regex(r"\w", re.UNICODE)
 * _charRange = Group(_singleChar + Suppress("-") + _singleChar)
 * _reBracketExpr = Literal("[") + Optional("^").setResultsName("negate") + Group(OneOrMore(_charRange | _singleChar)).setResultsName("body") + "]"             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Literal); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__828, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__829, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_setResultsName); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__830, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_13, __pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_charRange); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_17 = __Pyx_GetModuleGlobalName(__pyx_n_s_singleChar); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 4836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __pyx_t_19 = PyNumber_Or(__pyx_t_7, __pyx_t_17); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 4836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_17)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_17);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  if (!__pyx_t_17) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_19); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4836, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_17, __pyx_t_19};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4836, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_17, __pyx_t_19};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4836, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4836, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_17); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_17); __pyx_t_17 = NULL;
      __Pyx_GIVEREF(__pyx_t_19);
      PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_19);
      __pyx_t_19 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4836, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  if (!__pyx_t_9) {
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4836, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GOTREF(__pyx_t_8);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_1};
      __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4836, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_1};
      __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4836, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4836, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_9); __pyx_t_9 = NULL;
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_7, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4836, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_setResultsName); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_tuple__831, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = PyNumber_Add(__pyx_t_2, __pyx_t_8); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = PyNumber_Add(__pyx_t_13, __pyx_kp_u__18); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reBracketExpr, __pyx_t_8) < 0) __PYX_ERR(0, 4836, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":4839
 * 
 * 
 * def srange(s):             # <<<<<<<<<<<<<<
 *     r"""
 *     Helper to easily define string ranges for use in Word construction.  Borrows
 */
  __pyx_t_8 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_47srange, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_srange, __pyx_t_8) < 0) __PYX_ERR(0, 4839, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":4864
 * 
 * 
 * def matchOnlyAtCol(n):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for defining parse actions that require matching at a specific
 */
  __pyx_t_8 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_49matchOnlyAtCol, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_matchOnlyAtCol, __pyx_t_8) < 0) __PYX_ERR(0, 4864, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":4875
 * 
 * 
 * def replaceWith(replStr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for common parse actions that simply return a literal value.  Especially
 */
  __pyx_t_8 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_51replaceWith, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_replaceWith, __pyx_t_8) < 0) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":4890
 * 
 * 
 * def removeQuotes(s, l, t):             # <<<<<<<<<<<<<<
 *     """
 *     Helper parse action for removing quotation marks from parsed quoted strings.
 */
  __pyx_t_8 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_53removeQuotes, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_removeQuotes, __pyx_t_8) < 0) __PYX_ERR(0, 4890, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":4905
 * 
 * 
 * def tokenMap(func, *args):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to define a parse action by mapping a function to all elements of a ParseResults list.If any additional
 */
  __pyx_t_8 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_55tokenMap, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_tokenMap, __pyx_t_8) < 0) __PYX_ERR(0, 4905, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":4950
 * 
 * 
 * upcaseTokens = tokenMap(lambda t: _ustr(t).upper())             # <<<<<<<<<<<<<<
 * """(Deprecated) Helper parse action to convert tokens to upper case. Deprecated in favor of L{pyparsing_common.upcaseTokens}"""
 * 
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_tokenMap); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_81lambda46, 0, __pyx_n_s_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  if (!__pyx_t_7) {
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4950, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_8);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_2};
      __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4950, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_2};
      __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4950, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_1 = PyTuple_New(1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4950, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_7); __pyx_t_7 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_1, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_1, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4950, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_upcaseTokens, __pyx_t_8) < 0) __PYX_ERR(0, 4950, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":4953
 * """(Deprecated) Helper parse action to convert tokens to upper case. Deprecated in favor of L{pyparsing_common.upcaseTokens}"""
 * 
 * downcaseTokens = tokenMap(lambda t: _ustr(t).lower())             # <<<<<<<<<<<<<<
 * """(Deprecated) Helper parse action to convert tokens to lower case. Deprecated in favor of L{pyparsing_common.downcaseTokens}"""
 * 
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_tokenMap); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_82lambda47, 0, __pyx_n_s_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4953, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GOTREF(__pyx_t_8);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_1};
      __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4953, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_1};
      __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4953, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4953, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_7, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4953, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_downcaseTokens, __pyx_t_8) < 0) __PYX_ERR(0, 4953, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":4957
 * 
 * 
 * def _makeTags(tagStr, xml):             # <<<<<<<<<<<<<<
 *     """Internal helper to construct opening and closing tag expressions, given a tag name"""
 *     if isinstance(tagStr, basestring):
 */
  __pyx_t_8 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_57_makeTags, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4957, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_makeTags, __pyx_t_8) < 0) __PYX_ERR(0, 4957, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":4987
 * 
 * 
 * def makeHTMLTags(tagStr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to construct opening and closing tag expressions for HTML, given a tag name. Matches
 */
  __pyx_t_8 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_59makeHTMLTags, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4987, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_makeHTMLTags, __pyx_t_8) < 0) __PYX_ERR(0, 4987, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5007
 * 
 * 
 * def makeXMLTags(tagStr):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to construct opening and closing tag expressions for XML, given a tag name. Matches
 */
  __pyx_t_8 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_61makeXMLTags, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_makeXMLTags, __pyx_t_8) < 0) __PYX_ERR(0, 5007, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5017
 * 
 * 
 * class withAttribute(object):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to create a validating parse action to be used with start tags created
 */
  __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(__pyx_builtin_object);
  __Pyx_GIVEREF(__pyx_builtin_object);
  PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_builtin_object);
  __pyx_t_13 = __Pyx_CalculateMetaclass(NULL, __pyx_t_8); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_7 = __Pyx_Py3MetaclassPrepare(__pyx_t_13, __pyx_t_8, __pyx_n_s_withAttribute, __pyx_n_s_withAttribute, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Helper_to_create_a_validating_p); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);

  /* "cPyparsing.pyx":5067
 *         1,3 2,3 1,1
 *     """
 *     ANY_VALUE = object()             # <<<<<<<<<<<<<<
 * 
 *     def __new__(cls, *args, **attrDict):
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_builtin_object); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5067, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_ANY_VALUE, __pyx_t_1) < 0) __PYX_ERR(0, 5067, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5069
 *     ANY_VALUE = object()
 * 
 *     def __new__(cls, *args, **attrDict):             # <<<<<<<<<<<<<<
 *         if args:
 *             attrs = args[:]
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_13withAttribute_1__new__, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_withAttribute___new, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__849)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetItem(__pyx_t_7, __pyx_n_s_new, __pyx_t_1) < 0) __PYX_ERR(0, 5069, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5017
 * 
 * 
 * class withAttribute(object):             # <<<<<<<<<<<<<<
 *     """
 *     Helper to create a validating parse action to be used with start tags created
 */
  __pyx_t_1 = __Pyx_Py3ClassCreate(__pyx_t_13, __pyx_n_s_withAttribute, __pyx_t_8, __pyx_t_7, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_withAttribute, __pyx_t_1) < 0) __PYX_ERR(0, 5017, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5086
 * 
 * 
 * def withClass(classname, namespace=''):             # <<<<<<<<<<<<<<
 *     """
 *     Simplified version of C{L{withAttribute}} when matching on a div class - made
 */
  __pyx_t_8 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_63withClass, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_withClass, __pyx_t_8) < 0) __PYX_ERR(0, 5086, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5122
 * 
 * 
 * opAssoc = _Constants()             # <<<<<<<<<<<<<<
 * opAssoc.LEFT = object()
 * opAssoc.RIGHT = object()
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_Constants); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  if (__pyx_t_7) {
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5122, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  } else {
    __pyx_t_8 = __Pyx_PyObject_CallNoArg(__pyx_t_13); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5122, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_opAssoc, __pyx_t_8) < 0) __PYX_ERR(0, 5122, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5123
 * 
 * opAssoc = _Constants()
 * opAssoc.LEFT = object()             # <<<<<<<<<<<<<<
 * opAssoc.RIGHT = object()
 * 
 */
  __pyx_t_8 = __Pyx_PyObject_CallNoArg(__pyx_builtin_object); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_opAssoc); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_13, __pyx_n_s_LEFT, __pyx_t_8) < 0) __PYX_ERR(0, 5123, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":5124
 * opAssoc = _Constants()
 * opAssoc.LEFT = object()
 * opAssoc.RIGHT = object()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_13 = __Pyx_PyObject_CallNoArg(__pyx_builtin_object); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_opAssoc); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_8, __pyx_n_s_RIGHT, __pyx_t_13) < 0) __PYX_ERR(0, 5124, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5127
 * 
 * 
 * def infixNotation(baseExpr, opList, lpar=Suppress('('), rpar=Suppress(')')):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for constructing grammars of expressions made up of
 */
  __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_Suppress); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_tuple__852, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_k__187 = __pyx_t_13;
  __Pyx_GIVEREF(__pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_Suppress); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_tuple__853, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_k__188 = __pyx_t_8;
  __Pyx_GIVEREF(__pyx_t_8);
  __pyx_t_8 = 0;
  __pyx_t_8 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_65infixNotation, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_infixNotation, __pyx_t_8) < 0) __PYX_ERR(0, 5127, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5240
 * 
 * 
 * operatorPrecedence = infixNotation             # <<<<<<<<<<<<<<
 * """(Deprecated) Former name of C{L{infixNotation}}, will be dropped in a future release."""
 * 
 */
  __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_infixNotation); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_operatorPrecedence, __pyx_t_8) < 0) __PYX_ERR(0, 5240, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5243
 * """(Deprecated) Former name of C{L{infixNotation}}, will be dropped in a future release."""
 * 
 * dblQuotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"').setName("string enclosed in double quotes")             # <<<<<<<<<<<<<<
 * sglQuotedString = Combine(Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("string enclosed in single quotes")
 * quotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"' |
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_Combine); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__856, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_t_1, __pyx_kp_u__857); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  if (!__pyx_t_1) {
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5243, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_8);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_7};
      __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5243, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_7};
      __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5243, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else
    #endif
    {
      __pyx_t_2 = PyTuple_New(1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5243, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1); __pyx_t_1 = NULL;
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_2, 0+1, __pyx_t_7);
      __pyx_t_7 = 0;
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_2, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5243, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_setName); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_tuple__858, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_dblQuotedString, __pyx_t_8) < 0) __PYX_ERR(0, 5243, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5244
 * 
 * dblQuotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"').setName("string enclosed in double quotes")
 * sglQuotedString = Combine(Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("string enclosed in single quotes")             # <<<<<<<<<<<<<<
 * quotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"' |
 *                        Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("quotedString using single or double quotes")
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_Combine); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__859, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_7, __pyx_kp_u__860); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  if (!__pyx_t_7) {
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5244, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_8);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_2};
      __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5244, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_2};
      __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5244, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_1 = PyTuple_New(1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5244, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_7); __pyx_t_7 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_1, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_1, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5244, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_setName); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_tuple__861, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sglQuotedString, __pyx_t_8) < 0) __PYX_ERR(0, 5244, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5245
 * dblQuotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"').setName("string enclosed in double quotes")
 * sglQuotedString = Combine(Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("string enclosed in single quotes")
 * quotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"' |             # <<<<<<<<<<<<<<
 *                        Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("quotedString using single or double quotes")
 * unicodeString = Combine(_L('u') + quotedString.copy()).setName("unicode string literal")
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_Combine); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__862, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_kp_u__857); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5246
 * sglQuotedString = Combine(Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("string enclosed in single quotes")
 * quotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"' |
 *                        Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("quotedString using single or double quotes")             # <<<<<<<<<<<<<<
 * unicodeString = Combine(_L('u') + quotedString.copy()).setName("unicode string literal")
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__863, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_7, __pyx_kp_u__860); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":5245
 * dblQuotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"').setName("string enclosed in double quotes")
 * sglQuotedString = Combine(Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("string enclosed in single quotes")
 * quotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"' |             # <<<<<<<<<<<<<<
 *                        Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("quotedString using single or double quotes")
 * unicodeString = Combine(_L('u') + quotedString.copy()).setName("unicode string literal")
 */
  __pyx_t_7 = PyNumber_Or(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5245, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_8);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_7};
      __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5245, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_7};
      __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5245, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else
    #endif
    {
      __pyx_t_1 = PyTuple_New(1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5245, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_1, 0+1, __pyx_t_7);
      __pyx_t_7 = 0;
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_1, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5245, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "cPyparsing.pyx":5246
 * sglQuotedString = Combine(Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("string enclosed in single quotes")
 * quotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"' |
 *                        Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("quotedString using single or double quotes")             # <<<<<<<<<<<<<<
 * unicodeString = Combine(_L('u') + quotedString.copy()).setName("unicode string literal")
 * 
 */
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_setName); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_tuple__864, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_quotedString, __pyx_t_8) < 0) __PYX_ERR(0, 5245, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5247
 * quotedString = Combine(Regex(r'"(?:[^"\n\r\\]|(?:"")|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*') + '"' |
 *                        Regex(r"'(?:[^'\n\r\\]|(?:'')|(?:\\(?:[^x]|x[0-9a-fA-F]+)))*") + "'").setName("quotedString using single or double quotes")
 * unicodeString = Combine(_L('u') + quotedString.copy()).setName("unicode string literal")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_Combine); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_L); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__865, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_quotedString); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_copy); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5247, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5247, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = PyNumber_Add(__pyx_t_7, __pyx_t_1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  if (!__pyx_t_1) {
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5247, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_GOTREF(__pyx_t_8);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_9};
      __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5247, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_9};
      __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5247, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5247, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_1); __pyx_t_1 = NULL;
      __Pyx_GIVEREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_9);
      __pyx_t_9 = 0;
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_7, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5247, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_setName); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_tuple__866, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_unicodeString, __pyx_t_8) < 0) __PYX_ERR(0, 5247, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5250
 * 
 * 
 * def nestedExpr(opener="(", closer=")", content=None, ignoreExpr=quotedString.copy()):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for defining nested lists enclosed in opening and closing
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_quotedString); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_copy); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  if (__pyx_t_13) {
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_13); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5250, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  } else {
    __pyx_t_8 = __Pyx_PyObject_CallNoArg(__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5250, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_k__196 = __pyx_t_8;
  __Pyx_GIVEREF(__pyx_t_8);
  __pyx_t_8 = 0;
  __pyx_t_8 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_67nestedExpr, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_nestedExpr, __pyx_t_8) < 0) __PYX_ERR(0, 5250, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5341
 * 
 * 
 * def indentedBlock(blockStatementExpr, indentStack, indent=True):             # <<<<<<<<<<<<<<
 *     """
 *     Helper method for defining space-delimited indentation blocks, such as
 */
  __pyx_t_8 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_69indentedBlock, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_indentedBlock, __pyx_t_8) < 0) __PYX_ERR(0, 5341, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5458
 * 
 * 
 * alphas8bit = srange(r"[\0xc0-\0xd6\0xd8-\0xf6\0xf8-\0xff]")             # <<<<<<<<<<<<<<
 * punc8bit = srange(r"[\0xa1-\0xbf\0xd7\0xf7]")
 * 
 */
  __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_srange); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_tuple__871, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_alphas8bit, __pyx_t_7) < 0) __PYX_ERR(0, 5458, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":5459
 * 
 * alphas8bit = srange(r"[\0xc0-\0xd6\0xd8-\0xf6\0xf8-\0xff]")
 * punc8bit = srange(r"[\0xa1-\0xbf\0xd7\0xf7]")             # <<<<<<<<<<<<<<
 * 
 * anyOpenTag, anyCloseTag = makeHTMLTags(Word(alphas, alphanums + "_:").setName('any tag'))
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_srange); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__872, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_punc8bit, __pyx_t_8) < 0) __PYX_ERR(0, 5459, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5461
 * punc8bit = srange(r"[\0xa1-\0xbf\0xd7\0xf7]")
 * 
 * anyOpenTag, anyCloseTag = makeHTMLTags(Word(alphas, alphanums + "_:").setName('any tag'))             # <<<<<<<<<<<<<<
 * _htmlEntityMap = dict(zip("gt lt amp nbsp quot apos".split(), '><& "\''))
 * commonHTMLEntity = Regex('&(?P<entity>' + '|'.join(_htmlEntityMap.keys()) + ");").setName("common HTML entity")
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_makeHTMLTags); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_Word); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_alphas); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_alphanums); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_19 = PyNumber_Add(__pyx_t_2, __pyx_kp_u__873); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 5461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_9)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_t_1, __pyx_t_19};
    __pyx_t_13 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5461, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_t_1, __pyx_t_19};
    __pyx_t_13 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5461, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  } else
  #endif
  {
    __pyx_t_17 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    if (__pyx_t_2) {
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_t_2); __pyx_t_2 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_17, 0+__pyx_t_6, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_19);
    PyTuple_SET_ITEM(__pyx_t_17, 1+__pyx_t_6, __pyx_t_19);
    __pyx_t_1 = 0;
    __pyx_t_19 = 0;
    __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_17, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_setName); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__874, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  if (!__pyx_t_9) {
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_13); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5461, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_GOTREF(__pyx_t_8);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_13};
      __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5461, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_13};
      __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5461, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    } else
    #endif
    {
      __pyx_t_17 = PyTuple_New(1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5461, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_t_9); __pyx_t_9 = NULL;
      __Pyx_GIVEREF(__pyx_t_13);
      PyTuple_SET_ITEM(__pyx_t_17, 0+1, __pyx_t_13);
      __pyx_t_13 = 0;
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_17, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5461, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_8))) || (PyList_CheckExact(__pyx_t_8))) {
    PyObject* sequence = __pyx_t_8;
    #if !CYTHON_COMPILING_IN_PYPY
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 5461, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_7 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_17 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_7 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_17 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_7);
    __Pyx_INCREF(__pyx_t_17);
    #else
    __pyx_t_7 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_17 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    #endif
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_13 = PyObject_GetIter(__pyx_t_8); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_20 = Py_TYPE(__pyx_t_13)->tp_iternext;
    index = 0; __pyx_t_7 = __pyx_t_20(__pyx_t_13); if (unlikely(!__pyx_t_7)) goto __pyx_L47_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_7);
    index = 1; __pyx_t_17 = __pyx_t_20(__pyx_t_13); if (unlikely(!__pyx_t_17)) goto __pyx_L47_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_17);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_20(__pyx_t_13), 2) < 0) __PYX_ERR(0, 5461, __pyx_L1_error)
    __pyx_t_20 = NULL;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    goto __pyx_L48_unpacking_done;
    __pyx_L47_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_20 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 5461, __pyx_L1_error)
    __pyx_L48_unpacking_done:;
  }
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_anyOpenTag, __pyx_t_7) < 0) __PYX_ERR(0, 5461, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_anyCloseTag, __pyx_t_17) < 0) __PYX_ERR(0, 5461, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

  /* "cPyparsing.pyx":5462
 * 
 * anyOpenTag, anyCloseTag = makeHTMLTags(Word(alphas, alphanums + "_:").setName('any tag'))
 * _htmlEntityMap = dict(zip("gt lt amp nbsp quot apos".split(), '><& "\''))             # <<<<<<<<<<<<<<
 * commonHTMLEntity = Regex('&(?P<entity>' + '|'.join(_htmlEntityMap.keys()) + ");").setName("common HTML entity")
 * 
 */
  __pyx_t_8 = PyUnicode_Split(__pyx_kp_u_gt_lt_amp_nbsp_quot_apos, ((PyObject *)NULL), -1L); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_17 = PyTuple_New(2); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_GIVEREF(__pyx_t_8);
  PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_t_8);
  __Pyx_INCREF(__pyx_kp_u__875);
  __Pyx_GIVEREF(__pyx_kp_u__875);
  PyTuple_SET_ITEM(__pyx_t_17, 1, __pyx_kp_u__875);
  __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_zip, __pyx_t_17, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = PyTuple_New(1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_GIVEREF(__pyx_t_8);
  PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_t_8);
  __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(((PyObject *)(&PyDict_Type)), __pyx_t_17, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_htmlEntityMap, __pyx_t_8) < 0) __PYX_ERR(0, 5462, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5463
 * anyOpenTag, anyCloseTag = makeHTMLTags(Word(alphas, alphanums + "_:").setName('any tag'))
 * _htmlEntityMap = dict(zip("gt lt amp nbsp quot apos".split(), '><& "\''))
 * commonHTMLEntity = Regex('&(?P<entity>' + '|'.join(_htmlEntityMap.keys()) + ");").setName("common HTML entity")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_17 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_htmlEntityMap); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_keys); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  if (__pyx_t_13) {
    __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_13); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5463, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  } else {
    __pyx_t_7 = __Pyx_PyObject_CallNoArg(__pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5463, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = PyUnicode_Join(__pyx_kp_u__146, __pyx_t_7); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyUnicode_Concat(__pyx_kp_u_P_entity, __pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyUnicode_Concat(__pyx_t_7, __pyx_kp_u__876); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_17))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_17);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_17, function);
    }
  }
  if (!__pyx_t_7) {
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5463, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_GOTREF(__pyx_t_8);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_17)) {
      PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_9};
      __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_17, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5463, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_17)) {
      PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_9};
      __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_17, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5463, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    {
      __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5463, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_7); __pyx_t_7 = NULL;
      __Pyx_GIVEREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_t_9);
      __pyx_t_9 = 0;
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_17, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5463, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_setName); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_17, __pyx_tuple__877, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_commonHTMLEntity, __pyx_t_8) < 0) __PYX_ERR(0, 5463, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5466
 * 
 * 
 * def replaceHTMLEntity(t):             # <<<<<<<<<<<<<<
 *     """Helper parser action to replace common HTML entities with their special characters"""
 *     return _htmlEntityMap.get(t.entity)
 */
  __pyx_t_8 = PyCFunction_NewEx(&__pyx_mdef_10cPyparsing_71replaceHTMLEntity, NULL, __pyx_n_s_cPyparsing); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_replaceHTMLEntity, __pyx_t_8) < 0) __PYX_ERR(0, 5466, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5472
 * 
 * # it's easy to get these comment structures wrong - they're very common, so may as well make them available
 * cStyleComment = Combine(Regex(r"/\*(?:[^*]|\*(?!/))*") + '*[inserted by cython to avoid comment closer]/').setName("C style comment")             # <<<<<<<<<<<<<<
 * "Comment of the form C{/[inserted by cython to avoid comment start]* ... *[inserted by cython to avoid comment closer]/}"
 * 
 */
  __pyx_t_17 = __Pyx_GetModuleGlobalName(__pyx_n_s_Combine); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_tuple__881, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = PyNumber_Add(__pyx_t_9, __pyx_kp_u__882); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_17))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_17);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_17, function);
    }
  }
  if (!__pyx_t_9) {
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_t_13); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5472, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_GOTREF(__pyx_t_8);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_17)) {
      PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_13};
      __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_17, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5472, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_17)) {
      PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_13};
      __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_17, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5472, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5472, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_9); __pyx_t_9 = NULL;
      __Pyx_GIVEREF(__pyx_t_13);
      PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_13);
      __pyx_t_13 = 0;
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_17, __pyx_t_7, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5472, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_setName); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_17, __pyx_tuple__883, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_cStyleComment, __pyx_t_8) < 0) __PYX_ERR(0, 5472, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5475
 * "Comment of the form C{/[inserted by cython to avoid comment start]* ... *[inserted by cython to avoid comment closer]/}"
 * 
 * htmlComment = Regex(r"<!--[\s\S]*?-->").setName("HTML comment")             # <<<<<<<<<<<<<<
 * "Comment of the form C{<!-- ... -->}"
 * 
 */
  __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_tuple__884, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_setName); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_tuple__885, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_htmlComment, __pyx_t_17) < 0) __PYX_ERR(0, 5475, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

  /* "cPyparsing.pyx":5478
 * "Comment of the form C{<!-- ... -->}"
 * 
 * restOfLine = Regex(r".*").leaveWhitespace().setName("rest of line")             # <<<<<<<<<<<<<<
 * dblSlashComment = Regex(r"//(?:\\\n|[^\n])*").setName("// comment")
 * "Comment of the form C{// ... (to end of line)}"
 */
  __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_tuple__887, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_leaveWhitespace); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  if (__pyx_t_7) {
    __pyx_t_17 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_7); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5478, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  } else {
    __pyx_t_17 = __Pyx_PyObject_CallNoArg(__pyx_t_8); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5478, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_setName); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_tuple__888, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_restOfLine, __pyx_t_17) < 0) __PYX_ERR(0, 5478, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

  /* "cPyparsing.pyx":5479
 * 
 * restOfLine = Regex(r".*").leaveWhitespace().setName("rest of line")
 * dblSlashComment = Regex(r"//(?:\\\n|[^\n])*").setName("// comment")             # <<<<<<<<<<<<<<
 * "Comment of the form C{// ... (to end of line)}"
 * 
 */
  __pyx_t_17 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_17, __pyx_tuple__889, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_setName); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_17, __pyx_tuple__890, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_dblSlashComment, __pyx_t_8) < 0) __PYX_ERR(0, 5479, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5482
 * "Comment of the form C{// ... (to end of line)}"
 * 
 * cppStyleComment = Combine(Regex(r"/\*(?:[^*]|\*(?!/))*") + '*[inserted by cython to avoid comment closer]/' | dblSlashComment).setName("C++ style comment")             # <<<<<<<<<<<<<<
 * "Comment of either form C{L{cStyleComment}} or C{L{dblSlashComment}}"
 * 
 */
  __pyx_t_17 = __Pyx_GetModuleGlobalName(__pyx_n_s_Combine); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__891, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_t_13, __pyx_kp_u__882); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_dblSlashComment); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = PyNumber_Or(__pyx_t_7, __pyx_t_13); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_17))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_17);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_17, function);
    }
  }
  if (!__pyx_t_13) {
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5482, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_GOTREF(__pyx_t_8);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_17)) {
      PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_9};
      __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_17, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5482, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_17)) {
      PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_9};
      __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_17, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5482, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5482, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_13); __pyx_t_13 = NULL;
      __Pyx_GIVEREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_9);
      __pyx_t_9 = 0;
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_17, __pyx_t_7, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5482, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_setName); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_17, __pyx_tuple__892, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_cppStyleComment, __pyx_t_8) < 0) __PYX_ERR(0, 5482, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5485
 * "Comment of either form C{L{cStyleComment}} or C{L{dblSlashComment}}"
 * 
 * javaStyleComment = cppStyleComment             # <<<<<<<<<<<<<<
 * "Same as C{L{cppStyleComment}}"
 * 
 */
  __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_cppStyleComment); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_javaStyleComment, __pyx_t_8) < 0) __PYX_ERR(0, 5485, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5488
 * "Same as C{L{cppStyleComment}}"
 * 
 * pythonStyleComment = Regex(r"#.*").setName("Python style comment")             # <<<<<<<<<<<<<<
 * "Comment of the form C{# ... (to end of line)}"
 * 
 */
  __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_tuple__894, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_setName); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_tuple__895, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pythonStyleComment, __pyx_t_17) < 0) __PYX_ERR(0, 5488, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

  /* "cPyparsing.pyx":5491
 * "Comment of the form C{# ... (to end of line)}"
 * 
 * _commasepitem = Combine(OneOrMore(Word(printables, excludeChars=',') +             # <<<<<<<<<<<<<<
 *                                   Optional(Word(" \t") +
 *                                            ~Literal(",") + ~LineEnd()))).streamline().setName("commaItem")
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_Combine); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_19 = __Pyx_GetModuleGlobalName(__pyx_n_s_Word); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 5491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_printables); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_excludeChars, __pyx_kp_u__132) < 0) __PYX_ERR(0, 5491, __pyx_L1_error)
  __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_19, __pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5492
 * 
 * _commasepitem = Combine(OneOrMore(Word(printables, excludeChars=',') +
 *                                   Optional(Word(" \t") +             # <<<<<<<<<<<<<<
 *                                            ~Literal(",") + ~LineEnd()))).streamline().setName("commaItem")
 * commaSeparatedList = delimitedList(Optional(quotedString.copy() | _commasepitem, default="")).setName("commaSeparatedList")
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_19 = __Pyx_GetModuleGlobalName(__pyx_n_s_Word); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 5492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_22 = __Pyx_PyObject_Call(__pyx_t_19, __pyx_tuple__897, NULL); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 5492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":5493
 * _commasepitem = Combine(OneOrMore(Word(printables, excludeChars=',') +
 *                                   Optional(Word(" \t") +
 *                                            ~Literal(",") + ~LineEnd()))).streamline().setName("commaItem")             # <<<<<<<<<<<<<<
 * commaSeparatedList = delimitedList(Optional(quotedString.copy() | _commasepitem, default="")).setName("commaSeparatedList")
 * """(Deprecated) Predefined expression of 1 or more printable words or quoted strings, separated by commas.
 */
  __pyx_t_19 = __Pyx_GetModuleGlobalName(__pyx_n_s_Literal); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 5493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_23 = __Pyx_PyObject_Call(__pyx_t_19, __pyx_tuple__898, NULL); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 5493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = PyNumber_Invert(__pyx_t_23); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 5493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;

  /* "cPyparsing.pyx":5492
 * 
 * _commasepitem = Combine(OneOrMore(Word(printables, excludeChars=',') +
 *                                   Optional(Word(" \t") +             # <<<<<<<<<<<<<<
 *                                            ~Literal(",") + ~LineEnd()))).streamline().setName("commaItem")
 * commaSeparatedList = delimitedList(Optional(quotedString.copy() | _commasepitem, default="")).setName("commaSeparatedList")
 */
  __pyx_t_23 = PyNumber_Add(__pyx_t_22, __pyx_t_19); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 5492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "cPyparsing.pyx":5493
 * _commasepitem = Combine(OneOrMore(Word(printables, excludeChars=',') +
 *                                   Optional(Word(" \t") +
 *                                            ~Literal(",") + ~LineEnd()))).streamline().setName("commaItem")             # <<<<<<<<<<<<<<
 * commaSeparatedList = delimitedList(Optional(quotedString.copy() | _commasepitem, default="")).setName("commaSeparatedList")
 * """(Deprecated) Predefined expression of 1 or more printable words or quoted strings, separated by commas.
 */
  __pyx_t_22 = __Pyx_GetModuleGlobalName(__pyx_n_s_LineEnd); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 5493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __pyx_t_24 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_22))) {
    __pyx_t_24 = PyMethod_GET_SELF(__pyx_t_22);
    if (likely(__pyx_t_24)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_22);
      __Pyx_INCREF(__pyx_t_24);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_22, function);
    }
  }
  if (__pyx_t_24) {
    __pyx_t_19 = __Pyx_PyObject_CallOneArg(__pyx_t_22, __pyx_t_24); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 5493, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
  } else {
    __pyx_t_19 = __Pyx_PyObject_CallNoArg(__pyx_t_22); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 5493, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = PyNumber_Invert(__pyx_t_19); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 5493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = PyNumber_Add(__pyx_t_23, __pyx_t_22); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 5493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_22) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_19); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5492, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_22, __pyx_t_19};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5492, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_22, __pyx_t_19};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5492, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
    } else
    #endif
    {
      __pyx_t_23 = PyTuple_New(1+1); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 5492, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_23);
      __Pyx_GIVEREF(__pyx_t_22); PyTuple_SET_ITEM(__pyx_t_23, 0, __pyx_t_22); __pyx_t_22 = NULL;
      __Pyx_GIVEREF(__pyx_t_19);
      PyTuple_SET_ITEM(__pyx_t_23, 0+1, __pyx_t_19);
      __pyx_t_19 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_23, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5492, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cPyparsing.pyx":5491
 * "Comment of the form C{# ... (to end of line)}"
 * 
 * _commasepitem = Combine(OneOrMore(Word(printables, excludeChars=',') +             # <<<<<<<<<<<<<<
 *                                   Optional(Word(" \t") +
 *                                            ~Literal(",") + ~LineEnd()))).streamline().setName("commaItem")
 */
  __pyx_t_2 = PyNumber_Add(__pyx_t_21, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  if (!__pyx_t_1) {
    __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5491, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_9);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_2};
      __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5491, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_2};
      __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5491, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_21 = PyTuple_New(1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5491, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_21, 0, __pyx_t_1); __pyx_t_1 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_21, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_21, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5491, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  if (!__pyx_t_13) {
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5491, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_GOTREF(__pyx_t_8);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_9};
      __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5491, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_9};
      __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5491, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    {
      __pyx_t_21 = PyTuple_New(1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5491, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_21, 0, __pyx_t_13); __pyx_t_13 = NULL;
      __Pyx_GIVEREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_21, 0+1, __pyx_t_9);
      __pyx_t_9 = 0;
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_21, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5491, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":5493
 * _commasepitem = Combine(OneOrMore(Word(printables, excludeChars=',') +
 *                                   Optional(Word(" \t") +
 *                                            ~Literal(",") + ~LineEnd()))).streamline().setName("commaItem")             # <<<<<<<<<<<<<<
 * commaSeparatedList = delimitedList(Optional(quotedString.copy() | _commasepitem, default="")).setName("commaSeparatedList")
 * """(Deprecated) Predefined expression of 1 or more printable words or quoted strings, separated by commas.
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_streamline); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  if (__pyx_t_8) {
    __pyx_t_17 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5493, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  } else {
    __pyx_t_17 = __Pyx_PyObject_CallNoArg(__pyx_t_7); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5493, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_setName); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__899, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_commasepitem, __pyx_t_17) < 0) __PYX_ERR(0, 5491, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

  /* "cPyparsing.pyx":5494
 *                                   Optional(Word(" \t") +
 *                                            ~Literal(",") + ~LineEnd()))).streamline().setName("commaItem")
 * commaSeparatedList = delimitedList(Optional(quotedString.copy() | _commasepitem, default="")).setName("commaSeparatedList")             # <<<<<<<<<<<<<<
 * """(Deprecated) Predefined expression of 1 or more printable words or quoted strings, separated by commas.
 *    This expression is deprecated in favor of L{pyparsing_common.comma_separated_list}."""
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_delimitedList); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_quotedString); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_copy); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  if (__pyx_t_9) {
    __pyx_t_21 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_9); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5494, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  } else {
    __pyx_t_21 = __Pyx_PyObject_CallNoArg(__pyx_t_13); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5494, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_commasepitem); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = PyNumber_Or(__pyx_t_21, __pyx_t_13); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_9);
  PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_9);
  __pyx_t_9 = 0;
  __pyx_t_9 = PyDict_New(); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_default, __pyx_kp_u__9) < 0) __PYX_ERR(0, 5494, __pyx_L1_error)
  __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_13, __pyx_t_9); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  if (!__pyx_t_9) {
    __pyx_t_17 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_21); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5494, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __Pyx_GOTREF(__pyx_t_17);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_21};
      __pyx_t_17 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5494, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_21};
      __pyx_t_17 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5494, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    } else
    #endif
    {
      __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5494, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_9); __pyx_t_9 = NULL;
      __Pyx_GIVEREF(__pyx_t_21);
      PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_t_21);
      __pyx_t_21 = 0;
      __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_13, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5494, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_setName); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__900, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_commaSeparatedList, __pyx_t_17) < 0) __PYX_ERR(0, 5494, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

  /* "cPyparsing.pyx":5501
 * 
 * 
 * class pyparsing_common:             # <<<<<<<<<<<<<<
 *     """
 *     Here are some common low-level expressions that may be useful in jump-starting parser development:
 */
  __pyx_t_17 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_empty_tuple, __pyx_n_s_pyparsing_common, __pyx_n_s_pyparsing_common, (PyObject *) NULL, __pyx_n_s_cPyparsing, __pyx_kp_s_Here_are_some_common_low_level); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);

  /* "cPyparsing.pyx":5637
 *     """
 * 
 *     convertToInteger = tokenMap(int)             # <<<<<<<<<<<<<<
 *     """
 *     Parse action for converting parsed integers to Python int
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_tokenMap); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_21 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_21 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_21)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_21);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  if (!__pyx_t_21) {
    __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_13, ((PyObject *)(&PyInt_Type))); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5637, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_21, ((PyObject *)(&PyInt_Type))};
      __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5637, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
      __Pyx_GOTREF(__pyx_t_7);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_21, ((PyObject *)(&PyInt_Type))};
      __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5637, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
      __Pyx_GOTREF(__pyx_t_7);
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5637, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_21); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_21); __pyx_t_21 = NULL;
      __Pyx_INCREF(((PyObject *)(&PyInt_Type)));
      __Pyx_GIVEREF(((PyObject *)(&PyInt_Type)));
      PyTuple_SET_ITEM(__pyx_t_9, 0+1, ((PyObject *)(&PyInt_Type)));
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_9, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5637, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_convertToInteger, __pyx_t_7) < 0) __PYX_ERR(0, 5637, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":5642
 *     """
 * 
 *     convertToFloat = tokenMap(float)             # <<<<<<<<<<<<<<
 *     """
 *     Parse action for converting parsed numbers to Python float
 */
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_tokenMap); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  if (!__pyx_t_9) {
    __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_13, ((PyObject *)(&PyFloat_Type))); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5642, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_9, ((PyObject *)(&PyFloat_Type))};
      __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5642, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_7);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_13)) {
      PyObject *__pyx_temp[2] = {__pyx_t_9, ((PyObject *)(&PyFloat_Type))};
      __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5642, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_7);
    } else
    #endif
    {
      __pyx_t_21 = PyTuple_New(1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5642, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_21, 0, __pyx_t_9); __pyx_t_9 = NULL;
      __Pyx_INCREF(((PyObject *)(&PyFloat_Type)));
      __Pyx_GIVEREF(((PyObject *)(&PyFloat_Type)));
      PyTuple_SET_ITEM(__pyx_t_21, 0+1, ((PyObject *)(&PyFloat_Type)));
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_21, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5642, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_convertToFloat, __pyx_t_7) < 0) __PYX_ERR(0, 5642, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":5647
 *     """
 * 
 *     integer = Word(nums).setName("integer").setParseAction(convertToInteger)             # <<<<<<<<<<<<<<
 *     """expression that parses an unsigned integer, returns an int"""
 * 
 */
  __pyx_t_21 = __Pyx_GetModuleGlobalName(__pyx_n_s_Word); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_nums); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_21))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_21);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_21);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_21, function);
    }
  }
  if (!__pyx_t_8) {
    __pyx_t_13 = __Pyx_PyObject_CallOneArg(__pyx_t_21, __pyx_t_9); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5647, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_GOTREF(__pyx_t_13);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_21)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_9};
      __pyx_t_13 = __Pyx_PyFunction_FastCall(__pyx_t_21, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5647, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_21)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_9};
      __pyx_t_13 = __Pyx_PyCFunction_FastCall(__pyx_t_21, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5647, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    {
      __pyx_t_2 = PyTuple_New(1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5647, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_8); __pyx_t_8 = NULL;
      __Pyx_GIVEREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_2, 0+1, __pyx_t_9);
      __pyx_t_9 = 0;
      __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_21, __pyx_t_2, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5647, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_setName); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_21, __pyx_tuple__901, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_convertToInteger);
  if (unlikely(!__pyx_t_13)) {
    PyErr_Clear();
    __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_convertToInteger);
  }
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_21))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_21);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_21);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_21, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_21, __pyx_t_13); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5647, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_GOTREF(__pyx_t_7);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_21)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_13};
      __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_21, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5647, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_21)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_13};
      __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_21, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5647, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5647, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_GIVEREF(__pyx_t_13);
      PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_13);
      __pyx_t_13 = 0;
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_21, __pyx_t_9, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5647, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_integer, __pyx_t_7) < 0) __PYX_ERR(0, 5647, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":5650
 *     """expression that parses an unsigned integer, returns an int"""
 * 
 *     hex_integer = Word(hexnums).setName("hex integer").setParseAction(tokenMap(int, 16))             # <<<<<<<<<<<<<<
 *     """expression that parses a hexadecimal integer, returns an int"""
 * 
 */
  __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_Word); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_hexnums); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_21 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_13); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5650, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_GOTREF(__pyx_t_21);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_13};
      __pyx_t_21 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5650, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_13};
      __pyx_t_21 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5650, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    } else
    #endif
    {
      __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5650, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_GIVEREF(__pyx_t_13);
      PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_13);
      __pyx_t_13 = 0;
      __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_8, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5650, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_setName); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__902, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_tokenMap); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_13 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_8)) {
    PyObject *__pyx_temp[3] = {__pyx_t_13, ((PyObject *)(&PyInt_Type)), __pyx_int_16};
    __pyx_t_21 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5650, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_GOTREF(__pyx_t_21);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
    PyObject *__pyx_temp[3] = {__pyx_t_13, ((PyObject *)(&PyInt_Type)), __pyx_int_16};
    __pyx_t_21 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5650, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_GOTREF(__pyx_t_21);
  } else
  #endif
  {
    __pyx_t_2 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5650, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__pyx_t_13) {
      __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13); __pyx_t_13 = NULL;
    }
    __Pyx_INCREF(((PyObject *)(&PyInt_Type)));
    __Pyx_GIVEREF(((PyObject *)(&PyInt_Type)));
    PyTuple_SET_ITEM(__pyx_t_2, 0+__pyx_t_6, ((PyObject *)(&PyInt_Type)));
    __Pyx_INCREF(__pyx_int_16);
    __Pyx_GIVEREF(__pyx_int_16);
    PyTuple_SET_ITEM(__pyx_t_2, 1+__pyx_t_6, __pyx_int_16);
    __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_2, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5650, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  if (!__pyx_t_8) {
    __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_21); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5650, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __Pyx_GOTREF(__pyx_t_7);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_21};
      __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5650, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_21};
      __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5650, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    } else
    #endif
    {
      __pyx_t_2 = PyTuple_New(1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5650, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_8); __pyx_t_8 = NULL;
      __Pyx_GIVEREF(__pyx_t_21);
      PyTuple_SET_ITEM(__pyx_t_2, 0+1, __pyx_t_21);
      __pyx_t_21 = 0;
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_2, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5650, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_hex_integer_2, __pyx_t_7) < 0) __PYX_ERR(0, 5650, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":5653
 *     """expression that parses a hexadecimal integer, returns an int"""
 * 
 *     signed_integer = Regex(r'[+-]?\d+').setName("signed integer").setParseAction(convertToInteger)             # <<<<<<<<<<<<<<
 *     """expression that parses an integer with optional leading sign, returns an int"""
 * 
 */
  __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__903, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setName); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__904, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_convertToInteger);
  if (unlikely(!__pyx_t_2)) {
    PyErr_Clear();
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_convertToInteger);
  }
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_21 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_21 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_21)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_21);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  if (!__pyx_t_21) {
    __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5653, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_7);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_21, __pyx_t_2};
      __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5653, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_21, __pyx_t_2};
      __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5653, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5653, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_21); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_21); __pyx_t_21 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_8, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5653, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_signed_integer_2, __pyx_t_7) < 0) __PYX_ERR(0, 5653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":5656
 *     """expression that parses an integer with optional leading sign, returns an int"""
 * 
 *     fraction = (signed_integer().setParseAction(convertToFloat) + '/' + signed_integer().setParseAction(convertToFloat)).setName("fraction")             # <<<<<<<<<<<<<<
 *     """fractional expression of an integer divided by an integer, returns a float"""
 *     fraction.addParseAction(lambda t: t[0] / t[-1])
 */
  __pyx_t_8 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_signed_integer_2);
  if (unlikely(!__pyx_t_8)) {
    PyErr_Clear();
    __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_signed_integer_2);
  }
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5656, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_9 = __Pyx_PyObject_CallNoArg(__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5656, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_convertToFloat);
  if (unlikely(!__pyx_t_9)) {
    PyErr_Clear();
    __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_convertToFloat);
  }
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5656, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_GOTREF(__pyx_t_7);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_8)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_9};
      __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5656, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_9};
      __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5656, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    {
      __pyx_t_21 = PyTuple_New(1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5656, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_21, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_GIVEREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_21, 0+1, __pyx_t_9);
      __pyx_t_9 = 0;
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_21, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5656, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = PyNumber_Add(__pyx_t_7, __pyx_kp_u__166); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_9 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_signed_integer_2);
  if (unlikely(!__pyx_t_9)) {
    PyErr_Clear();
    __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_signed_integer_2);
  }
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_21 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_2); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5656, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_21 = __Pyx_PyObject_CallNoArg(__pyx_t_9); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5656, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_convertToFloat);
  if (unlikely(!__pyx_t_21)) {
    PyErr_Clear();
    __pyx_t_21 = __Pyx_GetModuleGlobalName(__pyx_n_s_convertToFloat);
  }
  if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_21); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5656, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __Pyx_GOTREF(__pyx_t_7);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_21};
      __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5656, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_21};
      __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5656, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    } else
    #endif
    {
      __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5656, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_GIVEREF(__pyx_t_21);
      PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_t_21);
      __pyx_t_21 = 0;
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_13, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5656, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = PyNumber_Add(__pyx_t_8, __pyx_t_7); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_setName); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__905, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_fraction, __pyx_t_9) < 0) __PYX_ERR(0, 5656, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5658
 *     fraction = (signed_integer().setParseAction(convertToFloat) + '/' + signed_integer().setParseAction(convertToFloat)).setName("fraction")
 *     """fractional expression of an integer divided by an integer, returns a float"""
 *     fraction.addParseAction(lambda t: t[0] / t[-1])             # <<<<<<<<<<<<<<
 * 
 *     mixed_integer = (fraction | signed_integer + Optional(Optional('-').suppress() + fraction)).setName("fraction or mixed integer-fraction")
 */
  __pyx_t_7 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_fraction);
  if (unlikely(!__pyx_t_7)) {
    PyErr_Clear();
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_fraction);
  }
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_addParseAction); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_16pyparsing_common_6lambda55, 0, __pyx_n_s_pyparsing_common_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  if (!__pyx_t_13) {
    __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_7); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5658, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_9);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_8)) {
      PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_7};
      __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5658, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
      PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_7};
      __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5658, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else
    #endif
    {
      __pyx_t_21 = PyTuple_New(1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5658, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_21, 0, __pyx_t_13); __pyx_t_13 = NULL;
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_21, 0+1, __pyx_t_7);
      __pyx_t_7 = 0;
      __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_21, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5658, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "cPyparsing.pyx":5660
 *     fraction.addParseAction(lambda t: t[0] / t[-1])
 * 
 *     mixed_integer = (fraction | signed_integer + Optional(Optional('-').suppress() + fraction)).setName("fraction or mixed integer-fraction")             # <<<<<<<<<<<<<<
 *     """mixed integer of the form 'integer - fraction', with optional leading integer, returns float"""
 *     mixed_integer.addParseAction(sum)
 */
  __pyx_t_9 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_fraction);
  if (unlikely(!__pyx_t_9)) {
    PyErr_Clear();
    __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_fraction);
  }
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_8 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_signed_integer_2);
  if (unlikely(!__pyx_t_8)) {
    PyErr_Clear();
    __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_signed_integer_2);
  }
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__906, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_suppress); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_1) {
    __pyx_t_13 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5660, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    __pyx_t_13 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5660, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_fraction);
  if (unlikely(!__pyx_t_2)) {
    PyErr_Clear();
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_fraction);
  }
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyNumber_Add(__pyx_t_13, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_21 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5660, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GOTREF(__pyx_t_21);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_1};
      __pyx_t_21 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5660, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_1};
      __pyx_t_21 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5660, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    {
      __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5660, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_13, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5660, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_t_8, __pyx_t_21); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = PyNumber_Or(__pyx_t_9, __pyx_t_7); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_setName); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__907, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_mixed_integer, __pyx_t_21) < 0) __PYX_ERR(0, 5660, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":5662
 *     mixed_integer = (fraction | signed_integer + Optional(Optional('-').suppress() + fraction)).setName("fraction or mixed integer-fraction")
 *     """mixed integer of the form 'integer - fraction', with optional leading integer, returns float"""
 *     mixed_integer.addParseAction(sum)             # <<<<<<<<<<<<<<
 * 
 *     real = Regex(r'[+-]?\d+\.\d*').setName("real number").setParseAction(convertToFloat)
 */
  __pyx_t_7 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_mixed_integer);
  if (unlikely(!__pyx_t_7)) {
    PyErr_Clear();
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_mixed_integer);
  }
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_addParseAction); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  if (!__pyx_t_7) {
    __pyx_t_21 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_builtin_sum); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5662, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_builtin_sum};
      __pyx_t_21 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5662, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_21);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_builtin_sum};
      __pyx_t_21 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5662, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_21);
    } else
    #endif
    {
      __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5662, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_7); __pyx_t_7 = NULL;
      __Pyx_INCREF(__pyx_builtin_sum);
      __Pyx_GIVEREF(__pyx_builtin_sum);
      PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_builtin_sum);
      __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_8, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5662, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":5664
 *     mixed_integer.addParseAction(sum)
 * 
 *     real = Regex(r'[+-]?\d+\.\d*').setName("real number").setParseAction(convertToFloat)             # <<<<<<<<<<<<<<
 *     """expression that parses a floating point number and returns a float"""
 * 
 */
  __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__908, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_setName); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__909, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_convertToFloat);
  if (unlikely(!__pyx_t_8)) {
    PyErr_Clear();
    __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_convertToFloat);
  }
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  if (!__pyx_t_7) {
    __pyx_t_21 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_8); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5664, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GOTREF(__pyx_t_21);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_8};
      __pyx_t_21 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5664, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_8};
      __pyx_t_21 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5664, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    } else
    #endif
    {
      __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5664, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_7); __pyx_t_7 = NULL;
      __Pyx_GIVEREF(__pyx_t_8);
      PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_t_8);
      __pyx_t_8 = 0;
      __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_13, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5664, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_real, __pyx_t_21) < 0) __PYX_ERR(0, 5664, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":5667
 *     """expression that parses a floating point number and returns a float"""
 * 
 *     sci_real = Regex(r'[+-]?\d+([eE][+-]?\d+|\.\d*([eE][+-]?\d+)?)').setName("real number with scientific notation").setParseAction(convertToFloat)             # <<<<<<<<<<<<<<
 *     """expression that parses a floating point number with optional scientific notation and returns a float"""
 * 
 */
  __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__910, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_setName); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__911, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_convertToFloat);
  if (unlikely(!__pyx_t_13)) {
    PyErr_Clear();
    __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_convertToFloat);
  }
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  if (!__pyx_t_8) {
    __pyx_t_21 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_13); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5667, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_GOTREF(__pyx_t_21);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_13};
      __pyx_t_21 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5667, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_13};
      __pyx_t_21 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5667, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5667, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_8); __pyx_t_8 = NULL;
      __Pyx_GIVEREF(__pyx_t_13);
      PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_13);
      __pyx_t_13 = 0;
      __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_7, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5667, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_sci_real, __pyx_t_21) < 0) __PYX_ERR(0, 5667, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":5671
 * 
 *     # streamlining this expression makes the docs nicer-looking
 *     number = (sci_real | real | signed_integer).streamline()             # <<<<<<<<<<<<<<
 *     """any numeric expression, returns the corresponding Python type"""
 * 
 */
  __pyx_t_9 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_sci_real);
  if (unlikely(!__pyx_t_9)) {
    PyErr_Clear();
    __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_sci_real);
  }
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_7 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_real);
  if (unlikely(!__pyx_t_7)) {
    PyErr_Clear();
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_real);
  }
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_13 = PyNumber_Or(__pyx_t_9, __pyx_t_7); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_signed_integer_2);
  if (unlikely(!__pyx_t_7)) {
    PyErr_Clear();
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_signed_integer_2);
  }
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_9 = PyNumber_Or(__pyx_t_13, __pyx_t_7); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_streamline); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  if (__pyx_t_9) {
    __pyx_t_21 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_9); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5671, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  } else {
    __pyx_t_21 = __Pyx_PyObject_CallNoArg(__pyx_t_7); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5671, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_number, __pyx_t_21) < 0) __PYX_ERR(0, 5671, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":5674
 *     """any numeric expression, returns the corresponding Python type"""
 * 
 *     fnumber = Regex(r'[+-]?\d+\.?\d*([eE][+-]?\d+)?').setName("fnumber").setParseAction(convertToFloat)             # <<<<<<<<<<<<<<
 *     """any int or real number, returned as float"""
 * 
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__912, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_setName); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__913, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_convertToFloat);
  if (unlikely(!__pyx_t_9)) {
    PyErr_Clear();
    __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_convertToFloat);
  }
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  if (!__pyx_t_13) {
    __pyx_t_21 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_9); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5674, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_GOTREF(__pyx_t_21);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_9};
      __pyx_t_21 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5674, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_9};
      __pyx_t_21 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5674, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    {
      __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5674, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_13); __pyx_t_13 = NULL;
      __Pyx_GIVEREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_9);
      __pyx_t_9 = 0;
      __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5674, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_fnumber, __pyx_t_21) < 0) __PYX_ERR(0, 5674, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":5677
 *     """any int or real number, returned as float"""
 * 
 *     identifier = Word(alphas + '_', alphanums + '_').setName("identifier")             # <<<<<<<<<<<<<<
 *     """typical code identifier (leading alpha or '_', followed by 0 or more alphas, nums, or '_')"""
 * 
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_Word); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_alphas); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = PyNumber_Add(__pyx_t_8, __pyx_n_u__653); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_alphanums); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_13 = PyNumber_Add(__pyx_t_8, __pyx_n_u__653); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_7)) {
    PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_t_9, __pyx_t_13};
    __pyx_t_21 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5677, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
    PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_t_9, __pyx_t_13};
    __pyx_t_21 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5677, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  } else
  #endif
  {
    __pyx_t_1 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5677, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__pyx_t_8) {
      __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_8); __pyx_t_8 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_9);
    PyTuple_SET_ITEM(__pyx_t_1, 0+__pyx_t_6, __pyx_t_9);
    __Pyx_GIVEREF(__pyx_t_13);
    PyTuple_SET_ITEM(__pyx_t_1, 1+__pyx_t_6, __pyx_t_13);
    __pyx_t_9 = 0;
    __pyx_t_13 = 0;
    __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_1, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5677, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_setName); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__914, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_identifier, __pyx_t_21) < 0) __PYX_ERR(0, 5677, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":5680
 *     """typical code identifier (leading alpha or '_', followed by 0 or more alphas, nums, or '_')"""
 * 
 *     ipv4_address = Regex(r'(25[0-5]|2[0-4][0-9]|1?[0-9]{1,2})(\.(25[0-5]|2[0-4][0-9]|1?[0-9]{1,2})){3}').setName("IPv4 address")             # <<<<<<<<<<<<<<
 *     "IPv4 address (C{0.0.0.0 - 255.255.255.255})"
 * 
 */
  __pyx_t_21 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_21, __pyx_tuple__915, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_setName); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_21, __pyx_tuple__916, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_ipv4_address, __pyx_t_7) < 0) __PYX_ERR(0, 5680, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":5683
 *     "IPv4 address (C{0.0.0.0 - 255.255.255.255})"
 * 
 *     _ipv6_part = Regex(r'[0-9a-fA-F]{1,4}').setName("hex_integer")             # <<<<<<<<<<<<<<
 *     _full_ipv6_address = (_ipv6_part + (':' + _ipv6_part) * 7).setName("full IPv6 address")
 *     _short_ipv6_address = (Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6)) + "::" + Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))).setName("short IPv6 address")
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__917, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_setName); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__918, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_ipv6_part, __pyx_t_21) < 0) __PYX_ERR(0, 5683, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":5684
 * 
 *     _ipv6_part = Regex(r'[0-9a-fA-F]{1,4}').setName("hex_integer")
 *     _full_ipv6_address = (_ipv6_part + (':' + _ipv6_part) * 7).setName("full IPv6 address")             # <<<<<<<<<<<<<<
 *     _short_ipv6_address = (Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6)) + "::" + Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))).setName("short IPv6 address")
 *     _short_ipv6_address.addCondition(lambda t: sum(1 for tt in t if pyparsing_common._ipv6_part.matches(tt)) < 8)
 */
  __pyx_t_21 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_ipv6_part);
  if (unlikely(!__pyx_t_21)) {
    PyErr_Clear();
    __pyx_t_21 = __Pyx_GetModuleGlobalName(__pyx_n_s_ipv6_part);
  }
  if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __pyx_t_7 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_ipv6_part);
  if (unlikely(!__pyx_t_7)) {
    PyErr_Clear();
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_ipv6_part);
  }
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = PyNumber_Add(__pyx_kp_u__182, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Multiply(__pyx_t_1, __pyx_int_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_21, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_setName); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__919, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_full_ipv6_address, __pyx_t_1) < 0) __PYX_ERR(0, 5684, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cPyparsing.pyx":5685
 *     _ipv6_part = Regex(r'[0-9a-fA-F]{1,4}').setName("hex_integer")
 *     _full_ipv6_address = (_ipv6_part + (':' + _ipv6_part) * 7).setName("full IPv6 address")
 *     _short_ipv6_address = (Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6)) + "::" + Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))).setName("short IPv6 address")             # <<<<<<<<<<<<<<
 *     _short_ipv6_address.addCondition(lambda t: sum(1 for tt in t if pyparsing_common._ipv6_part.matches(tt)) < 8)
 *     _mixed_ipv6_address = ("::ffff:" + ipv4_address).setName("mixed IPv6 address")
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_21 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_ipv6_part);
  if (unlikely(!__pyx_t_21)) {
    PyErr_Clear();
    __pyx_t_21 = __Pyx_GetModuleGlobalName(__pyx_n_s_ipv6_part);
  }
  if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __pyx_t_13 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_ipv6_part);
  if (unlikely(!__pyx_t_13)) {
    PyErr_Clear();
    __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_ipv6_part);
  }
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = PyNumber_Add(__pyx_kp_u__182, __pyx_t_13); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = PyNumber_Multiply(__pyx_t_9, __pyx_tuple__920); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = PyNumber_Add(__pyx_t_21, __pyx_t_13); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  if (!__pyx_t_13) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5685, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_9};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5685, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_9};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5685, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    } else
    #endif
    {
      __pyx_t_21 = PyTuple_New(1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5685, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_21, 0, __pyx_t_13); __pyx_t_13 = NULL;
      __Pyx_GIVEREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_21, 0+1, __pyx_t_9);
      __pyx_t_9 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_21, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5685, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_t_1, __pyx_kp_u__921); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_21 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __pyx_t_9 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_ipv6_part);
  if (unlikely(!__pyx_t_9)) {
    PyErr_Clear();
    __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_ipv6_part);
  }
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_13 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_ipv6_part);
  if (unlikely(!__pyx_t_13)) {
    PyErr_Clear();
    __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_ipv6_part);
  }
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_8 = PyNumber_Add(__pyx_kp_u__182, __pyx_t_13); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = PyNumber_Multiply(__pyx_t_8, __pyx_tuple__922); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = PyNumber_Add(__pyx_t_9, __pyx_t_13); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_21))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_21);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_21);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_21, function);
    }
  }
  if (!__pyx_t_13) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_21, __pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5685, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_21)) {
      PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_8};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_21, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5685, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_21)) {
      PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_8};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_21, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5685, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5685, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_13); __pyx_t_13 = NULL;
      __Pyx_GIVEREF(__pyx_t_8);
      PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_8);
      __pyx_t_8 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_21, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5685, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = PyNumber_Add(__pyx_t_7, __pyx_t_1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_setName); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__923, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_short_ipv6_address, __pyx_t_21) < 0) __PYX_ERR(0, 5685, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":5686
 *     _full_ipv6_address = (_ipv6_part + (':' + _ipv6_part) * 7).setName("full IPv6 address")
 *     _short_ipv6_address = (Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6)) + "::" + Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))).setName("short IPv6 address")
 *     _short_ipv6_address.addCondition(lambda t: sum(1 for tt in t if pyparsing_common._ipv6_part.matches(tt)) < 8)             # <<<<<<<<<<<<<<
 *     _mixed_ipv6_address = ("::ffff:" + ipv4_address).setName("mixed IPv6 address")
 *     ipv6_address = Combine((_full_ipv6_address | _mixed_ipv6_address | _short_ipv6_address).setName("IPv6 address")).setName("IPv6 address")
 */
  __pyx_t_1 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_short_ipv6_address);
  if (unlikely(!__pyx_t_1)) {
    PyErr_Clear();
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_short_ipv6_address);
  }
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_addCondition); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_16pyparsing_common_7lambda56, 0, __pyx_n_s_pyparsing_common_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  if (!__pyx_t_9) {
    __pyx_t_21 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5686, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GOTREF(__pyx_t_21);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_1};
      __pyx_t_21 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5686, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_1};
      __pyx_t_21 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5686, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    {
      __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5686, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_9); __pyx_t_9 = NULL;
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5686, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":5687
 *     _short_ipv6_address = (Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6)) + "::" + Optional(_ipv6_part + (':' + _ipv6_part) * (0, 6))).setName("short IPv6 address")
 *     _short_ipv6_address.addCondition(lambda t: sum(1 for tt in t if pyparsing_common._ipv6_part.matches(tt)) < 8)
 *     _mixed_ipv6_address = ("::ffff:" + ipv4_address).setName("mixed IPv6 address")             # <<<<<<<<<<<<<<
 *     ipv6_address = Combine((_full_ipv6_address | _mixed_ipv6_address | _short_ipv6_address).setName("IPv6 address")).setName("IPv6 address")
 *     "IPv6 address (long, short, or mixed form)"
 */
  __pyx_t_21 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_ipv4_address);
  if (unlikely(!__pyx_t_21)) {
    PyErr_Clear();
    __pyx_t_21 = __Pyx_GetModuleGlobalName(__pyx_n_s_ipv4_address);
  }
  if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __pyx_t_7 = PyNumber_Add(__pyx_kp_u_ffff, __pyx_t_21); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_setName); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_21, __pyx_tuple__924, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_mixed_ipv6_address, __pyx_t_7) < 0) __PYX_ERR(0, 5687, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":5688
 *     _short_ipv6_address.addCondition(lambda t: sum(1 for tt in t if pyparsing_common._ipv6_part.matches(tt)) < 8)
 *     _mixed_ipv6_address = ("::ffff:" + ipv4_address).setName("mixed IPv6 address")
 *     ipv6_address = Combine((_full_ipv6_address | _mixed_ipv6_address | _short_ipv6_address).setName("IPv6 address")).setName("IPv6 address")             # <<<<<<<<<<<<<<
 *     "IPv6 address (long, short, or mixed form)"
 * 
 */
  __pyx_t_21 = __Pyx_GetModuleGlobalName(__pyx_n_s_Combine); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __pyx_t_8 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_full_ipv6_address);
  if (unlikely(!__pyx_t_8)) {
    PyErr_Clear();
    __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_full_ipv6_address);
  }
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_1 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_mixed_ipv6_address);
  if (unlikely(!__pyx_t_1)) {
    PyErr_Clear();
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_mixed_ipv6_address);
  }
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_9 = PyNumber_Or(__pyx_t_8, __pyx_t_1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_short_ipv6_address);
  if (unlikely(!__pyx_t_1)) {
    PyErr_Clear();
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_short_ipv6_address);
  }
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_8 = PyNumber_Or(__pyx_t_9, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_setName); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__925, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_21))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_21);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_21);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_21, function);
    }
  }
  if (!__pyx_t_1) {
    __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_21, __pyx_t_8); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5688, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GOTREF(__pyx_t_7);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_21)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_8};
      __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_21, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5688, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_21)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_8};
      __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_21, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5688, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5688, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_1); __pyx_t_1 = NULL;
      __Pyx_GIVEREF(__pyx_t_8);
      PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_8);
      __pyx_t_8 = 0;
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_21, __pyx_t_9, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5688, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_setName); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_21, __pyx_tuple__926, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_ipv6_address, __pyx_t_7) < 0) __PYX_ERR(0, 5688, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":5691
 *     "IPv6 address (long, short, or mixed form)"
 * 
 *     mac_address = Regex(r'[0-9a-fA-F]{2}([:.-])[0-9a-fA-F]{2}(?:\1[0-9a-fA-F]{2}){4}').setName("MAC address")             # <<<<<<<<<<<<<<
 *     "MAC address xx:xx:xx:xx:xx (may also have '-' or '.' delimiters)"
 * 
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__927, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_setName); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__928, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_mac_address, __pyx_t_21) < 0) __PYX_ERR(0, 5691, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":5695
 * 
 *     @staticmethod
 *     def convertToDate(fmt="%Y-%m-%d"):             # <<<<<<<<<<<<<<
 *         """
 *         Helper to create a parse action for converting parsed date string to Python datetime.date
 */
  __pyx_t_21 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_16pyparsing_common_1convertToDate, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_pyparsing_common_convertToDate, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__930)); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_21, __pyx_tuple__931);

  /* "cPyparsing.pyx":5694
 *     "MAC address xx:xx:xx:xx:xx (may also have '-' or '.' delimiters)"
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def convertToDate(fmt="%Y-%m-%d"):
 *         """
 */
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_21);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_21);
  __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_Call(__pyx_builtin_staticmethod, __pyx_t_7, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_convertToDate, __pyx_t_21) < 0) __PYX_ERR(0, 5695, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":5717
 * 
 *     @staticmethod
 *     def convertToDatetime(fmt="%Y-%m-%dT%H:%M:%S.%f"):             # <<<<<<<<<<<<<<
 *         """
 *         Helper to create a parse action for converting parsed datetime string to Python datetime.datetime
 */
  __pyx_t_21 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_16pyparsing_common_3convertToDatetime, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_pyparsing_common_convertToDateti_2, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__933)); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_21, __pyx_tuple__934);

  /* "cPyparsing.pyx":5716
 *         return cvt_fn
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def convertToDatetime(fmt="%Y-%m-%dT%H:%M:%S.%f"):
 *         """
 */
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5716, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_21);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_21);
  __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_Call(__pyx_builtin_staticmethod, __pyx_t_7, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5716, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_convertToDatetime, __pyx_t_21) < 0) __PYX_ERR(0, 5717, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":5738
 *         return cvt_fn
 * 
 *     iso8601_date = Regex(r'(?P<year>\d{4})(?:-(?P<month>\d\d)(?:-(?P<day>\d\d))?)?').setName("ISO8601 date")             # <<<<<<<<<<<<<<
 *     "ISO8601 date (C{yyyy-mm-dd})"
 * 
 */
  __pyx_t_21 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_21, __pyx_tuple__935, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_setName); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_21, __pyx_tuple__936, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_iso8601_date, __pyx_t_7) < 0) __PYX_ERR(0, 5738, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":5741
 *     "ISO8601 date (C{yyyy-mm-dd})"
 * 
 *     iso8601_datetime = Regex(r'(?P<year>\d{4})-(?P<month>\d\d)-(?P<day>\d\d)[T ](?P<hour>\d\d):(?P<minute>\d\d)(:(?P<second>\d\d(\.\d*)?)?)?(?P<tz>Z|[+-]\d\d:?\d\d)?').setName("ISO8601 datetime")             # <<<<<<<<<<<<<<
 *     "ISO8601 datetime (C{yyyy-mm-ddThh:mm:ss.s(Z|+-00:00)}) - trailing seconds, milliseconds, and timezone optional; accepts separating C{'T'} or C{' '}"
 * 
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__937, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_setName); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__938, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_iso8601_datetime, __pyx_t_21) < 0) __PYX_ERR(0, 5741, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "cPyparsing.pyx":5744
 *     "ISO8601 datetime (C{yyyy-mm-ddThh:mm:ss.s(Z|+-00:00)}) - trailing seconds, milliseconds, and timezone optional; accepts separating C{'T'} or C{' '}"
 * 
 *     uuid = Regex(r'[0-9a-fA-F]{8}(-[0-9a-fA-F]{4}){3}-[0-9a-fA-F]{12}').setName("UUID")             # <<<<<<<<<<<<<<
 *     "UUID (C{xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx})"
 * 
 */
  __pyx_t_21 = __Pyx_GetModuleGlobalName(__pyx_n_s_Regex); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_21, __pyx_tuple__939, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_setName); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_21, __pyx_tuple__940, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_uuid, __pyx_t_7) < 0) __PYX_ERR(0, 5744, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "cPyparsing.pyx":5747
 *     "UUID (C{xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx})"
 * 
 *     _html_stripper = anyOpenTag.suppress() | anyCloseTag.suppress()             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
  __pyx_t_21 = __Pyx_GetModuleGlobalName(__pyx_n_s_anyOpenTag); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_suppress); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_21 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_21)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_21);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  if (__pyx_t_21) {
    __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_21); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5747, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  } else {
    __pyx_t_7 = __Pyx_PyObject_CallNoArg(__pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5747, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_21 = __Pyx_GetModuleGlobalName(__pyx_n_s_anyCloseTag); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_suppress); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_21 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_21)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_21);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  if (__pyx_t_21) {
    __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_21); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5747, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  } else {
    __pyx_t_9 = __Pyx_PyObject_CallNoArg(__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5747, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = PyNumber_Or(__pyx_t_7, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_html_stripper, __pyx_t_8) < 0) __PYX_ERR(0, 5747, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5750
 * 
 *     @staticmethod
 *     def stripHTMLTags(s, l, tokens):             # <<<<<<<<<<<<<<
 *         """
 *         Parse action to remove HTML tags from web page HTML source
 */
  __pyx_t_8 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_16pyparsing_common_5stripHTMLTags, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_n_s_pyparsing_common_stripHTMLTags, NULL, __pyx_n_s_cPyparsing, __pyx_d, ((PyObject *)__pyx_codeobj__942)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);

  /* "cPyparsing.pyx":5749
 *     _html_stripper = anyOpenTag.suppress() | anyCloseTag.suppress()
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def stripHTMLTags(s, l, tokens):
 *         """
 */
  __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_8);
  PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8);
  __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_staticmethod, __pyx_t_9, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_stripHTMLTags, __pyx_t_8) < 0) __PYX_ERR(0, 5750, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5764
 *         return pyparsing_common._html_stripper.transformString(tokens[0])
 * 
 *     _commasepitem = Combine(OneOrMore(~Literal(",") + ~LineEnd() + Word(printables, excludeChars=',')             # <<<<<<<<<<<<<<
 *                                       + Optional(White(" \t")))).streamline().setName("commaItem")
 *     comma_separated_list = delimitedList(Optional(quotedString.copy() | _commasepitem, default="")).setName("comma separated list")
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_Combine); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_OneOrMore); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_Literal); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_tuple__943, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = PyNumber_Invert(__pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_23 = __Pyx_GetModuleGlobalName(__pyx_n_s_LineEnd); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 5764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  __pyx_t_19 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_23))) {
    __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_23);
    if (likely(__pyx_t_19)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_23);
      __Pyx_INCREF(__pyx_t_19);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_23, function);
    }
  }
  if (__pyx_t_19) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_23, __pyx_t_19); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5764, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_23); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5764, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
  __pyx_t_23 = PyNumber_Invert(__pyx_t_2); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 5764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_13, __pyx_t_23); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
  __pyx_t_23 = __Pyx_GetModuleGlobalName(__pyx_n_s_Word); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 5764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_printables); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_19 = PyTuple_New(1); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 5764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_19, 0, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = PyDict_New(); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_excludeChars, __pyx_kp_u__132) < 0) __PYX_ERR(0, 5764, __pyx_L1_error)
  __pyx_t_22 = __Pyx_PyObject_Call(__pyx_t_23, __pyx_t_19, __pyx_t_13); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 5764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = PyNumber_Add(__pyx_t_2, __pyx_t_22); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;

  /* "cPyparsing.pyx":5765
 * 
 *     _commasepitem = Combine(OneOrMore(~Literal(",") + ~LineEnd() + Word(printables, excludeChars=',')
 *                                       + Optional(White(" \t")))).streamline().setName("commaItem")             # <<<<<<<<<<<<<<
 *     comma_separated_list = delimitedList(Optional(quotedString.copy() | _commasepitem, default="")).setName("comma separated list")
 *     """Predefined expression of 1 or more printable words or quoted strings, separated by commas."""
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_19 = __Pyx_GetModuleGlobalName(__pyx_n_s_White); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 5765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_23 = __Pyx_PyObject_Call(__pyx_t_19, __pyx_tuple__944, NULL); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 5765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_19)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_19);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_19) {
    __pyx_t_22 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_23); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 5765, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
    __Pyx_GOTREF(__pyx_t_22);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_19, __pyx_t_23};
      __pyx_t_22 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 5765, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
      __Pyx_GOTREF(__pyx_t_22);
      __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_19, __pyx_t_23};
      __pyx_t_22 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 5765, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
      __Pyx_GOTREF(__pyx_t_22);
      __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
    } else
    #endif
    {
      __pyx_t_24 = PyTuple_New(1+1); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 5765, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_24);
      __Pyx_GIVEREF(__pyx_t_19); PyTuple_SET_ITEM(__pyx_t_24, 0, __pyx_t_19); __pyx_t_19 = NULL;
      __Pyx_GIVEREF(__pyx_t_23);
      PyTuple_SET_ITEM(__pyx_t_24, 0+1, __pyx_t_23);
      __pyx_t_23 = 0;
      __pyx_t_22 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_24, NULL); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 5765, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_22);
      __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_13, __pyx_t_22); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (!__pyx_t_22) {
    __pyx_t_21 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5764, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_21);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_22, __pyx_t_2};
      __pyx_t_21 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5764, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[2] = {__pyx_t_22, __pyx_t_2};
      __pyx_t_21 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5764, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5764, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_GIVEREF(__pyx_t_22); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_22); __pyx_t_22 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_13, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5764, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  if (!__pyx_t_1) {
    __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_21); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5764, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __Pyx_GOTREF(__pyx_t_9);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_21};
      __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5764, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_21};
      __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5764, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    } else
    #endif
    {
      __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5764, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_1); __pyx_t_1 = NULL;
      __Pyx_GIVEREF(__pyx_t_21);
      PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_t_21);
      __pyx_t_21 = 0;
      __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_13, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5764, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_streamline); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  if (__pyx_t_9) {
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5765, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  } else {
    __pyx_t_8 = __Pyx_PyObject_CallNoArg(__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5765, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_setName); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__945, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_commasepitem, __pyx_t_8) < 0) __PYX_ERR(0, 5764, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5766
 *     _commasepitem = Combine(OneOrMore(~Literal(",") + ~LineEnd() + Word(printables, excludeChars=',')
 *                                       + Optional(White(" \t")))).streamline().setName("commaItem")
 *     comma_separated_list = delimitedList(Optional(quotedString.copy() | _commasepitem, default="")).setName("comma separated list")             # <<<<<<<<<<<<<<
 *     """Predefined expression of 1 or more printable words or quoted strings, separated by commas."""
 * 
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_delimitedList); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_Optional); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_21 = __Pyx_GetModuleGlobalName(__pyx_n_s_quotedString); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_copy); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_21 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_21)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_21);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (__pyx_t_21) {
    __pyx_t_13 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_21); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5766, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  } else {
    __pyx_t_13 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5766, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetItem(__pyx_t_17, __pyx_n_s_commasepitem);
  if (unlikely(!__pyx_t_1)) {
    PyErr_Clear();
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_commasepitem);
  }
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_21 = PyNumber_Or(__pyx_t_13, __pyx_t_1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_21);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_21);
  __pyx_t_21 = 0;
  __pyx_t_21 = PyDict_New(); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  if (PyDict_SetItem(__pyx_t_21, __pyx_n_s_default, __pyx_kp_u__9) < 0) __PYX_ERR(0, 5766, __pyx_L1_error)
  __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_1, __pyx_t_21); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_21 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_21)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_21);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  if (!__pyx_t_21) {
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_13); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5766, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_GOTREF(__pyx_t_8);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_21, __pyx_t_13};
      __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5766, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_21, __pyx_t_13};
      __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5766, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    } else
    #endif
    {
      __pyx_t_1 = PyTuple_New(1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5766, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_21); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_21); __pyx_t_21 = NULL;
      __Pyx_GIVEREF(__pyx_t_13);
      PyTuple_SET_ITEM(__pyx_t_1, 0+1, __pyx_t_13);
      __pyx_t_13 = 0;
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_1, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5766, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_setName); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__946, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_comma_separated_list_2, __pyx_t_8) < 0) __PYX_ERR(0, 5766, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5769
 *     """Predefined expression of 1 or more printable words or quoted strings, separated by commas."""
 * 
 *     upcaseTokens = staticmethod(tokenMap(lambda t: _ustr(t).upper()))             # <<<<<<<<<<<<<<
 *     """Parse action to convert tokens to upper case."""
 * 
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_tokenMap); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_16pyparsing_common_8lambda58, 0, __pyx_n_s_pyparsing_common_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  if (!__pyx_t_13) {
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5769, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GOTREF(__pyx_t_8);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_1};
      __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5769, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_1};
      __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5769, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    {
      __pyx_t_21 = PyTuple_New(1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5769, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_21);
      __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_21, 0, __pyx_t_13); __pyx_t_13 = NULL;
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_21, 0+1, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_21, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5769, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_8);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_8);
  __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_staticmethod, __pyx_t_7, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_upcaseTokens, __pyx_t_8) < 0) __PYX_ERR(0, 5769, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5772
 *     """Parse action to convert tokens to upper case."""
 * 
 *     downcaseTokens = staticmethod(tokenMap(lambda t: _ustr(t).lower()))             # <<<<<<<<<<<<<<
 *     """Parse action to convert tokens to lower case."""
 * 
 */
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_tokenMap); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5772, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_21 = __Pyx_CyFunction_NewEx(&__pyx_mdef_10cPyparsing_16pyparsing_common_9lambda59, 0, __pyx_n_s_pyparsing_common_lambda, NULL, __pyx_n_s_cPyparsing, __pyx_d, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5772, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  if (!__pyx_t_1) {
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_21); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5772, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __Pyx_GOTREF(__pyx_t_8);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_21};
      __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5772, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_21};
      __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5772, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    } else
    #endif
    {
      __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5772, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_1); __pyx_t_1 = NULL;
      __Pyx_GIVEREF(__pyx_t_21);
      PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_t_21);
      __pyx_t_21 = 0;
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5772, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5772, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_8);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_8);
  __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_staticmethod, __pyx_t_7, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5772, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyObject_SetItem(__pyx_t_17, __pyx_n_s_downcaseTokens, __pyx_t_8) < 0) __PYX_ERR(0, 5772, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "cPyparsing.pyx":5501
 * 
 * 
 * class pyparsing_common:             # <<<<<<<<<<<<<<
 *     """
 *     Here are some common low-level expressions that may be useful in jump-starting parser development:
 */
  __pyx_t_8 = __Pyx_Py3ClassCreate(((PyObject*)&__Pyx_DefaultClassType), __pyx_n_s_pyparsing_common, __pyx_empty_tuple, __pyx_t_17, NULL, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyparsing_common, __pyx_t_8) < 0) __PYX_ERR(0, 5501, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

  /* "cPyparsing.pyx":5776
 * 
 * 
 * if __name__ == "__main__":             # <<<<<<<<<<<<<<
 * 
 *     selectToken = CaselessLiteral("select")
 */
  __pyx_t_17 = __Pyx_GetModuleGlobalName(__pyx_n_s_name_2); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __pyx_t_18 = (__Pyx_PyUnicode_Equals(__pyx_t_17, __pyx_n_u_main, Py_EQ)); if (unlikely(__pyx_t_18 < 0)) __PYX_ERR(0, 5776, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (__pyx_t_18) {

    /* "cPyparsing.pyx":5778
 * if __name__ == "__main__":
 * 
 *     selectToken = CaselessLiteral("select")             # <<<<<<<<<<<<<<
 *     fromToken = CaselessLiteral("from")
 * 
 */
    __pyx_t_17 = __Pyx_GetModuleGlobalName(__pyx_n_s_CaselessLiteral); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5778, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_17, __pyx_tuple__947, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5778, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_selectToken, __pyx_t_8) < 0) __PYX_ERR(0, 5778, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "cPyparsing.pyx":5779
 * 
 *     selectToken = CaselessLiteral("select")
 *     fromToken = CaselessLiteral("from")             # <<<<<<<<<<<<<<
 * 
 *     ident = Word(alphas, alphanums + "_$")
 */
    __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_CaselessLiteral); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5779, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_tuple__948, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5779, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_fromToken, __pyx_t_17) < 0) __PYX_ERR(0, 5779, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

    /* "cPyparsing.pyx":5781
 *     fromToken = CaselessLiteral("from")
 * 
 *     ident = Word(alphas, alphanums + "_$")             # <<<<<<<<<<<<<<
 * 
 *     columnName = delimitedList(ident, ".", combine=True).setParseAction(upcaseTokens)
 */
    __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_Word); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5781, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_alphas); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5781, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_alphanums); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5781, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_21 = PyNumber_Add(__pyx_t_13, __pyx_kp_u__508); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5781, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_13)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
        __pyx_t_6 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_8)) {
      PyObject *__pyx_temp[3] = {__pyx_t_13, __pyx_t_7, __pyx_t_21};
      __pyx_t_17 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5781, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
      PyObject *__pyx_temp[3] = {__pyx_t_13, __pyx_t_7, __pyx_t_21};
      __pyx_t_17 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5781, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    } else
    #endif
    {
      __pyx_t_1 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5781, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (__pyx_t_13) {
        __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_13); __pyx_t_13 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_1, 0+__pyx_t_6, __pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_21);
      PyTuple_SET_ITEM(__pyx_t_1, 1+__pyx_t_6, __pyx_t_21);
      __pyx_t_7 = 0;
      __pyx_t_21 = 0;
      __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_1, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5781, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_ident, __pyx_t_17) < 0) __PYX_ERR(0, 5781, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

    /* "cPyparsing.pyx":5783
 *     ident = Word(alphas, alphanums + "_$")
 * 
 *     columnName = delimitedList(ident, ".", combine=True).setParseAction(upcaseTokens)             # <<<<<<<<<<<<<<
 *     columnNameList = Group(delimitedList(columnName)).setName("columns")
 *     columnSpec = ('*' | columnNameList)
 */
    __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_delimitedList); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ident); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_21 = PyTuple_New(2); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_21, 0, __pyx_t_1);
    __Pyx_INCREF(__pyx_kp_u__129);
    __Pyx_GIVEREF(__pyx_kp_u__129);
    PyTuple_SET_ITEM(__pyx_t_21, 1, __pyx_kp_u__129);
    __pyx_t_1 = 0;
    __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_combine, Py_True) < 0) __PYX_ERR(0, 5783, __pyx_L1_error)
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_21, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_upcaseTokens); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_21 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_21 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_21)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_21);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (!__pyx_t_21) {
      __pyx_t_17 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_7); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5783, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_17);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_21, __pyx_t_7};
        __pyx_t_17 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5783, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
        __Pyx_GOTREF(__pyx_t_17);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_21, __pyx_t_7};
        __pyx_t_17 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5783, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
        __Pyx_GOTREF(__pyx_t_17);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5783, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_21); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_21); __pyx_t_21 = NULL;
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_8, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5783, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_17);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_columnName, __pyx_t_17) < 0) __PYX_ERR(0, 5783, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

    /* "cPyparsing.pyx":5784
 * 
 *     columnName = delimitedList(ident, ".", combine=True).setParseAction(upcaseTokens)
 *     columnNameList = Group(delimitedList(columnName)).setName("columns")             # <<<<<<<<<<<<<<
 *     columnSpec = ('*' | columnNameList)
 * 
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5784, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_delimitedList); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5784, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_21 = __Pyx_GetModuleGlobalName(__pyx_n_s_columnName); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5784, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_21);
    __pyx_t_13 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_13)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    if (!__pyx_t_13) {
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_21); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5784, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
      __Pyx_GOTREF(__pyx_t_8);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_21};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5784, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_21};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5784, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5784, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_13); __pyx_t_13 = NULL;
        __Pyx_GIVEREF(__pyx_t_21);
        PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_21);
        __pyx_t_21 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_9, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5784, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (!__pyx_t_7) {
      __pyx_t_17 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_8); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5784, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_17);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_8};
        __pyx_t_17 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5784, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_17);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_8};
        __pyx_t_17 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5784, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_17);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5784, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_9, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5784, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_17);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_setName); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5784, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__949, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5784, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_columnNameList, __pyx_t_17) < 0) __PYX_ERR(0, 5784, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

    /* "cPyparsing.pyx":5785
 *     columnName = delimitedList(ident, ".", combine=True).setParseAction(upcaseTokens)
 *     columnNameList = Group(delimitedList(columnName)).setName("columns")
 *     columnSpec = ('*' | columnNameList)             # <<<<<<<<<<<<<<
 * 
 *     tableName = delimitedList(ident, ".", combine=True).setParseAction(upcaseTokens)
 */
    __pyx_t_17 = __Pyx_GetModuleGlobalName(__pyx_n_s_columnNameList); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5785, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    __pyx_t_1 = PyNumber_Or(__pyx_kp_u__38, __pyx_t_17); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5785, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_columnSpec, __pyx_t_1) < 0) __PYX_ERR(0, 5785, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5787
 *     columnSpec = ('*' | columnNameList)
 * 
 *     tableName = delimitedList(ident, ".", combine=True).setParseAction(upcaseTokens)             # <<<<<<<<<<<<<<
 *     tableNameList = Group(delimitedList(tableName)).setName("tables")
 * 
 */
    __pyx_t_17 = __Pyx_GetModuleGlobalName(__pyx_n_s_delimitedList); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5787, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_ident); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5787, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5787, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_9);
    PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_9);
    __Pyx_INCREF(__pyx_kp_u__129);
    __Pyx_GIVEREF(__pyx_kp_u__129);
    PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_kp_u__129);
    __pyx_t_9 = 0;
    __pyx_t_9 = PyDict_New(); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5787, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_combine, Py_True) < 0) __PYX_ERR(0, 5787, __pyx_L1_error)
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_17, __pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5787, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5787, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_upcaseTokens); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5787, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
      }
    }
    if (!__pyx_t_8) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5787, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5787, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5787, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_17 = PyTuple_New(1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5787, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_17);
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_t_8); __pyx_t_8 = NULL;
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_17, 0+1, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_17, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5787, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_tableName, __pyx_t_1) < 0) __PYX_ERR(0, 5787, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5788
 * 
 *     tableName = delimitedList(ident, ".", combine=True).setParseAction(upcaseTokens)
 *     tableNameList = Group(delimitedList(tableName)).setName("tables")             # <<<<<<<<<<<<<<
 * 
 *     simpleSQL = selectToken("command") + columnSpec("columns") + fromToken + tableNameList("tables")
 */
    __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_Group); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_delimitedList); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_tableName); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_21 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_21 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_21)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_21);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    if (!__pyx_t_21) {
      __pyx_t_17 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5788, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_17);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_21, __pyx_t_8};
        __pyx_t_17 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5788, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
        __Pyx_GOTREF(__pyx_t_17);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_21, __pyx_t_8};
        __pyx_t_17 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5788, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
        __Pyx_GOTREF(__pyx_t_17);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5788, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_GIVEREF(__pyx_t_21); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_21); __pyx_t_21 = NULL;
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_13, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5788, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_17);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
      }
    }
    if (!__pyx_t_7) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_17); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5788, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_17};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5788, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_17};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5788, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5788, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_7); __pyx_t_7 = NULL;
        __Pyx_GIVEREF(__pyx_t_17);
        PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_t_17);
        __pyx_t_17 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_13, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5788, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_setName); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__950, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_tableNameList, __pyx_t_1) < 0) __PYX_ERR(0, 5788, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5790
 *     tableNameList = Group(delimitedList(tableName)).setName("tables")
 * 
 *     simpleSQL = selectToken("command") + columnSpec("columns") + fromToken + tableNameList("tables")             # <<<<<<<<<<<<<<
 * 
 *     # demo runTests method, including embedded comments in test string
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_selectToken); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5790, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__951, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5790, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_columnSpec); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5790, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__952, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5790, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Add(__pyx_t_9, __pyx_t_13); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5790, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_fromToken); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5790, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_9 = PyNumber_Add(__pyx_t_1, __pyx_t_13); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5790, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_tableNameList); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5790, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_tuple__953, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5790, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = PyNumber_Add(__pyx_t_9, __pyx_t_1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5790, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_simpleSQL, __pyx_t_13) < 0) __PYX_ERR(0, 5790, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

    /* "cPyparsing.pyx":5793
 * 
 *     # demo runTests method, including embedded comments in test string
 *     simpleSQL.runTests("""             # <<<<<<<<<<<<<<
 *         # '*' as column list and dotted table name
 *         select * from SYS.XYZZY
 */
    __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_simpleSQL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5793, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_runTests); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5793, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__954, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5793, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

    /* "cPyparsing.pyx":5817
 *         """)
 * 
 *     pyparsing_common.number.runTests("""             # <<<<<<<<<<<<<<
 *         100
 *         -100
 */
    __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_pyparsing_common); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5817, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_number); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5817, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_runTests); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5817, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_tuple__955, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5817, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5827
 * 
 *     # any int or real number, returned as float
 *     pyparsing_common.fnumber.runTests("""             # <<<<<<<<<<<<<<
 *         100
 *         -100
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_pyparsing_common); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_fnumber); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_runTests); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__956, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

    /* "cPyparsing.pyx":5836
 *         """)
 * 
 *     pyparsing_common.hex_integer.runTests("""             # <<<<<<<<<<<<<<
 *         100
 *         FF
 */
    __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_pyparsing_common); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5836, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_hex_integer_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5836, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_runTests); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5836, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_tuple__957, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5836, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5841
 *         """)
 * 
 *     import uuid             # <<<<<<<<<<<<<<
 *     pyparsing_common.uuid.setParseAction(tokenMap(uuid.UUID))
 *     pyparsing_common.uuid.runTests("""
 */
    __pyx_t_1 = __Pyx_Import(__pyx_n_s_uuid, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5841, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_uuid, __pyx_t_1) < 0) __PYX_ERR(0, 5841, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5842
 * 
 *     import uuid
 *     pyparsing_common.uuid.setParseAction(tokenMap(uuid.UUID))             # <<<<<<<<<<<<<<
 *     pyparsing_common.uuid.runTests("""
 *         12345678-1234-5678-1234-567812345678
 */
    __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_pyparsing_common); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5842, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_uuid); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5842, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_setParseAction); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5842, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_17 = __Pyx_GetModuleGlobalName(__pyx_n_s_tokenMap); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5842, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_17);
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_uuid); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5842, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_UUID); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5842, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_17))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_17);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_17, function);
      }
    }
    if (!__pyx_t_7) {
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5842, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_9);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_17)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_8};
        __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_17, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5842, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_17)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_8};
        __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_17, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5842, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_21 = PyTuple_New(1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5842, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_21);
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_21, 0, __pyx_t_7); __pyx_t_7 = NULL;
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_21, 0+1, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_17, __pyx_t_21, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5842, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
    __pyx_t_17 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
      __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_13);
      if (likely(__pyx_t_17)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
        __Pyx_INCREF(__pyx_t_17);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_13, function);
      }
    }
    if (!__pyx_t_17) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5842, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_13)) {
        PyObject *__pyx_temp[2] = {__pyx_t_17, __pyx_t_9};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5842, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_13)) {
        PyObject *__pyx_temp[2] = {__pyx_t_17, __pyx_t_9};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5842, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_21 = PyTuple_New(1+1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 5842, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_21);
        __Pyx_GIVEREF(__pyx_t_17); PyTuple_SET_ITEM(__pyx_t_21, 0, __pyx_t_17); __pyx_t_17 = NULL;
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_21, 0+1, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_21, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5842, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cPyparsing.pyx":5843
 *     import uuid
 *     pyparsing_common.uuid.setParseAction(tokenMap(uuid.UUID))
 *     pyparsing_common.uuid.runTests("""             # <<<<<<<<<<<<<<
 *         12345678-1234-5678-1234-567812345678
 *         """)
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_pyparsing_common); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_uuid); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_runTests); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__958, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

    /* "cPyparsing.pyx":5776
 * 
 * 
 * if __name__ == "__main__":             # <<<<<<<<<<<<<<
 * 
 *     selectToken = CaselessLiteral("select")
 */
  }

  /* "cPyparsing.pyx":1
 * # -*- coding: utf-8 -*-             # <<<<<<<<<<<<<<
 * 
 * #-----------------------------------------------------------------------------------------------------------------------
 */
  __pyx_t_13 = PyDict_New(); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_13) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_XDECREF(__pyx_t_21);
  __Pyx_XDECREF(__pyx_t_22);
  __Pyx_XDECREF(__pyx_t_23);
  __Pyx_XDECREF(__pyx_t_24);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init cPyparsing", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_DECREF(__pyx_m); __pyx_m = 0;
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init cPyparsing");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if PY_MAJOR_VERSION < 3
  return;
  #else
  return __pyx_m;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule((char *)modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, (char *)"RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* GetModuleGlobalName */
static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name) {
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
    result = PyDict_GetItem(__pyx_d, name);
    if (likely(result)) {
        Py_INCREF(result);
    } else {
#else
    result = PyObject_GetItem(__pyx_d, name);
    if (!result) {
        PyErr_Clear();
#endif
        result = __Pyx_GetBuiltinName(name);
    }
    return result;
}

/* PyObjectCall */
  #if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* RaiseArgTupleInvalid */
  static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* RaiseDoubleKeywords */
  static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
  static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_CheckExact(key)) || likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (PyUnicode_GET_SIZE(**name) != PyUnicode_GET_SIZE(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (PyUnicode_GET_SIZE(**argname) != PyUnicode_GET_SIZE(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* GetItemInt */
  static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (wraparound & unlikely(i < 0)) i += PyList_GET_SIZE(o);
    if ((!boundscheck) || likely((0 <= i) & (i < PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (wraparound & unlikely(i < 0)) i += PyTuple_GET_SIZE(o);
    if ((!boundscheck) || likely((0 <= i) & (i < PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely((n >= 0) & (n < PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely((n >= 0) & (n < PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* PyCFunctionFastCall */
  #if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    return (*((__Pyx_PyCFunctionFast)meth)) (self, args, nargs, NULL);
}
#endif  // CYTHON_FAST_PYCCALL

/* PyFunctionFastCall */
  #if CYTHON_FAST_PYCALL
#include "frameobject.h"
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = PyThreadState_GET();
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = f->f_localsplus;
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, int nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif  // CPython < 3.6
#endif  // CYTHON_FAST_PYCALL

/* PyObjectCallMethO */
  #if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallOneArg */
  #if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || PyObject_TypeCheck(func, __pyx_CyFunctionType))) {
#else
    if (likely(PyCFunction_Check(func))) {
#endif
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (PyCFunction_GET_FLAGS(func) & METH_FASTCALL) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* SliceObject */
    static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, CYTHON_UNUSED int wraparound) {
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_slice(obj, cstart, cstop);
    }
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    PyErr_Format(PyExc_TypeError,
        "'%.200s' object is unsliceable", Py_TYPE(obj)->tp_name);
bad:
    return NULL;
}

/* PyObjectCallNoArg */
    #if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, NULL, 0);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || PyObject_TypeCheck(func, __pyx_CyFunctionType))) {
#else
    if (likely(PyCFunction_Check(func))) {
#endif
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

/* RaiseTooManyValuesToUnpack */
      static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
      static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* IterFinish */
      static CYTHON_INLINE int __Pyx_IterFinish(void) {
#if CYTHON_FAST_THREAD_STATE
    PyThreadState *tstate = PyThreadState_GET();
    PyObject* exc_type = tstate->curexc_type;
    if (unlikely(exc_type)) {
        if (likely(exc_type == PyExc_StopIteration) || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)) {
            PyObject *exc_value, *exc_tb;
            exc_value = tstate->curexc_value;
            exc_tb = tstate->curexc_traceback;
            tstate->curexc_type = 0;
            tstate->curexc_value = 0;
            tstate->curexc_traceback = 0;
            Py_DECREF(exc_type);
            Py_XDECREF(exc_value);
            Py_XDECREF(exc_tb);
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#else
    if (unlikely(PyErr_Occurred())) {
        if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) {
            PyErr_Clear();
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#endif
}

/* UnpackItemEndCheck */
      static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    } else {
        return __Pyx_IterFinish();
    }
    return 0;
}

/* BytesEquals */
      static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
      static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* PyErrFetchRestore */
      #if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* RaiseException */
      #if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    __Pyx_PyThreadState_declare
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
#if PY_VERSION_HEX >= 0x03030000
    if (cause) {
#else
    if (cause && cause != Py_None) {
#endif
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = PyThreadState_GET();
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* PyIntBinop */
        #if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, CYTHON_UNUSED int inplace) {
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a - b);
            if (likely((x^a) >= 0 || (x^~b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                default: return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
            }
        }
                x = a - b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla - llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("subtract", return NULL)
            result = ((double)a) - (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceSubtract : PyNumber_Subtract)(op1, op2);
}
#endif

/* SaveResetException */
        #if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
#endif

/* PyErrExceptionMatches */
        #if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    PyObject *exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
    return PyErr_GivenExceptionMatches(exc_type, err);
}
#endif

/* GetException */
        #if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb) {
#endif
    PyObject *local_type, *local_value, *local_tb;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* PyIntBinop */
          #if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, CYTHON_UNUSED int inplace) {
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a + b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* PyObjectCallMethod0 */
          static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
    PyObject *method, *result = NULL;
    method = __Pyx_PyObject_GetAttrStr(obj, method_name);
    if (unlikely(!method)) goto bad;
#if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(method))) {
        PyObject *self = PyMethod_GET_SELF(method);
        if (likely(self)) {
            PyObject *function = PyMethod_GET_FUNCTION(method);
            result = __Pyx_PyObject_CallOneArg(function, self);
            Py_DECREF(method);
            return result;
        }
    }
#endif
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
}

/* RaiseNoneIterError */
          static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* UnpackTupleError */
          static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else if (PyTuple_GET_SIZE(t) < index) {
      __Pyx_RaiseNeedMoreValuesError(PyTuple_GET_SIZE(t));
    } else {
      __Pyx_RaiseTooManyValuesError(index);
    }
}

/* UnpackTuple2 */
          static CYTHON_INLINE int __Pyx_unpack_tuple2(PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2,
                                             int is_tuple, int has_known_size, int decref_tuple) {
    Py_ssize_t index;
    PyObject *value1 = NULL, *value2 = NULL, *iter = NULL;
    if (!is_tuple && unlikely(!PyTuple_Check(tuple))) {
        iternextfunc iternext;
        iter = PyObject_GetIter(tuple);
        if (unlikely(!iter)) goto bad;
        if (decref_tuple) { Py_DECREF(tuple); tuple = NULL; }
        iternext = Py_TYPE(iter)->tp_iternext;
        value1 = iternext(iter); if (unlikely(!value1)) { index = 0; goto unpacking_failed; }
        value2 = iternext(iter); if (unlikely(!value2)) { index = 1; goto unpacking_failed; }
        if (!has_known_size && unlikely(__Pyx_IternextUnpackEndCheck(iternext(iter), 2))) goto bad;
        Py_DECREF(iter);
    } else {
        if (!has_known_size && unlikely(PyTuple_GET_SIZE(tuple) != 2)) {
            __Pyx_UnpackTupleError(tuple, 2);
            goto bad;
        }
#if CYTHON_COMPILING_IN_PYPY
        value1 = PySequence_ITEM(tuple, 0);
        if (unlikely(!value1)) goto bad;
        value2 = PySequence_ITEM(tuple, 1);
        if (unlikely(!value2)) goto bad;
#else
        value1 = PyTuple_GET_ITEM(tuple, 0);
        value2 = PyTuple_GET_ITEM(tuple, 1);
        Py_INCREF(value1);
        Py_INCREF(value2);
#endif
        if (decref_tuple) { Py_DECREF(tuple); }
    }
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
unpacking_failed:
    if (!has_known_size && __Pyx_IterFinish() == 0)
        __Pyx_RaiseNeedMoreValuesError(index);
bad:
    Py_XDECREF(iter);
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
}

/* dict_iter */
          static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* iterable, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_source_is_dict) {
    is_dict = is_dict || likely(PyDict_CheckExact(iterable));
    *p_source_is_dict = is_dict;
#if !CYTHON_COMPILING_IN_PYPY
    if (is_dict) {
        *p_orig_length = PyDict_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
    }
#endif
    *p_orig_length = 0;
    if (method_name) {
        PyObject* iter;
        iterable = __Pyx_PyObject_CallMethod0(iterable, method_name);
        if (!iterable)
            return NULL;
#if !CYTHON_COMPILING_IN_PYPY
        if (PyTuple_CheckExact(iterable) || PyList_CheckExact(iterable))
            return iterable;
#endif
        iter = PyObject_GetIter(iterable);
        Py_DECREF(iterable);
        return iter;
    }
    return PyObject_GetIter(iterable);
}
static CYTHON_INLINE int __Pyx_dict_iter_next(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem, int source_is_dict) {
    PyObject* next_item;
#if !CYTHON_COMPILING_IN_PYPY
    if (source_is_dict) {
        PyObject *key, *value;
        if (unlikely(orig_length != PyDict_Size(iter_obj))) {
            PyErr_SetString(PyExc_RuntimeError, "dictionary changed size during iteration");
            return -1;
        }
        if (unlikely(!PyDict_Next(iter_obj, ppos, &key, &value))) {
            return 0;
        }
        if (pitem) {
            PyObject* tuple = PyTuple_New(2);
            if (unlikely(!tuple)) {
                return -1;
            }
            Py_INCREF(key);
            Py_INCREF(value);
            PyTuple_SET_ITEM(tuple, 0, key);
            PyTuple_SET_ITEM(tuple, 1, value);
            *pitem = tuple;
        } else {
            if (pkey) {
                Py_INCREF(key);
                *pkey = key;
            }
            if (pvalue) {
                Py_INCREF(value);
                *pvalue = value;
            }
        }
        return 1;
    } else if (PyTuple_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyTuple_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyTuple_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else if (PyList_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyList_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyList_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else
#endif
    {
        next_item = PyIter_Next(iter_obj);
        if (unlikely(!next_item)) {
            return __Pyx_IterFinish();
        }
    }
    if (pitem) {
        *pitem = next_item;
    } else if (pkey && pvalue) {
        if (__Pyx_unpack_tuple2(next_item, pkey, pvalue, source_is_dict, source_is_dict, 1))
            return -1;
    } else if (pkey) {
        *pkey = next_item;
    } else {
        *pvalue = next_item;
    }
    return 1;
}

/* None */
          static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname) {
    PyErr_Format(PyExc_NameError, "free variable '%s' referenced before assignment in enclosing scope", varname);
}

/* PyObjectCallMethod1 */
          static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
    PyObject *method, *result = NULL;
    method = __Pyx_PyObject_GetAttrStr(obj, method_name);
    if (unlikely(!method)) goto done;
#if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(method))) {
        PyObject *self = PyMethod_GET_SELF(method);
        if (likely(self)) {
            PyObject *args;
            PyObject *function = PyMethod_GET_FUNCTION(method);
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(function)) {
                PyObject *args[2] = {self, arg};
                result = __Pyx_PyFunction_FastCall(function, args, 2);
                goto done;
            }
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(function)) {
                PyObject *args[2] = {self, arg};
                result = __Pyx_PyCFunction_FastCall(function, args, 2);
                goto done;
            }
            #endif
            args = PyTuple_New(2);
            if (unlikely(!args)) goto done;
            Py_INCREF(self);
            PyTuple_SET_ITEM(args, 0, self);
            Py_INCREF(arg);
            PyTuple_SET_ITEM(args, 1, arg);
            Py_INCREF(function);
            Py_DECREF(method); method = NULL;
            result = __Pyx_PyObject_Call(function, args, NULL);
            Py_DECREF(args);
            Py_DECREF(function);
            return result;
        }
    }
#endif
    result = __Pyx_PyObject_CallOneArg(method, arg);
done:
    Py_XDECREF(method);
    return result;
}

/* append */
          static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x) {
    if (likely(PyList_CheckExact(L))) {
        if (unlikely(__Pyx_PyList_Append(L, x) < 0)) return -1;
    } else {
        PyObject* retval = __Pyx_PyObject_CallMethod1(L, __pyx_n_s_append, x);
        if (unlikely(!retval))
            return -1;
        Py_DECREF(retval);
    }
    return 0;
}

/* SliceObject */
          static CYTHON_INLINE int __Pyx_PyObject_SetSlice(PyObject* obj, PyObject* value,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, CYTHON_UNUSED int wraparound) {
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_ass_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_ass_slice(obj, cstart, cstop, value);
    }
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_ass_subscript))
#endif
    {
        int result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_ass_subscript(obj, py_slice, value);
#else
        result = value ? PyObject_SetItem(obj, py_slice, value) : PyObject_DelItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    PyErr_Format(PyExc_TypeError,
        "'%.200s' object does not support slice %.10s",
        Py_TYPE(obj)->tp_name, value ? "assignment" : "deletion");
bad:
    return -1;
}

/* FetchCommonType */
          static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* fake_module;
    PyTypeObject* cached_type = NULL;
    fake_module = PyImport_AddModule((char*) "_cython_" CYTHON_ABI);
    if (!fake_module) return NULL;
    Py_INCREF(fake_module);
    cached_type = (PyTypeObject*) PyObject_GetAttrString(fake_module, type->tp_name);
    if (cached_type) {
        if (!PyType_Check((PyObject*)cached_type)) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s is not a type object",
                type->tp_name);
            goto bad;
        }
        if (cached_type->tp_basicsize != type->tp_basicsize) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s has the wrong size, try recompiling",
                type->tp_name);
            goto bad;
        }
    } else {
        if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
        PyErr_Clear();
        if (PyType_Ready(type) < 0) goto bad;
        if (PyObject_SetAttrString(fake_module, type->tp_name, (PyObject*) type) < 0)
            goto bad;
        Py_INCREF(type);
        cached_type = type;
    }
done:
    Py_DECREF(fake_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* CythonFunction */
          static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *closure)
{
    if (unlikely(op->func_doc == NULL)) {
        if (op->func.m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(op->func.m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(op->func.m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp = op->func_doc;
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    op->func_doc = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(op->func.m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(op->func.m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
#else
    if (unlikely(value == NULL || !PyString_Check(value))) {
#endif
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = op->func_name;
    Py_INCREF(value);
    op->func_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op)
{
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
#else
    if (unlikely(value == NULL || !PyString_Check(value))) {
#endif
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = op->func_qualname;
    Py_INCREF(value);
    op->func_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_self(__pyx_CyFunctionObject *m, CYTHON_UNUSED void *closure)
{
    PyObject *self;
    self = m->func_closure;
    if (self == NULL)
        self = Py_None;
    Py_INCREF(self);
    return self;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    tmp = op->func_dict;
    Py_INCREF(value);
    op->func_dict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op)
{
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(CYTHON_UNUSED __pyx_CyFunctionObject *op)
{
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyTuple_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_tuple;
    op->defaults_tuple = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_kwdict;
    op->defaults_kwdict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value || value == Py_None) {
        value = NULL;
    } else if (!PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    tmp = op->func_annotations;
    op->func_annotations = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "__self__", (getter)__Pyx_CyFunction_get_self, 0, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
    {(char *) "__module__", T_OBJECT, offsetof(__pyx_CyFunctionObject, func.m_module), PY_WRITE_RESTRICTED, 0},
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, CYTHON_UNUSED PyObject *args)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromString(m->func.m_ml->ml_name);
#else
    return PyString_FromString(m->func.m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func.m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_New(PyTypeObject *type, PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    __pyx_CyFunctionObject *op = PyObject_GC_New(__pyx_CyFunctionObject, type);
    if (op == NULL)
        return NULL;
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
    op->func.m_ml = ml;
    op->func.m_self = (PyObject *) op;
    Py_XINCREF(closure);
    op->func_closure = closure;
    Py_XINCREF(module);
    op->func.m_module = module;
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
    op->func_classobj = NULL;
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    PyObject_GC_Track(op);
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
    Py_CLEAR(m->func.m_module);
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
    Py_CLEAR(m->func_classobj);
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    PyObject_GC_Del(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
    Py_VISIT(m->func.m_module);
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
    Py_VISIT(m->func_classobj);
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject *__Pyx_CyFunction_descr_get(PyObject *func, PyObject *obj, PyObject *type)
{
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    if (m->flags & __Pyx_CYFUNCTION_STATICMETHOD) {
        Py_INCREF(func);
        return func;
    }
    if (m->flags & __Pyx_CYFUNCTION_CLASSMETHOD) {
        if (type == NULL)
            type = (PyObject *)(Py_TYPE(obj));
        return __Pyx_PyMethod_New(func, type, (PyObject *)(Py_TYPE(type)));
    }
    if (obj == Py_None)
        obj = NULL;
    return __Pyx_PyMethod_New(func, obj, type);
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    Py_ssize_t size;
    switch (f->m_ml->ml_flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 0))
                return (*meth)(self, NULL);
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 1)) {
                PyObject *result, *arg0 = PySequence_ITEM(arg, 0);
                if (unlikely(!arg0)) return NULL;
                result = (*meth)(self, arg0);
                Py_DECREF(arg0);
                return result;
            }
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags in "
                        "__Pyx_CyFunction_Call. METH_OLDARGS is no "
                        "longer supported!");
        return NULL;
    }
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    return __Pyx_CyFunction_CallMethod(func, ((PyCFunctionObject*)func)->m_self, arg, kw);
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
        argc = PyTuple_GET_SIZE(args);
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
    0,
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_CyFunction_descr_get,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
};
static int __pyx_CyFunction_init(void) {
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
    if (__pyx_CyFunctionType == NULL) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (!m->defaults)
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* PyIntBinop */
              #if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, CYTHON_UNUSED int inplace) {
    if (op1 == op2) {
        Py_RETURN_TRUE;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        if (a == b) {
            Py_RETURN_TRUE;
        } else {
            Py_RETURN_FALSE;
        }
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a;
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                #if PyLong_SHIFT < 30 && PyLong_SHIFT != 15
                default: return PyLong_Type.tp_richcompare(op1, op2, Py_EQ);
                #else
                default: Py_RETURN_FALSE;
                #endif
            }
        }
            if (a == b) {
                Py_RETURN_TRUE;
            } else {
                Py_RETURN_FALSE;
            }
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            if ((double)a == (double)b) {
                Py_RETURN_TRUE;
            } else {
                Py_RETURN_FALSE;
            }
    }
    return PyObject_RichCompare(op1, op2, Py_EQ);
}
#endif

/* IterNext */
              static CYTHON_INLINE PyObject *__Pyx_PyIter_Next2(PyObject* iterator, PyObject* defval) {
    PyObject* next;
    iternextfunc iternext = Py_TYPE(iterator)->tp_iternext;
#if CYTHON_USE_TYPE_SLOTS
    if (unlikely(!iternext)) {
#else
    if (unlikely(!iternext) || unlikely(!PyIter_Check(iterator))) {
#endif
        PyErr_Format(PyExc_TypeError,
            "%.200s object is not an iterator", Py_TYPE(iterator)->tp_name);
        return NULL;
    }
    next = iternext(iterator);
    if (likely(next))
        return next;
#if CYTHON_USE_TYPE_SLOTS
#if PY_VERSION_HEX >= 0x02070000
    if (unlikely(iternext == &_PyObject_NextNotImplemented))
        return NULL;
#endif
#endif
    if (defval) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
            if (unlikely(exc_type != PyExc_StopIteration) &&
                    !PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))
                return NULL;
            PyErr_Clear();
        }
        Py_INCREF(defval);
        return defval;
    }
    if (!PyErr_Occurred())
        PyErr_SetNone(PyExc_StopIteration);
    return NULL;
}

/* KeywordStringCheck */
                static CYTHON_INLINE int __Pyx_CheckKeywordStrings(
    PyObject *kwdict,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kwdict, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    while (PyDict_Next(kwdict, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_CheckExact(key)) && unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if ((!kw_allowed) && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

/* SliceTupleAndList */
                #if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_crop_slice(Py_ssize_t* _start, Py_ssize_t* _stop, Py_ssize_t* _length) {
    Py_ssize_t start = *_start, stop = *_stop, length = *_length;
    if (start < 0) {
        start += length;
        if (start < 0)
            start = 0;
    }
    if (stop < 0)
        stop += length;
    else if (stop > length)
        stop = length;
    *_length = stop - start;
    *_start = start;
    *_stop = stop;
}
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject** CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    PyObject* dest;
    Py_ssize_t length = PyList_GET_SIZE(src);
    __Pyx_crop_slice(&start, &stop, &length);
    if (unlikely(length <= 0))
        return PyList_New(0);
    dest = PyList_New(length);
    if (unlikely(!dest))
        return NULL;
    __Pyx_copy_object_array(
        ((PyListObject*)src)->ob_item + start,
        ((PyListObject*)dest)->ob_item,
        length);
    return dest;
}
static CYTHON_INLINE PyObject* __Pyx_PyTuple_GetSlice(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    PyObject* dest;
    Py_ssize_t length = PyTuple_GET_SIZE(src);
    __Pyx_crop_slice(&start, &stop, &length);
    if (unlikely(length <= 0))
        return PyTuple_New(0);
    dest = PyTuple_New(length);
    if (unlikely(!dest))
        return NULL;
    __Pyx_copy_object_array(
        ((PyTupleObject*)src)->ob_item + start,
        ((PyTupleObject*)dest)->ob_item,
        length);
    return dest;
}
#endif

/* SwapException */
                #if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* None */
                static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* GetAttr */
                static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_COMPILING_IN_CPYTHON
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* GetAttr3 */
                static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r = __Pyx_GetAttr(o, n);
    if (unlikely(!r)) {
        if (!PyErr_ExceptionMatches(PyExc_AttributeError))
            goto bad;
        PyErr_Clear();
        r = d;
        Py_INCREF(d);
    }
    return r;
bad:
    return NULL;
}

/* Import */
                static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_VERSION_HEX < 0x03030000
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.')) {
                #if PY_VERSION_HEX < 0x03030000
                PyObject *py_level = PyInt_FromLong(1);
                if (!py_level)
                    goto bad;
                module = PyObject_CallFunctionObjArgs(py_import,
                    name, global_dict, empty_dict, list, py_level, NULL);
                Py_DECREF(py_level);
                #else
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                #endif
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_VERSION_HEX < 0x03030000
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_VERSION_HEX < 0x03030000
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* dict_getitem_default */
                static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value) {
    PyObject* value;
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (unlikely(PyErr_Occurred()))
            return NULL;
        value = default_value;
    }
    Py_INCREF(value);
#else
    if (PyString_CheckExact(key) || PyUnicode_CheckExact(key) || PyInt_CheckExact(key)) {
        value = PyDict_GetItem(d, key);
        if (unlikely(!value)) {
            value = default_value;
        }
        Py_INCREF(value);
    } else {
        if (default_value == Py_None)
            default_value = NULL;
        value = PyObject_CallMethodObjArgs(
            d, __pyx_n_s_get, key, default_value, NULL);
    }
#endif
    return value;
}

/* SetItemInt */
                static CYTHON_INLINE int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v) {
    int r;
    if (!j) return -1;
    r = PyObject_SetItem(o, j, v);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v, int is_list,
                                               CYTHON_NCP_UNUSED int wraparound, CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = (!wraparound) ? i : ((likely(i >= 0)) ? i : i + PyList_GET_SIZE(o));
        if ((!boundscheck) || likely((n >= 0) & (n < PyList_GET_SIZE(o)))) {
            PyObject* old = PyList_GET_ITEM(o, n);
            Py_INCREF(v);
            PyList_SET_ITEM(o, n, v);
            Py_DECREF(old);
            return 1;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_ass_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return -1;
                    PyErr_Clear();
                }
            }
            return m->sq_ass_item(o, i, v);
        }
    }
#else
#if CYTHON_COMPILING_IN_PYPY
    if (is_list || (PySequence_Check(o) && !PyDict_Check(o))) {
#else
    if (is_list || PySequence_Check(o)) {
#endif
        return PySequence_SetItem(o, i, v);
    }
#endif
    return __Pyx_SetItemInt_Generic(o, PyInt_FromSsize_t(i), v);
}

/* DelItemInt */
                  static CYTHON_INLINE int __Pyx_DelItem_Generic(PyObject *o, PyObject *j) {
    int r;
    if (!j) return -1;
    r = PyObject_DelItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE int __Pyx_DelItemInt_Fast(PyObject *o, Py_ssize_t i,
                                               CYTHON_UNUSED int is_list, CYTHON_NCP_UNUSED int wraparound) {
#if !CYTHON_USE_TYPE_SLOTS
    if (is_list || PySequence_Check(o)) {
        return PySequence_DelItem(o, i);
    }
#else
    PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
    if (likely(m && m->sq_ass_item)) {
        if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
            Py_ssize_t l = m->sq_length(o);
            if (likely(l >= 0)) {
                i += l;
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    return -1;
                PyErr_Clear();
            }
        }
        return m->sq_ass_item(o, i, (PyObject *)NULL);
    }
#endif
    return __Pyx_DelItem_Generic(o, PyInt_FromSsize_t(i));
}

/* UnicodeAsUCS4 */
                  static CYTHON_INLINE Py_UCS4 __Pyx_PyUnicode_AsPy_UCS4(PyObject* x) {
   Py_ssize_t length;
   #if CYTHON_PEP393_ENABLED
   length = PyUnicode_GET_LENGTH(x);
   if (likely(length == 1)) {
       return PyUnicode_READ_CHAR(x, 0);
   }
   #else
   length = PyUnicode_GET_SIZE(x);
   if (likely(length == 1)) {
       return PyUnicode_AS_UNICODE(x)[0];
   }
   #if Py_UNICODE_SIZE == 2
   else if (PyUnicode_GET_SIZE(x) == 2) {
       Py_UCS4 high_val = PyUnicode_AS_UNICODE(x)[0];
       if (high_val >= 0xD800 && high_val <= 0xDBFF) {
           Py_UCS4 low_val = PyUnicode_AS_UNICODE(x)[1];
           if (low_val >= 0xDC00 && low_val <= 0xDFFF) {
               return 0x10000 + (((high_val & ((1<<10)-1)) << 10) | (low_val & ((1<<10)-1)));
           }
       }
   }
   #endif
   #endif
   PyErr_Format(PyExc_ValueError,
                "only single character unicode strings can be converted to Py_UCS4, "
                "got length %" CYTHON_FORMAT_SSIZE_T "d", length);
   return (Py_UCS4)-1;
}

/* object_ord */
                  static long __Pyx__PyObject_Ord(PyObject* c) {
    Py_ssize_t size;
    if (PyBytes_Check(c)) {
        size = PyBytes_GET_SIZE(c);
        if (likely(size == 1)) {
            return (unsigned char) PyBytes_AS_STRING(c)[0];
        }
#if PY_MAJOR_VERSION < 3
    } else if (PyUnicode_Check(c)) {
        return (long)__Pyx_PyUnicode_AsPy_UCS4(c);
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    } else if (PyByteArray_Check(c)) {
        size = PyByteArray_GET_SIZE(c);
        if (likely(size == 1)) {
            return (unsigned char) PyByteArray_AS_STRING(c)[0];
        }
#endif
    } else {
        PyErr_Format(PyExc_TypeError,
            "ord() expected string of length 1, but %.200s found", c->ob_type->tp_name);
        return (long)(Py_UCS4)-1;
    }
    PyErr_Format(PyExc_TypeError,
        "ord() expected a character, but string of length %zd found", size);
    return (long)(Py_UCS4)-1;
}

/* UnpackUnboundCMethod */
                  static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    target->method = method;
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION >= 3
    if (likely(PyObject_TypeCheck(method, &PyMethodDescr_Type)))
    #endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST);
    }
#endif
    return 0;
}

/* CallUnboundCMethod0 */
                  static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_ASSUME_SAFE_MACROS
    args = PyTuple_New(1);
    if (unlikely(!args)) goto bad;
    Py_INCREF(self);
    PyTuple_SET_ITEM(args, 0, self);
#else
    args = PyTuple_Pack(1, self);
    if (unlikely(!args)) goto bad;
#endif
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    Py_DECREF(args);
bad:
    return result;
}

/* py_dict_items */
                  static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d) {
    if (PY_MAJOR_VERSION >= 3)
        return __Pyx_CallUnboundCMethod0(&__pyx_umethod_PyDict_Type_items, d);
    else
        return PyDict_Items(d);
}

/* pop */
                  static CYTHON_INLINE PyObject* __Pyx__PyObject_Pop(PyObject* L) {
    if (Py_TYPE(L) == &PySet_Type) {
        return PySet_Pop(L);
    }
    return __Pyx_PyObject_CallMethod0(L, __pyx_n_s_pop);
}
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE PyObject* __Pyx_PyList_Pop(PyObject* L) {
    if (likely(PyList_GET_SIZE(L) > (((PyListObject*)L)->allocated >> 1))) {
        Py_SIZE(L) -= 1;
        return PyList_GET_ITEM(L, PyList_GET_SIZE(L));
    }
    return __Pyx_CallUnboundCMethod0(&__pyx_umethod_PyList_Type_pop, L);
}
#endif

/* ImportFrom */
                  static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* CalculateMetaclass */
                  static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases = PyTuple_GET_SIZE(bases);
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
        tmptype = Py_TYPE(tmp);
#if PY_MAJOR_VERSION < 3
        if (tmptype == &PyClass_Type)
            continue;
#endif
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
#if PY_MAJOR_VERSION < 3
        metaclass = &PyClass_Type;
#else
        metaclass = &PyType_Type;
#endif
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* Py3ClassCreate */
                  static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStr(metaclass, __pyx_n_s_prepare);
        if (prep) {
            PyObject *pargs = PyTuple_Pack(2, name, bases);
            if (unlikely(!pargs)) {
                Py_DECREF(prep);
                return NULL;
            }
            ns = PyObject_Call(prep, pargs, mkw);
            Py_DECREF(prep);
            Py_DECREF(pargs);
        } else {
            if (unlikely(!PyErr_ExceptionMatches(PyExc_AttributeError)))
                return NULL;
            PyErr_Clear();
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_module, modname) < 0)) goto bad;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_qualname, qualname) < 0)) goto bad;
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_n_s_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result, *margs;
    PyObject *owned_metaclass = NULL;
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_n_s_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    margs = PyTuple_Pack(3, name, bases, dict);
    if (unlikely(!margs)) {
        result = NULL;
    } else {
        result = PyObject_Call(metaclass, margs, mkw);
        Py_DECREF(margs);
    }
    Py_XDECREF(owned_metaclass);
    return result;
}

/* ClassMethod */
                  static PyObject* __Pyx_Method_ClassMethod(PyObject *method) {
#if CYTHON_COMPILING_IN_PYPY
    if (PyObject_TypeCheck(method, &PyWrapperDescr_Type)) {
        return PyClassMethod_New(method);
    }
#else
#if CYTHON_COMPILING_IN_PYSTON
    if (PyMethodDescr_Check(method)) {
#else
    static PyTypeObject *methoddescr_type = NULL;
    if (methoddescr_type == NULL) {
       PyObject *meth = PyObject_GetAttrString((PyObject*)&PyList_Type, "append");
       if (!meth) return NULL;
       methoddescr_type = Py_TYPE(meth);
       Py_DECREF(meth);
    }
    if (PyObject_TypeCheck(method, methoddescr_type)) {
#endif
        PyMethodDescrObject *descr = (PyMethodDescrObject *)method;
        #if PY_VERSION_HEX < 0x03020000
        PyTypeObject *d_type = descr->d_type;
        #else
        PyTypeObject *d_type = descr->d_common.d_type;
        #endif
        return PyDescr_NewClassMethod(d_type, descr->d_method);
    }
#endif
    else if (PyMethod_Check(method)) {
        return PyClassMethod_New(PyMethod_GET_FUNCTION(method));
    }
    else if (PyCFunction_Check(method)) {
        return PyClassMethod_New(method);
    }
#ifdef __Pyx_CyFunction_USED
    else if (PyObject_TypeCheck(method, __pyx_CyFunctionType)) {
        return PyClassMethod_New(method);
    }
#endif
    PyErr_SetString(PyExc_TypeError,
                   "Class-level classmethod() can only be called on "
                   "a method_descriptor or instance method.");
    return NULL;
}

/* CodeObjectCache */
                    static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, (size_t)new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
                    #include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    py_code = __pyx_find_code_object(c_line ? c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        PyThreadState_GET(), /*PyThreadState *tstate,*/
        py_code,             /*PyCodeObject *code,*/
        __pyx_d,      /*PyObject *globals,*/
        0                    /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* CIntToPy */
                    static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) -1, const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntFromPyVerify */
                    #define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* BaseCaseSigned */
                    static CYTHON_INLINE long __Pyx_add_long_checking_overflow(long a, long b, int *overflow) {
    if (sizeof(long) < sizeof(long)) {
        long big_r = ((long) a) + ((long) b);
        long r = (long) big_r;
        *overflow |= big_r != r;
        return r;
#ifdef HAVE_LONG_LONG
    } else if (sizeof(long) < sizeof(PY_LONG_LONG)) {
        PY_LONG_LONG big_r = ((PY_LONG_LONG) a) + ((PY_LONG_LONG) b);
        long r = (long) big_r;
        *overflow |= big_r != r;
        return r;
#endif
    } else {
        long r = (long) ((unsigned long) a + (unsigned long) b);
        long sign_a = __PYX_SIGN_BIT(long) & a;
        long sign_b = __PYX_SIGN_BIT(long) & b;
        long sign_r = __PYX_SIGN_BIT(long) & r;
        *overflow |= (sign_a == sign_b) & (sign_a != sign_r);
        return r;
    }
}
static CYTHON_INLINE long __Pyx_add_const_long_checking_overflow(long a, long b, int *overflow) {
    if (b > 0) {
        *overflow |= a > __PYX_MAX(long) - b;
    } else if (b < 0) {
        *overflow |= a < __PYX_MIN(long) - b;
    }
    return a + b;
}
static CYTHON_INLINE long __Pyx_sub_long_checking_overflow(long a, long b, int *overflow) {
    *overflow |= b == __PYX_MIN(long);
    return __Pyx_add_long_checking_overflow(a, -b, overflow);
}
static CYTHON_INLINE long __Pyx_sub_const_long_checking_overflow(long a, long b, int *overflow) {
    *overflow |= b == __PYX_MIN(long);
    return __Pyx_add_const_long_checking_overflow(a, -b, overflow);
}
static CYTHON_INLINE long __Pyx_mul_long_checking_overflow(long a, long b, int *overflow) {
    if (sizeof(long) < sizeof(long)) {
        long big_r = ((long) a) * ((long) b);
        long r = (long) big_r;
        *overflow |= big_r != r;
        return (long) r;
#ifdef HAVE_LONG_LONG
    } else if (sizeof(long) < sizeof(PY_LONG_LONG)) {
        PY_LONG_LONG big_r = ((PY_LONG_LONG) a) * ((PY_LONG_LONG) b);
        long r = (long) big_r;
        *overflow |= big_r != r;
        return (long) r;
#endif
    } else {
        long prod = a * b;
        double dprod = ((double) a) * ((double) b);
        *overflow |= fabs(dprod - prod) > (__PYX_MAX(long) / 2);
        return prod;
    }
}
static CYTHON_INLINE long __Pyx_mul_const_long_checking_overflow(long a, long b, int *overflow) {
    if (b > 1) {
        *overflow |= a > __PYX_MAX(long) / b;
        *overflow |= a < __PYX_MIN(long) / b;
    } else if (b == -1) {
        *overflow |= a == __PYX_MIN(long);
    } else if (b < -1) {
        *overflow |= a > __PYX_MIN(long) / b;
        *overflow |= a < __PYX_MAX(long) / b;
    }
    return a * b;
}
static CYTHON_INLINE long __Pyx_div_long_checking_overflow(long a, long b, int *overflow) {
    if (b == 0) {
        *overflow |= 1;
        return 0;
    }
    *overflow |= (a == __PYX_MIN(long)) & (b == -1);
    return a / b;
}

/* CIntToPy */
                    static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
    const int neg_one = (int) -1, const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

/* BaseCaseSigned */
                    static CYTHON_INLINE int __Pyx_add_int_checking_overflow(int a, int b, int *overflow) {
    if (sizeof(int) < sizeof(long)) {
        long big_r = ((long) a) + ((long) b);
        int r = (int) big_r;
        *overflow |= big_r != r;
        return r;
#ifdef HAVE_LONG_LONG
    } else if (sizeof(int) < sizeof(PY_LONG_LONG)) {
        PY_LONG_LONG big_r = ((PY_LONG_LONG) a) + ((PY_LONG_LONG) b);
        int r = (int) big_r;
        *overflow |= big_r != r;
        return r;
#endif
    } else {
        int r = (int) ((unsigned int) a + (unsigned int) b);
        int sign_a = __PYX_SIGN_BIT(int) & a;
        int sign_b = __PYX_SIGN_BIT(int) & b;
        int sign_r = __PYX_SIGN_BIT(int) & r;
        *overflow |= (sign_a == sign_b) & (sign_a != sign_r);
        return r;
    }
}
static CYTHON_INLINE int __Pyx_add_const_int_checking_overflow(int a, int b, int *overflow) {
    if (b > 0) {
        *overflow |= a > __PYX_MAX(int) - b;
    } else if (b < 0) {
        *overflow |= a < __PYX_MIN(int) - b;
    }
    return a + b;
}
static CYTHON_INLINE int __Pyx_sub_int_checking_overflow(int a, int b, int *overflow) {
    *overflow |= b == __PYX_MIN(int);
    return __Pyx_add_int_checking_overflow(a, -b, overflow);
}
static CYTHON_INLINE int __Pyx_sub_const_int_checking_overflow(int a, int b, int *overflow) {
    *overflow |= b == __PYX_MIN(int);
    return __Pyx_add_const_int_checking_overflow(a, -b, overflow);
}
static CYTHON_INLINE int __Pyx_mul_int_checking_overflow(int a, int b, int *overflow) {
    if (sizeof(int) < sizeof(long)) {
        long big_r = ((long) a) * ((long) b);
        int r = (int) big_r;
        *overflow |= big_r != r;
        return (int) r;
#ifdef HAVE_LONG_LONG
    } else if (sizeof(int) < sizeof(PY_LONG_LONG)) {
        PY_LONG_LONG big_r = ((PY_LONG_LONG) a) * ((PY_LONG_LONG) b);
        int r = (int) big_r;
        *overflow |= big_r != r;
        return (int) r;
#endif
    } else {
        int prod = a * b;
        double dprod = ((double) a) * ((double) b);
        *overflow |= fabs(dprod - prod) > (__PYX_MAX(int) / 2);
        return prod;
    }
}
static CYTHON_INLINE int __Pyx_mul_const_int_checking_overflow(int a, int b, int *overflow) {
    if (b > 1) {
        *overflow |= a > __PYX_MAX(int) / b;
        *overflow |= a < __PYX_MIN(int) / b;
    } else if (b == -1) {
        *overflow |= a == __PYX_MIN(int);
    } else if (b < -1) {
        *overflow |= a > __PYX_MIN(int) / b;
        *overflow |= a < __PYX_MAX(int) / b;
    }
    return a * b;
}
static CYTHON_INLINE int __Pyx_div_int_checking_overflow(int a, int b, int *overflow) {
    if (b == 0) {
        *overflow |= 1;
        return 0;
    }
    *overflow |= (a == __PYX_MIN(int)) & (b == -1);
    return a / b;
}

/* BaseCaseSigned */
                    static CYTHON_INLINE long long __Pyx_add_long_long_checking_overflow(long long a, long long b, int *overflow) {
    if (sizeof(long long) < sizeof(long)) {
        long big_r = ((long) a) + ((long) b);
        long long r = (long long) big_r;
        *overflow |= big_r != r;
        return r;
#ifdef HAVE_LONG_LONG
    } else if (sizeof(long long) < sizeof(PY_LONG_LONG)) {
        PY_LONG_LONG big_r = ((PY_LONG_LONG) a) + ((PY_LONG_LONG) b);
        long long r = (long long) big_r;
        *overflow |= big_r != r;
        return r;
#endif
    } else {
        long long r = (long long) ((unsigned long long) a + (unsigned long long) b);
        long long sign_a = __PYX_SIGN_BIT(long long) & a;
        long long sign_b = __PYX_SIGN_BIT(long long) & b;
        long long sign_r = __PYX_SIGN_BIT(long long) & r;
        *overflow |= (sign_a == sign_b) & (sign_a != sign_r);
        return r;
    }
}
static CYTHON_INLINE long long __Pyx_add_const_long_long_checking_overflow(long long a, long long b, int *overflow) {
    if (b > 0) {
        *overflow |= a > __PYX_MAX(long long) - b;
    } else if (b < 0) {
        *overflow |= a < __PYX_MIN(long long) - b;
    }
    return a + b;
}
static CYTHON_INLINE long long __Pyx_sub_long_long_checking_overflow(long long a, long long b, int *overflow) {
    *overflow |= b == __PYX_MIN(long long);
    return __Pyx_add_long_long_checking_overflow(a, -b, overflow);
}
static CYTHON_INLINE long long __Pyx_sub_const_long_long_checking_overflow(long long a, long long b, int *overflow) {
    *overflow |= b == __PYX_MIN(long long);
    return __Pyx_add_const_long_long_checking_overflow(a, -b, overflow);
}
static CYTHON_INLINE long long __Pyx_mul_long_long_checking_overflow(long long a, long long b, int *overflow) {
    if (sizeof(long long) < sizeof(long)) {
        long big_r = ((long) a) * ((long) b);
        long long r = (long long) big_r;
        *overflow |= big_r != r;
        return (long long) r;
#ifdef HAVE_LONG_LONG
    } else if (sizeof(long long) < sizeof(PY_LONG_LONG)) {
        PY_LONG_LONG big_r = ((PY_LONG_LONG) a) * ((PY_LONG_LONG) b);
        long long r = (long long) big_r;
        *overflow |= big_r != r;
        return (long long) r;
#endif
    } else {
        long long prod = a * b;
        double dprod = ((double) a) * ((double) b);
        *overflow |= fabs(dprod - prod) > (__PYX_MAX(long long) / 2);
        return prod;
    }
}
static CYTHON_INLINE long long __Pyx_mul_const_long_long_checking_overflow(long long a, long long b, int *overflow) {
    if (b > 1) {
        *overflow |= a > __PYX_MAX(long long) / b;
        *overflow |= a < __PYX_MIN(long long) / b;
    } else if (b == -1) {
        *overflow |= a == __PYX_MIN(long long);
    } else if (b < -1) {
        *overflow |= a > __PYX_MIN(long long) / b;
        *overflow |= a < __PYX_MAX(long long) / b;
    }
    return a * b;
}
static CYTHON_INLINE long long __Pyx_div_long_long_checking_overflow(long long a, long long b, int *overflow) {
    if (b == 0) {
        *overflow |= 1;
        return 0;
    }
    *overflow |= (a == __PYX_MIN(long long)) & (b == -1);
    return a / b;
}

/* BaseCaseUnsigned */
                    static CYTHON_INLINE unsigned int __Pyx_add_unsigned_int_checking_overflow(unsigned int a, unsigned int b, int *overflow) {
    unsigned int r = a + b;
    *overflow |= r < a;
    return r;
}
static CYTHON_INLINE unsigned int __Pyx_sub_unsigned_int_checking_overflow(unsigned int a, unsigned int b, int *overflow) {
    unsigned int r = a - b;
    *overflow |= r > a;
    return r;
}
static CYTHON_INLINE unsigned int __Pyx_mul_unsigned_int_checking_overflow(unsigned int a, unsigned int b, int *overflow) {
    if (sizeof(unsigned int) < sizeof(unsigned long)) {
        unsigned long big_r = ((unsigned long) a) * ((unsigned long) b);
        unsigned int r = (unsigned int) big_r;
        *overflow |= big_r != r;
        return r;
#ifdef HAVE_LONG_LONG
    } else if (sizeof(unsigned int) < sizeof(unsigned PY_LONG_LONG)) {
        unsigned PY_LONG_LONG big_r = ((unsigned PY_LONG_LONG) a) * ((unsigned PY_LONG_LONG) b);
        unsigned int r = (unsigned int) big_r;
        *overflow |= big_r != r;
        return r;
#endif
    } else {
        unsigned int prod = a * b;
        double dprod = ((double) a) * ((double) b);
        *overflow |= fabs(dprod - prod) > (__PYX_MAX(unsigned int) / 2);
        return prod;
    }
}
static CYTHON_INLINE unsigned int __Pyx_mul_const_unsigned_int_checking_overflow(unsigned int a, unsigned int b, int *overflow) {
    if (b > 1) {
        *overflow |= a > __PYX_MAX(unsigned int) / b;
    }
    return a * b;
}
static CYTHON_INLINE unsigned int __Pyx_div_unsigned_int_checking_overflow(unsigned int a, unsigned int b, int *overflow) {
    if (b == 0) {
        *overflow |= 1;
        return 0;
    }
    return a / b;
}

/* BaseCaseUnsigned */
                    static CYTHON_INLINE unsigned long __Pyx_add_unsigned_long_checking_overflow(unsigned long a, unsigned long b, int *overflow) {
    unsigned long r = a + b;
    *overflow |= r < a;
    return r;
}
static CYTHON_INLINE unsigned long __Pyx_sub_unsigned_long_checking_overflow(unsigned long a, unsigned long b, int *overflow) {
    unsigned long r = a - b;
    *overflow |= r > a;
    return r;
}
static CYTHON_INLINE unsigned long __Pyx_mul_unsigned_long_checking_overflow(unsigned long a, unsigned long b, int *overflow) {
    if (sizeof(unsigned long) < sizeof(unsigned long)) {
        unsigned long big_r = ((unsigned long) a) * ((unsigned long) b);
        unsigned long r = (unsigned long) big_r;
        *overflow |= big_r != r;
        return r;
#ifdef HAVE_LONG_LONG
    } else if (sizeof(unsigned long) < sizeof(unsigned PY_LONG_LONG)) {
        unsigned PY_LONG_LONG big_r = ((unsigned PY_LONG_LONG) a) * ((unsigned PY_LONG_LONG) b);
        unsigned long r = (unsigned long) big_r;
        *overflow |= big_r != r;
        return r;
#endif
    } else {
        unsigned long prod = a * b;
        double dprod = ((double) a) * ((double) b);
        *overflow |= fabs(dprod - prod) > (__PYX_MAX(unsigned long) / 2);
        return prod;
    }
}
static CYTHON_INLINE unsigned long __Pyx_mul_const_unsigned_long_checking_overflow(unsigned long a, unsigned long b, int *overflow) {
    if (b > 1) {
        *overflow |= a > __PYX_MAX(unsigned long) / b;
    }
    return a * b;
}
static CYTHON_INLINE unsigned long __Pyx_div_unsigned_long_checking_overflow(unsigned long a, unsigned long b, int *overflow) {
    if (b == 0) {
        *overflow |= 1;
        return 0;
    }
    return a / b;
}

/* BaseCaseUnsigned */
                    static CYTHON_INLINE unsigned long long __Pyx_add_unsigned_long_long_checking_overflow(unsigned long long a, unsigned long long b, int *overflow) {
    unsigned long long r = a + b;
    *overflow |= r < a;
    return r;
}
static CYTHON_INLINE unsigned long long __Pyx_sub_unsigned_long_long_checking_overflow(unsigned long long a, unsigned long long b, int *overflow) {
    unsigned long long r = a - b;
    *overflow |= r > a;
    return r;
}
static CYTHON_INLINE unsigned long long __Pyx_mul_unsigned_long_long_checking_overflow(unsigned long long a, unsigned long long b, int *overflow) {
    if (sizeof(unsigned long long) < sizeof(unsigned long)) {
        unsigned long big_r = ((unsigned long) a) * ((unsigned long) b);
        unsigned long long r = (unsigned long long) big_r;
        *overflow |= big_r != r;
        return r;
#ifdef HAVE_LONG_LONG
    } else if (sizeof(unsigned long long) < sizeof(unsigned PY_LONG_LONG)) {
        unsigned PY_LONG_LONG big_r = ((unsigned PY_LONG_LONG) a) * ((unsigned PY_LONG_LONG) b);
        unsigned long long r = (unsigned long long) big_r;
        *overflow |= big_r != r;
        return r;
#endif
    } else {
        unsigned long long prod = a * b;
        double dprod = ((double) a) * ((double) b);
        *overflow |= fabs(dprod - prod) > (__PYX_MAX(unsigned long long) / 2);
        return prod;
    }
}
static CYTHON_INLINE unsigned long long __Pyx_mul_const_unsigned_long_long_checking_overflow(unsigned long long a, unsigned long long b, int *overflow) {
    if (b > 1) {
        *overflow |= a > __PYX_MAX(unsigned long long) / b;
    }
    return a * b;
}
static CYTHON_INLINE unsigned long long __Pyx_div_unsigned_long_long_checking_overflow(unsigned long long a, unsigned long long b, int *overflow) {
    if (b == 0) {
        *overflow |= 1;
        return 0;
    }
    return a / b;
}

/* Binop */
                    static CYTHON_INLINE Py_ssize_t __Pyx_add_Py_ssize_t_checking_overflow(Py_ssize_t a, Py_ssize_t b, int *overflow) {
    if (sizeof(Py_ssize_t) < sizeof(int)) {
        return __Pyx_add_no_overflow(a, b, overflow);
    } else if (__PYX_IS_UNSIGNED(Py_ssize_t)) {
        if (sizeof(Py_ssize_t) == sizeof(unsigned int)) {
            return __Pyx_add_unsigned_int_checking_overflow(a, b, overflow);
        } else if (sizeof(Py_ssize_t) == sizeof(unsigned long)) {
            return __Pyx_add_unsigned_long_checking_overflow(a, b, overflow);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(Py_ssize_t) == sizeof(unsigned PY_LONG_LONG)) {
            return __Pyx_add_unsigned_long_long_checking_overflow(a, b, overflow);
#endif
        } else {
            abort(); return 0; // handled elsewhere
        }
    } else {
        if (sizeof(Py_ssize_t) == sizeof(int)) {
            return __Pyx_add_int_checking_overflow(a, b, overflow);
        } else if (sizeof(Py_ssize_t) == sizeof(long)) {
            return __Pyx_add_long_checking_overflow(a, b, overflow);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(Py_ssize_t) == sizeof(PY_LONG_LONG)) {
            return __Pyx_add_long_long_checking_overflow(a, b, overflow);
#endif
        } else {
            abort(); return 0; // handled elsewhere
        }
    }
}

/* Binop */
                    static CYTHON_INLINE Py_ssize_t __Pyx_sub_const_Py_ssize_t_checking_overflow(Py_ssize_t a, Py_ssize_t b, int *overflow) {
    if (sizeof(Py_ssize_t) < sizeof(int)) {
        return __Pyx_sub_const_no_overflow(a, b, overflow);
    } else if (__PYX_IS_UNSIGNED(Py_ssize_t)) {
        if (sizeof(Py_ssize_t) == sizeof(unsigned int)) {
            return __Pyx_sub_const_unsigned_int_checking_overflow(a, b, overflow);
        } else if (sizeof(Py_ssize_t) == sizeof(unsigned long)) {
            return __Pyx_sub_const_unsigned_long_checking_overflow(a, b, overflow);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(Py_ssize_t) == sizeof(unsigned PY_LONG_LONG)) {
            return __Pyx_sub_const_unsigned_long_long_checking_overflow(a, b, overflow);
#endif
        } else {
            abort(); return 0; // handled elsewhere
        }
    } else {
        if (sizeof(Py_ssize_t) == sizeof(int)) {
            return __Pyx_sub_const_int_checking_overflow(a, b, overflow);
        } else if (sizeof(Py_ssize_t) == sizeof(long)) {
            return __Pyx_sub_const_long_checking_overflow(a, b, overflow);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(Py_ssize_t) == sizeof(PY_LONG_LONG)) {
            return __Pyx_sub_const_long_long_checking_overflow(a, b, overflow);
#endif
        } else {
            abort(); return 0; // handled elsewhere
        }
    }
}

/* CIntFromPy */
                    static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) -1, const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntFromPy */
                    static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) -1, const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CoroutineBase */
                    #include <structmember.h>
#include <frameobject.h>
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value);
static PyObject *__Pyx_Coroutine_Close(PyObject *self);
static PyObject *__Pyx_Coroutine_Throw(PyObject *gen, PyObject *args);
#define __Pyx_Coroutine_Undelegate(gen) Py_CLEAR((gen)->yieldfrom)
#if 1 || PY_VERSION_HEX < 0x030300B0
static int __Pyx_PyGen_FetchStopIterationValue(PyObject **pvalue) {
    PyObject *et, *ev, *tb;
    PyObject *value = NULL;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&et, &ev, &tb);
    if (!et) {
        Py_XDECREF(tb);
        Py_XDECREF(ev);
        Py_INCREF(Py_None);
        *pvalue = Py_None;
        return 0;
    }
    if (likely(et == PyExc_StopIteration)) {
        if (!ev) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#if PY_VERSION_HEX >= 0x030300A0
        else if (Py_TYPE(ev) == (PyTypeObject*)PyExc_StopIteration) {
            value = ((PyStopIterationObject *)ev)->value;
            Py_INCREF(value);
            Py_DECREF(ev);
        }
#endif
        else if (unlikely(PyTuple_Check(ev))) {
            if (PyTuple_GET_SIZE(ev) >= 1) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                value = PyTuple_GET_ITEM(ev, 0);
                Py_INCREF(value);
#else
                value = PySequence_ITEM(ev, 0);
#endif
            } else {
                Py_INCREF(Py_None);
                value = Py_None;
            }
            Py_DECREF(ev);
        }
        else if (!PyObject_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration)) {
            value = ev;
        }
        if (likely(value)) {
            Py_XDECREF(tb);
            Py_DECREF(et);
            *pvalue = value;
            return 0;
        }
    } else if (!PyErr_GivenExceptionMatches(et, PyExc_StopIteration)) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    PyErr_NormalizeException(&et, &ev, &tb);
    if (unlikely(!PyObject_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration))) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    Py_XDECREF(tb);
    Py_DECREF(et);
#if PY_VERSION_HEX >= 0x030300A0
    value = ((PyStopIterationObject *)ev)->value;
    Py_INCREF(value);
    Py_DECREF(ev);
#else
    {
        PyObject* args = __Pyx_PyObject_GetAttrStr(ev, __pyx_n_s_args);
        Py_DECREF(ev);
        if (likely(args)) {
            value = PySequence_GetItem(args, 0);
            Py_DECREF(args);
        }
        if (unlikely(!value)) {
            __Pyx_ErrRestore(NULL, NULL, NULL);
            Py_INCREF(Py_None);
            value = Py_None;
        }
    }
#endif
    *pvalue = value;
    return 0;
}
#endif
static CYTHON_INLINE
void __Pyx_Coroutine_ExceptionClear(__pyx_CoroutineObject *self) {
    PyObject *exc_type = self->exc_type;
    PyObject *exc_value = self->exc_value;
    PyObject *exc_traceback = self->exc_traceback;
    self->exc_type = NULL;
    self->exc_value = NULL;
    self->exc_traceback = NULL;
    Py_XDECREF(exc_type);
    Py_XDECREF(exc_value);
    Py_XDECREF(exc_traceback);
}
static CYTHON_INLINE
int __Pyx_Coroutine_CheckRunning(__pyx_CoroutineObject *gen) {
    if (unlikely(gen->is_running)) {
        PyErr_SetString(PyExc_ValueError,
                        "generator already executing");
        return 1;
    }
    return 0;
}
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_SendEx(__pyx_CoroutineObject *self, PyObject *value) {
    PyObject *retval;
    __Pyx_PyThreadState_declare
    assert(!self->is_running);
    if (unlikely(self->resume_label == 0)) {
        if (unlikely(value && value != Py_None)) {
            PyErr_SetString(PyExc_TypeError,
                            "can't send non-None value to a "
                            "just-started generator");
            return NULL;
        }
    }
    if (unlikely(self->resume_label == -1)) {
        PyErr_SetNone(PyExc_StopIteration);
        return NULL;
    }
    __Pyx_PyThreadState_assign
    if (value) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_PYSTON
#else
        if (self->exc_traceback) {
            PyTracebackObject *tb = (PyTracebackObject *) self->exc_traceback;
            PyFrameObject *f = tb->tb_frame;
            Py_XINCREF(__pyx_tstate->frame);
            assert(f->f_back == NULL);
            f->f_back = __pyx_tstate->frame;
        }
#endif
        __Pyx_ExceptionSwap(&self->exc_type, &self->exc_value,
                            &self->exc_traceback);
    } else {
        __Pyx_Coroutine_ExceptionClear(self);
    }
    self->is_running = 1;
    retval = self->body((PyObject *) self, value);
    self->is_running = 0;
    if (retval) {
        __Pyx_ExceptionSwap(&self->exc_type, &self->exc_value,
                            &self->exc_traceback);
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_PYSTON
#else
        if (self->exc_traceback) {
            PyTracebackObject *tb = (PyTracebackObject *) self->exc_traceback;
            PyFrameObject *f = tb->tb_frame;
            Py_CLEAR(f->f_back);
        }
#endif
    } else {
        __Pyx_Coroutine_ExceptionClear(self);
    }
    return retval;
}
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_MethodReturn(PyObject *retval) {
    if (unlikely(!retval && !PyErr_Occurred())) {
        PyErr_SetNone(PyExc_StopIteration);
    }
    return retval;
}
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_FinishDelegation(__pyx_CoroutineObject *gen) {
    PyObject *ret;
    PyObject *val = NULL;
    __Pyx_Coroutine_Undelegate(gen);
    __Pyx_PyGen_FetchStopIterationValue(&val);
    ret = __Pyx_Coroutine_SendEx(gen, val);
    Py_XDECREF(val);
    return ret;
}
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value) {
    PyObject *retval;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(__Pyx_Coroutine_CheckRunning(gen)))
        return NULL;
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        {
            if (value == Py_None)
                ret = Py_TYPE(yf)->tp_iternext(yf);
            else
                ret = __Pyx_PyObject_CallMethod1(yf, __pyx_n_s_send, value);
        }
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        retval = __Pyx_Coroutine_FinishDelegation(gen);
    } else {
        retval = __Pyx_Coroutine_SendEx(gen, value);
    }
    return __Pyx_Coroutine_MethodReturn(retval);
}
static int __Pyx_Coroutine_CloseIter(__pyx_CoroutineObject *gen, PyObject *yf) {
    PyObject *retval = NULL;
    int err = 0;
    #ifdef __Pyx_Generator_USED
    if (__Pyx_Generator_CheckExact(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_Coroutine_USED
    if (__Pyx_Coroutine_CheckExact(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    #endif
    {
        PyObject *meth;
        gen->is_running = 1;
        meth = __Pyx_PyObject_GetAttrStr(yf, __pyx_n_s_close);
        if (unlikely(!meth)) {
            if (!PyErr_ExceptionMatches(PyExc_AttributeError)) {
                PyErr_WriteUnraisable(yf);
            }
            PyErr_Clear();
        } else {
            retval = PyObject_CallFunction(meth, NULL);
            Py_DECREF(meth);
            if (!retval)
                err = -1;
        }
        gen->is_running = 0;
    }
    Py_XDECREF(retval);
    return err;
}
static PyObject *__Pyx_Generator_Next(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(__Pyx_Coroutine_CheckRunning(gen)))
        return NULL;
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Generator_Next(yf);
        } else
        #endif
            ret = Py_TYPE(yf)->tp_iternext(yf);
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        return __Pyx_Coroutine_FinishDelegation(gen);
    }
    return __Pyx_Coroutine_SendEx(gen, Py_None);
}
static PyObject *__Pyx_Coroutine_Close(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *retval, *raised_exception;
    PyObject *yf = gen->yieldfrom;
    int err = 0;
    if (unlikely(__Pyx_Coroutine_CheckRunning(gen)))
        return NULL;
    if (yf) {
        Py_INCREF(yf);
        err = __Pyx_Coroutine_CloseIter(gen, yf);
        __Pyx_Coroutine_Undelegate(gen);
        Py_DECREF(yf);
    }
    if (err == 0)
        PyErr_SetNone(PyExc_GeneratorExit);
    retval = __Pyx_Coroutine_SendEx(gen, NULL);
    if (retval) {
        Py_DECREF(retval);
        PyErr_SetString(PyExc_RuntimeError,
                        "generator ignored GeneratorExit");
        return NULL;
    }
    raised_exception = PyErr_Occurred();
    if (!raised_exception
        || raised_exception == PyExc_StopIteration
        || raised_exception == PyExc_GeneratorExit
        || PyErr_GivenExceptionMatches(raised_exception, PyExc_GeneratorExit)
        || PyErr_GivenExceptionMatches(raised_exception, PyExc_StopIteration))
    {
        if (raised_exception) PyErr_Clear();
        Py_INCREF(Py_None);
        return Py_None;
    }
    return NULL;
}
static PyObject *__Pyx_Coroutine_Throw(PyObject *self, PyObject *args) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *typ;
    PyObject *tb = NULL;
    PyObject *val = NULL;
    PyObject *yf = gen->yieldfrom;
    if (!PyArg_UnpackTuple(args, (char *)"throw", 1, 3, &typ, &val, &tb))
        return NULL;
    if (unlikely(__Pyx_Coroutine_CheckRunning(gen)))
        return NULL;
    if (yf) {
        PyObject *ret;
        Py_INCREF(yf);
        if (PyErr_GivenExceptionMatches(typ, PyExc_GeneratorExit)) {
            int err = __Pyx_Coroutine_CloseIter(gen, yf);
            Py_DECREF(yf);
            __Pyx_Coroutine_Undelegate(gen);
            if (err < 0)
                return __Pyx_Coroutine_MethodReturn(__Pyx_Coroutine_SendEx(gen, NULL));
            goto throw_here;
        }
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Throw(yf, args);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Throw(yf, args);
        } else
        #endif
        {
            PyObject *meth = __Pyx_PyObject_GetAttrStr(yf, __pyx_n_s_throw);
            if (unlikely(!meth)) {
                Py_DECREF(yf);
                if (!PyErr_ExceptionMatches(PyExc_AttributeError)) {
                    gen->is_running = 0;
                    return NULL;
                }
                PyErr_Clear();
                __Pyx_Coroutine_Undelegate(gen);
                gen->is_running = 0;
                goto throw_here;
            }
            ret = PyObject_CallObject(meth, args);
            Py_DECREF(meth);
        }
        gen->is_running = 0;
        Py_DECREF(yf);
        if (!ret) {
            ret = __Pyx_Coroutine_FinishDelegation(gen);
        }
        return __Pyx_Coroutine_MethodReturn(ret);
    }
throw_here:
    __Pyx_Raise(typ, val, tb, NULL);
    return __Pyx_Coroutine_MethodReturn(__Pyx_Coroutine_SendEx(gen, NULL));
}
static int __Pyx_Coroutine_traverse(PyObject *self, visitproc visit, void *arg) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    Py_VISIT(gen->closure);
    Py_VISIT(gen->classobj);
    Py_VISIT(gen->yieldfrom);
    Py_VISIT(gen->exc_type);
    Py_VISIT(gen->exc_value);
    Py_VISIT(gen->exc_traceback);
    return 0;
}
static int __Pyx_Coroutine_clear(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    Py_CLEAR(gen->closure);
    Py_CLEAR(gen->classobj);
    Py_CLEAR(gen->yieldfrom);
    Py_CLEAR(gen->exc_type);
    Py_CLEAR(gen->exc_value);
    Py_CLEAR(gen->exc_traceback);
    Py_CLEAR(gen->gi_name);
    Py_CLEAR(gen->gi_qualname);
    return 0;
}
static void __Pyx_Coroutine_dealloc(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject_GC_UnTrack(gen);
    if (gen->gi_weakreflist != NULL)
        PyObject_ClearWeakRefs(self);
    if (gen->resume_label > 0) {
        PyObject_GC_Track(self);
#if PY_VERSION_HEX >= 0x030400a1
        if (PyObject_CallFinalizerFromDealloc(self))
#else
        Py_TYPE(gen)->tp_del(self);
        if (self->ob_refcnt > 0)
#endif
        {
            return;
        }
        PyObject_GC_UnTrack(self);
    }
    __Pyx_Coroutine_clear(self);
    PyObject_GC_Del(gen);
}
static void __Pyx_Coroutine_del(PyObject *self) {
    PyObject *res;
    PyObject *error_type, *error_value, *error_traceback;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    __Pyx_PyThreadState_declare
    if (gen->resume_label <= 0)
        return ;
#if PY_VERSION_HEX < 0x030400a1
    assert(self->ob_refcnt == 0);
    self->ob_refcnt = 1;
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&error_type, &error_value, &error_traceback);
    res = __Pyx_Coroutine_Close(self);
    if (res == NULL)
        PyErr_WriteUnraisable(self);
    else
        Py_DECREF(res);
    __Pyx_ErrRestore(error_type, error_value, error_traceback);
#if PY_VERSION_HEX < 0x030400a1
    assert(self->ob_refcnt > 0);
    if (--self->ob_refcnt == 0) {
        return;
    }
    {
        Py_ssize_t refcnt = self->ob_refcnt;
        _Py_NewReference(self);
        self->ob_refcnt = refcnt;
    }
#if CYTHON_COMPILING_IN_CPYTHON
    assert(PyType_IS_GC(self->ob_type) &&
           _Py_AS_GC(self)->gc.gc_refs != _PyGC_REFS_UNTRACKED);
    _Py_DEC_REFTOTAL;
#endif
#ifdef COUNT_ALLOCS
    --Py_TYPE(self)->tp_frees;
    --Py_TYPE(self)->tp_allocs;
#endif
#endif
}
static PyObject *
__Pyx_Coroutine_get_name(__pyx_CoroutineObject *self)
{
    PyObject *name = self->gi_name;
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_name(__pyx_CoroutineObject *self, PyObject *value)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
#else
    if (unlikely(value == NULL || !PyString_Check(value))) {
#endif
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = self->gi_name;
    Py_INCREF(value);
    self->gi_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_qualname(__pyx_CoroutineObject *self)
{
    PyObject *name = self->gi_qualname;
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_qualname(__pyx_CoroutineObject *self, PyObject *value)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
#else
    if (unlikely(value == NULL || !PyString_Check(value))) {
#endif
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = self->gi_qualname;
    Py_INCREF(value);
    self->gi_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
            PyTypeObject* type, __pyx_coroutine_body_t body, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    __pyx_CoroutineObject *gen = PyObject_GC_New(__pyx_CoroutineObject, type);
    if (gen == NULL)
        return NULL;
    gen->body = body;
    gen->closure = closure;
    Py_XINCREF(closure);
    gen->is_running = 0;
    gen->resume_label = 0;
    gen->classobj = NULL;
    gen->yieldfrom = NULL;
    gen->exc_type = NULL;
    gen->exc_value = NULL;
    gen->exc_traceback = NULL;
    gen->gi_weakreflist = NULL;
    Py_XINCREF(qualname);
    gen->gi_qualname = qualname;
    Py_XINCREF(name);
    gen->gi_name = name;
    Py_XINCREF(module_name);
    gen->gi_modulename = module_name;
    PyObject_GC_Track(gen);
    return gen;
}

/* PatchModuleWithCoroutine */
                        static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    int result;
    PyObject *globals, *result_obj;
    globals = PyDict_New();  if (unlikely(!globals)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_coroutine_type",
    #ifdef __Pyx_Coroutine_USED
        (PyObject*)__pyx_CoroutineType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_generator_type",
    #ifdef __Pyx_Generator_USED
        (PyObject*)__pyx_GeneratorType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "_module", module) < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "__builtins__", __pyx_b) < 0)) goto ignore;
    result_obj = PyRun_String(py_code, Py_file_input, globals, globals);
    if (unlikely(!result_obj)) goto ignore;
    Py_DECREF(result_obj);
    Py_DECREF(globals);
    return module;
ignore:
    Py_XDECREF(globals);
    PyErr_WriteUnraisable(module);
    if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, "Cython module failed to patch module with custom type", 1) < 0)) {
        Py_DECREF(module);
        module = NULL;
    }
#else
    py_code++;
#endif
    return module;
}

/* PatchGeneratorABC */
                        #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
static PyObject* __Pyx_patch_abc_module(PyObject *module);
static PyObject* __Pyx_patch_abc_module(PyObject *module) {
    module = __Pyx_Coroutine_patch_module(
        module, ""
"if _cython_generator_type is not None:\n"
"    try: Generator = _module.Generator\n"
"    except AttributeError: pass\n"
"    else: Generator.register(_cython_generator_type)\n"
"if _cython_coroutine_type is not None:\n"
"    try: Coroutine = _module.Coroutine\n"
"    except AttributeError: pass\n"
"    else: Coroutine.register(_cython_coroutine_type)\n"
    );
    return module;
}
#endif
static int __Pyx_patch_abc(void) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    static int abc_patched = 0;
    if (!abc_patched) {
        PyObject *module;
        module = PyImport_ImportModule((PY_VERSION_HEX >= 0x03030000) ? "collections.abc" : "collections");
        if (!module) {
            PyErr_WriteUnraisable(NULL);
            if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning,
                    ((PY_VERSION_HEX >= 0x03030000) ?
                        "Cython module failed to register with collections.abc module" :
                        "Cython module failed to register with collections module"), 1) < 0)) {
                return -1;
            }
        } else {
            module = __Pyx_patch_abc_module(module);
            abc_patched = 1;
            if (unlikely(!module))
                return -1;
            Py_DECREF(module);
        }
        module = PyImport_ImportModule("backports_abc");
        if (module) {
            module = __Pyx_patch_abc_module(module);
            Py_XDECREF(module);
        }
        if (!module) {
            PyErr_Clear();
        }
    }
#else
    if (0) __Pyx_Coroutine_patch_module(NULL, NULL);
#endif
    return 0;
}

/* Generator */
                        static PyMethodDef __pyx_Generator_methods[] = {
    {"send", (PyCFunction) __Pyx_Coroutine_Send, METH_O,
     (char*) PyDoc_STR("send(arg) -> send 'arg' into generator,\nreturn next yielded value or raise StopIteration.")},
    {"throw", (PyCFunction) __Pyx_Coroutine_Throw, METH_VARARGS,
     (char*) PyDoc_STR("throw(typ[,val[,tb]]) -> raise exception in generator,\nreturn next yielded value or raise StopIteration.")},
    {"close", (PyCFunction) __Pyx_Coroutine_Close, METH_NOARGS,
     (char*) PyDoc_STR("close() -> raise GeneratorExit inside generator.")},
    {0, 0, 0, 0}
};
static PyMemberDef __pyx_Generator_memberlist[] = {
    {(char *) "gi_running", T_BOOL, offsetof(__pyx_CoroutineObject, is_running), READONLY, NULL},
    {(char*) "gi_yieldfrom", T_OBJECT, offsetof(__pyx_CoroutineObject, yieldfrom), READONLY,
     (char*) PyDoc_STR("object being iterated by 'yield from', or None")},
    {0, 0, 0, 0, 0}
};
static PyGetSetDef __pyx_Generator_getsets[] = {
    {(char *) "__name__", (getter)__Pyx_Coroutine_get_name, (setter)__Pyx_Coroutine_set_name,
     (char*) PyDoc_STR("name of the generator"), 0},
    {(char *) "__qualname__", (getter)__Pyx_Coroutine_get_qualname, (setter)__Pyx_Coroutine_set_qualname,
     (char*) PyDoc_STR("qualified name of the generator"), 0},
    {0, 0, 0, 0, 0}
};
static PyTypeObject __pyx_GeneratorType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "generator",
    sizeof(__pyx_CoroutineObject),
    0,
    (destructor) __Pyx_Coroutine_dealloc,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_FINALIZE,
    0,
    (traverseproc) __Pyx_Coroutine_traverse,
    0,
    0,
    offsetof(__pyx_CoroutineObject, gi_weakreflist),
    0,
    (iternextfunc) __Pyx_Generator_Next,
    __pyx_Generator_methods,
    __pyx_Generator_memberlist,
    __pyx_Generator_getsets,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#else
    __Pyx_Coroutine_del,
#endif
    0,
#if PY_VERSION_HEX >= 0x030400a1
    __Pyx_Coroutine_del,
#endif
};
static int __pyx_Generator_init(void) {
    __pyx_GeneratorType_type.tp_getattro = PyObject_GenericGetAttr;
    __pyx_GeneratorType_type.tp_iter = PyObject_SelfIter;
    __pyx_GeneratorType = __Pyx_FetchCommonType(&__pyx_GeneratorType_type);
    if (unlikely(!__pyx_GeneratorType)) {
        return -1;
    }
    return 0;
}

/* CheckBinaryVersion */
                        static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* InitStrings */
                        static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
static CYTHON_INLINE char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if CYTHON_COMPILING_IN_CPYTHON && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
#if PY_VERSION_HEX < 0x03030000
        char* defenc_c;
        PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
        if (!defenc) return NULL;
        defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        {
            char* end = defenc_c + PyBytes_GET_SIZE(defenc);
            char* c;
            for (c = defenc_c; c < end; c++) {
                if ((unsigned char) (*c) >= 128) {
                    PyUnicode_AsASCIIString(o);
                    return NULL;
                }
            }
        }
#endif
        *length = PyBytes_GET_SIZE(defenc);
        return defenc_c;
#else
        if (__Pyx_PyUnicode_READY(o) == -1) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        if (PyUnicode_IS_ASCII(o)) {
            *length = PyUnicode_GET_LENGTH(o);
            return PyUnicode_AsUTF8(o);
        } else {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
#else
        return PyUnicode_AsUTF8AndSize(o, length);
#endif
#endif
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (PyInt_Check(x) || PyLong_Check(x))
#else
  if (PyLong_Check(x))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = PyNumber_Long(x);
  }
  #else
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Long(x);
  }
  #endif
#else
  res = PyNumber_Int(x);
#endif
  if (res) {
#if PY_MAJOR_VERSION < 3
    if (!PyInt_Check(res) && !PyLong_Check(res)) {
#else
    if (!PyLong_Check(res)) {
#endif
      PyErr_Format(PyExc_TypeError,
                   "__%.4s__ returned non-%.4s (type %.200s)",
                   name, name, Py_TYPE(res)->tp_name);
      Py_DECREF(res);
      return NULL;
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(x);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
